@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,7 @@
 package org.eclipse.jdt.astview.views;
 
 import java.util.ArrayList;
+import java.util.Objects;
 import java.util.function.Function;
 
 import org.eclipse.jdt.astview.ASTViewPlugin;
@@ -96,6 +97,7 @@ public class Binding extends ASTAttribute {
 					res.add(new BindingProperty(this, "IS FIELD", variableBinding.isField(), true)); //$NON-NLS-1$
 					res.add(new BindingProperty(this, "IS ENUM CONSTANT", variableBinding.isEnumConstant(), true)); //$NON-NLS-1$
 					res.add(new BindingProperty(this, "IS PARAMETER", variableBinding.isParameter(), true)); //$NON-NLS-1$
+					res.add(new BindingProperty(this, "IS RECORD COMPONENT", variableBinding.isRecordComponent(), true)); //$NON-NLS-1$
 					res.add(new BindingProperty(this, "VARIABLE ID", variableBinding.getVariableId(), true)); //$NON-NLS-1$
 					res.add(new BindingProperty(this, "MODIFIERS", getModifiersString(fBinding.getModifiers(), false), true)); //$NON-NLS-1$
 					res.add(new Binding(this, "TYPE", variableBinding.getType(), true)); //$NON-NLS-1$
@@ -123,7 +125,7 @@ public class Binding extends ASTAttribute {
 					boolean isRefType= isType(typeKind, REF_TYPE);
 					final boolean isNonPrimitive= ! isType(typeKind, PRIMITIVE_TYPE);
 
-					StringBuffer kinds= new StringBuffer("KIND:"); //$NON-NLS-1$
+					StringBuilder kinds= new StringBuilder("KIND:"); //$NON-NLS-1$
 					if (typeBinding.isArray()) kinds.append(" isArray"); //$NON-NLS-1$
 					if (typeBinding.isCapture()) kinds.append(" isCapture"); //$NON-NLS-1$
 					if (typeBinding.isNullType()) kinds.append(" isNullType"); //$NON-NLS-1$
@@ -137,7 +139,7 @@ public class Binding extends ASTAttribute {
 					if (typeBinding.isEnum()) kinds.append(" isEnum"); //$NON-NLS-1$
 					res.add(new BindingProperty(this, kinds, true));
 
-					StringBuffer generics= new StringBuffer("GENERICS:"); //$NON-NLS-1$
+					StringBuilder generics= new StringBuilder("GENERICS:"); //$NON-NLS-1$
 					if (typeBinding.isRawType()) generics.append(" isRawType"); //$NON-NLS-1$
 					if (typeBinding.isGenericType()) generics.append(" isGenericType"); //$NON-NLS-1$
 					if (typeBinding.isParameterizedType()) generics.append(" isParameterizedType"); //$NON-NLS-1$
@@ -163,7 +165,7 @@ public class Binding extends ASTAttribute {
 						}
 					}
 
-					StringBuffer origin= new StringBuffer("ORIGIN:"); //$NON-NLS-1$
+					StringBuilder origin= new StringBuilder("ORIGIN:"); //$NON-NLS-1$
 					if (typeBinding.isTopLevel()) origin.append(" isTopLevel"); //$NON-NLS-1$
 					if (typeBinding.isNested()) origin.append(" isNested"); //$NON-NLS-1$
 					if (typeBinding.isLocal()) origin.append(" isLocal"); //$NON-NLS-1$
@@ -216,7 +218,7 @@ public class Binding extends ASTAttribute {
 					res.add(new BindingProperty(this, "IS VARARGS", methodBinding.isVarargs(), true)); //$NON-NLS-1$
 					res.add(new BindingProperty(this, "EXCEPTION TYPES", methodBinding.getExceptionTypes(), true)); //$NON-NLS-1$
 
-					StringBuffer genericsM= new StringBuffer("GENERICS:"); //$NON-NLS-1$
+					StringBuilder genericsM= new StringBuilder("GENERICS:"); //$NON-NLS-1$
 					if (methodBinding.isRawMethod()) genericsM.append(" isRawMethod"); //$NON-NLS-1$
 					if (methodBinding.isGenericMethod()) genericsM.append(" isGenericMethod"); //$NON-NLS-1$
 					if (methodBinding.isParameterizedMethod()) genericsM.append(" isParameterizedMethod"); //$NON-NLS-1$
@@ -433,24 +435,15 @@ public class Binding extends ASTAttribute {
 		}
 
 		Binding other= (Binding) obj;
-		if (fParent == null) {
-			if (other.fParent != null)
-				return false;
-		} else if (! fParent.equals(other.fParent)) {
+		if (!Objects.equals(fParent, other.fParent)) {
 			return false;
 		}
 
-		if (fBinding == null) {
-			if (other.fBinding != null)
-				return false;
-		} else if (! fBinding.equals(other.fBinding)) {
+		if (!Objects.equals(fBinding, other.fBinding)) {
 			return false;
 		}
 
-		if (fLabel == null) {
-			if (other.fLabel != null)
-				return false;
-		} else if (! fLabel.equals(other.fLabel)) {
+		if (!Objects.equals(fLabel, other.fLabel)) {
 			return false;
 		}
 
