@@ -18,6 +18,7 @@ import java.util.jar.Attributes.Name;
 
 import org.eclipse.osgi.util.NLS;
 
+import org.eclipse.core.runtime.ILog;
 import org.eclipse.core.runtime.IPath;
 
 import org.eclipse.core.resources.IProject;
@@ -32,6 +33,7 @@ import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IField;
 import org.eclipse.jdt.core.IInitializer;
 import org.eclipse.jdt.core.IJavaElement;
+import org.eclipse.jdt.core.IJavaModelStatusConstants;
 import org.eclipse.jdt.core.ILocalVariable;
 import org.eclipse.jdt.core.IMember;
 import org.eclipse.jdt.core.IMemberValuePair;
@@ -460,7 +462,11 @@ public class JavaElementLabelComposerCore {
 			}
 
 		} catch (JavaModelException e) {
-			JavaManipulationPlugin.logException("", e); //$NON-NLS-1$ // NotExistsException will not reach this point
+			if(e.getStatus().getCode() == IJavaModelStatusConstants.ELEMENT_DOES_NOT_EXIST) {
+				// don't care, we are decorating already removed element
+				return;
+			}
+			ILog.of(this.getClass()).error("Error rendering method label", e); //$NON-NLS-1$ // NotExistsException will not reach this point
 		}
 	}
 
@@ -471,8 +477,7 @@ public class JavaElementLabelComposerCore {
 
 
 	protected void appendAnnotationLabels(IAnnotation[] annotations, long flags) throws JavaModelException {
-		for (int j= 0; j < annotations.length; j++) {
-			IAnnotation annotation= annotations[j];
+		for (IAnnotation annotation : annotations) {
 			appendAnnotationLabel(annotation, flags);
 			fBuffer.append(' ');
 		}
@@ -537,7 +542,7 @@ public class JavaElementLabelComposerCore {
 					fBuffer.append(ASTNodes.getEscapedStringLiteral((String) value));
 					break;
 				case IMemberValuePair.K_CHAR:
-					fBuffer.append(ASTNodes.getEscapedCharacterLiteral(((Character) value).charValue()));
+					fBuffer.append(ASTNodes.getEscapedCharacterLiteral(((Character) value)));
 					break;
 				default:
 					fBuffer.append(String.valueOf(value));
@@ -676,7 +681,7 @@ public class JavaElementLabelComposerCore {
 			}
 
 		} catch (JavaModelException e) {
-			JavaManipulationPlugin.logException("", e); //$NON-NLS-1$ // NotExistsException will not reach this point
+			ILog.of(this.getClass()).error("Error rendering type parameters", e); //$NON-NLS-1$ // NotExistsException will not reach this point
 		}
 	}
 
@@ -686,7 +691,7 @@ public class JavaElementLabelComposerCore {
 		if (typeParameter.exists()) {
 			String[] bounds= typeParameter.getBoundsSignatures();
 			if (bounds.length > 0 &&
-					! (bounds.length == 1 && "Ljava.lang.Object;".equals(bounds[0]))) { //$NON-NLS-1$
+					(bounds.length != 1 || !"Ljava.lang.Object;".equals(bounds[0]))) { //$NON-NLS-1$
 				fBuffer.append(" extends "); //$NON-NLS-1$
 				for (int j= 0; j < bounds.length; j++) {
 					if (j > 0) {
@@ -1204,12 +1209,12 @@ public class JavaElementLabelComposerCore {
 	protected void appendModuleLabel(IModuleDescription module, long flags) {
 		fBuffer.append(module.getElementName());
 		// category
-		if (getFlag(flags, JavaElementLabelsCore.MOD_CATEGORY) && module.exists()) {
+		if (getFlag(flags, JavaElementLabelsCore.MOD_CATEGORY2) && module.exists()) {
 			try {
 				appendCategoryLabel(module, flags);
 			} catch (JavaModelException e) {
 				// ignore
-			}	
+			}
 		}
 	}
 
