@@ -11,6 +11,8 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     John Kaplan, johnkaplantech@gmail.com - 108071 [code templates] template for body of newly created class
+ *     Taiming Wang <3120205503@bit.edu.cn> - [extract local] Automated Name Recommendation For The Extract Local Variable Refactoring. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/601
+ *     Taiming Wang <3120205503@bit.edu.cn> - [extract local] Context-based Automated Name Recommendation For The Extract Local Variable Refactoring. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/655
  *******************************************************************************/
 package org.eclipse.jdt.internal.core.manipulation;
 
@@ -88,6 +90,7 @@ import org.eclipse.jdt.core.dom.MethodInvocation;
 import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.NumberLiteral;
 import org.eclipse.jdt.core.dom.ParameterizedType;
+import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
 import org.eclipse.jdt.core.dom.StringLiteral;
 import org.eclipse.jdt.core.dom.StructuralPropertyDescriptor;
@@ -106,6 +109,7 @@ import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
+import org.eclipse.jdt.internal.corext.fix.ConvertLoopOperation;
 
 import org.eclipse.jdt.internal.ui.util.ASTHelper;
 
@@ -140,7 +144,13 @@ public class StubUtility {
 	 * Don't use this method directly, use CodeGeneration.
 	 */
 	public static String getMethodBodyContent(boolean isConstructor, IJavaProject project, String destTypeName, String methodName, String bodyStatement, String lineDelimiter) throws CoreException {
-		String templateName= isConstructor ? CodeTemplateContextType.CONSTRUCTORSTUB_ID : CodeTemplateContextType.METHODSTUB_ID;
+		return getMethodBodyContent(false, isConstructor, project, destTypeName, methodName, bodyStatement, lineDelimiter);
+	}
+
+	public static String getMethodBodyContent(boolean useAlternativeMethodBody, boolean isConstructor, IJavaProject project, String destTypeName, String methodName, String bodyStatement, String lineDelimiter) throws CoreException {
+		String templateName= isConstructor ? CodeTemplateContextType.CONSTRUCTORSTUB_ID
+							: useAlternativeMethodBody ? CodeTemplateContextType.METHODSTUB_ALTERNATIVE_ID
+							: CodeTemplateContextType.METHODSTUB_ID;
 		Template template= getCodeTemplate(templateName, project);
 		if (template == null) {
 			return bodyStatement;
@@ -1042,6 +1052,85 @@ public class StubUtility {
 		return res.toArray(new String[res.size()]);
 	}
 
+	public static String[] getVariableNameSuggestions(int variableKind, IJavaProject project, ITypeBinding expectedType, Expression assignedExpression, Collection<String> excluded,
+			String usedNameForIdenticalExpressionInCu, Collection<String> usedNamesForIdenticalExpressionInMethod) {
+		LinkedHashSet<String> res= new LinkedHashSet<>(); // avoid duplicates but keep order
+
+		String typeName= null;
+		int dim= 0;
+		if (expectedType != null) {
+			expectedType= Bindings.normalizeTypeBinding(expectedType);
+			if (expectedType != null) {
+				if (expectedType.isArray()) {
+					dim= expectedType.getDimensions();
+					expectedType= expectedType.getElementType();
+				}
+				if (expectedType.isParameterizedType()) {
+					expectedType= expectedType.getTypeDeclaration();
+				}
+				typeName= expectedType.getName();
+			}
+		}
+
+		boolean isTypeAvailable= typeName != null && typeName.length() > 0;
+		if (assignedExpression != null) {
+			if (isTypeAvailable) {
+				if (assignedExpression instanceof MethodInvocation) {
+					// if we have a method invocation, see if we can recycle some previously used variable name that is assigned with the same expression.
+					String recycledName= recycleNames(typeName, assignedExpression, excluded, usedNameForIdenticalExpressionInCu, usedNamesForIdenticalExpressionInMethod);
+					if (recycledName != null) {
+						add(getVariableNameSuggestions(variableKind, project, recycledName, 0, excluded, false), res); // pass 0 as dimension, base name already contains plural.
+					}
+				}
+			}
+
+			String nameFromExpression= getBaseNameFromExpression(project, assignedExpression, variableKind);
+			if (nameFromExpression != null) {
+				add(getVariableNameSuggestions(variableKind, project, nameFromExpression, 0, excluded, false), res); // pass 0 as dimension, base name already contains plural.
+			}
+
+			String nameFromParent= getBaseNameFromLocationInParent(assignedExpression);
+			if (nameFromParent != null) {
+				add(getVariableNameSuggestions(variableKind, project, nameFromParent, 0, excluded, false), res); // pass 0 as dimension, base name already contains plural.
+			}
+		}
+
+		if (isTypeAvailable) {
+			add(getVariableNameSuggestions(variableKind, project, typeName, dim, excluded, false), res);
+		}
+
+
+		if (res.isEmpty()) {
+			return getDefaultVariableNameSuggestions(variableKind, excluded);
+		}
+		return res.toArray(new String[res.size()]);
+	}
+
+	private static String recycleNames(String typeName, Expression assignedExpression, Collection<String> excluded,
+			String usedNameForIdenticalExpressionInCu, Collection<String> usedNamesForIdenticalExpressionInMethod) {
+
+		MethodInvocation methodInvocation= (MethodInvocation)assignedExpression;
+		String name= methodInvocation.getName().getIdentifier();
+		if (!name.toLowerCase().contains(typeName.toLowerCase())) {
+			List<Expression> arguments= methodInvocation.arguments();
+			List<Integer> argumentTypes= new ArrayList<>();
+			for (Expression argument : arguments)
+				argumentTypes.add(Integer.valueOf(argument.getNodeType()));
+			if (arguments.size() > 1 || argumentTypes.contains(Integer.valueOf(ASTNode.METHOD_INVOCATION))) {
+				if (usedNameForIdenticalExpressionInCu != null) {
+					if (excluded.contains(usedNameForIdenticalExpressionInCu) || usedNamesForIdenticalExpressionInMethod.contains(usedNameForIdenticalExpressionInCu))
+						return null;
+					else
+						return usedNameForIdenticalExpressionInCu;
+				}
+			}
+		}
+
+		return null;
+	}
+
+
+
 	public static String[] getVariableNameSuggestions(int variableKind, IJavaProject project, Type expectedType, Expression assignedExpression, Collection<String> excluded) {
 		LinkedHashSet<String> res= new LinkedHashSet<>(); // avoid duplicates but keep order
 
@@ -1150,7 +1239,15 @@ public class StubUtility {
 
 			return ASTNodes.getSimpleNameIdentifier(simpleNode);
 		} else if (assignedExpression instanceof MethodInvocation) {
-			name= ((MethodInvocation)assignedExpression).getName().getIdentifier();
+			MethodInvocation methodInvocation= (MethodInvocation)assignedExpression;
+			name= methodInvocation.getName().getIdentifier();
+			if (name.equals("next")) { //$NON-NLS-1$
+				Expression receiver= methodInvocation.getExpression();
+				String modifiedName= getBaseNameFromReceiver(receiver);
+				if (!modifiedName.equals("element")) //$NON-NLS-1$
+					return modifiedName;
+			}
+
 		} else if (assignedExpression instanceof SuperMethodInvocation) {
 			name= ((SuperMethodInvocation)assignedExpression).getName().getIdentifier();
 		} else if (assignedExpression instanceof FieldAccess) {
@@ -1188,6 +1285,16 @@ public class StubUtility {
 		return name;
 	}
 
+	private static String getBaseNameFromReceiver(Expression receiver) {
+		if (receiver != null) {
+			if (receiver instanceof SimpleName) {
+				String receiverStr= receiver.toString();
+				return ConvertLoopOperation.modifyBaseName(receiverStr);
+			}
+		}
+		return "element"; //$NON-NLS-1$
+	}
+
 	private static String getBaseNameFromLocationInParent(Expression assignedExpression, List<Expression> arguments, IMethodBinding binding) {
 		if (binding == null)
 			return null;
@@ -1571,3 +1678,5 @@ public class StubUtility {
 	}
 
 }
+
+
