@@ -23,7 +23,7 @@ import org.eclipse.jdt.internal.ui.PreferenceConstantsCore;
 
 public class ProfileVersionerCore {
 
-	private static final int CURRENT_VERSION= 22;
+	private static final int CURRENT_VERSION= 23;
 
 	public static int getFirstVersion() {
 		return 1;
@@ -97,6 +97,9 @@ public class ProfileVersionerCore {
 		case 21:
 			version21to22(oldSettings);
 			//$FALL-THROUGH$
+		case 22:
+			version22to23(oldSettings);
+			//$FALL-THROUGH$
 		default:
 			for (Map.Entry<String, String> entry : oldSettings.entrySet()) {
 				final String key= entry.getKey();
@@ -746,6 +749,11 @@ public class ProfileVersionerCore {
 					DefaultCodeFormatterConstants.createAlignmentValue(false, DefaultCodeFormatterConstants.WRAP_NO_SPLIT, DefaultCodeFormatterConstants.INDENT_DEFAULT));
 		}
 
+		private static void version22to23(Map<String, String> oldSettings) {
+			checkAndReplace(oldSettings, DefaultCodeFormatterConstants.FORMATTER_ALIGNMENT_FOR_SUPERINTERFACES_IN_TYPE_DECLARATION,
+					DefaultCodeFormatterConstants.FORMATTER_ALIGNMENT_FOR_PERMITTED_TYPES_IN_TYPE_DECLARATION);
+		}
+
 		/* old format constant values */
 
 	    private static final String FORMATTER_METHOD_DECLARATION_ARGUMENTS_ALIGNMENT = JavaCore.PLUGIN_ID + ".formatter.method_declaration_arguments_alignment"; //$NON-NLS-1$
