@@ -123,7 +123,7 @@ public final class AddDelegateMethodsOperation implements IWorkspaceRunnable {
 	 *
 	 * @return the method binding keys
 	 */
-	public final String[] getCreatedMethods() {
+	public String[] getCreatedMethods() {
 		final String[] keys= new String[fCreated.size()];
 		fCreated.toArray(keys);
 		return keys;
@@ -134,7 +134,7 @@ public final class AddDelegateMethodsOperation implements IWorkspaceRunnable {
 	 *
 	 * @return the resulting text edit
 	 */
-	public final TextEdit getResultingEdit() {
+	public TextEdit getResultingEdit() {
 		return fResultingEdit;
 	}
 
@@ -143,7 +143,7 @@ public final class AddDelegateMethodsOperation implements IWorkspaceRunnable {
 	 *
 	 * @return the scheduling rule
 	 */
-	public final ISchedulingRule getSchedulingRule() {
+	public ISchedulingRule getSchedulingRule() {
 		return ResourcesPlugin.getWorkspace().getRoot();
 	}
 
@@ -151,7 +151,7 @@ public final class AddDelegateMethodsOperation implements IWorkspaceRunnable {
 	 * @see org.eclipse.core.resources.IWorkspaceRunnable#run(org.eclipse.core.runtime.IProgressMonitor)
 	 */
 	@Override
-	public final void run(IProgressMonitor monitor) throws CoreException {
+	public void run(IProgressMonitor monitor) throws CoreException {
 		if (monitor == null)
 			monitor= new NullProgressMonitor();
 		try {
