@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -20,33 +20,14 @@ import org.eclipse.core.runtime.Assert;
 
 import org.eclipse.jdt.core.dom.*;
 
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
+
 public class ASTFlattener extends GenericVisitor {
 /*
  * XXX: Keep in sync with org.eclipse.jdt.internal.core.dom.NaiveASTFlattener:
  * Rename NaiveASTFlattener#buffer to fBuffer, compare with this class, focus on structural changes
  */
 
-	/**
-	 * @deprecated to avoid deprecation warnings
-	 */
-	@Deprecated
-	private static final int JLS3= AST.JLS3;
-	/**
-	 * @deprecated to avoid deprecation warnings
-	 */
-	@Deprecated
-	private static final int JLS4= AST.JLS4;
-	/**
-	 * @deprecated to avoid deprecation warnings
-	 */
-	@Deprecated
-	private static final int JLS8= AST.JLS8;
-	/**
-	 * @deprecated to avoid deprecation warnings
-	 */
-	@Deprecated
-	private static final int JLS9= AST.JLS9;
-
 	/**
 	 * The string buffer into which the serialized representation of the AST is
 	 * written.
@@ -99,8 +80,8 @@ public class ASTFlattener extends GenericVisitor {
 	 * (element type: <code>IExtendedModifier</code>)
 	 */
 	private void printModifiers(List<IExtendedModifier> ext) {
-		for (Iterator<IExtendedModifier> it= ext.iterator(); it.hasNext();) {
-			ASTNode p= (ASTNode) it.next();
+		for (IExtendedModifier iExtendedModifier : ext) {
+			ASTNode p= (ASTNode) iExtendedModifier;
 			p.accept(this);
 			this.fBuffer.append(" ");//$NON-NLS-1$
 		}
@@ -135,7 +116,7 @@ public class ASTFlattener extends GenericVisitor {
 	}
 
 	void printTypeAnnotations(AnnotatableType node) {
-		if (node.getAST().apiLevel() >= JLS8) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS8) {
 			printAnnotationsList(node.annotations());
 		}
 	}
@@ -217,8 +198,7 @@ public class ASTFlattener extends GenericVisitor {
 	public boolean visit(AnonymousClassDeclaration node) {
 		this.fBuffer.append("{");//$NON-NLS-1$
 		List<BodyDeclaration> bodyDeclarations= node.bodyDeclarations();
-		for (Iterator<BodyDeclaration> it= bodyDeclarations.iterator(); it.hasNext();) {
-			BodyDeclaration b= it.next();
+		for (BodyDeclaration b : bodyDeclarations) {
 			b.accept(this);
 		}
 		this.fBuffer.append("}");//$NON-NLS-1$
@@ -286,14 +266,13 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(ArrayType node) {
-		if (node.getAST().apiLevel() < JLS8) {
+		if (node.getAST().apiLevel() < ASTHelper.JLS8) {
 			getComponentType(node).accept(this);
 			this.fBuffer.append("[]");//$NON-NLS-1$
 		} else {
 			node.getElementType().accept(this);
 			List<Dimension> dimensions = node.dimensions();
-			for (int i = 0; i < dimensions.size() ; i++) {
-				Dimension dimension = dimensions.get(i);
+			for (Dimension dimension : dimensions) {
 				dimension.accept(this);
 			}
 		}
@@ -377,6 +356,14 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(CaseDefaultExpression node) {
+		if (ASTHelper.isPatternSupported(node.getAST())) {
+			this.fBuffer.append("default");//$NON-NLS-1$
+		}
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(CastExpression)
 	 */
@@ -420,7 +407,7 @@ public class ASTFlattener extends GenericVisitor {
 			this.fBuffer.append(".");//$NON-NLS-1$
 		}
 		this.fBuffer.append("new ");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (!node.typeArguments().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
 				for (Iterator<Type> it= node.typeArguments().iterator(); it.hasNext();) {
@@ -454,7 +441,7 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(CompilationUnit node) {
-		if (node.getAST().apiLevel() >= JLS9) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS9) {
 			if (node.getModule() != null) {
 				node.getModule().accept(this);
 			}
@@ -491,7 +478,7 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(ConstructorInvocation node) {
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (!node.typeArguments().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
 				for (Iterator<Type> it= node.typeArguments().iterator(); it.hasNext();) {
@@ -708,7 +695,7 @@ public class ASTFlattener extends GenericVisitor {
 		if (node.getJavadoc() != null) {
 			node.getJavadoc().accept(this);
 		}
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 		}
 		node.getType().accept(this);
@@ -748,6 +735,16 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(GuardedPattern node) {
+		if (ASTHelper.isPatternSupported(node.getAST())) {
+			node.getPattern().accept(this);
+			this.fBuffer.append(" when ");//$NON-NLS-1$
+			node.getExpression().accept(this);
+		}
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(IfStatement)
 	 */
@@ -770,7 +767,7 @@ public class ASTFlattener extends GenericVisitor {
 	@Override
 	public boolean visit(ImportDeclaration node) {
 		this.fBuffer.append("import ");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (node.isStatic()) {
 				this.fBuffer.append("static ");//$NON-NLS-1$
 			}
@@ -796,9 +793,8 @@ public class ASTFlattener extends GenericVisitor {
 		final List<Expression>extendedOperands = node.extendedOperands();
 		if (!extendedOperands.isEmpty()) {
 			this.fBuffer.append(' ');
-			for (Iterator<Expression> it = extendedOperands.iterator(); it.hasNext(); ) {
+			for (Expression e : extendedOperands) {
 				this.fBuffer.append(node.getOperator().toString()).append(' ');
-				Expression e = it.next();
 				e.accept(this);
 			}
 		}
@@ -813,7 +809,7 @@ public class ASTFlattener extends GenericVisitor {
 		if (node.getJavadoc() != null) {
 			node.getJavadoc().accept(this);
 		}
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 		}
 		node.getBody().accept(this);
@@ -831,6 +827,14 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(PatternInstanceofExpression node) {
+		node.getLeftOperand().accept(this);
+		this.fBuffer.append(" instanceof ");//$NON-NLS-1$
+		node.getRightOperand().accept(this);
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(IntersectionType)
 	 */
@@ -860,6 +864,17 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(JavaDocRegion node) {
+		return false;
+	}
+
+	@Override
+	public boolean visit(JavaDocTextElement node) {
+		this.fBuffer.append(node.getText());
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(LabeledStatement)
 	 */
@@ -970,7 +985,7 @@ public class ASTFlattener extends GenericVisitor {
 	@Override
 	public boolean visit(MethodRefParameter node) {
 		node.getType().accept(this);
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (node.isVarargs()) {
 				this.fBuffer.append("...");//$NON-NLS-1$
 			}
@@ -990,7 +1005,7 @@ public class ASTFlattener extends GenericVisitor {
 		if (node.getJavadoc() != null) {
 			node.getJavadoc().accept(this);
 		}
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 			if (!node.typeParameters().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
@@ -1015,7 +1030,7 @@ public class ASTFlattener extends GenericVisitor {
 		}
 		node.getName().accept(this);
 		this.fBuffer.append("(");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS8) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS8) {
 			Type receiverType= node.getReceiverType();
 			if (receiverType != null) {
 				receiverType.accept(this);
@@ -1039,10 +1054,9 @@ public class ASTFlattener extends GenericVisitor {
 			}
 		}
 		this.fBuffer.append(")");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS8) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS8) {
 			List<Dimension> dimensions = node.extraDimensions();
-			for (Iterator<Dimension> it= dimensions.iterator(); it.hasNext(); ) {
-				Dimension e= it.next();
+			for (Dimension e : dimensions) {
 				e.accept(this);
 			}
 		} else {
@@ -1050,7 +1064,7 @@ public class ASTFlattener extends GenericVisitor {
 				this.fBuffer.append("[]"); //$NON-NLS-1$
 			}
 		}
-		List<? extends ASTNode> thrownExceptions= node.getAST().apiLevel() >= JLS8 ? node.thrownExceptionTypes() : getThrownExceptions(node);
+		List<? extends ASTNode> thrownExceptions= node.getAST().apiLevel() >= ASTHelper.JLS8 ? node.thrownExceptionTypes() : getThrownExceptions(node);
 		if (!thrownExceptions.isEmpty()) {
 			this.fBuffer.append(" throws ");//$NON-NLS-1$
 			for (Iterator<? extends ASTNode> it= thrownExceptions.iterator(); it.hasNext();) {
@@ -1079,7 +1093,7 @@ public class ASTFlattener extends GenericVisitor {
 			node.getExpression().accept(this);
 			this.fBuffer.append(".");//$NON-NLS-1$
 		}
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (!node.typeArguments().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
 				for (Iterator<Type> it= node.typeArguments().iterator(); it.hasNext();) {
@@ -1194,6 +1208,14 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(NullPattern node) {
+		if (ASTHelper.isPatternSupported(node.getAST())) {
+			this.fBuffer.append("null");//$NON-NLS-1$
+		}
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(NumberLiteral)
 	 */
@@ -1213,7 +1235,7 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(PackageDeclaration node) {
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (node.getJavadoc() != null) {
 				node.getJavadoc().accept(this);
 			}
@@ -1299,6 +1321,17 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(ModuleQualifiedName node) {
+		node.getModuleQualifier().accept(this);
+		this.fBuffer.append("/");//$NON-NLS-1$
+		ASTNode cNode = node.getName();
+		if (cNode != null) {
+			cNode.accept(this);
+		}
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(QualifiedName)
 	 */
@@ -1323,6 +1356,107 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(RecordDeclaration node) {
+		if (node.getJavadoc() != null) {
+			node.getJavadoc().accept(this);
+		}
+		printModifiers(node.modifiers());
+		this.fBuffer.append("record ");//$NON-NLS-1$
+		node.getName().accept(this);
+		this.fBuffer.append(" ");//$NON-NLS-1$
+
+		if (!node.typeParameters().isEmpty()) {
+			this.fBuffer.append("<");//$NON-NLS-1$
+			for (Iterator<TypeParameter> it = node.typeParameters().iterator(); it.hasNext(); ) {
+				TypeParameter t = it.next();
+				t.accept(this);
+				if (it.hasNext()) {
+					this.fBuffer.append(",");//$NON-NLS-1$
+				}
+			}
+			this.fBuffer.append(">");//$NON-NLS-1$
+		}
+		this.fBuffer.append(" ");//$NON-NLS-1$
+		this.fBuffer.append("(");//$NON-NLS-1$
+		for (Iterator<SingleVariableDeclaration> it = node.recordComponents().iterator(); it.hasNext(); ) {
+			SingleVariableDeclaration v = it.next();
+			v.accept(this);
+			if (it.hasNext()) {
+				this.fBuffer.append(",");//$NON-NLS-1$
+			}
+		}
+		this.fBuffer.append(")");//$NON-NLS-1$
+		if (!node.superInterfaceTypes().isEmpty()) {
+			this.fBuffer.append(" implements ");//$NON-NLS-1$
+			for (Iterator<Type> it = node.superInterfaceTypes().iterator(); it.hasNext(); ) {
+				Type t = it.next();
+				t.accept(this);
+				if (it.hasNext()) {
+					this.fBuffer.append(", ");//$NON-NLS-1$
+				}
+			}
+			this.fBuffer.append(" ");//$NON-NLS-1$
+		}
+		this.fBuffer.append("{");//$NON-NLS-1$
+		if (!node.bodyDeclarations().isEmpty()) {
+			this.fBuffer.append("\n");//$NON-NLS-1$
+			for (Iterator<BodyDeclaration> it = node.bodyDeclarations().iterator(); it.hasNext(); ) {
+				BodyDeclaration d = it.next();
+				d.accept(this);
+				// other body declarations include trailing punctuation
+			}
+		}
+		this.fBuffer.append("}\n");//$NON-NLS-1$
+		return false;
+	}
+
+	@Override
+	public boolean visit(RecordPattern node) {
+		if (ASTHelper.isRecordPatternSupported(node.getAST())) {
+
+			if (node.getPatternType() != null) {
+				node.getPatternType().accept(this);
+			}
+			boolean addBraces = node.patterns().size() >= 1;
+			if (addBraces) {
+				this.fBuffer.append("(");//$NON-NLS-1$
+			}
+			int size = 1;
+			for (Pattern pattern : node.patterns()) {
+					visitPattern(pattern);
+					if (addBraces && size < node.patterns().size()) {
+						this.fBuffer.append(", ");//$NON-NLS-1$
+					}
+					size++;
+			}
+			if (addBraces) {
+				this.fBuffer.append(")");//$NON-NLS-1$
+			}
+			if (node.getPatternName() != null) {
+				this.fBuffer.append(" ");//$NON-NLS-1$
+				node.getPatternName().accept(this);
+			}
+		}
+		return false;
+	}
+
+	private boolean visitPattern(Pattern node) {
+		if (!ASTHelper.isPatternSupported(node.getAST())) {
+			return false;
+		}
+		if (node instanceof RecordPattern) {
+			return visit((RecordPattern) node);
+		}
+		if (node instanceof GuardedPattern) {
+			return visit((GuardedPattern) node);
+		}
+		if (node instanceof TypePattern) {
+			return visit((TypePattern) node);
+		}
+		return false;
+	}
+
 	@Override
 	public boolean visit(RequiresDirective node) {
 		this.fBuffer.append("requires");//$NON-NLS-1$
@@ -1385,13 +1519,13 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(SingleVariableDeclaration node) {
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 		}
 		node.getType().accept(this);
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (node.isVarargs()) {
-				if (node.getAST().apiLevel() >= JLS8) {
+				if (node.getAST().apiLevel() >= ASTHelper.JLS8) {
 					this.fBuffer.append(' ');
 					List<Annotation> annotations= node.varargsAnnotations();
 					printAnnotationsList(annotations);
@@ -1401,10 +1535,9 @@ public class ASTFlattener extends GenericVisitor {
 		}
 		this.fBuffer.append(" ");//$NON-NLS-1$
 		node.getName().accept(this);
-		if (node.getAST().apiLevel() >= JLS8) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS8) {
 			List<Dimension> dimensions = node.extraDimensions();
-			for (Iterator<Dimension> it= dimensions.iterator(); it.hasNext(); ) {
-				Dimension e= it.next();
+			for (Dimension e : dimensions) {
 				e.accept(this);
 			}
 		} else {
@@ -1428,15 +1561,6 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
-	/*
-	 * @see ASTVisitor#visit(StringLiteral)
-	 */
-	@Override
-	public boolean visit(TextBlock node) {
-		this.fBuffer.append(node.getEscapedValue());
-		return false;
-	}
-
 	/*
 	 * @see ASTVisitor#visit(SuperConstructorInvocation)
 	 */
@@ -1446,7 +1570,7 @@ public class ASTFlattener extends GenericVisitor {
 			node.getExpression().accept(this);
 			this.fBuffer.append(".");//$NON-NLS-1$
 		}
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (!node.typeArguments().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
 				for (Iterator<Type> it= node.typeArguments().iterator(); it.hasNext();) {
@@ -1495,7 +1619,7 @@ public class ASTFlattener extends GenericVisitor {
 			this.fBuffer.append(".");//$NON-NLS-1$
 		}
 		this.fBuffer.append("super.");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (!node.typeArguments().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
 				for (Iterator<Type> it= node.typeArguments().iterator(); it.hasNext();) {
@@ -1538,8 +1662,8 @@ public class ASTFlattener extends GenericVisitor {
 
 	@Override
 	public boolean visit(SwitchCase node) {
-		if (node.getAST().isPreviewEnabled()) {
-			if (node.isDefault()) {
+		if (ASTHelper.isSwitchCaseExpressionsSupportedInAST(node.getAST())) {
+			if (node.isDefault() && !isCaseDefaultExpression(node)) {
 				this.fBuffer.append("default");//$NON-NLS-1$
 				this.fBuffer.append(node.isSwitchLabeledRule() ? " ->" : ":");//$NON-NLS-1$ //$NON-NLS-2$
 			} else {
@@ -1552,7 +1676,7 @@ public class ASTFlattener extends GenericVisitor {
 				}
 			}
 		} else {
-			if (node.isDefault()) {
+			if (node.isDefault() && !isCaseDefaultExpression(node)) {
 				this.fBuffer.append("default :\n");//$NON-NLS-1$
 			} else {
 				this.fBuffer.append("case ");//$NON-NLS-1$
@@ -1563,9 +1687,16 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	private boolean isCaseDefaultExpression(SwitchCase node) {
+		if (node.expressions() != null && node.expressions().size() == 1 && node.expressions().get(0) instanceof CaseDefaultExpression) {
+			return true;
+		}
+		return false;
+	}
+
 	@Override
 	public boolean visit(YieldStatement node) {
-		if (node.getAST().isPreviewEnabled() && node.isImplicit() && node.getExpression() == null) {
+		if (ASTHelper.isYieldNodeSupportedInAST(node.getAST()) && node.isImplicit() && node.getExpression() == null) {
 			return false;
 		}
 		this.fBuffer.append("yield"); //$NON-NLS-1$
@@ -1659,12 +1790,38 @@ public class ASTFlattener extends GenericVisitor {
 			e.accept(this);
 			previousRequiresWhiteSpace= !currentIncludesWhiteSpace && !(e instanceof TagElement);
 		}
+		if (ASTHelper.isJavaDocCodeSnippetSupported(node.getAST())) {
+			for (Iterator<TagProperty> it = node.tagProperties().iterator(); it.hasNext(); ) {
+				TagProperty tagProperty = it.next();
+				tagProperty.accept(this);
+			}
+
+		}
 		if (node.isNested()) {
 			this.fBuffer.append("}");//$NON-NLS-1$
 		}
 		return false;
 	}
 
+	@Override
+	public boolean visit(TagProperty node) {
+		this.fBuffer.append("\n{"); //$NON-NLS-1$
+		this.fBuffer.append(node.getName());
+		this.fBuffer.append(" = "); //$NON-NLS-1$
+		this.fBuffer.append(node.getStringValue());
+		node.getNodeValue().accept(this);
+		this.fBuffer.append("}"); //$NON-NLS-1$
+		return false;
+	}
+
+
+
+	@Override
+	public boolean visit(TextBlock node) {
+		this.fBuffer.append(node.getEscapedValue());
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(TextElement)
 	 * @since 3.0
@@ -1705,7 +1862,7 @@ public class ASTFlattener extends GenericVisitor {
 	@Override
 	public boolean visit(TryStatement node) {
 		this.fBuffer.append("try ");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS4) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS4) {
 			if (!node.resources().isEmpty()) {
 				this.fBuffer.append("(");//$NON-NLS-1$
 				for (Iterator<Expression> it= node.resources().iterator(); it.hasNext();) {
@@ -1739,12 +1896,12 @@ public class ASTFlattener extends GenericVisitor {
 		if (node.getJavadoc() != null) {
 			node.getJavadoc().accept(this);
 		}
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 		}
 		this.fBuffer.append(node.isInterface() ? "interface " : "class ");//$NON-NLS-2$//$NON-NLS-1$
 		node.getName().accept(this);
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (!node.typeParameters().isEmpty()) {
 				this.fBuffer.append("<");//$NON-NLS-1$
 				for (Iterator<TypeParameter> it= node.typeParameters().iterator(); it.hasNext();) {
@@ -1758,7 +1915,7 @@ public class ASTFlattener extends GenericVisitor {
 			}
 		}
 		this.fBuffer.append(" ");//$NON-NLS-1$
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			if (node.getSuperclassType() != null) {
 				this.fBuffer.append("extends ");//$NON-NLS-1$
 				node.getSuperclassType().accept(this);
@@ -1776,6 +1933,17 @@ public class ASTFlattener extends GenericVisitor {
 				this.fBuffer.append(" ");//$NON-NLS-1$
 			}
 		}
+		if (ASTHelper.isSealedTypeSupportedInAST(node.getAST()) && !node.permittedTypes().isEmpty()) {
+			this.fBuffer.append("permits ");//$NON-NLS-1$
+			for (Iterator<Type> it = node.permittedTypes().iterator(); it.hasNext(); ) {
+				Type t = it.next();
+				t.accept(this);
+				if (it.hasNext()) {
+					this.fBuffer.append(", ");//$NON-NLS-1$
+				}
+			}
+			this.fBuffer.append(" ");//$NON-NLS-1$
+		}
 		this.fBuffer.append("{");//$NON-NLS-1$
 		BodyDeclaration prev= null;
 		for (Iterator<BodyDeclaration> it= node.bodyDeclarations().iterator(); it.hasNext();) {
@@ -1803,7 +1971,7 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(TypeDeclarationStatement node) {
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			node.getDeclaration().accept(this);
 		}
 		return false;
@@ -1851,6 +2019,14 @@ public class ASTFlattener extends GenericVisitor {
 		return false;
 	}
 
+	@Override
+	public boolean visit(TypePattern node) {
+		if (ASTHelper.isPatternSupported(node.getAST())) {
+			node.getPatternVariable().accept(this);
+		}
+		return false;
+	}
+
 	/*
 	 * @see ASTVisitor#visit(UnionType)
 	 */
@@ -1880,7 +2056,7 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(VariableDeclarationExpression node) {
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 		}
 		node.getType().accept(this);
@@ -1901,10 +2077,9 @@ public class ASTFlattener extends GenericVisitor {
 	@Override
 	public boolean visit(VariableDeclarationFragment node) {
 		node.getName().accept(this);
-		if (node.getAST().apiLevel() >= JLS8) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS8) {
 			List<Dimension> dimensions = node.extraDimensions();
-			for (Iterator<Dimension> it= dimensions.iterator(); it.hasNext(); ) {
-				Dimension e= it.next();
+			for (Dimension e : dimensions) {
 				e.accept(this);
 			}
 		} else {
@@ -1924,7 +2099,7 @@ public class ASTFlattener extends GenericVisitor {
 	 */
 	@Override
 	public boolean visit(VariableDeclarationStatement node) {
-		if (node.getAST().apiLevel() >= JLS3) {
+		if (node.getAST().apiLevel() >= ASTHelper.JLS3) {
 			printModifiers(node.modifiers());
 		}
 		node.getType().accept(this);
