@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -1035,6 +1035,16 @@ public abstract class HierarchicalASTVisitor extends ASTVisitor {
 		endVisit((Statement)node);
 	}
 
+	@Override
+	public boolean visit(EnhancedForWithRecordPattern node) {
+		return visit((Statement)node);
+	}
+
+	@Override
+	public void endVisit(EnhancedForWithRecordPattern node) {
+		endVisit((Statement)node);
+	}
+
 	@Override
 	public boolean visit(ExpressionStatement node) {
 		return visit((Statement)node);
