@@ -20,7 +20,6 @@ import java.util.Arrays;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.Hashtable;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Random;
 
@@ -82,8 +81,8 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 	private static final String NAME_FIELD= "serialVersionUID"; //$NON-NLS-1$
 
 	public interface ISerialVersionFixContext {
-		public RefactoringStatus initialize(IProgressMonitor monitor) throws CoreException;
-		public Long getSerialVersionId(ITypeBinding binding);
+		RefactoringStatus initialize(IProgressMonitor monitor) throws CoreException;
+		Long getSerialVersionId(ITypeBinding binding);
 	}
 
 	public static class SerialVersionHashContext implements ISerialVersionFixContext {
@@ -130,9 +129,7 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 							} else {
 							   	result.addWarning(Messages.format(FixMessages.PotentialProgrammingProblemsFix_calculatingUIDFailed_unknown, BasicElementLabels.getJavaElementName(typeBinding.getName())));
 							}
-						} catch (IOException e) {
-						   	result.addWarning(Messages.format(FixMessages.PotentialProgrammingProblemsFix_calculatingUIDFailed_exception, new String[] { BasicElementLabels.getJavaElementName(typeBinding.getName()), e.getLocalizedMessage()}), JavaStatusContext.create(types[i]));
-				        } catch (CoreException e) {
+						} catch (IOException | CoreException e) {
 						   	result.addWarning(Messages.format(FixMessages.PotentialProgrammingProblemsFix_calculatingUIDFailed_exception, new String[] { BasicElementLabels.getJavaElementName(typeBinding.getName()), e.getLocalizedMessage()}), JavaStatusContext.create(types[i]));
 				        }
 					}
@@ -164,17 +161,15 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 					//500 is a guess. Building the type hierarchy on serializable is very expensive
 					//depending on how many subtypes exit in the project.
 
-					HashSet<ICompilationUnit> cus= new HashSet<>();
-					cus.addAll(Arrays.asList(compilationUnits));
-
+					HashSet<ICompilationUnit> cus= new HashSet<>(Arrays.asList(compilationUnits));
 					monitor.subTask(Messages.format(FixMessages.Java50Fix_SerialVersion_CalculateHierarchy_description, SERIALIZABLE_NAME));
 					ITypeHierarchy hierarchy1= serializable.newTypeHierarchy(project, new SubProgressMonitor(monitor, compilationUnits.length));
 					IType[] allSubtypes1= hierarchy1.getAllSubtypes(serializable);
 					addTypes(allSubtypes1, cus, types);
 				} else {
 					monitor.subTask(FixMessages.Java50Fix_InitializeSerialVersionId_subtask_description);
-                    for (int i= 0; i < compilationUnits.length; i++) {
-                    	collectChildrenWithMissingSerialVersionId(compilationUnits[i].getChildren(), serializable, types);
+                    for (ICompilationUnit compilationUnit : compilationUnits) {
+                    	collectChildrenWithMissingSerialVersionId(compilationUnit.getChildren(), serializable, types);
                     	if (monitor.isCanceled())
                     		throw new OperationCanceledException();
                     	monitor.worked(1);
@@ -188,9 +183,7 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 		}
 
 		private void addTypes(IType[] allSubtypes, HashSet<ICompilationUnit> cus, List<IType> types) throws JavaModelException {
-			for (int i= 0; i < allSubtypes.length; i++) {
-				IType type= allSubtypes[i];
-
+			for (IType type : allSubtypes) {
 				IField field= type.getField(NAME_FIELD);
 				if (!field.exists()) {
 					if (type.isClass() && cus.contains(type.getCompilationUnit())){
@@ -201,8 +194,7 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 		}
 
 		private void collectChildrenWithMissingSerialVersionId(IJavaElement[] children, IType serializable, List<IType> result) throws JavaModelException {
-			for (int i= 0; i < children.length; i++) {
-				IJavaElement child= children[i];
+			for (IJavaElement child : children) {
 				if (child instanceof IType) {
 					IType type= (IType)child;
 
@@ -210,9 +202,8 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
     					IField field= type.getField(NAME_FIELD);
     					if (!field.exists()) {
     						ITypeHierarchy hierarchy= type.newSupertypeHierarchy(new NullProgressMonitor());
-    						IType[] interfaces= hierarchy.getAllSuperInterfaces(type);
-    						for (int j= 0; j < interfaces.length; j++) {
-    							if (interfaces[j].equals(serializable)) {
+    						for (IType interface1 : hierarchy.getAllSuperInterfaces(type)) {
+    							if (interface1.equals(serializable)) {
     								result.add(type);
     								break;
     							}
@@ -294,7 +285,7 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 			fCurrentContext= new ISerialVersionFixContext() {
 				@Override
 				public Long getSerialVersionId(ITypeBinding binding) {
-					return Long.valueOf(1);
+					return 1L;
 				}
 				@Override
 				public RefactoringStatus initialize(IProgressMonitor pm) throws CoreException {
@@ -307,7 +298,7 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 				private Random rng;
 				@Override
 				public Long getSerialVersionId(ITypeBinding binding) {
-					return Long.valueOf(rng.nextLong());
+					return rng.nextLong();
 				}
 				@Override
 				public RefactoringStatus initialize(IProgressMonitor pm) throws CoreException {
@@ -350,9 +341,9 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 				return null;
 
 			List<ASTNode> declarationNodes= new ArrayList<>();
-			for (int i= 0; i < problems.length; i++) {
-				if (problems[i].getProblemId() == IProblem.MissingSerialVersion) {
-					final SimpleName simpleName= getSelectedName(compilationUnit, problems[i]);
+			for (IProblemLocationCore problem : problems) {
+				if (problem.getProblemId() == IProblem.MissingSerialVersion) {
+					final SimpleName simpleName= getSelectedName(compilationUnit, problem);
 					if (simpleName != null) {
 						ASTNode declarationNode= getDeclarationNode(simpleName);
 						if (declarationNode != null) {
@@ -364,8 +355,7 @@ public class PotentialProgrammingProblemsFixCore extends CompilationUnitRewriteO
 			if (declarationNodes.size() == 0)
 				return null;
 
-			for (Iterator<ASTNode> iter= declarationNodes.iterator(); iter.hasNext();) {
-	            ASTNode declarationNode= iter.next();
+			for (ASTNode declarationNode : declarationNodes) {
 	            ITypeBinding binding= getTypeBinding(declarationNode);
 	            if (fCurrentContext.getSerialVersionId(binding) != null) {
 	            	SerialVersionHashBatchOperation op= new SerialVersionHashBatchOperation(unit, declarationNodes.toArray(new ASTNode[declarationNodes.size()]), fCurrentContext);
