@@ -261,7 +261,7 @@ public enum UpdateProperty {
 					Object propertykey2= expression2.resolveConstantExpressionValue();
 					if (propertykey instanceof String && propertykey2 instanceof String && visited.getParent() instanceof MethodInvocation) {
 						MethodInvocation parent=(MethodInvocation) visited.getParent();
-						if (ASTNodes.usesGivenSignature(parent, Boolean.class.getCanonicalName(), METHOD_PARSEBOOLEAN, String.class.getCanonicalName()) && ((String)propertykey2).toLowerCase().equals("false")) { //$NON-NLS-1$
+						if (ASTNodes.usesGivenSignature(parent, Boolean.class.getCanonicalName(), METHOD_PARSEBOOLEAN, String.class.getCanonicalName()) && ((String)propertykey2).equalsIgnoreCase("false")) { //$NON-NLS-1$
 							operations.add(upp.rewrite(parent, (String) propertykey,expression, UNUSED));
 							nodesprocessed.add(visited);
 							return false;
@@ -303,7 +303,7 @@ public enum UpdateProperty {
 					Object propertykey2= expression2.resolveConstantExpressionValue();
 					if (propertykey instanceof String && propertykey2 instanceof String && visited.getParent() instanceof MethodInvocation) {
 						MethodInvocation parent=(MethodInvocation) visited.getParent();
-						if (ASTNodes.usesGivenSignature(parent, Integer.class.getCanonicalName(), METHOD_PARSEINTEGER, String.class.getCanonicalName())&& ((String)propertykey2).toLowerCase().equals("0")) { //$NON-NLS-1$
+						if (ASTNodes.usesGivenSignature(parent, Integer.class.getCanonicalName(), METHOD_PARSEINTEGER, String.class.getCanonicalName())&& ((String)propertykey2).equalsIgnoreCase("0")) { //$NON-NLS-1$
 							operations.add(upp.rewrite(parent, (String) propertykey,expression, UNUSED));
 							nodesprocessed.add(visited);
 							return false;
@@ -349,7 +349,7 @@ public enum UpdateProperty {
 					Object propertykey2= expression2.resolveConstantExpressionValue();
 					if (propertykey instanceof String && propertykey2 instanceof String && visited.getParent() instanceof MethodInvocation) {
 						MethodInvocation parent=(MethodInvocation) visited.getParent();
-						if (ASTNodes.usesGivenSignature(parent, Long.class.getCanonicalName(), METHOD_PARSELONG, String.class.getCanonicalName()) && ((String)propertykey2).toLowerCase().equals("0")) { //$NON-NLS-1$
+						if (ASTNodes.usesGivenSignature(parent, Long.class.getCanonicalName(), METHOD_PARSELONG, String.class.getCanonicalName()) && ((String)propertykey2).equalsIgnoreCase("0")) { //$NON-NLS-1$
 							operations.add(upp.rewrite(parent, (String) propertykey,expression, UNUSED));
 							nodesprocessed.add(visited);
 							return false;
