@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -15,7 +15,9 @@
  *     Yves Joan <yves.joan@oracle.com> - [reorg] Copy action should NOT add 'copy of' prefix - https://bugs.eclipse.org/bugs/show_bug.cgi?id=151668
  *     Red Hat Inc. - copied to jdt.core.manipulation
  *     Pierre-Yves B. <pyvesdev@gmail.com> - [inline] Allow inlining of local variable initialized to null. - https://bugs.eclipse.org/93850
- *******************************************************************************/
+ *     Nikolay Metchev - <nikolaymetchev@gmail.com> - [inline] Inline Local Variable does not qualify accesses to obscured types - https://bugs.eclipse.org/367536
+ *     Xiaye Chi <xychichina@gmail.com> - [extract local] Improve the Safety of "Extract Local Variable" Refactorings by Identifying the Side Effect of Selected Expression - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/348
+ ********************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring;
 
 import org.eclipse.osgi.util.NLS;
@@ -704,6 +706,8 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String ExtractTempRefactoring_select_expression;
 
+	public static String ExtractTempRefactoring_side_effcts_in_selected_expression;
+
 	public static String FlowAnalyzer_execution_flow;
 
 	public static String HierarchyRefactoring_add_member;
@@ -886,6 +890,8 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String InlineTemRefactoring_error_message_fieldsCannotBeInlined;
 
+	public static String InlineTemRefactoring_error_message_inliningClashes;
+
 	public static String IntroduceFactory_addFactoryMethod;
 
 	public static String IntroduceFactory_callSitesInBinaryClass;
@@ -2292,6 +2298,8 @@ public final class RefactoringCoreMessages extends NLS {
 
 	public static String SelfEncapsulateField_setter_pattern;
 
+	public static String SelfEncapsulateField_subtype_method_exists;
+
 	public static String SelfEncapsulateField_type_not_resolveable;
 
 	public static String SelfEncapsulateField_use_accessors;
