@@ -33,7 +33,6 @@ import javax.xml.transform.OutputKeys;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerConfigurationException;
 import javax.xml.transform.TransformerException;
-import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.TransformerFactoryConfigurationError;
 import javax.xml.transform.sax.SAXSource;
 import javax.xml.transform.stream.StreamResult;
@@ -41,6 +40,7 @@ import javax.xml.transform.stream.StreamResult;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 
+import org.eclipse.jdt.junit.ITestRunListener;
 import org.eclipse.jdt.junit.TestRunListener;
 
 import org.eclipse.core.runtime.Assert;
@@ -65,7 +65,7 @@ import org.eclipse.jdt.internal.junit.JUnitPreferencesConstants;
 import org.eclipse.jdt.internal.junit.Messages;
 import org.eclipse.jdt.internal.junit.launcher.JUnitLaunchConfigurationConstants;
 import org.eclipse.jdt.internal.junit.model.TestElement.Status;
-import org.eclipse.jdt.junit.ITestRunListener;
+import org.eclipse.jdt.internal.junit.util.XmlProcessorFactoryJdtJunit;
 
 /**
  * Central registry for JUnit test runs.
@@ -362,7 +362,7 @@ public final class JUnitModel {
 				List<TestRunSession> excess= fTestRunSessions.subList(maxCount, size);
 				for (Iterator<TestRunSession> iter= excess.iterator(); iter.hasNext();) {
 					TestRunSession oldSession= iter.next();
-					if (!(oldSession.isStarting() || oldSession.isRunning() || oldSession.isKeptAlive())) {
+					if (!oldSession.isStarting() && !oldSession.isRunning() && !oldSession.isKeptAlive()) {
 						toRemove.add(oldSession);
 						iter.remove();
 					}
@@ -370,8 +370,7 @@ public final class JUnitModel {
 			}
 		}
 
-		for (int i= 0; i < toRemove.size(); i++) {
-			TestRunSession oldSession= toRemove.get(i);
+		for (TestRunSession oldSession : toRemove) {
 			notifyTestRunSessionRemoved(oldSession);
 		}
 		notifyTestRunSessionAdded(testRunSession);
@@ -386,7 +385,7 @@ public final class JUnitModel {
 	 */
 	public static TestRunSession importTestRunSession(File file) throws CoreException {
 		try {
-			SAXParserFactory parserFactory= SAXParserFactory.newInstance();
+			SAXParserFactory parserFactory= XmlProcessorFactoryJdtJunit.createSAXFactoryWithErrorOnDOCTYPE();
 //			parserFactory.setValidating(true); // TODO: add DTD and debug flag
 			SAXParser parser= parserFactory.newSAXParser();
 			TestRunHandler handler= new TestRunHandler();
@@ -394,9 +393,7 @@ public final class JUnitModel {
 			TestRunSession session= handler.getTestRunSession();
 			JUnitCorePlugin.getModel().addTestRunSession(session);
 			return session;
-		} catch (ParserConfigurationException e) {
-			throwImportError(file, e);
-		} catch (SAXException e) {
+		} catch (ParserConfigurationException | SAXException e) {
 			throwImportError(file, e);
 		} catch (IOException e) {
 			throwImportError(file, e);
@@ -429,16 +426,14 @@ public final class JUnitModel {
 			@Override
 			public void run() {
 				try {
-					SAXParserFactory parserFactory= SAXParserFactory.newInstance();
+					SAXParserFactory parserFactory= XmlProcessorFactoryJdtJunit.createSAXFactoryWithErrorOnDOCTYPE();
 //					parserFactory.setValidating(true); // TODO: add DTD and debug flag
 					SAXParser parser= parserFactory.newSAXParser();
 					parser.parse(trimmedUrl, handler);
 					session[0]= handler.getTestRunSession();
 				} catch (OperationCanceledException e) {
 					// canceled
-				} catch (ParserConfigurationException e) {
-					storeImportError(e);
-				} catch (SAXException e) {
+				} catch (ParserConfigurationException | SAXException e) {
 					storeImportError(e);
 				} catch (IOException e) {
 					storeImportError(e);
@@ -477,14 +472,12 @@ public final class JUnitModel {
 
 	public static void importIntoTestRunSession(File swapFile, TestRunSession testRunSession) throws CoreException {
 		try {
-			SAXParserFactory parserFactory= SAXParserFactory.newInstance();
+			SAXParserFactory parserFactory= XmlProcessorFactoryJdtJunit.createSAXFactoryWithErrorOnDOCTYPE();
 //			parserFactory.setValidating(true); // TODO: add DTD and debug flag
 			SAXParser parser= parserFactory.newSAXParser();
 			TestRunHandler handler= new TestRunHandler(testRunSession);
 			parser.parse(swapFile, handler);
-		} catch (ParserConfigurationException e) {
-			throwImportError(swapFile, e);
-		} catch (SAXException e) {
+		} catch (ParserConfigurationException | SAXException e) {
 			throwImportError(swapFile, e);
 		} catch (IOException e) {
 			throwImportError(swapFile, e);
@@ -502,32 +495,19 @@ public final class JUnitModel {
 	 * @throws CoreException if an error occurred
 	 */
 	public static void exportTestRunSession(TestRunSession testRunSession, File file) throws CoreException {
-		FileOutputStream out= null;
-		try {
-			out= new FileOutputStream(file);
-            exportTestRunSession(testRunSession, out);
-
-		} catch (IOException e) {
-			throwExportError(file, e);
-		} catch (TransformerConfigurationException e) {
+		try (FileOutputStream out= new FileOutputStream(file)) {
+			exportTestRunSession(testRunSession, out);
+		} catch (IOException | TransformerConfigurationException e) {
 			throwExportError(file, e);
 		} catch (TransformerException e) {
 			throwExportError(file, e);
-		} finally {
-			if (out != null) {
-				try {
-					out.close();
-				} catch (IOException e2) {
-					JUnitCorePlugin.log(e2);
-				}
-			}
 		}
 	}
 
 	public static void exportTestRunSession(TestRunSession testRunSession, OutputStream out)
 			throws TransformerFactoryConfigurationError, TransformerException {
 
-		Transformer transformer= TransformerFactory.newInstance().newTransformer();
+		Transformer transformer= XmlProcessorFactoryJdtJunit.createTransformerFactoryWithErrorOnDOCTYPE().newTransformer();
 		InputSource inputSource= new InputSource();
 		SAXSource source= new SAXSource(new TestRunSessionSerializer(testRunSession), inputSource);
 		StreamResult result= new StreamResult(out);
