@@ -14,5 +14,5 @@
 package org.eclipse.jdt.internal.junit.ui;
 
 public interface ITraceDisplay {
-	public abstract void addTraceLine(int lineType, String label);
+	void addTraceLine(int lineType, String label);
 }
