@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2016, 2018 IBM Corporation and others.
+ * Copyright (c) 2016, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -113,45 +113,62 @@ public class JUnit5TestListener implements TestExecutionListener {
 		}
 
 		if (exception instanceof MultipleFailuresError) {
-			String expectedStr= ""; //$NON-NLS-1$
-			String actualStr= ""; //$NON-NLS-1$
-			String delimiter= "\n\n"; //$NON-NLS-1$
-			List<Throwable> failures= ((MultipleFailuresError) exception).getFailures();
-			for (Throwable assertionError : failures) {
-				if (assertionError instanceof AssertionFailedError) {
-					AssertionFailedError assertionFailedError= (AssertionFailedError) assertionError;
-					ValueWrapper expected= assertionFailedError.getExpected();
-					ValueWrapper actual= assertionFailedError.getActual();
-					if (expected == null || actual == null) {
-						return null;
-					}
-					expectedStr+= expected.getStringRepresentation() + delimiter;
-					actualStr+= actual.getStringRepresentation() + delimiter;
-				} else {
-					return null;
-				}
-			}
-			return new FailedComparison(expectedStr, actualStr);
+			return getComparisonForMultipleFailures(exception);
 		}
 
-		// Avoid reference to ComparisonFailure initially to avoid NoClassDefFoundError for ComparisonFailure when junit.jar is not on the build path 
-		String classname= exception.getClass().getName();
-		if (classname.equals("junit.framework.ComparisonFailure")) { //$NON-NLS-1$
-			junit.framework.ComparisonFailure comparisonFailure= (junit.framework.ComparisonFailure) exception;
-			return new FailedComparison(comparisonFailure.getExpected(), comparisonFailure.getActual());
-		}
-		if (classname.equals("org.junit.ComparisonFailure")) { //$NON-NLS-1$
-			org.junit.ComparisonFailure comparisonFailure= (org.junit.ComparisonFailure) exception;
-			return new FailedComparison(comparisonFailure.getExpected(), comparisonFailure.getActual());
+		// Avoid reference to ComparisonFailure initially to avoid NoClassDefFoundError for ComparisonFailure when junit.jar is not on the build path
+		for(Class<?> it= exception.getClass(); !Object.class.equals(it); it= it.getSuperclass()) {
+			if ("junit.framework.ComparisonFailure".equals(it.getName())) { //$NON-NLS-1$
+				junit.framework.ComparisonFailure comparisonFailure= (junit.framework.ComparisonFailure) exception;
+				return new FailedComparison(comparisonFailure.getExpected(), comparisonFailure.getActual());
+			}
+			if ("org.junit.ComparisonFailure".equals(it.getName())) { //$NON-NLS-1$
+				org.junit.ComparisonFailure comparisonFailure= (org.junit.ComparisonFailure) exception;
+				return new FailedComparison(comparisonFailure.getExpected(), comparisonFailure.getActual());
+			}
 		}
 
 		return null;
 	}
 
+	protected FailedComparison getComparisonForMultipleFailures(Throwable exception) {
+		StringBuilder expectedStr= new StringBuilder();
+		StringBuilder actualStr= new StringBuilder();
+		String delimiter= "\n\n"; //$NON-NLS-1$
+		List<Throwable> failures= ((MultipleFailuresError) exception).getFailures();
+		for (Throwable assertionError : failures) {
+			if (assertionError instanceof MultipleFailuresError) {
+				FailedComparison failedComparison= getComparisonForMultipleFailures(assertionError);
+				if(failedComparison == null) {
+					return null;
+				}
+				String expected= failedComparison.getExpected();
+				String actual= failedComparison.getActual();
+				if (expected == null || actual == null) {
+					return null;
+				}
+				expectedStr.append(expected);
+				actualStr.append(actual);
+			} else if (assertionError instanceof AssertionFailedError) {
+				AssertionFailedError assertionFailedError= (AssertionFailedError) assertionError;
+				ValueWrapper expected= assertionFailedError.getExpected();
+				ValueWrapper actual= assertionFailedError.getActual();
+				if (expected == null || actual == null) {
+					return null;
+				}
+				expectedStr.append(expected.getStringRepresentation()).append(delimiter);
+				actualStr.append(actual.getStringRepresentation()).append(delimiter);
+			} else {
+				return null;
+			}
+		}
+		return new FailedComparison(expectedStr.toString(), actualStr.toString());
+	}
+
 	@Override
 	public void executionSkipped(TestIdentifier testIdentifier, String reason) {
 		if (testIdentifier.isContainer() && fTestPlan != null) {
-			fTestPlan.getDescendants(testIdentifier).stream().filter(t -> t.isTest()).forEachOrdered(t -> notifySkipped(t));
+			fTestPlan.getDescendants(testIdentifier).stream().filter(TestIdentifier::isTest).forEachOrdered(this::notifySkipped);
 		} else {
 			notifySkipped(testIdentifier);
 		}
@@ -204,7 +221,7 @@ public class JUnit5TestListener implements TestExecutionListener {
 		return new JUnit5Identifier(testIdentifier);
 	}
 
-	private class IgnoredTestIdentifier extends JUnit5Identifier {
+	private static class IgnoredTestIdentifier extends JUnit5Identifier {
 		public IgnoredTestIdentifier(TestIdentifier description) {
 			super(description);
 		}
@@ -218,7 +235,7 @@ public class JUnit5TestListener implements TestExecutionListener {
 		}
 	}
 
-	private class AssumptionFailedTestIdentifier extends JUnit5Identifier {
+	private static class AssumptionFailedTestIdentifier extends JUnit5Identifier {
 		public AssumptionFailedTestIdentifier(TestIdentifier description) {
 			super(description);
 		}
