@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2013 IBM Corporation and others.
+ * Copyright (c) 2009, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,9 +13,12 @@
  *******************************************************************************/
 package org.eclipse.jdt.text.tests;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.core.runtime.ILogListener;
 import org.eclipse.core.runtime.IStatus;
@@ -38,12 +41,7 @@ import org.eclipse.jdt.internal.ui.text.java.JavaAutoIndentStrategy;
  *
  * @since 3.6
  */
-public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener {
-
-	public static Test suite() {
-		return new TestSuite(JavaAutoIndentStrategyTest.class);
-	}
-
+public class JavaAutoIndentStrategyTest implements ILogListener {
 	private FastPartitioner fPartitioner;
 
 	private Document fDocument;
@@ -80,6 +78,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		fAccessor.invoke("smartPaste", new Class[] { IDocument.class, DocumentCommand.class }, new Object[] { fDocument, fDocumentCommand });
 	}
 
+	@Test
 	public void testPasteDefaultAtEnd() {
 		fDocument.set("public class Test2 {\r\n\r\n}\r\n");
 
@@ -91,6 +90,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(result, fDocumentCommand.text);
 	}
 
+	@Test
 	public void testPasteFooAtEnd() {
 		fDocument.set("public class Test2 {\r\n\r\n}\r\n");
 
@@ -102,6 +102,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(result, fDocumentCommand.text);
 	}
 
+	@Test
 	public void testPasteAndIndentOfLongStringWithContinuations1() {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=330556
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=65317
@@ -151,6 +152,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(result, fDocumentCommand.text);
 	}
 
+	@Test
 	public void testPasteAndIndentOfStringWithContinuations2() {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=337150
 		fDocument.set("public class Test2 {\n}");
@@ -167,6 +169,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(result, fDocumentCommand.text);
 	}
 
+	@Test
 	public void testPasteAndIndentOfStringWithContinuations3() {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=337150
 		fDocument.set("public class Test2 {\n}");
@@ -183,6 +186,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(result, fDocumentCommand.text);
 	}
 
+	@Test
 	public void testPasteAndIndentOfStringWithContinuations4() {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=337150
 		fDocument.set("public class Test2 {\n}");
@@ -199,6 +203,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(result, fDocumentCommand.text);
 	}
 
+	@Test
 	public void testPasteAndIndentOfStringWithContinuations5() {
 		//https://bugs.eclipse.org/bugs/show_bug.cgi?id=337150
 		fDocument.set("public class Test2 {\n}");
@@ -221,6 +226,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		fCommandAccessor.invoke("execute", new Class[] { IDocument.class }, new Object[] { fDocument });
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine1() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=29379
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -247,6 +253,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf1.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine2() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=395071
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -273,6 +280,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf1.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine3() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=395071
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -288,6 +296,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine4() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=254704
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -315,6 +324,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf1.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine5() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=256087
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -341,6 +351,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf1.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine6() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=200015
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -362,6 +373,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine7() {
 		fDocument.setInitialLineDelimiter("\r\n");
 		fDocument.set("int[] a= new int[] { ;");
@@ -376,6 +388,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine8() {
 		fDocument.setInitialLineDelimiter("\r\n");
 		fDocument.set("String[] strs = {\"a\",\"b\",");
@@ -390,6 +403,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine9() {
 		fDocument.setInitialLineDelimiter("\r\n");
 		fDocument.set("{ int a;");
@@ -404,6 +418,7 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf.toString(), fDocument.get());
 	}
 
+	@Test
 	public void testSmartIndentAfterNewLine10() {
 		// https://bugs.eclipse.org/bugs/show_bug.cgi?id=404879
 		fDocument.setInitialLineDelimiter("\r\n");
@@ -419,21 +434,13 @@ public class JavaAutoIndentStrategyTest extends TestCase implements ILogListener
 		assertEquals(buf.toString(), fDocument.get());
 	}
 
-	/*
-	 * @see junit.framework.TestCase#setUp()
-	 */
-	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	@Before
+	public void setUp() throws Exception {
 		JavaPlugin.getDefault().getLog().addLogListener(this);
 	}
 
-	/*
-	 * @see junit.framework.TestCase#tearDown()
-	 */
-	@Override
-	protected void tearDown() throws Exception {
-		super.tearDown();
+	@After
+	public void tearDown() throws Exception {
 		JavaPlugin.getDefault().getLog().removeLogListener(this);
 	}
 
