@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2012, 2013 IBM Corporation and others.
+ * Copyright (c) 2012, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,9 +16,7 @@ package org.eclipse.jdt.text.tests;
 import java.lang.reflect.Field;
 import java.util.ArrayList;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.StringAsserts;
 
@@ -26,8 +24,7 @@ import org.eclipse.jdt.internal.corext.util.CollectionsUtil;
 
 import org.eclipse.jdt.internal.ui.text.JavaElementPrefixPatternMatcher;
 
-public class JavaElementPrefixPatternMatcherTest extends TestCase {
-
+public class JavaElementPrefixPatternMatcherTest {
 	private static final String toString_int_int= "toString(int, int) : String - java.lang.Integer";
 
 	private static final String toString_int= "toString(int) : String - java.lang.Integer";
@@ -71,19 +68,13 @@ public class JavaElementPrefixPatternMatcherTest extends TestCase {
 			if (String.class.equals(field.getType()))
 				try {
 					strings.add((String) field.get(null));
-				} catch (IllegalArgumentException e) {
-					e.printStackTrace();
-				} catch (IllegalAccessException e) {
+				} catch (IllegalArgumentException | IllegalAccessException e) {
 					e.printStackTrace();
 				}
 		}
 		ALL_STRING_CONSTANTS= strings.toArray(new String[strings.size()]);
 	}
 
-	public static Test suite() {
-		return new TestSuite(JavaElementPrefixPatternMatcherTest.class);
-	}
-
 	private static void doMatch(String pattern, String... labelStrings) {
 		JavaElementPrefixPatternMatcher matcher= new JavaElementPrefixPatternMatcher(pattern);
 
@@ -96,89 +87,103 @@ public class JavaElementPrefixPatternMatcherTest extends TestCase {
 		StringAsserts.assertEqualStringsIgnoreOrder(CollectionsUtil.toArray(matched, String.class), labelStrings);
 	}
 
-
+	@Test
 	public void testEmptyPattern() throws Exception {
 		doMatch("", ALL_STRING_CONSTANTS);
 	}
 
+	@Test
 	public void testStarPattern() throws Exception {
 		doMatch("*", ALL_STRING_CONSTANTS);
 	}
 
-
+	@Test
 	public void testMethodPattern_1() throws Exception {
 		doMatch("*tos", toString_int_int, toString_int);
 	}
 
-
+	@Test
 	public void testMethodPattern_2() throws Exception {
 		doMatch("tS", toString_int_int, toString_int);
 	}
 
+	@Test
 	public void testMethodPattern_3() throws Exception {
 		doMatch("tS(", toString_int_int, toString_int);
 	}
 
+	@Test
 	public void testMethodPattern_4() throws Exception {
 		doMatch("tS(int", toString_int_int, toString_int);
 	}
 
+	@Test
 	public void testMethodPattern_5() throws Exception {
 		doMatch("tS(int, ", toString_int_int);
 	}
 
+	@Test
 	public void testMethodPattern_6() throws Exception {
 		doMatch("toString(int, int) : S", toString_int_int);
 	}
 
+	@Test
 	public void testMethodPattern_7() throws Exception {
 		doMatch("*(in", toString_int_int, toString_int, Integer_int);
 	}
 
+	@Test
 	public void testMethodPattern_8() throws Exception {
 		doMatch("*) : St", toString_int_int, toString_int);
 	}
 
+	@Test
 	public void testMethodPattern_9() throws Exception {
 		doMatch("p*) : i", parseInt_String, parseInt_String_int);
 	}
 
+	@Test
 	public void testMethodPattern_10() throws Exception {
 		doMatch("to*ng(", toString_int_int, toString_int);
 	}
 
+	@Test
 	public void testMethodPattern_11() throws Exception {
 		doMatch("tS*ng(");
 	}
 
+	@Test
 	public void testReturnPattern_1() throws Exception {
 		doMatch("*: int", parseInt_String, parseInt_String_int, MIN_VALUE__int);
 	}
 
+	@Test
 	public void testReturnPattern_2() throws Exception {
 		doMatch("*: Class<In", TYPE__Class_Integer);
 	}
 
-
+	@Test
 	public void testFieldPattern_1() throws Exception {
 		doMatch("DT : ", DigitTens__char_);
 	}
 
-
+	@Test
 	public void testTypePattern_2() throws Exception {
 		doMatch("AI", AtomicInteger);
 	}
 
+	@Test
 	public void testTypePattern_3() throws Exception {
 		doMatch("b", BigDecimal, Byte, BigInteger);
 	}
 
+	@Test
 	public void testDeclaringClassPattern_1() throws Exception {
 		doMatch("*-", ALL_STRING_CONSTANTS);
 	}
 
+	@Test
 	public void testDeclaringClassPattern_2() throws Exception {
 		doMatch("*- java.lang", toString_int_int, toString_int, parseInt_String, parseInt_String_int, Integer_int, MIN_VALUE__int, TYPE__Class_Integer, DigitTens__char_, Object, Number, Byte, Long, Double);
 	}
-
 }
