@@ -2,9 +2,9 @@ package p;
 
 public class TestTextBlock {
 	public void foo() {
-			String x = """
+			String x = 
+				"""
 				This is a text block
-				
 				   with an indent
 				""";
 	}
