@@ -3,8 +3,8 @@ package expression_out;
 public class A_test627 {
 
 	public void foo() {
-		int i= 1 - (extracted());
-		int j= 1 - (extracted());
+		int i= 1 - extracted();
+		int j= 1 - extracted();
 	}
 
 	protected int extracted() {
