@@ -1,11 +1,11 @@
 package p;
 public class Z extends A {
 	public final int a;
-	public final boolean b;
+	public final int b;
 
-	public Z(int a, int a_2, boolean b) {
-		super(a);
-		this.a = a_2;
+	public Z(int a, int b) {
+		super();
+		this.a = a;
 		this.b = b;
 	}
 
@@ -13,7 +13,7 @@ public class Z extends A {
 		return a;
 	}
 
-	public boolean getb() {
+	public int getb() {
 		return b;
 	}
 }
\ No newline at end of file
