@@ -7,16 +7,16 @@ class A{
 }
 class B extends A{
 	public final int a;
-	public final boolean b;
+	public final int b;
 	public int geta() {
 		return a;
 	}
-	public boolean getb() {
+	public int getb() {
 		return b;
 	}
-	public B(int k, boolean l) {
+	public B(int a, int b) {
 		super(4);
-		a = k;
-		b = l;
+		this.a = a;
+		this.b = b;
 	}
 }
