@@ -6,7 +6,7 @@ class A{
 	}
 }
 class B extends Z{
-	public B(int k, boolean l) {
-		super(4, k, l);
+	public B(int a, int b) {
+		super(4, a, b);
 	}
 }
