@@ -7,7 +7,10 @@ abstract class C implements A {
 	public abstract void m();
 }
 class B extends C{
-	@Override
+	class Override {
+		// used to force @java.lang.Override instead of @Override
+	}
+	@java.lang.Override
 	public void m() {
 
 	}
