@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -26,6 +26,8 @@ import org.junit.runners.Suite;
 	SurroundWithTests.class,
 	SurroundWithTests1d7.class,
 	SurroundWithTests1d8.class,
+	SurroundWithTests16.class,
+	SurroundWithResourcesTests1d8.class,
 })
 public class AllTests {
 }
\ No newline at end of file
