@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2011 IBM Corporation and others.
+ * Copyright (c) 2010, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,18 +13,19 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import static org.junit.Assert.assertEquals;
+
 import java.lang.reflect.InvocationTargetException;
 
-import junit.extensions.TestSetup;
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
 
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.ILogListener;
 import org.eclipse.core.runtime.IProgressMonitor;
-import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.MultiStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.OperationCanceledException;
@@ -57,6 +58,7 @@ import org.eclipse.ltk.core.refactoring.RefactoringCore;
 import org.eclipse.ltk.core.refactoring.RefactoringStatus;
 
 import org.eclipse.jdt.ui.JavaUI;
+import org.eclipse.jdt.ui.tests.refactoring.rules.RefactoringTestSetup;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
@@ -66,45 +68,28 @@ import org.eclipse.jdt.internal.ui.JavaPlugin;
  *
  * @since 3.6
  */
-public class DocumentChangeTest extends RefactoringTest {
+public class DocumentChangeTest extends GenericRefactoringTest {
 
-	public static Test suite() {
-		return setUpTest(new TestSuite(DocumentChangeTest.class));
+	public DocumentChangeTest() {
+		rts= new RefactoringTestSetup();
 	}
 
-	public static Test suiteWithoutRefactoringTestSetup() {
-		return new TestSetup(new TestSuite(DocumentChangeTest.class)) {
-			@Override
-			protected void setUp() throws Exception {
-				PlatformUI.getWorkbench().showPerspective(JavaUI.ID_PERSPECTIVE, JavaPlugin.getActiveWorkbenchWindow());
-			}
-
-			@Override
-			protected void tearDown() throws Exception {
-				IWorkbenchPage activePage= JavaPlugin.getActivePage();
-				if (activePage != null) {
-					activePage.closeAllPerspectives(true, true);
-				}
-			}
-		};
+	@Before
+	public void setUp() throws Exception {
+		PlatformUI.getWorkbench().showPerspective(JavaUI.ID_PERSPECTIVE, JavaPlugin.getActiveWorkbenchWindow());
 	}
 
-	public static Test setUpTest(Test test) {
-		return new RefactoringTestSetup(test) {
-			@Override
-			protected void setUp() throws Exception {
-				super.setUp(); // closes the perspective, need to reopen
-				PlatformUI.getWorkbench().showPerspective(JavaUI.ID_PERSPECTIVE, JavaPlugin.getActiveWorkbenchWindow());
-			}
-		};
-	}
-
-	public DocumentChangeTest(String name) {
-		super(name);
+	@After
+	public void tearDown() throws Exception {
+		IWorkbenchPage activePage= JavaPlugin.getActivePage();
+		if (activePage != null) {
+			activePage.closeAllPerspectives(true, true);
+		}
 	}
 
+	@Test
 	public void testDocumentChange() throws Exception {
-		IProject project= RefactoringTestSetup.getProject().getProject();
+		IProject project= rts.getProject().getProject();
 		IFile file= project.getFile("file.txt");
 		final String prolog= "This is a ";
 		final String insertion= "modified ";
@@ -155,22 +140,14 @@ public class DocumentChangeTest extends RefactoringTest {
 
 		final MultiStatus statusCollector= new MultiStatus(JavaTestPlugin.getPluginId(), 0, "", null);
 
-		ILogListener logListener= new ILogListener() {
-			@Override
-			public void logging(IStatus status, String plugin) {
-				statusCollector.add(status);
-			}
-		};
+		ILogListener logListener= (status, plugin) -> statusCollector.add(status);
 		Platform.addLogListener(logListener);
 		try {
-			IRunnableWithProgress runnable= new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					try {
-						performRefactoring(ref);
-					} catch (Exception e) {
-						throw new InvocationTargetException(e);
-					}
+			IRunnableWithProgress runnable= monitor -> {
+				try {
+					performRefactoring(ref);
+				} catch (Exception e) {
+					throw new InvocationTargetException(e);
 				}
 			};
 			JavaPlugin.getActiveWorkbenchWindow().run(true, true, runnable);
@@ -182,14 +159,11 @@ public class DocumentChangeTest extends RefactoringTest {
 
 			// undo:
 
-			runnable= new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					try {
-						RefactoringCore.getUndoManager().performUndo(null, new NullProgressMonitor());
-					} catch (Exception e) {
-						throw new InvocationTargetException(e);
-					}
+			runnable= monitor -> {
+				try {
+					RefactoringCore.getUndoManager().performUndo(null, new NullProgressMonitor());
+				} catch (Exception e) {
+					throw new InvocationTargetException(e);
 				}
 			};
 			JavaPlugin.getActiveWorkbenchWindow().run(true, true, runnable);
@@ -204,14 +178,11 @@ public class DocumentChangeTest extends RefactoringTest {
 
 			JavaPlugin.getActivePage().closeEditor(editor, true);
 
-			runnable= new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					try {
-						RefactoringCore.getUndoManager().performRedo(null, new NullProgressMonitor());
-					} catch (Exception e) {
-						throw new InvocationTargetException(e);
-					}
+			runnable= monitor -> {
+				try {
+					RefactoringCore.getUndoManager().performRedo(null, new NullProgressMonitor());
+				} catch (Exception e) {
+					throw new InvocationTargetException(e);
 				}
 			};
 			JavaPlugin.getActiveWorkbenchWindow().run(true, true, runnable);
