@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2019 IBM Corporation and others.
+ * Copyright (c) 2019, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,37 +13,32 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import org.junit.Test;
+import org.junit.runner.RunWith;
 
-import junit.framework.Test;
+import org.eclipse.jdt.ui.tests.CustomBaseRunner;
+import org.eclipse.jdt.ui.tests.IgnoreInheritedTests;
+import org.eclipse.jdt.ui.tests.refactoring.rules.Java13Setup;
 
+@IgnoreInheritedTests
+@RunWith(CustomBaseRunner.class)
 public class ExtractConstantTests13 extends ExtractConstantTests {
-
-	private static final Class<ExtractConstantTests13> clazz = ExtractConstantTests13.class;
-
-	public ExtractConstantTests13(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new Java13Setup(new NoSuperTestsSuite(clazz));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new Java13Setup(test);
+	public ExtractConstantTests13() {
+		super(new Java13Setup());
 	}
 
 	@Override
 	protected String getTestFileName(boolean canExtract, boolean input) {
-		String fileName= TEST_PATH_PREFIX + getRefactoringPath();
-		fileName+= (canExtract ? "canExtract13/" : "cannotExtract13/");
-		return fileName + getSimpleTestFileName(canExtract, input);
+		StringBuilder fileName= new StringBuilder(TEST_PATH_PREFIX).append(getRefactoringPath());
+		fileName.append(canExtract ? "canExtract13/" : "cannotExtract13/");
+		return fileName.append(getSimpleTestFileName(canExtract, input)).toString();
 	}
 
 	//--- TESTS
 
 	@Override
+	@Test
 	public void test0() throws Exception {
 		helper1(6, 19, 9, 22, true, false, "CONSTANT", "STRING");
 	}
 }
-
