@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2018 IBM Corporation and others.
+ * Copyright (c) 2018, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -18,19 +18,15 @@ import org.eclipse.ltk.core.refactoring.RefactoringCore;
 import org.eclipse.jdt.core.IPackageFragment;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
 
-import junit.framework.Test;
+import org.eclipse.jdt.ui.tests.refactoring.rules.Java10Setup;
 
 public class ExtractMethodTestSetup10 extends Java10Setup {
 
 	private IPackageFragment fTry10Package;
 
-	public ExtractMethodTestSetup10(Test test) {
-		super(test);
-	}
-
 	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	public void before() throws Exception {
+		super.before();
 
 		RefactoringCore.getUndoManager().flush();
 
