@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -2675,4 +2675,10 @@ public class ExtractMethodTests extends AbstractJunit4SelectionTestCase {
 	public void test2005() throws Exception {
 		wikiTest();
 	}
+
+	//--- Test Issues
+	@Test
+	public void testIssue671() throws Exception {
+		validSelectionTestChecked();
+	}
 }
