@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2017 IBM Corporation and others.
+ * Copyright (c) 2005, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,10 +14,16 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.IOException;
 import java.util.Hashtable;
 import java.util.Map;
 
+import org.junit.Test;
+
 import org.eclipse.core.runtime.NullProgressMonitor;
 
 import org.eclipse.jface.preference.IPreferenceStore;
@@ -39,31 +45,23 @@ import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatur
 import org.eclipse.jdt.internal.corext.refactoring.base.RefactoringStatusCodes;
 
 import org.eclipse.jdt.ui.PreferenceConstants;
+import org.eclipse.jdt.ui.tests.refactoring.rules.RefactoringTestSetup;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-public class IntroduceParameterObjectTests extends RefactoringTest {
-
-	private static final Class<IntroduceParameterObjectTests> CLAZZ= IntroduceParameterObjectTests.class;
+public class IntroduceParameterObjectTests extends GenericRefactoringTest {
 	private static final String DEFAULT_SUB_DIR= "sub";
 	private static final String REFACTORING_PATH= "IntroduceParameterObject/";
 
-	public static Test setUpTest(Test someTest) {
-		return new RefactoringTestSetup(someTest);
-	}
-
-	public static Test suite() {
-		return new RefactoringTestSetup(new TestSuite(CLAZZ));
-	}
-
 	private IPackageFragment fPack;
 	protected IntroduceParameterObjectDescriptor fDescriptor;
 
-	public IntroduceParameterObjectTests(String name) {
-		super(name);
+	public IntroduceParameterObjectTests() {
+		this.rts= new RefactoringTestSetup();
+	}
+
+	protected IntroduceParameterObjectTests(RefactoringTestSetup rts) {
+		super(rts);
 	}
 
 	private void checkAdditionalFile(String subdir, String fileName) throws Exception, JavaModelException, IOException {
@@ -173,8 +171,8 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 	}
 
 	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	public void genericbefore() throws Exception {
+		super.genericbefore();
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, false);
 		fDescriptor= RefactoringSignatureDescriptorFactory.createIntroduceParameterObjectDescriptor();
@@ -202,20 +200,22 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 	}
 
 	@Override
-	protected void tearDown() throws Exception {
-		super.tearDown();
+	public void genericafter() throws Exception {
+		super.genericafter();
 		fDescriptor=null;
 		fPack=null;
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setToDefault(PreferenceConstants.CODEGEN_ADD_COMMENTS);
 	}
 
+	@Test
 	public void testBodyUpdate() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testDefaultPackagePoint() throws Exception {
 		setupPackage("");
 		fDescriptor.setMethod(setupMethod());
@@ -224,6 +224,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testDefaultPackagePointTopLevel() throws Exception {
 		setupPackage("");
 		fDescriptor.setMethod(setupMethod());
@@ -232,6 +233,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testDelegateCreation() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setGetters(true);
@@ -247,6 +249,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testDelegateCreationCodeStyle() throws Exception {
 		IJavaProject javaProject= getRoot().getJavaProject();
 		Map<String, String> originalOptions= javaProject.getOptions(false);
@@ -271,6 +274,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		}
 	}
 
+	@Test
 	public void testImportAddEnclosing() throws Exception {
 		createCaller(null);
 		fDescriptor.setMethod(setupMethod());
@@ -283,6 +287,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		checkCaller(null);
 	}
 
+	@Test
 	public void testImportAddTopLevel() throws Exception {
 		createCaller(DEFAULT_SUB_DIR);
 		fDescriptor.setMethod(setupMethod());
@@ -293,6 +298,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		checkCaller(DEFAULT_SUB_DIR);
 	}
 
+	@Test
 	public void testImportNameSimple() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setClassName("ArrayList");
@@ -301,6 +307,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testInlineRename() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
@@ -311,6 +318,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testSubclassInCU() throws Exception {
 		// test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=259095
 		fDescriptor.setMethod(setupMethod());
@@ -320,6 +328,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testInterfaceMethod() throws Exception {
 		createAdditionalFile(null, "TestInterfaceMethod2Impl");
 		createAdditionalFile(null, "ITestInterfaceMethod");
@@ -332,6 +341,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		checkAdditionalFile(null, "TestInterfaceMethod2Impl");
 	}
 
+	@Test
 	public void testRecursiveReordered() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
@@ -344,12 +354,14 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testRecursiveSimple() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testRecursiveSimpleReordered() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
@@ -357,6 +369,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 	}
 
 
+	@Test
 	public void testReorderGetter() throws Exception{
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setGetters(true);
@@ -370,12 +383,14 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testSimpleEnclosing() throws Exception{
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testSimpleEnclosingCodeStyle() throws Exception {
 		IJavaProject javaProject= getRoot().getJavaProject();
 		Map<String, String> originalOptions= javaProject.getOptions(false);
@@ -395,12 +410,14 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		}
 	}
 
+	@Test
 	public void testVarArgsNotReordered() throws Exception{
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testVarArgsReordered() throws Exception{
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
@@ -413,6 +430,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testMethodTypeParamArgs() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(false);
@@ -420,6 +438,7 @@ public class IntroduceParameterObjectTests extends RefactoringTest {
 		runRefactoring(false, true);
 	}
 
+	@Test
 	public void testMethodTypeParamArgsTopLevel() throws Exception {
 		fDescriptor.setMethod(setupMethod());
 		fDescriptor.setTopLevel(true);
