@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,6 +13,12 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.refactoring;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.BufferedInputStream;
 import java.io.ByteArrayInputStream;
 import java.io.File;
@@ -29,6 +35,10 @@ import java.util.Map;
 import java.util.zip.ZipInputStream;
 
 import org.junit.Assert;
+import org.junit.FixMethodOrder;
+import org.junit.Ignore;
+import org.junit.Test;
+import org.junit.runners.MethodSorters;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
@@ -83,19 +93,12 @@ import org.eclipse.jdt.internal.corext.refactoring.util.JavaElementUtil;
 
 import org.eclipse.jdt.ui.tests.refactoring.infra.DebugUtils;
 import org.eclipse.jdt.ui.tests.refactoring.infra.ZipTools;
+import org.eclipse.jdt.ui.tests.refactoring.rules.Java1d5Setup;
 
 import org.eclipse.jdt.internal.ui.util.CoreUtility;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-
-public class RenamePackageTests extends RefactoringTest {
-	private static final boolean BUG_PACKAGE_CANT_BE_RENAMED_TO_A_PACKAGE_THAT_ALREADY_EXISTS= true;
-	private static final boolean BUG_6054= false;
-	private static final boolean BUG_54962_71267= false;
-
-	private static final Class<RenamePackageTests> clazz= RenamePackageTests.class;
+@FixMethodOrder(MethodSorters.NAME_ASCENDING)
+public class RenamePackageTests extends GenericRefactoringTest {
 	private static final String REFACTORING_PATH= "RenamePackage/";
 
 	private boolean fUpdateReferences;
@@ -103,16 +106,8 @@ public class RenamePackageTests extends RefactoringTest {
 	private String fQualifiedNamesFilePatterns;
 	private boolean fRenameSubpackages;
 
-	public RenamePackageTests(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return new Java15Setup(new TestSuite(clazz));
-	}
-
-	public static Test setUpTest(Test someTest) {
-		return new Java15Setup(someTest);
+	public RenamePackageTests() {
+		rts= new Java1d5Setup();
 	}
 
 //	public void run(TestResult result) {
@@ -121,8 +116,8 @@ public class RenamePackageTests extends RefactoringTest {
 //	}
 
 	@Override
-	protected void setUp() throws Exception {
-		super.setUp();
+	public void genericbefore() throws Exception {
+		super.genericbefore();
 		fUpdateReferences= true;
 		fUpdateTextualMatches= false;
 		fQualifiedNamesFilePatterns= null;
@@ -221,7 +216,7 @@ public class RenamePackageTests extends RefactoringTest {
 			setFilePatterns(descriptor);
 			Refactoring refactoring= createRefactoring(descriptor);
 			RefactoringStatus result= performRefactoring(refactoring);
-			assertEquals("preconditions were supposed to pass", null, result);
+			assertNull("preconditions were supposed to pass", result);
 
 			if (isRename) {
 				ParticipantTesting.testRename(renameHandles,
@@ -255,7 +250,7 @@ public class RenamePackageTests extends RefactoringTest {
 			if (hasSubpackages) {
 				assertTrue("old package does not exist anymore", getRoot().getPackageFragment(packageNames[0]).exists());
 			} else {
-				assertTrue("package not renamed", ! getRoot().getPackageFragment(packageNames[0]).exists());
+				assertFalse("package not renamed", getRoot().getPackageFragment(packageNames[0]).exists());
 			}
 			IPackageFragment newPackage= getRoot().getPackageFragment(newPackageName);
 			assertTrue("new package does not exist", newPackage.exists());
@@ -338,7 +333,7 @@ public class RenamePackageTests extends RefactoringTest {
 			descriptor.setUpdateHierarchy(fRenameSubpackages);
 			RefactoringStatus result= performRefactoring(descriptor);
 			if (expectedSeverity == RefactoringStatus.OK)
-				assertEquals("preconditions were supposed to pass", null, result);
+				assertNull("preconditions were supposed to pass", result);
 			else
 				assertEquals(expectedSeverity, result.getSeverity());
 		}
@@ -347,7 +342,7 @@ public class RenamePackageTests extends RefactoringTest {
 			createAndPerform(RefactoringStatus.OK);
 
 			IPackageFragment oldPackage= getRoot().getPackageFragment(fPackageNames[0]);
-			assertTrue("package not renamed: " + fPackageNames[0], ! oldPackage.exists());
+			assertFalse("package not renamed: " + fPackageNames[0], oldPackage.exists());
 			IPackageFragment newPackage= getRoot().getPackageFragment(fNewPackageName);
 			assertTrue("new package does not exist", newPackage.exists());
 
@@ -470,9 +465,9 @@ public class RenamePackageTests extends RefactoringTest {
 		setFilePatterns(descriptor);
 		descriptor.setUpdateHierarchy(fRenameSubpackages);
 		RefactoringStatus result= performRefactoring(descriptor);
-		assertEquals("preconditions were supposed to pass", null, result);
+		assertNull("preconditions were supposed to pass", result);
 
-		assertTrue("package not renamed", ! roots[0].getPackageFragment(packageNames[0][0]).exists());
+		assertFalse("package not renamed", roots[0].getPackageFragment(packageNames[0][0]).exists());
 		IPackageFragment newPackage= roots[0].getPackageFragment(newPackageName);
 		assertTrue("new package does not exist", newPackage.exists());
 
@@ -588,6 +583,7 @@ public class RenamePackageTests extends RefactoringTest {
 	// ---------- tests -------------
 
 
+	@Test
 	public void testPackageRenameWithResource1() throws Exception {
 		IPackageFragment fragment= getRoot().createPackageFragment("org.test", true, null);
 
@@ -599,7 +595,7 @@ public class RenamePackageTests extends RefactoringTest {
 		fragment.createCompilationUnit("MyClass.java", buf.toString(), true, null);
 
 		IFile file= ((IFolder) getRoot().getResource()).getFile("x.properties");
-		byte[] content= "This is about 'org.test' and more".getBytes();
+		byte[] content= "This is about 'org.test' and more".getBytes(ENCODING);
 		file.create(new ByteArrayInputStream(content), true, null);
 		file.refreshLocal(IResource.DEPTH_ONE, null);
 
@@ -625,6 +621,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void testPackageRenameWithResource2() throws Exception {
 		IPackageFragment fragment= getRoot().createPackageFragment("org.test", true, null);
 
@@ -635,7 +632,7 @@ public class RenamePackageTests extends RefactoringTest {
 		fragment.createCompilationUnit("MyClass.java", buf.toString(), true, null);
 
 		IFile file= ((IFolder) fragment.getResource()).getFile("x.properties");
-		byte[] content= "This is about 'org.test' and more".getBytes();
+		byte[] content= "This is about 'org.test' and more".getBytes(ENCODING);
 		file.create(new ByteArrayInputStream(content), true, null);
 		file.refreshLocal(IResource.DEPTH_ONE, null);
 
@@ -663,6 +660,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void testPackageRenameWithResource3() throws Exception {
 		// regression test for https://bugs.eclipse.org/bugs/show_bug.cgi?id=108019
 		fIsPreDeltaTest= true;
@@ -674,23 +672,22 @@ public class RenamePackageTests extends RefactoringTest {
 		IFolder myPackFolder= getRoot().getJavaProject().getProject().getFolder("my").getFolder("pack");
 		CoreUtility.createFolder(myPackFolder, true, true, null);
 		IFile textfile= myPackFolder.getFile(textFileName);
-		textfile.create(new ByteArrayInputStream(textfileContent.getBytes()), true, null);
+		textfile.create(new ByteArrayInputStream(textfileContent.getBytes(ENCODING)), true, null);
 
 		helper2(new String[]{"my.pack", "my"}, new String[][]{{}, {}}, "my");
 
-		InputStreamReader reader= new InputStreamReader(textfile.getContents(true));
+
 		StringBuilder newContent= new StringBuilder();
-		try {
+		try (InputStreamReader reader= new InputStreamReader(textfile.getContents(true), ENCODING)){
 			int ch;
 			while((ch= reader.read()) != -1)
 				newContent.append((char)ch);
-		} finally {
-			reader.close();
 		}
 		String definedContent= getFileContents(getTestPath() + getName() + TEST_OUTPUT_INFIX + "my/" + textFileName);
 		assertEqualLines("invalid updating", definedContent, newContent.toString());
 	}
 
+	@Test
 	public void testHierarchical01() throws Exception {
 		fRenameSubpackages= true;
 
@@ -712,11 +709,9 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Ignore("BUG_PACKAGE_CANT_BE_RENAMED_TO_A_PACKAGE_THAT_ALREADY_EXISTS")
+	@Test
 	public void testHierarchical02() throws Exception {
-		if (BUG_PACKAGE_CANT_BE_RENAMED_TO_A_PACKAGE_THAT_ALREADY_EXISTS) {
-			printTestDisabledMessage("package can't be renamed to a package that already exists.");
-			return;
-		}
 		fRenameSubpackages= true;
 
 		PackageRename rename= new PackageRename(new String[]{"my", "my.a", "my.b", "your"}, new String[][]{{"MyA"},{"ATest"},{"B"}, {"Y"}}, "your");
@@ -750,6 +745,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void testHierarchical03() throws Exception {
 		fRenameSubpackages= true;
 		fUpdateTextualMatches= true;
@@ -780,6 +776,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void testHierarchicalToSubpackage() throws Exception {
 		fRenameSubpackages= true;
 
@@ -828,6 +825,7 @@ public class RenamePackageTests extends RefactoringTest {
 		rename.checkOriginalState();
 	}
 
+	@Test
 	public void testHierarchicalToSuperpackage() throws Exception {
 		fRenameSubpackages= true;
 
@@ -868,6 +866,7 @@ public class RenamePackageTests extends RefactoringTest {
 		rename.checkOriginalState();
 	}
 
+	@Test
 	public void testHierarchicalToSuperpackage2() throws Exception {
 		fRenameSubpackages= true;
 
@@ -910,6 +909,7 @@ public class RenamePackageTests extends RefactoringTest {
 		rename.checkOriginalState();
 	}
 
+	@Test
 	public void testHierarchicalToSuperpackageFail() throws Exception {
 		fRenameSubpackages= true;
 
@@ -924,6 +924,7 @@ public class RenamePackageTests extends RefactoringTest {
 		rename.checkOriginalState();
 	}
 
+	@Test
 	public void testHierarchicalDisabledImport() throws Exception {
 		fRenameSubpackages= true;
 		fUpdateTextualMatches= true;
@@ -946,6 +947,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void testHierarchicalJUnit() throws Exception {
 		fRenameSubpackages= true;
 
@@ -998,10 +1000,10 @@ public class RenamePackageTests extends RefactoringTest {
 		assertTrue(status.hasWarning());
 		for (RefactoringStatusEntry entry : status.getEntries()) {
 			assertTrue(entry.isWarning());
-			assertTrue(entry.getCode() == RefactoringStatusCodes.MAIN_METHOD);
+			assertEquals(RefactoringStatusCodes.MAIN_METHOD, entry.getCode());
 		}
 
-		assertTrue("package not renamed: " + rename.fPackageNames[0], ! src.getPackageFragment(rename.fPackageNames[0]).exists());
+		assertFalse("package not renamed: " + rename.fPackageNames[0], src.getPackageFragment(rename.fPackageNames[0]).exists());
 		IPackageFragment newPackage= src.getPackageFragment(rename.fNewPackageName);
 		assertTrue("new package does not exist", newPackage.exists());
 		// ---
@@ -1011,68 +1013,77 @@ public class RenamePackageTests extends RefactoringTest {
 		PerformChangeOperation performUndo= new PerformChangeOperation(undo);
 		ResourcesPlugin.getWorkspace().run(performUndo, new NullProgressMonitor());
 
-		assertTrue("new package still exists", ! newPackage.exists());
+		assertFalse("new package still exists", newPackage.exists());
 		assertTrue("original package does not exist: " + rename.fPackageNames[0], src.getPackageFragment(rename.fPackageNames[0]).exists());
 
 		ZipInputStream zis= new ZipInputStream(new BufferedInputStream(new FileInputStream(junitSrcArchive)));
 		ZipTools.compareWithZipped(src, zis, JavaProjectHelper.JUNIT_SRC_ENCODING);
 	}
 
+	@Test
 	public void testFail0() throws Exception{
 		helper1(new String[]{"r"}, new String[][]{{"A"}}, "9");
 	}
 
+	@Ignore("needs revisiting")
+	@Test
 	public void testFail1() throws Exception{
-		printTestDisabledMessage("needs revisiting");
-		//helper1(new String[]{"r.p1"}, new String[][]{{"A"}}, "r");
+		helper1(new String[]{"r.p1"}, new String[][]{{"A"}}, "r");
 	}
 
+	@Test
 	public void testFail3() throws Exception{
 		helper1(new String[]{"r"}, new String[][]{{"A"}}, "fred");
 	}
 
+	@Test
 	public void testFail4() throws Exception{
 		helper1();
 	}
 
+	@Test
 	public void testFail5() throws Exception{
 		helper1();
 	}
 
+	@Test
 	public void testFail6() throws Exception{
 		helper1();
 	}
 
+	@Ignore("corner case - name obscuring")
+	@Test
 	public void testFail7() throws Exception{
 		//printTestDisabledMessage("1GK90H4: ITPJCORE:WIN2000 - search: missing package reference");
-		printTestDisabledMessage("corner case - name obscuring");
-//		helper1(new String[]{"r", "p1"}, new String[][]{{"A"}, {"A"}}, "fred");
+		helper1(new String[]{"r", "p1"}, new String[][]{{"A"}, {"A"}}, "fred");
 	}
 
+	@Ignore("corner case - name obscuring")
+	@Test
 	public void testFail8() throws Exception{
-		printTestDisabledMessage("corner case - name obscuring");
-//		helper1(new String[]{"r", "p1"}, new String[][]{{"A"}, {"A"}}, "fred");
+		helper1(new String[]{"r", "p1"}, new String[][]{{"A"}, {"A"}}, "fred");
 	}
 
 	//native method used r.A as a parameter
+	@Ignore("corner case - qualified name used  as a parameter of a native method")
+	@Test
 	public void testFail9() throws Exception{
-		printTestDisabledMessage("corner case - qualified name used  as a parameter of a native method");
-		//helper1(new String[]{"r", "p1"}, new String[][]{{"A"}, {"A"}}, "fred");
+		helper1(new String[]{"r", "p1"}, new String[][]{{"A"}, {"A"}}, "fred");
 	}
 
+	@Test
 	public void testFail10() throws Exception{
 		helper1(new String[]{"r.p1", "r"}, new String[][]{{"A"}, {"A"}}, "r");
 	}
 
 	//-------
+//	@Ignore("bugs 54962, 71267")
+	@Test
 	public void test0() throws Exception{
-		if (BUG_54962_71267) {
-			printTestDisabledMessage("bugs 54962, 71267");
-			return;
-		}
 		fIsPreDeltaTest= true;
 	}
 
+	@Test
 	public void test1() throws Exception{
 		fIsPreDeltaTest= true;
 		RenamePackageProcessor proc= helper2(new String[]{"r"}, new String[][]{{"A"}}, "p1");
@@ -1102,6 +1113,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void test2() throws Exception{
 		fIsPreDeltaTest= true;
 		RenamePackageProcessor processor= helper2(new String[]{"r", "fred"}, new String[][]{{"A"}, {"A"}}, "p1");
@@ -1127,11 +1139,13 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void test3() throws Exception{
 		fIsPreDeltaTest= true;
 		helper2(new String[]{"fred", "r.r"}, new String[][]{{"A"}, {"B"}}, "r");
 	}
 
+	@Test
 	public void test4() throws Exception{
 		fIsPreDeltaTest= true;
 
@@ -1140,29 +1154,28 @@ public class RenamePackageTests extends RefactoringTest {
 
 		String textfileContent= getFileContents(getTestPath() + getName() + TEST_INPUT_INFIX + textFileName);
 		IFile textfile= getRoot().getJavaProject().getProject().getFile(textFileName);
-		textfile.create(new ByteArrayInputStream(textfileContent.getBytes()), true, null);
+		textfile.create(new ByteArrayInputStream(textfileContent.getBytes(ENCODING)), true, null);
 
 		helper2(new String[]{"r.p1", "r"}, new String[][]{{"A"}, {"A"}}, "q");
 
-		InputStreamReader reader= new InputStreamReader(textfile.getContents(true));
 		StringBuilder newContent= new StringBuilder();
-		try {
+		try (InputStreamReader reader= new InputStreamReader(textfile.getContents(true), ENCODING)){
 			int ch;
 			while((ch= reader.read()) != -1)
 				newContent.append((char)ch);
-		} finally {
-			reader.close();
 		}
 		String definedContent= getFileContents(getTestPath() + getName() + TEST_OUTPUT_INFIX + textFileName);
 		assertEqualLines("invalid updating", definedContent, newContent.toString());
 	}
 
+	@Test
 	public void test5() throws Exception{
 		fUpdateReferences= false;
 		fIsPreDeltaTest= true;
 		helper2(new String[]{"r"}, new String[][]{{"A"}}, "p1");
 	}
 
+	@Test
 	public void test6() throws Exception{ //bug 66250
 		fUpdateReferences= false;
 		fUpdateTextualMatches= true;
@@ -1170,18 +1183,22 @@ public class RenamePackageTests extends RefactoringTest {
 		helper2(new String[]{"r"}, new String[][]{{"A"}}, "p1");
 	}
 
+	@Test
 	public void test7() throws Exception{
 		helper2(new String[]{"r", "r.s"}, new String[][]{{"A"}, {"B"}}, "q");
 	}
 
+	@Test
 	public void test8() throws Exception{
 		helper2(new String[]{"java.lang.reflect"}, new String[][]{{"Klass"}}, "nonjava");
 	}
 
+	@Test
 	public void testToEmptyPack() throws Exception{
 		helper2(new String[]{"r.p1", "fred"}, new String[][] {{"A"}, {}}, "fred");
 	}
 
+	@Test
 	public void testToEmptySubPack() throws Exception{
 		fRenameSubpackages= true;
 
@@ -1207,6 +1224,7 @@ public class RenamePackageTests extends RefactoringTest {
 		));
 	}
 
+	@Test
 	public void testWithEmptySubPack() throws Exception{
 		fRenameSubpackages= true;
 
@@ -1232,11 +1250,9 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+//	@Ignore("see bug#6054 (renaming a read-only package resets the read-only flag)")
+	@Test
 	public void testReadOnly() throws Exception{
-		if (BUG_6054) {
-			printTestDisabledMessage("see bug#6054 (renaming a read-only package resets the read-only flag)");
-			return;
-		}
 
 		fIsPreDeltaTest= true;
 		String[] packageNames= new String[]{"r"};
@@ -1257,14 +1273,15 @@ public class RenamePackageTests extends RefactoringTest {
 		if (attributes != null)
 			attributes.setReadOnly(true);
 		RefactoringStatus result= performRefactoring(createRefactoringDescriptor(thisPackage, newPackageName));
-		assertEquals("preconditions were supposed to pass", null, result);
+		assertNull("preconditions were supposed to pass", result);
 
-		assertTrue("package not renamed", ! getRoot().getPackageFragment(packageNames[0]).exists());
+		assertFalse("package not renamed", getRoot().getPackageFragment(packageNames[0]).exists());
 		IPackageFragment newPackage= getRoot().getPackageFragment(newPackageName);
 		assertTrue("new package does not exist", newPackage.exists());
 		assertTrue("new package should be read-only", attributes == null || attributes.isReadOnly());
 	}
 
+	@Test
 	public void testImportFromMultiRoots1() throws Exception {
 		fUpdateTextualMatches= true;
 		helperProjectsPrgTest(
@@ -1278,6 +1295,7 @@ public class RenamePackageTests extends RefactoringTest {
 		});
 	}
 
+	@Test
 	public void testImportFromMultiRoots2() throws Exception {
 		helperProjectsPrgTest(
 				new String[][] {
@@ -1292,6 +1310,7 @@ public class RenamePackageTests extends RefactoringTest {
 			);
 	}
 
+	@Test
 	public void testImportFromMultiRoots3() throws Exception {
 		helperMultiRoots(new String[]{"srcPrg", "srcTest"},
 			new String[][] {
@@ -1306,6 +1325,7 @@ public class RenamePackageTests extends RefactoringTest {
 			);
 	}
 
+	@Test
 	public void testImportFromMultiRoots4() throws Exception {
 		//circular buildpath references
 		IJavaProject projectPrg= null;
@@ -1345,6 +1365,7 @@ public class RenamePackageTests extends RefactoringTest {
 		}
 	}
 
+	@Test
 	public void testImportFromMultiRoots5() throws Exception {
 		//rename srcTest-p.p to q => ATest now must import p.p.A
 		IJavaProject projectPrg= null;
@@ -1377,6 +1398,7 @@ public class RenamePackageTests extends RefactoringTest {
 
 	}
 
+	@Test
 	public void testImportFromMultiRoots6() throws Exception {
 		//rename srcTest-p.p to a.b.c => ATest must retain import p.p.A
 		helperMultiRoots(new String[]{"srcTest", "srcPrg"},
@@ -1392,6 +1414,7 @@ public class RenamePackageTests extends RefactoringTest {
 		);
 	}
 
+	@Test
 	public void testImportFromMultiRoots7() throws Exception {
 		IJavaProject prj= null;
 		IJavaProject prjRef= null;
@@ -1433,10 +1456,12 @@ public class RenamePackageTests extends RefactoringTest {
 		}
 	}
 
+	@Test
 	public void testStatic1() throws Exception {
 		helper2(new String[]{"s1.j.l", "s1"}, new String[][]{{"S"},{"B"}}, "s1.java.lang");
 	}
 
+	@Test
 	public void testStaticMultiRoots1() throws Exception {
 		helperProjectsPrgTest(
 			new String[][] {
