@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,20 +13,16 @@
  *******************************************************************************/
  package org.eclipse.jdt.ui.tests.refactoring.all;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 import org.eclipse.jdt.ui.tests.refactoring.reorg.AllReorgPerformanceTests;
 import org.eclipse.jdt.ui.tests.refactoring.type.AllTypeConstraintsPerformanceTests;
 
-public class AllRefactoringPerformanceTests extends TestCase {
-
-	public static Test suite() {
-		TestSuite suite= new TestSuite("All Refactoring Performance Tests"); //$NON-NLS-1$
-		suite.addTest(AllReorgPerformanceTests.suite());
-		suite.addTest(AllTypeConstraintsPerformanceTests.suite());
-		return suite;
-	}
-
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	AllReorgPerformanceTests.class,
+	AllTypeConstraintsPerformanceTests.class
+})
+public class AllRefactoringPerformanceTests {
 }
