@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2008 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,11 +19,7 @@ import org.eclipse.jdt.core.IPackageFragment;
 
 import org.eclipse.jdt.internal.corext.refactoring.rename.RenamePackageProcessor;
 
-public abstract class AbstractRenamePackagePerfTest extends RepeatingRefactoringPerformanceTestCase {
-
-	public AbstractRenamePackagePerfTest(String name) {
-		super(name);
-	}
+public abstract class AbstractRenamePackagePerfTest extends RepeatingRefactoringPerformanceTestCaseCommon {
 
 	@Override
 	protected void doExecuteRefactoring(int numberOfCus, int numberOfRefs, boolean measure) throws Exception {
