@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2012 IBM Corporation and others.
+ * Copyright (c) 2005, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,9 +16,8 @@ package org.eclipse.jdt.ui.tests.refactoring.type;
 import java.util.ArrayList;
 import java.util.List;
 
-import junit.framework.Test;
-
-import org.eclipse.test.OrderedTestSuite;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.ltk.core.refactoring.Refactoring;
 import org.eclipse.ltk.core.refactoring.participants.ProcessorBasedRefactoring;
@@ -32,7 +31,7 @@ import org.eclipse.jdt.internal.corext.refactoring.structure.ExtractInterfacePro
 
 import org.eclipse.jdt.ui.tests.performance.SWTTestProject;
 import org.eclipse.jdt.ui.tests.refactoring.infra.RefactoringHeapTestCase;
-import org.eclipse.jdt.ui.tests.refactoring.infra.RefactoringPerformanceTestSetup;
+import org.eclipse.jdt.ui.tests.refactoring.rules.RefactoringPerformanceTestSetup;
 
 import org.eclipse.jdt.internal.ui.preferences.JavaPreferencesSettings;
 
@@ -41,24 +40,11 @@ public class ExtractInterfaceHeapAcceptanceTests extends RefactoringHeapTestCase
 	private SWTTestProject fProject;
 	private Refactoring fRefactoring;
 
-	public static Test suite() {
-		// we must make sure that cold is executed before warm
-		OrderedTestSuite suite= new OrderedTestSuite(ExtractInterfaceHeapAcceptanceTests.class, new String[] {
-			"testExtractControl",
-		});
-        return new RefactoringPerformanceTestSetup(suite);
-	}
-
-	public static Test setUpTest(Test someTest) {
-		return new RefactoringPerformanceTestSetup(someTest);
-	}
-
-	public ExtractInterfaceHeapAcceptanceTests(String test) {
-		super(test);
-	}
+	@Rule
+	public RefactoringPerformanceTestSetup rpts= new RefactoringPerformanceTestSetup();
 
 	@Override
-	protected void setUp() throws Exception {
+	public void setUp() throws Exception {
 		super.setUp();
 		fProject= new SWTTestProject();
 		IType control= fProject.getProject().findType("org.eclipse.swt.widgets.Control");
@@ -79,11 +65,12 @@ public class ExtractInterfaceHeapAcceptanceTests extends RefactoringHeapTestCase
 	}
 
 	@Override
-	protected void tearDown() throws Exception {
+	public void tearDown() throws Exception {
 		fProject.delete();
 		super.tearDown();
 	}
 
+	@Test
 	public void testExtractControl() throws Exception {
 		executeRefactoring(fRefactoring, true);
 	}
