@@ -17,17 +17,14 @@ import java.util.ArrayList;
 
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.ui.leaktest.LeakTestCase;
 import org.eclipse.jdt.ui.tests.core.rules.LeakTestSetup;
 
-@RunWith(JUnit4.class)
 public class LeakTestExample extends LeakTestCase {
 
 	@Rule
-	public LeakTestSetup projectsetup = new LeakTestSetup();
+	public LeakTestSetup projectSetup = new LeakTestSetup();
 
 	private static class MyClass {
 	}
