@@ -14,8 +14,9 @@
 package org.eclipse.jdt.ui.tests.leaks;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
 
 import java.io.ByteArrayInputStream;
 
@@ -23,8 +24,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.util.DisplayHelper;
@@ -79,11 +78,10 @@ import org.eclipse.jdt.internal.ui.wizards.JavaProjectWizard;
 import org.eclipse.jdt.internal.ui.wizards.NewClassCreationWizard;
 import org.eclipse.jdt.internal.ui.wizards.NewInterfaceCreationWizard;
 
-@RunWith(JUnit4.class)
 public class JavaLeakTest extends LeakTestCase {
 
 	@Rule
-	public LeakTestSetup projectsetup = new LeakTestSetup();
+	public LeakTestSetup projectSetup = new LeakTestSetup();
 
 	private IJavaProject fJProject;
 
@@ -279,7 +277,7 @@ public class JavaLeakTest extends LeakTestCase {
 	public void setUp() throws Exception {
 		super.setUp();
 		fJProject= JavaProjectHelper.createJavaProject("TestProject1", "bin");
-		assertTrue("RT not found", JavaProjectHelper.addRTJar(fJProject) != null);
+		assertNotNull("RT not found", JavaProjectHelper.addRTJar(fJProject));
 		assertTrue(JavaPlugin.getActivePage().closeAllEditors(false));
 	}
 
@@ -367,8 +365,7 @@ public class JavaLeakTest extends LeakTestCase {
 
 			message= "\n" + listener;
 		}
-		if (message != null)
-			fail("Property listeners leaked:" + message);
+		assertNull("Property listeners leaked:" + message, message);
 	}
 
 	private void activateBreadcrumb(JavaEditor editor) {
@@ -453,12 +450,7 @@ public class JavaLeakTest extends LeakTestCase {
 
         menu.setVisible(true);
 
-		display.asyncExec(new Runnable() {
-            @Override
-			public void run() {
-                menu.setVisible(false);
-            }
-        });
+		display.asyncExec(() -> menu.setVisible(false));
 
         while (!menu.isDisposed() && display.readAndDispatch()) {
         	//loop, don't sleep
