@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2012 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,24 +14,25 @@
 
 package org.eclipse.jdt.ui.tests.performance.views;
 
+import static org.junit.Assert.assertNotNull;
+
 import java.io.File;
 import java.util.zip.ZipFile;
 
-import junit.extensions.TestSetup;
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.FixMethodOrder;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.ExternalResource;
+import org.junit.runners.MethodSorters;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
-import org.eclipse.test.OrderedTestSuite;
 
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.IProgressMonitor;
 
 import org.eclipse.core.resources.IFile;
 import org.eclipse.core.resources.IFolder;
 import org.eclipse.core.resources.IResource;
-import org.eclipse.core.resources.IResourceVisitor;
 import org.eclipse.core.resources.IWorkspaceRunnable;
 import org.eclipse.core.resources.ResourcesPlugin;
 
@@ -46,52 +47,42 @@ import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IPackageFragmentRoot;
 
 import org.eclipse.jdt.ui.JavaUI;
-import org.eclipse.jdt.ui.tests.performance.JdtPerformanceTestCase;
+import org.eclipse.jdt.ui.tests.performance.JdtPerformanceTestCaseCommon;
 
 import org.eclipse.jdt.internal.ui.packageview.PackageExplorerPart;
 
-public class PackageExplorerPerfTest extends JdtPerformanceTestCase {
+@FixMethodOrder(MethodSorters.NAME_ASCENDING)
+public class PackageExplorerPerfTest extends JdtPerformanceTestCaseCommon {
 
-	private static class MyTestSetup extends TestSetup {
+	private static class MyTestSetup extends ExternalResource {
 		public static final String SRC_CONTAINER= "src";
 
 		public static IJavaProject fJProject1;
 
-		public MyTestSetup(Test test) {
-			super(test);
-		}
 		@Override
-		protected void setUp() throws Exception {
+		public void before() throws Throwable {
 			fJProject1= JavaProjectHelper.createJavaProject("Testing", "bin");
 			// we must make sure that the performance test are compatible to 2.1.3 & 3.0 so use rt13
-			assertTrue("rt not found", JavaProjectHelper.addRTJar13(fJProject1) != null);
+			assertNotNull("rt not found", JavaProjectHelper.addRTJar13(fJProject1));
 			File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.JUNIT_SRC_381);
 			JavaProjectHelper.addSourceContainerWithImport(fJProject1, SRC_CONTAINER, junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 		}
 		@Override
-		protected void tearDown() throws Exception {
-			if (fJProject1 != null && fJProject1.exists())
-				JavaProjectHelper.delete(fJProject1);
+		public void after() {
+			try {
+				if (fJProject1 != null && fJProject1.exists())
+					JavaProjectHelper.delete(fJProject1);
+			} catch (Exception e) {
+				e.printStackTrace();
+			}
 		}
 	}
 
-	public static Test suite() {
-		TestSuite suite= new OrderedTestSuite(PackageExplorerPerfTest.class, new String[] {
-			"testOpen", "testSelect", "testExpand",
-			"testRefreshClassFolder"
-		});
-		return new MyTestSetup(suite);
-	}
+	@Rule
+	public MyTestSetup stup= new MyTestSetup();
 
-	public static Test setUpTest(Test someTest) {
-		return new MyTestSetup(someTest);
-	}
-
-	public PackageExplorerPerfTest(String name) {
-		super(name);
-	}
-
-	public void testOpen() throws Exception {
+	@Test
+	public void testAOpen() throws Exception {
 		IWorkbenchWindow activeWorkbenchWindow= PlatformUI.getWorkbench().getActiveWorkbenchWindow();
 		IWorkbenchPage page= activeWorkbenchWindow.getActivePage();
 		page.close();
@@ -102,7 +93,8 @@ public class PackageExplorerPerfTest extends JdtPerformanceTestCase {
 		finishMeasurements();
 	}
 
-	public void testSelect() throws Exception {
+	@Test
+	public void testBSelect() throws Exception {
 		joinBackgroudActivities();
 		TreeViewer viewer= getViewer();
 		StructuredSelection selection= new StructuredSelection(MyTestSetup.fJProject1);
@@ -111,7 +103,8 @@ public class PackageExplorerPerfTest extends JdtPerformanceTestCase {
 		finishMeasurements();
 	}
 
-	public void testExpand() throws Exception {
+	@Test
+	public void testCExpand() throws Exception {
 		joinBackgroudActivities();
 		TreeViewer viewer= getViewer();
 		startMeasuring();
@@ -120,7 +113,8 @@ public class PackageExplorerPerfTest extends JdtPerformanceTestCase {
 	}
 
 	// test for Bug 311212: [package explorer] Performance problem with refreshing external class folders
-	public void testRefreshClassFolder() throws Throwable {
+	@Test
+	public void testDRefreshClassFolder() throws Throwable {
 		// Import rtstubs a few times. Caveat: Only import class files, but not META-INF.
 		// PackageExplorerContentProvider#processResourceDelta(..) refreshes the parent if a resource changes.
 		// This is not what we want to test.
@@ -139,12 +133,7 @@ public class PackageExplorerPerfTest extends JdtPerformanceTestCase {
 			}
 		}
 
-		javaProject.getProject().getWorkspace().run(new IWorkspaceRunnable() {
-			@Override
-			public void run(IProgressMonitor monitor) throws CoreException {
-				javaProject.getProject().refreshLocal(IResource.DEPTH_INFINITE, null);
-			}
-		}, null);
+		javaProject.getProject().getWorkspace().run((IWorkspaceRunnable) monitor -> javaProject.getProject().refreshLocal(IResource.DEPTH_INFINITE, null), null);
 		getViewer().expandToLevel(classFolder, 1);
 
 		PackageExplorerPart view= getView();
@@ -162,15 +151,12 @@ public class PackageExplorerPerfTest extends JdtPerformanceTestCase {
 
 	private void touchAllFilesOnDisk(IFolder folder) throws CoreException {
 		final long now= System.currentTimeMillis();
-		folder.accept(new IResourceVisitor() {
-			@Override
-			public boolean visit(IResource resource) throws CoreException {
-				if (resource instanceof IFile) {
-					IFile file= (IFile) resource;
-					file.getRawLocation().toFile().setLastModified(now);
-				}
-				return true;
+		folder.accept(resource -> {
+			if (resource instanceof IFile) {
+				IFile file= (IFile) resource;
+				file.getRawLocation().toFile().setLastModified(now);
 			}
+			return true;
 		});
 	}
 
