@@ -286,9 +286,9 @@ public class TestPriorization extends TestCase {
 		collectOrder(reordered, order);
 
 		// can't check for exact order, since order of Class.getDeclaredMethods() is unspecified (bug 144503)
-		List<String> suiteTests= new ArrayList<>(Arrays.asList(new String[] { "testX", "testY", "testZ" }));
-		List<String> suite1Tests= new ArrayList<>(Arrays.asList(new String[] { "testA", "testB", "testC" }));
-		List<String> suite2Tests= new ArrayList<>(Arrays.asList(new String[] { "testD", "testE", "testF" }));
+		List<String> suiteTests= new ArrayList<>(Arrays.asList("testX", "testY", "testZ"));
+		List<String> suite1Tests= new ArrayList<>(Arrays.asList("testA", "testB", "testC"));
+		List<String> suite2Tests= new ArrayList<>(Arrays.asList("testD", "testE", "testF"));
 
 		assertEquals("testF", order.get(0));
 		assertEquals("testZ", order.get(6));
