@@ -496,6 +496,57 @@ public class AddImportTest extends CoreTests {
 		assertEqualString(cu.getSource(), buf.toString());
 	}
 
+	@Test
+	public void testAddImportStaticForSubclassReference() throws Exception {
+		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
+
+		IPackageFragment pack1= sourceFolder.createPackageFragment("test1", false, null);
+		StringBuilder buf= new StringBuilder();
+		buf.append("package test1;\n");
+		buf.append("public class T {\n");
+		buf.append("    public static void foo() { };\n");
+		buf.append("}\n");
+		pack1.createCompilationUnit("T.java", buf.toString(), false, null);
+
+		buf= new StringBuilder();
+		buf.append("package test1;\n");
+		buf.append("public class TSub extends T {\n");
+		buf.append("}\n");
+		pack1.createCompilationUnit("TSub.java", buf.toString(), false, null);
+
+		IPackageFragment pack2= sourceFolder.createPackageFragment("test2", false, null);
+		buf= new StringBuilder();
+		buf.append("package test2;\n");
+		buf.append("\n");
+		buf.append("import test1.TSub;\n");
+		buf.append("public class S {\n");
+		buf.append("    public S() {\n");
+		buf.append("        TSub.foo();\n");
+		buf.append("        TSub.foo();\n");
+		buf.append("    }\n");
+		buf.append("}\n");
+		ICompilationUnit cu= pack2.createCompilationUnit("S.java", buf.toString(), false, null);
+
+		int selOffset= buf.indexOf("foo");
+
+		AddImportsOperation op= new AddImportsOperation(cu, selOffset, 0, null, true);
+		op.run(null);
+
+		StringBuilder expectation= new StringBuilder();
+		expectation.append("package test2;\n");
+		expectation.append("\n");
+		expectation.append("import static test1.T.foo;\n");
+		expectation.append("\n");
+		expectation.append("import test1.TSub;\n");
+		expectation.append("public class S {\n");
+		expectation.append("    public S() {\n");
+		expectation.append("        foo();\n");
+		expectation.append("        TSub.foo();\n");
+		expectation.append("    }\n");
+		expectation.append("}\n");
+		assertEqualString(cu.getSource(), expectation.toString());
+	}
+
 	@Test
 	public void testImportStructureWithSignatures() throws Exception {
 
