@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2015 IBM Corporation and others.
+ * Copyright (c) 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,10 +13,17 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
 import org.eclipse.core.runtime.CoreException;
 
+import org.eclipse.jface.preference.IPreferenceStore;
+
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IMethod;
@@ -25,39 +32,39 @@ import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.ITypeParameter;
 import org.eclipse.jdt.core.JavaModelException;
-import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.IBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 
 import org.eclipse.jdt.ui.JavaElementLabels;
+import org.eclipse.jdt.ui.PreferenceConstants;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
+import org.eclipse.jdt.internal.ui.util.ASTHelper;
 import org.eclipse.jdt.internal.ui.viewsupport.JavaElementLinks;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-
 /**
  * This test suite is copied and adjusted from {@link JavaElementLabelsTest}
  */
 public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
-	private static final Class<BindingLabelsTest> THIS= BindingLabelsTest.class;
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
+	@Before
+	public void setUp() throws Exception {
+		fJProject1= pts.getProject();
 
-	public BindingLabelsTest(String name) {
-		super(name);
+		IPreferenceStore store= PreferenceConstants.getPreferenceStore();
+		store.setValue(PreferenceConstants.APPEARANCE_COMPRESS_PACKAGE_NAMES, false);
 	}
 
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fJProject1, pts.getDefaultClasspath());
 	}
 
+	@Test
 	public void testTypeLabelOuter() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -89,6 +96,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeLabelInner() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -127,6 +135,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeLabelLocal() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -163,6 +172,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeParameterLabelType() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -224,6 +234,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeParameterLabelMethod() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -262,6 +273,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		assertLinkMatch(lab, "NoBound - {{org.test.X}}.{{org.test.X|method}}({{org.test.X.method(...)|Element}}, NoBound)");
 	}
 
+	@Test
 	public void testTypeLabelAnonymous() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -298,6 +310,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeLabelAnonymousInAnonymous() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -344,6 +357,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeLabelAnonymousInFieldInitializer() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -378,6 +392,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeLabelAnonymousInInitializer() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -414,6 +429,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testTypeLabelWildcards() throws Exception {
 
 			IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -443,6 +459,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 
 		}
 
+	@Test
 	public void testPackageLabels() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -468,7 +485,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		IJavaElement t1= cu.getElementAt(content.indexOf("T1"));
 		IJavaElement t2= cu.getElementAt(content.indexOf("T2"));
 
-		ASTParser parser= ASTParser.newParser(AST.JLS8);
+		ASTParser parser= ASTParser.newParser(ASTHelper.JLS8);
 		parser.setResolveBindings(true);
 		parser.setProject(fJProject1);
 		IBinding[] bindings= parser.createBindings(new IJavaElement[]{main, t1, t2}, null);
@@ -549,6 +566,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
  */
 	}
 
+	@Test
 	public void testMethodLabelVarargsDeclaration() throws Exception {
 
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
@@ -581,6 +599,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		assertLinkMatch(lab, "foo(int, {{java.lang|String}}...)");
 	}
 
+	@Test
 	public void testMethodLabelVarargsReference0() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -617,14 +636,17 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		assertLinkMatch(lab, "asList({{java.lang|Object}}...)");
 	}
 
+	@Test
 	public void testMethodLabelVarargsReference1() throws Exception {
 		assertMethodLabelVarargsReference("1");
 	}
 
+	@Test
 	public void testMethodLabelVarargsReference2() throws Exception {
 		assertMethodLabelVarargsReference("1, 2");
 	}
 
+	@Test
 	public void testMethodLabelVarargsReference3() throws Exception {
 		assertMethodLabelVarargsReference("1, 2, Integer.valueOf(3)");
 	}
@@ -665,7 +687,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		assertLinkMatch(lab, "asList({{java.lang|Integer}}...)");
 	}
 
-
+	@Test
 	public void testMethodLabelAnnotatedParameters() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 		IPackageFragment pack1= sourceFolder.createPackageFragment("org.test", false, null);
@@ -705,6 +727,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 	}
 
 	// disabled, because we cannot retrieve a binding for the selected element: local variable inside instance initializer
+	@Test
 	public void testLocalClassInInitializer() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -741,6 +764,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 //		assertLinkMatch(lab, "{{org.test.LambdaTests}}.{...}.{{org.test.LambdaTests.{...}.|Local}}.Local()");
 	}
 
+	@Test
 	public void testLocalClassInStaticInitializer() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -772,6 +796,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		assertLinkMatch(lab, "{{org.test.LambdaTests.{...}|Local}} toStringL - {{org}}.{{test}}.{{LambdaTests}}.{...}");
 	}
 
+	@Test
 	public void testRecursiveType() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
@@ -796,6 +821,7 @@ public class BindingLabelsTest extends AbstractBindingLabelsTest {
 		assertLinkMatch(lab, "V extends {{java.lang|Comparable}}<? super V> - {{org.test.TypeTest}}.{{org.test.TypeTest|compare}}(V)");
 	}
 
+	@Test
 	public void testMultipleTypeVariables() throws Exception {
 		IPackageFragmentRoot sourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
