@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,11 +13,16 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+
 import java.io.File;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.JavaTestPlugin;
@@ -38,33 +43,21 @@ import org.eclipse.jdt.core.IPackageFragmentRoot;
 import org.eclipse.jdt.core.JavaCore;
 
 import org.eclipse.jdt.ui.PreferenceConstants;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
 import org.eclipse.jdt.internal.ui.util.CoreUtility;
 import org.eclipse.jdt.internal.ui.wizards.ClassPathDetector;
 
-
-public class ClassPathDetectorTest extends TestCase {
-
-	private static final Class<ClassPathDetectorTest> THIS= ClassPathDetectorTest.class;
+public class ClassPathDetectorTest {
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 
 	private boolean fEnableAutoBuildAfterTesting;
 
-	public ClassPathDetectorTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
-
-	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 
 		IWorkspace workspace= JavaTestPlugin.getWorkspace();
 		assertNotNull(workspace);
@@ -82,8 +75,8 @@ public class ClassPathDetectorTest extends TestCase {
 		fJProject1= null;
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		if (fJProject1 != null) {
 			JavaProjectHelper.delete(fJProject1);
 		}
@@ -104,7 +97,6 @@ public class ClassPathDetectorTest extends TestCase {
 		return true;
 	}
 
-
 	private IClasspathEntry findEntry(IClasspathEntry entry, IClasspathEntry[] entries) {
 		for (IClasspathEntry curr : entries) {
 			if (curr.getPath().equals(entry.getPath()) && curr.getEntryKind() == entry.getEntryKind()) {
@@ -126,7 +118,7 @@ public class ClassPathDetectorTest extends TestCase {
 		assertEquals("Number of classpath entries", projectEntries.length, entries.length);
 
 		for (IClasspathEntry curr : projectEntries) {
-			assertTrue("entry not found: " + curr.getPath(), findEntry(curr, entries) != null);
+			assertNotNull("entry not found: " + curr.getPath(), findEntry(curr, entries));
 		}
 	}
 
@@ -141,18 +133,21 @@ public class ClassPathDetectorTest extends TestCase {
 
 
 
-	public void testSourceAndLibrary() throws Exception {
+	@Test
+	public void sourceAndLibrary() throws Exception {
 		fJProject1= JavaProjectHelper.createJavaProject("TestProject1", "bin");
 
 		// source folder & internal JAR
 
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.JUNIT_SRC_381);
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("junit src not found", junitSrcArchive);
+		assertTrue("junit src not found", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 
 		File mylibJar= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.MYLIB);
-		assertTrue("lib not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("lib not found", junitSrcArchive);
+		assertTrue("lib not found", junitSrcArchive.exists());
 
 		JavaProjectHelper.addLibraryWithImport(fJProject1, Path.fromOSString(mylibJar.getPath()), null, null);
 
@@ -177,12 +172,14 @@ public class ClassPathDetectorTest extends TestCase {
 		assertTrue("Output folder", outputLocation.equals(projectOutput));
 	}
 
-	public void testTwoSourceFolders() throws Exception {
+	@Test
+	public void twoSourceFolders() throws Exception {
 		fJProject1= JavaProjectHelper.createJavaProject("TestProject1", "bin");
 		// 2 source folders
 
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.JUNIT_SRC_381);
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("junit src not found", junitSrcArchive);
+		assertTrue("junit src not found", junitSrcArchive.exists());
 
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src1", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 
@@ -218,12 +215,14 @@ public class ClassPathDetectorTest extends TestCase {
 		assertTrue("Output folder", outputLocation.equals(projectOutput));
 	}
 
-	public void testNestedSources() throws Exception {
+	@Test
+	public void nestedSources() throws Exception {
 		fJProject1= JavaProjectHelper.createJavaProject("TestProject1", "bin");
 		// 2 nested source folders
 
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.JUNIT_SRC_381);
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("junit src not found", junitSrcArchive);
+		assertTrue("junit src not found", junitSrcArchive.exists());
 
 		IPath[] exclusionFilter= new IPath[] { new Path("src2/") };
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "src1", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING, exclusionFilter);
@@ -260,13 +259,15 @@ public class ClassPathDetectorTest extends TestCase {
 		assertTrue("Output folder", outputLocation.equals(projectOutput));
 	}
 
-	public void testSourceAndOutputOnProject() throws Exception {
+	@Test
+	public void sourceAndOutputOnProject() throws Exception {
 		fJProject1= JavaProjectHelper.createJavaProject("TestProject1", "");
 
 		// source folder & internal JAR
 
 		File junitSrcArchive= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.JUNIT_SRC_381);
-		assertTrue("junit src not found", junitSrcArchive != null && junitSrcArchive.exists());
+		assertNotNull("junit src not found", junitSrcArchive);
+		assertTrue("junit src not found", junitSrcArchive.exists());
 		JavaProjectHelper.addSourceContainerWithImport(fJProject1, "", junitSrcArchive, JavaProjectHelper.JUNIT_SRC_ENCODING);
 
 		for (IClasspathEntry jreEntry : PreferenceConstants.getDefaultJRELibrary()) {
@@ -290,7 +291,8 @@ public class ClassPathDetectorTest extends TestCase {
 		assertTrue("Output folder", outputLocation.equals(projectOutput));
 	}
 
-	public void testClassFolder() throws Exception {
+	@Test
+	public void classFolder() throws Exception {
 		fJProject1= JavaProjectHelper.createJavaProject("TestProject1", "bin");
 		// class folder:
 
@@ -306,7 +308,8 @@ public class ClassPathDetectorTest extends TestCase {
 		pack1.createCompilationUnit("E.java", buf.toString(), false, null);
 
 		File lib= JavaTestPlugin.getDefault().getFileInPlugin(JavaProjectHelper.MYLIB);
-		assertTrue("lib not found", lib != null && lib.exists());
+		assertNotNull("lib not found", lib);
+		assertTrue("lib not found", lib.exists());
 
 		IPackageFragmentRoot cfroot= JavaProjectHelper.addClassFolderWithImport(fJProject1, "cf", null, null, lib);
 
@@ -331,5 +334,4 @@ public class ClassPathDetectorTest extends TestCase {
 		assertSameClasspath(projectEntries, entries);
 		assertTrue("Output folder", outputLocation.equals(projectOutput));
 	}
-
 }
