@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,10 +13,14 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
+import static org.junit.Assert.assertNotNull;
+
 import java.util.Hashtable;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -42,34 +46,24 @@ import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.formatter.CodeFormatter;
 import org.eclipse.jdt.core.formatter.DefaultCodeFormatterConstants;
 
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.util.CodeFormatterUtil;
 
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
+
 import org.eclipse.jdt.internal.ui.JavaPlugin;
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 
 public class CodeFormatterUtilTest extends CoreTests {
 
-	private static final Class<CodeFormatterUtilTest> THIS= CodeFormatterUtilTest.class;
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 
-	public CodeFormatterUtilTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
-
-
-	@Override
-	protected void setUp() throws Exception {
+	@Before
+	public void setUp() throws Exception {
 		fJProject1= JavaProjectHelper.createJavaProject("TestProject1", "bin");
-		JavaProjectHelper.addRequiredProject(fJProject1, ProjectTestSetup.getProject());
+		JavaProjectHelper.addRequiredProject(fJProject1, pts.getProject());
 
 		Hashtable<String, String> options= TestOptions.getDefaultOptions();
 		options.put(DefaultCodeFormatterConstants.FORMATTER_TAB_CHAR, JavaCore.SPACE);
@@ -78,9 +72,8 @@ public class CodeFormatterUtilTest extends CoreTests {
 		JavaCore.setOptions(options);
 	}
 
-
-	@Override
-	protected void tearDown() throws Exception {
+	@After
+	public void tearDown() throws Exception {
 		JavaProjectHelper.delete(fJProject1);
 	}
 
@@ -133,8 +126,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 	}
 
 
+	@Test
 	public void testCU() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -146,7 +140,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 		String formatted= CodeFormatterUtil.format(CodeFormatter.K_COMPILATION_UNIT, contents, 0, "\n", fJProject1);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -158,8 +152,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertEqualString(formatted, expected);
 	}
 
+	@Test
 	public void testCUIndented() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -171,7 +166,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 		String formatted= CodeFormatterUtil.format(CodeFormatter.K_COMPILATION_UNIT, contents, 1, "\n", fJProject1);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("    package test1;\n");
 		buf.append("    public class A {\n");
 		buf.append("        public void foo() {\n");
@@ -183,8 +178,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertEqualString(formatted, expected);
 	}
 
+	@Test
 	public void testCUNewAPI() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -199,7 +195,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		String formatted= doc.get();
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -211,8 +207,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertEqualString(formatted, expected);
 	}
 
+	@Test
 	public void testCUNewAPI2() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("/**\n");
@@ -230,7 +227,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		String formatted= doc.get();
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    /**\n");
@@ -245,8 +242,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertEqualString(formatted, expected);
 	}
 
+	@Test
 	public void testCUWithPos() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -264,7 +262,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -279,8 +277,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertEqualString(curr1, word1);
 	}
 
+	@Test
 	public void testPackage() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("  package   com . test1;");
 		String contents= buf.toString();
 
@@ -292,13 +291,14 @@ public class CodeFormatterUtilTest extends CoreTests {
 		Document document= new Document(contents);
 		edit.apply(document);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package com.test1;");
 		assertEqualString(document.get(), buf.toString());
 	}
 
+	@Test
 	public void testPackageWithPos() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package   com . test1;");
 		String contents= buf.toString();
 
@@ -318,7 +318,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package com.test1;");
 		String expected= buf.toString();
 		assertEqualString(formatted, expected);
@@ -331,8 +331,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVarDeclStatemenetWithPos() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("x[ ]=\nnew  int[ offset]");
 		String contents= buf.toString();
 
@@ -352,7 +353,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("x[] = new int[offset]");
 		String expected= buf.toString();
 		assertEqualString(formatted, expected);
@@ -365,8 +366,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testJavadoc() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("/** bar\n");
 		buf.append(" * foo\n");
 		buf.append(" */\n");
@@ -388,7 +390,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("/** bar\n");
 		buf.append(" * foo\n");
 		buf.append(" */\n");
@@ -403,8 +405,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testJavadoc2() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("/** bar\n");
 		buf.append(" * foo\n");
 		buf.append(" */");
@@ -426,7 +429,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("    /** bar\n");
 		buf.append("     * foo\n");
 		buf.append("     */");
@@ -441,8 +444,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testJavadoc3() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("/** bar\n");
 		buf.append(" * foo\n");
 		buf.append(" */");
@@ -465,7 +469,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("/** bar\r\n");
 		buf.append(" * foo\r\n");
 		buf.append(" */");
@@ -480,8 +484,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testCatchClause() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("catch\n");
 		buf.append("(Exception e) {\n");
 		buf.append("}");
@@ -503,7 +508,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append(" catch (Exception e) {\n");
 		buf.append("}");
 		String expected= buf.toString();
@@ -517,8 +522,9 @@ public class CodeFormatterUtilTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testCatchStringLiteral() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("\"Hello\" ");
 		String contents= buf.toString();
 
@@ -530,15 +536,16 @@ public class CodeFormatterUtilTest extends CoreTests {
 		Document document= new Document(contents);
 		edit.apply(document);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("\"Hello\"");
 		String expected= buf.toString();
 		assertEqualString(document.get(), expected);
 
 	}
 
+	@Test
 	public void testFormatSubstring() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("import java.util.Vector;\n");
@@ -572,7 +579,7 @@ public class CodeFormatterUtilTest extends CoreTests {
 		assertNotNull(edit);
 		String formatted= evaluateFormatterEdit(contents, edit, new Position[] { pos1, pos2, pos3});
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("\n");
 		buf.append("import java.util.Vector;\n");
