@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,10 +13,14 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core;
 
+import static org.junit.Assert.fail;
+
 import java.util.Hashtable;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -31,35 +35,25 @@ import org.eclipse.jdt.core.dom.ASTParser;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.IBinding;
 
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.dom.ScopeAnalyzer;
 
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
 /**
   */
 public class ScopeAnalyzerTest extends CoreTests {
 
-	private static final Class<ScopeAnalyzerTest> THIS= ScopeAnalyzerTest.class;
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 
-	public ScopeAnalyzerTest(String name) {
-		super(name);
-	}
+	@Before
+	public void setUp() throws Exception {
 
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	@Override
-	protected void setUp() throws Exception {
-
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= pts.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 
 		Hashtable<String, String> options= TestOptions.getDefaultOptions();
@@ -69,11 +63,12 @@ public class ScopeAnalyzerTest extends CoreTests {
 		JavaCore.setOptions(options);
 	}
 
-	@Override
-	protected void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+	@After
+	public void tearDown() throws Exception {
+		JavaProjectHelper.clear(fJProject1, pts.getDefaultClasspath());
 	}
 
+	@Test
 	public void testVariableDeclarations1() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
 		StringBuilder buf= new StringBuilder();
@@ -131,6 +126,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVariableDeclarations2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
 		StringBuilder buf= new StringBuilder();
@@ -212,6 +208,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVariableDeclarations3() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -258,9 +255,10 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVariableDeclarations4() throws Exception {
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("\n");
 		buf.append("public class Rectangle {\n");
@@ -270,7 +268,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 		pack0.createCompilationUnit("Rectangle.java", buf.toString(), false, null);
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1.ae;\n");
 		buf.append("import pack1.Rectangle;\n");
 		buf.append("public class E {\n");
@@ -297,10 +295,11 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVariableDeclarations5() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("pack1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package pack1;\n");
 		buf.append("\n");
 		buf.append("public interface IConstants {\n");
@@ -309,7 +308,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 		pack0.createCompilationUnit("IConstants.java", buf.toString(), false, null);
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1.ae;\n");
 		buf.append("public class E {\n");
 		buf.append("    private int fVar1, fVar2;\n");
@@ -357,6 +356,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVariableDeclarations6() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
 		StringBuilder buf= new StringBuilder();
@@ -439,6 +439,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testVariableDeclarations7() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -468,6 +469,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 		}
 	}
 
+	@Test
 	public void testSwitchOnEnum() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
 		StringBuilder buf= new StringBuilder();
@@ -508,6 +510,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 		}
 	}
 
+	@Test
 	public void testDeclarationsAfter() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -575,6 +578,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testTypeDeclarations1() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -651,6 +655,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testTypeDeclarations2() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -688,10 +693,11 @@ public class ScopeAnalyzerTest extends CoreTests {
 		}
 	}
 
+	@Test
 	public void testTypeDeclarationsTypeParameters() throws Exception {
 
 		IPackageFragment pack0= fSourceFolder.createPackageFragment("test0.ae", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1.ae;\n");
 		buf.append("public class H<M> {\n");
 		buf.append("}\n");
@@ -699,7 +705,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1.ae;\n");
 		buf.append("import test0.ae.H;\n");
 		buf.append("public class G<X, Y> extends H<String> {\n");
@@ -723,6 +729,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 		}
 	}
 
+	@Test
 	public void testClassInstanceCreation() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
 		StringBuilder buf= new StringBuilder();
@@ -759,6 +766,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 
 
+	@Test
 	public void testMethodDeclarations1() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -793,6 +801,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 
 	}
 
+	@Test
 	public void testMethodDeclarations2() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1.ae", false, null);
@@ -877,6 +886,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 		assertEqualStringsIgnoreOrder(names, expected);
 	}
 
+	@Test
 	public void testEnumConstantDeclaration1() throws Exception {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test", false, null);
@@ -906,7 +916,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 					return;
 				}
 			}
-			assertFalse("getDefaultValue not found", true);
+			fail("getDefaultValue not found");
 		}
 
 	}
@@ -926,7 +936,7 @@ public class ScopeAnalyzerTest extends CoreTests {
 			for (IProblem problem : problems) {
 				buf.append(problem.getMessage()).append('\n');
 			}
-			assertTrue(buf.toString(), false);
+			fail(buf.toString());
 		}
 	}
 
