@@ -13,12 +13,14 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.core.source;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
 import java.lang.reflect.Modifier;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-import org.junit.Assert;
+import org.junit.Ignore;
+import org.junit.Rule;
+import org.junit.Test;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
@@ -31,6 +33,7 @@ import org.eclipse.jdt.core.IField;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IMember;
 import org.eclipse.jdt.core.IMethod;
+import org.eclipse.jdt.core.IPackageFragment;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.IMethodBinding;
@@ -42,13 +45,12 @@ import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.internal.corext.codemanipulation.AddCustomConstructorOperation;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.refactoring.structure.ASTNodeSearchUtil;
 import org.eclipse.jdt.internal.corext.refactoring.util.RefactoringASTParser;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
-import org.eclipse.jdt.ui.tests.core.ProjectTestSetup;
-
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
+import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 
 /**
  * Tests generation of constructors using fields
@@ -57,20 +59,8 @@ import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
  *
  */
 public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
-
-	static final Class<GenerateConstructorUsingFieldsTest> THIS= GenerateConstructorUsingFieldsTest.class;
-
-	public GenerateConstructorUsingFieldsTest(String name) {
-		super(name);
-	}
-
-	public static Test suite() {
-		return setUpTest(new TestSuite(THIS));
-	}
-
-	public static Test setUpTest(Test test) {
-		return new ProjectTestSetup(test);
-	}
+	@Rule
+	public ProjectTestSetup pts= new ProjectTestSetup();
 
 	public void runOperation(IType type, IField[] fields, IMethod superConstructor, IJavaElement insertBefore, boolean createComments, boolean omitSuper, int visibility) throws CoreException {
 
@@ -81,7 +71,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 
 		IVariableBinding[] bindings= new IVariableBinding[fields.length];
 		for (int i= 0; i < fields.length; i++) {
-			Assert.assertTrue(fields[i].exists());
+			assertTrue(fields[i].exists());
 			VariableDeclarationFragment frag= ASTNodeSearchUtil.getFieldDeclarationFragmentNode(fields[i], unit);
 			bindings[i]= frag.resolveBinding();
 		}
@@ -138,6 +128,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test01() throws Exception {
 
 		runIt("A",
@@ -170,10 +161,10 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Ignore("see bug 113052 (import issue)")
+	@Test
 	public void test02() throws Exception {
 
-		printTestDisabledMessage("see bug 113052 (import issue)");
-
 //		ICompilationUnit pB= fPackageP.createCompilationUnit("B.java", "package p;\r\n" +
 //		"\r\n" +
 //		"public class B {\r\n" +
@@ -181,44 +172,44 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 //		"}\r\n" +
 //		"", true, null);
 
-//		IPackageFragment packageQ= fRoot.createPackageFragment("q", true, null);
-//		packageQ.createCompilationUnit("B.java", "package p;\r\n" +
-//		"\r\n" +
-//		"public class B {\r\n" +
-//		"\r\n" +
-//		"}\r\n" +
-//		"", true, null);
+		IPackageFragment packageQ= fRoot.createPackageFragment("q", true, null);
+		packageQ.createCompilationUnit("B.java", "package p;\r\n" +
+		"\r\n" +
+		"public class B {\r\n" +
+		"\r\n" +
+		"}\r\n" +
+		"", true, null);
 
-//		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
-//		"\r\n" +
-//		"public class A {\r\n" +
-//		"	q.B field1;\r\n" +
-//		"	B field2;\r\n" +
-//		"}\r\n" +
-//		"", true, null);
+		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
+		"\r\n" +
+		"public class A {\r\n" +
+		"	q.B field1;\r\n" +
+		"	B field2;\r\n" +
+		"}\r\n" +
+		"", true, null);
 
-//		IField f1= a.getType("A").getField("field1");
-//		IField f2= a.getType("A").getField("field2");
+		IField f1= a.getType("A").getField("field1");
+		IField f2= a.getType("A").getField("field2");
 
-//		runOperation(a.getType("A"), new IField[] { f1, f2 }, null);
+		runOperation(a.getType("A"), new IField[] { f1, f2 }, null);
 
-//		compareSource("package p;\r\n" +
-//		"\r\n" +
-//		"public class A {\r\n" +
-//		"	q.B field1;\r\n" +
-//		"	B field2;\r\n" +
-//		"	/**\r\n" +
-//		"	 * @param field1\r\n" +
-//		"	 * @param field2\r\n" +
-//		"	 */\r\n" +
-//		"	public A(q.B field1, B field2) {\r\n" +
-//		"		super();\r\n" +
-//		"		// TODO Auto-generated constructor stub\r\n" +
-//		"		this.field1 = field1;\r\n" +
-//		"		this.field2 = field2;\r\n" +
-//		"	}\r\n" +
-//		"}\r\n" +
-//		"", a.getSource());
+		compareSource("package p;\r\n" +
+		"\r\n" +
+		"public class A {\r\n" +
+		"	q.B field1;\r\n" +
+		"	B field2;\r\n" +
+		"	/**\r\n" +
+		"	 * @param field1\r\n" +
+		"	 * @param field2\r\n" +
+		"	 */\r\n" +
+		"	public A(q.B field1, B field2) {\r\n" +
+		"		super();\r\n" +
+		"		// TODO Auto-generated constructor stub\r\n" +
+		"		this.field1 = field1;\r\n" +
+		"		this.field2 = field2;\r\n" +
+		"	}\r\n" +
+		"}\r\n" +
+		"", a.getSource());
 	}
 
 	/**
@@ -226,6 +217,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test03() throws Exception {
 
 		runIt("A", new String[] { "firstField", "secondField", "beforeHandThirdField" },
@@ -267,6 +259,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test04() throws Exception {
 
 		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
@@ -305,6 +298,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test05() throws Exception {
 
 		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
@@ -334,6 +328,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test06() throws Exception {
 
 		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
@@ -363,6 +358,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test07() throws Exception {
 
 		ICompilationUnit a= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
@@ -391,6 +387,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test08() throws Exception {
 
 		fPackageP.createCompilationUnit("B.java", "package p;\r\n" +
@@ -439,6 +436,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test09() throws Exception {
 
 		runIt("A", new String[] { "field1" },
@@ -469,6 +467,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test10() throws Exception {
 
 		runIt("A", new String[] { "field1" },
@@ -498,6 +497,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test11() throws Exception {
 
 		runIt("A", new String[] { "startDate", "endDate" },
@@ -535,6 +535,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 * @throws Exception
 	 *
 	 */
+	@Test
 	public void test12() throws Exception {
 
 		ICompilationUnit unit= fPackageP.createCompilationUnit("SuperA.java", "package p;\r\n" +
@@ -584,6 +585,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 *
 	 * @throws Exception
 	 */
+	@Test
 	public void test13() throws Exception {
 
 		ICompilationUnit unit= fPackageP.createCompilationUnit("SuperA.java", "package p;\r\n" +
@@ -634,6 +636,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 	 * Inner types
 	 * @throws Exception
 	 */
+	@Test
 	public void test14() throws Exception {
 
 		ICompilationUnit unit= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
@@ -669,6 +672,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 				"}", unit.getSource());
 	}
 
+	@Test
 	public void test15() throws Exception {
 
 		ICompilationUnit unit= fPackageP.createCompilationUnit("A.java", "package p;\r\n" +
@@ -704,8 +708,9 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 				"", unit.getSource());
 	}
 
-	public void testInsertAt1() throws Exception {
-		StringBuffer buf= new StringBuffer();
+	@Test
+	public void insertAt1() throws Exception {
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("\n");
 		buf.append("public class A  {\n");
@@ -730,7 +735,7 @@ public class GenerateConstructorUsingFieldsTest extends SourceTestCase {
 
 		final int NUM_MEMBERS= 6;
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("public A(int x) {\n");
 		buf.append("		this.x = x;\n");
 		buf.append("	}");
