@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2013 IBM Corporation and others.
+ * Copyright (c) 2007, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,17 +14,13 @@
  *******************************************************************************/
 package org.eclipse.jdt.ui.tests.jarexport;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	PlainJarExportTests.class,
+	FatJarExportTests.class
+})
 public class JarExportTests {
-
-	public static Test suite() {
-		TestSuite suite= new TestSuite(JarExportTests.class.getName());
-		//$JUnit-BEGIN$
-		suite.addTest(PlainJarExportTests.suite());
-		suite.addTest(FatJarExportTests.suite());
-		//$JUnit-END$
-		return suite;
-	}
 }
