@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2018, 2020 IBM Corporation and others.
+ * Copyright (c) 2018, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -22,8 +22,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -47,15 +45,16 @@ import org.eclipse.jdt.ui.text.java.IJavaCompletionProposal;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.text.correction.AssistContext;
+import org.eclipse.jdt.internal.ui.text.correction.proposals.LinkedCorrectionProposal;
 import org.eclipse.jdt.internal.ui.text.correction.proposals.TypeChangeCorrectionProposal;
 
-@RunWith(JUnit4.class)
 public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new Java10ProjectTestSetup();
+    public ProjectTestSetup projectSetup= new Java10ProjectTestSetup();
 
 	private static final Class<?>[] TYPE_CHANGE_PROPOSAL_TYPE= { TypeChangeCorrectionProposal.class };
+	private static final Class<?>[] LINKED_PROPOSAL_TYPE= { LinkedCorrectionProposal.class };
 
 	private IJavaProject fJProject1;
 
@@ -89,25 +88,25 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 		StubUtility.setCodeTemplate(CodeTemplateContextType.METHODSTUB_ID, "//TODO\n${body_statement}", null);
 
-		fJProject1= Java10ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, Java10ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
 	@Test
 	public void testChangeVarTypeToBindingTypeProposal() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Cls {\n");
 		buf.append(" {\n");
@@ -125,7 +124,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Cls {\n");
 		buf.append(" {\n");
@@ -137,14 +136,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeTypeToVarTypeProposal() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Cls {\n");
 		buf.append(" {\n");
@@ -162,7 +161,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Cls {\n");
 		buf.append(" {\n");
@@ -175,14 +174,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeVarTypeToBindingTypeProposalWithTypeAnnotation() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("import java.lang.annotation.Target;\n\n");
@@ -205,7 +204,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("import java.lang.annotation.Target;\n\n");
@@ -222,14 +221,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeTypeToVarTypeProposalWithoutTypeAnnotation() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("import java.lang.annotation.Target;\n\n");
@@ -252,7 +251,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
 		buf.append("import java.lang.annotation.Target;\n\n");
@@ -270,14 +269,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeVarToTypeNoTypeChangeProposal() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n");
 		buf.append("public class Cls {\n");
 		buf.append(" {\n");
@@ -309,14 +308,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeTypeToVarChangeProposalRemoveUnusedImport() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.List;\n\n");
 		buf.append("public class Second {\n");
@@ -327,7 +326,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		pack.createCompilationUnit("Second.java", buf.toString(), false, null);
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.List;\n\n");
 		buf.append("public class Cls {\n");
@@ -346,7 +345,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("public class Cls {\n");
 		buf.append(" {\n");
@@ -358,14 +357,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeTypeToVarChangeProposalDonotRemoveUsedImport() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.List;\n\n");
 		buf.append("public class Second {\n");
@@ -376,7 +375,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		pack.createCompilationUnit("Second.java", buf.toString(), false, null);
 
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.List;\n\n");
 		buf.append("public class Cls {\n");
@@ -396,7 +395,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.List;\n\n");
 		buf.append("public class Cls {\n");
@@ -410,14 +409,14 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	@Test
 	public void testChangeParametrizedTypeToVarTypeProposalDoesNotLoseTypeArguments() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module test {\n");
 		buf.append("}\n");
 		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.ArrayList;\n\n");
 		buf.append("public class Cls {\n");
@@ -436,7 +435,7 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 		assertNumberOfProposals(proposals, 1);
 
 		String preview= getPreviewContent((TypeChangeCorrectionProposal) proposals.get(0));
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test;\n\n");
 		buf.append("import java.util.ArrayList;\n\n");
 		buf.append("public class Cls {\n");
@@ -448,6 +447,46 @@ public class AssistQuickFixTest10 extends QuickFixTest {
 
 	}
 
+	@Test
+	public void testConvertToForUsingIndexWithVar() throws Exception {
+		StringBuilder buf= new StringBuilder();
+		buf.append("module test {\n");
+		buf.append("}\n");
+		IPackageFragment def= fSourceFolder.createPackageFragment("", false, null);
+		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
+
+		IPackageFragment pack= fSourceFolder.createPackageFragment("test", false, null);
+		buf= new StringBuilder();
+		buf.append("package test;\n\n");
+		buf.append("public class Cls {\n");
+		buf.append("  public void foo() {\n");
+	    buf.append("    for (var y : new int[0]) {\n");
+	    buf.append("      System.out.println(y);\n");
+	    buf.append("    }\n");
+	    buf.append("  }\n");
+		buf.append("}\n");
+		ICompilationUnit cu= pack.createCompilationUnit("Cls.java", buf.toString(), false, null);
+
+		int offset= buf.toString().indexOf("for");
+
+		AssistContext context= getCorrectionContext(cu, offset, 3);
+		assertNoErrors(context);
+		List<IJavaCompletionProposal> proposals= getExpectedProposals(collectAssists(context, false), LINKED_PROPOSAL_TYPE);
+
+		buf= new StringBuilder();
+		buf.append("package test;\n\n");
+		buf.append("public class Cls {\n");
+		buf.append("  public void foo() {\n");
+	    buf.append("    var is = new int[0];\n");
+	    buf.append("    for (int i = 0; i < is.length; i++) {\n");
+	    buf.append("        var y = is[i];\n");
+	    buf.append("        System.out.println(y);\n");
+	    buf.append("    }\n");
+	    buf.append("  }\n");
+		buf.append("}\n");
+		assertExpectedExistInProposals(proposals, new String[] {buf.toString()});
+	}
+
 	private static final ArrayList<IJavaCompletionProposal> getExpectedProposals(ArrayList<IJavaCompletionProposal> proposals, Class<?>[] expectedTypes) {
 		ArrayList<IJavaCompletionProposal> expected= new ArrayList<>(proposals);
 		if (expectedTypes != null && expectedTypes.length > 0) {
