@@ -125,11 +125,10 @@ public class JarUtil {
                 flushDirectoryContent(dir);
             } else {
                 // remove only old sub-dirs
-                File[] testDirs = dir.listFiles();
-                for (int i=0,l=testDirs.length; i<l; i++) {
-                    if (testDirs[i].isDirectory()) {
-                        if ((now - testDirs[i].lastModified()) > delay) {
-                            delete(testDirs[i]);
+                for (File testDir : dir.listFiles()) {
+                    if (testDir.isDirectory()) {
+                        if ((now - testDir.lastModified()) > delay) {
+                            delete(testDir);
                         }
                     }
                 }
@@ -175,12 +174,7 @@ private static class Requestor implements ICompilerRequestor {
 			this.classFileFilter = classFileFilter;
 		} else {
 			// default: all without errors
-			this.classFileFilter = new ClassFileFilter() {
-				@Override
-				public boolean include(CompilationResult unitResult) {
-					return (unitResult != null) && !unitResult.hasErrors();
-				}
-			};
+			this.classFileFilter = unitResult -> (unitResult != null) && !unitResult.hasErrors();
 		}
 	}
 
@@ -192,11 +186,8 @@ private static class Requestor implements ICompilerRequestor {
 	}
 	protected void outputClassFiles(CompilationResult unitResult) {
 		if (this.classFileFilter.include(unitResult)) {
-			ClassFile[] classFiles = unitResult.getClassFiles();
 			if (this.outputPath != null) {
-				for (int i = 0, fileCount = classFiles.length; i < fileCount; i++) {
-					// retrieve the key and the corresponding classfile
-					ClassFile classFile = classFiles[i];
+				for (ClassFile classFile : unitResult.getClassFiles()) {
 					String relativeName =
 						new String(classFile.fileName()).replace('/', File.separatorChar) + ".class";
 					try {
@@ -326,8 +317,8 @@ public static boolean delete(File file) {
 public static void flushDirectoryContent(File dir) {
     File[] files = dir.listFiles();
     if (files == null) return;
-    for (int i = 0, max = files.length; i < max; i++) {
-        delete(files[i]);
+    for (File file : files) {
+        delete(file);
     }
 }
 private static Map<String, String> getCompileOptions(String compliance) {
@@ -389,12 +380,7 @@ public static String[] getJavaClassLibs() {
 		String[] jarsNames = null;
 		ArrayList<String> paths = new ArrayList<>();
 		if ("DRLVM".equals(vmName)) {
-			FilenameFilter jarFilter = new FilenameFilter() {
-				@Override
-				public boolean accept(File dir, String name) {
-					return name.endsWith(".jar") & !name.endsWith("-src.jar");
-				}
-			};
+			FilenameFilter jarFilter = (dir, name) -> name.endsWith(".jar") & !name.endsWith("-src.jar");
 			jarsNames = new File(jreDir + "/lib/boot/").list(jarFilter);
 			addJarEntries(jreDir + "/lib/boot/", jarsNames, paths);
 		} else {
@@ -414,8 +400,8 @@ public static String[] getJavaClassLibs() {
 	return jars;
 }
 private static void addJarEntries(String jreDir, String[] jarNames, ArrayList<String> paths) {
-	for (int i = 0, max = jarNames.length; i < max; i++) {
-		final String currentName = jreDir + jarNames[i];
+	for (String jarName : jarNames) {
+		final String currentName = jreDir + jarName;
 		File f = new File(currentName);
 		if (f.exists()) {
 			paths.add(toNativePath(currentName));
@@ -453,11 +439,9 @@ private static File getParentChildFile(File file) {
     int length = files==null ? 0 : files.length;
     if (length > 0) {
         for (int i=0; i<length; i++) {
-            if (files[i] == file) {
-                return files[i];
-            } else if (files[i].equals(file)) {
-                return files[i];
-            } else if (files[i].getPath().equals(file.getPath())) {
+            if (files[i] == file
+                    || files[i].equals(file)
+                    || files[i].getPath().equals(file.getPath())) {
                 return files[i];
             }
         }
@@ -733,8 +717,7 @@ public static void zip(File rootDir, String zipPath) throws IOException {
 private static void zip(File dir, ZipOutputStream zip, int rootPathLength) throws IOException {
     File[] files = dir.listFiles();
     if (files != null) {
-        for (int i = 0, length = files.length; i < length; i++) {
-            File file = files[i];
+        for (File file : files) {
             if (file.isFile()) {
                 String path = file.getPath();
                 path = path.substring(rootPathLength);
@@ -748,4 +731,7 @@ private static void zip(File dir, ZipOutputStream zip, int rootPathLength) throw
         }
     }
 }
+
+	private JarUtil() {
+	}
 }
