@@ -20,8 +20,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 
@@ -44,11 +42,10 @@ import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 import org.eclipse.jdt.ui.text.java.IJavaCompletionProposal;
 import org.eclipse.jdt.ui.text.java.correction.CUCorrectionProposal;
 
-@RunWith(JUnit4.class)
 public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new Java9ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new Java9ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 
@@ -64,14 +61,14 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		IPackageFragmentRoot java9Src= JavaProjectHelper.addSourceContainer(fJProject2, "src");
 		IPackageFragment def= java9Src.createPackageFragment("", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("module annots {\n");
 		buf.append("     exports annots; \n");
 		buf.append("}\n");
 		def.createCompilationUnit("module-info.java", buf.toString(), false, null);
 
 		IPackageFragment annots= java9Src.createPackageFragment("annots", false, null);
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package annots;\n");
 		buf.append("\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
@@ -82,7 +79,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 		buf.append("}\n");
 		annots.createCompilationUnit("Nullable.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package annots;\n");
 		buf.append("\n");
 		buf.append("import java.lang.annotation.ElementType;\n");
@@ -93,7 +90,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 		buf.append("}\n");
 		annots.createCompilationUnit("NonNull.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package annots;\n");
 		buf.append("\n");
 		buf.append("public enum DefaultLocation {\n");
@@ -102,7 +99,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 		buf.append("");
 		annots.createCompilationUnit("DefaultLocation.java", buf.toString(), false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package annots;\n");
 		buf.append("\n");
 		buf.append("import static annots.DefaultLocation.*;\n");
@@ -146,7 +143,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 	@Test
 	public void testBug530580a() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("@annots.NonNullByDefault module test {\n");
 		buf.append(" requires annots;");
 		buf.append("}\n");
@@ -155,7 +152,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
 		buf.append("import annots.*;\n");
@@ -178,7 +175,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
 		buf.append("import annots.*;\n");
@@ -200,7 +197,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
 		buf.append("import annots.*;\n");
@@ -220,7 +217,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Map;\n");
 		buf.append("import annots.*;\n");
@@ -236,7 +233,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 	}
 	@Test
 	public void testBug530580b() throws Exception {
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("@annots.NonNullByDefault module test {\n");
 		buf.append(" requires annots;");
 		buf.append("}\n");
@@ -245,7 +242,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import annots.*;\n");
 		buf.append("\n");
@@ -269,7 +266,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import annots.*;\n");
 		buf.append("\n");
@@ -290,7 +287,7 @@ public class NullAnnotationsQuickFixTest9 extends QuickFixTest {
 
 		preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import annots.*;\n");
 		buf.append("\n");
