@@ -20,8 +20,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -38,18 +36,17 @@ import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.ui.tests.core.rules.ProjectTestSetup;
 import org.eclipse.jdt.ui.text.java.IJavaCompletionProposal;
 
-@RunWith(JUnit4.class)
 public class QuickFixEnablementTest extends QuickFixTest {
 
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup = new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
 
 	@Before
 	public void setUp() throws Exception {
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
@@ -58,7 +55,7 @@ public class QuickFixEnablementTest extends QuickFixTest {
 	@After
 	public void tearDown() throws Exception {
 		TestOptions.initializeProjectOptions(fJProject1);
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
 
@@ -71,7 +68,7 @@ public class QuickFixEnablementTest extends QuickFixTest {
 
 		// quick fix is contributed only for files with name 'A.java' in a 1.5 project
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -87,7 +84,7 @@ public class QuickFixEnablementTest extends QuickFixTest {
 
 		String[] previewContents= getPreviewContents(proposals);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -103,7 +100,7 @@ public class QuickFixEnablementTest extends QuickFixTest {
 	public void testContributedQuickFix2() throws Exception {
 		// quick fix is contributed only for files with name 'A.java' in a 1.5 project
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class A {\n");
 		buf.append("    public void foo() {\n");
@@ -124,7 +121,7 @@ public class QuickFixEnablementTest extends QuickFixTest {
 
 		assertNumberOfProposals(collectCorrections(cu, getASTRoot(cu)), 0); // wrong version
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class B {\n");
 		buf.append("    public void foo() {\n");
