@@ -17,13 +17,12 @@ import static org.junit.Assert.assertTrue;
 
 import java.util.ArrayList;
 import java.util.Hashtable;
+import java.util.List;
 
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.runner.RunWith;
-import org.junit.runners.JUnit4;
 
 import org.eclipse.jdt.testplugin.JavaProjectHelper;
 import org.eclipse.jdt.testplugin.TestOptions;
@@ -46,11 +45,9 @@ import org.eclipse.jdt.ui.text.java.correction.CUCorrectionProposal;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 
-@RunWith(JUnit4.class)
 public class ReturnTypeQuickFixTest extends QuickFixTest {
-
 	@Rule
-    public ProjectTestSetup projectsetup = new ProjectTestSetup();
+    public ProjectTestSetup projectSetup= new ProjectTestSetup();
 
 	private IJavaProject fJProject1;
 	private IPackageFragmentRoot fSourceFolder;
@@ -66,22 +63,20 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		IPreferenceStore store= JavaPlugin.getDefault().getPreferenceStore();
 		store.setValue(PreferenceConstants.CODEGEN_ADD_COMMENTS, false);
 
-		fJProject1= ProjectTestSetup.getProject();
+		fJProject1= projectSetup.getProject();
 
 		fSourceFolder= JavaProjectHelper.addSourceContainer(fJProject1, "src");
 	}
 
-
 	@After
 	public void tearDown() throws Exception {
-		JavaProjectHelper.clear(fJProject1, ProjectTestSetup.getDefaultClasspath());
+		JavaProjectHelper.clear(fJProject1, projectSetup.getDefaultClasspath());
 	}
 
-
 	@Test
 	public void testReturnTypeMissingWithSimpleType() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class E {\n");
@@ -98,8 +93,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 		boolean addReturnType= true, doRename= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			Object elem= proposals.get(i);
+		for (IJavaCompletionProposal elem : proposals) {
 			if (elem instanceof ASTRewriteCorrectionProposal) {
 				ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) elem;
 				assertTrue("duplicated entries", addReturnType);
@@ -107,7 +101,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				String preview= getPreviewContent(proposal);
 
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("import java.util.Enumeration;\n");
 				buf.append("import java.util.Vector;\n");
@@ -123,7 +117,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) elem;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("import java.util.Vector;\n");
 				buf.append("public class E {\n");
@@ -140,7 +134,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissingWithVoid() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public foo() {\n");
@@ -156,8 +150,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 		boolean addReturnType= true, doRename= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			Object elem= proposals.get(i);
+		for (IJavaCompletionProposal elem : proposals) {
 			if (elem instanceof ASTRewriteCorrectionProposal) {
 				ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) elem;
 				assertTrue("duplicated entries", addReturnType);
@@ -165,7 +158,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				String preview= getPreviewContent(proposal);
 
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public void foo() {\n");
@@ -179,7 +172,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) elem;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public E() {\n");
@@ -196,7 +189,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissing() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public interface E {\n");
 		buf.append("    public foo();\n");
@@ -211,7 +204,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public interface E {\n");
 		buf.append("    public void foo();\n");
@@ -226,7 +219,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissingWithVoid2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public foo() {\n");
@@ -245,8 +238,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 		boolean addReturnType= true, doRename= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			Object elem= proposals.get(i);
+		for (IJavaCompletionProposal elem : proposals) {
 			if (elem instanceof ASTRewriteCorrectionProposal) {
 				ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) elem;
 				assertTrue("duplicated entries", addReturnType);
@@ -254,7 +246,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				String preview= getPreviewContent(proposal);
 
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public void foo() {\n");
@@ -271,7 +263,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) elem;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public E() {\n");
@@ -289,7 +281,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testVoidMissingInAnonymousType() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -312,7 +304,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void foo() {\n");
@@ -331,7 +323,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissingWithNull() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public foo() {\n");
@@ -347,8 +339,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 		boolean addReturnType= true, doRename= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			Object elem= proposals.get(i);
+		for (IJavaCompletionProposal elem : proposals) {
 			if (elem instanceof ASTRewriteCorrectionProposal) {
 				ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) elem;
 				assertTrue("duplicated entries", addReturnType);
@@ -356,7 +347,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				String preview= getPreviewContent(proposal);
 
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public Object foo() {\n");
@@ -370,7 +361,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) elem;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public E() {\n");
@@ -385,7 +376,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissingWithArrayType() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public foo() {\n");
@@ -401,8 +392,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 		boolean addReturnType= true, doRename= true;
 
-		for (int i= 0; i < proposals.size(); i++) {
-			Object elem= proposals.get(i);
+		for (IJavaCompletionProposal elem : proposals) {
 			if (elem instanceof ASTRewriteCorrectionProposal) {
 				ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) elem;
 				assertTrue("duplicated entries", addReturnType);
@@ -410,7 +400,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				String preview= getPreviewContent(proposal);
 
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public int[][] foo() {\n");
@@ -424,7 +414,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 
 				CUCorrectionProposal proposal= (CUCorrectionProposal) elem;
 				String preview= getPreviewContent(proposal);
-				buf= new StringBuffer();
+				buf= new StringBuilder();
 				buf.append("package test1;\n");
 				buf.append("public class E {\n");
 				buf.append("    public E() {\n");
@@ -439,7 +429,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testVoidMethodReturnsStatement() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.Vector;\n");
 		buf.append("public class E {\n");
@@ -459,7 +449,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 			ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 			String preview= getPreviewContent(proposal);
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("package test1;\n");
 			buf.append("import java.util.Vector;\n");
 			buf.append("public class E {\n");
@@ -474,7 +464,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 			ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 			String preview= getPreviewContent(proposal);
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("package test1;\n");
 			buf.append("import java.util.Vector;\n");
 			buf.append("public class E {\n");
@@ -490,7 +480,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testVoidMethodReturnsAnonymClass() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void getOperation() {\n");
@@ -509,7 +499,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public Runnable getOperation() {\n");
@@ -523,7 +513,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void getOperation() {\n");
@@ -538,7 +528,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissingWithWildcardSuper() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -556,7 +546,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -569,7 +559,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (CUCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -585,7 +575,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testReturnTypeMissingWithWildcardExtends() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -604,7 +594,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		CUCorrectionProposal proposal= (CUCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -618,7 +608,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (CUCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -635,7 +625,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testConstructorReturnsValue() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public E() {\n");
@@ -653,7 +643,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 			ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 			String preview= getPreviewContent(proposal);
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("package test1;\n");
 			buf.append("\n");
 			buf.append("import java.util.Properties;\n");
@@ -669,7 +659,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 			ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 			String preview= getPreviewContent(proposal);
 
-			buf= new StringBuffer();
+			buf= new StringBuilder();
 			buf.append("package test1;\n");
 			buf.append("public class E {\n");
 			buf.append("    public E() {\n");
@@ -683,7 +673,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testVoidMethodReturnsWildcardSuper() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -701,7 +691,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -714,7 +704,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -730,7 +720,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testVoidMethodReturnsWildcardExtends() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -748,7 +738,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -761,7 +751,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("import java.util.ArrayList;\n");
 		buf.append("public class E {\n");
@@ -778,7 +768,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testCorrectReturnStatement() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public Runnable getOperation() {\n");
@@ -795,7 +785,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public Runnable getOperation() {\n");
@@ -807,7 +797,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void getOperation() {\n");
@@ -819,10 +809,123 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		assertEqualStringsIgnoreOrder(new String[] { preview1, preview2 }, new String[] { expected1, expected2 });
 	}
 
+	@Test
+	public void testCorrectReturnStatementInConditional() throws Exception {
+		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
+		String input= "" //
+				+ "package test1;\n" //
+				+ "\n" //
+				+ "import java.util.Map;\n" //
+				+ "\n" //
+				+ "public class E {\n" //
+				+ "    <K1, K2, V> V foo(K1 key1, Map<K1, Map<K2, V>> map) {\n" //
+				+ "        Map<K2, V> map2 = map.get(key1);\n" //
+				+ "        return map2 == null ? null : map2.entrySet();\n" //
+				+ "    }\n" //
+				+ "}\n"; //
+		ICompilationUnit cu= pack1.createCompilationUnit("E.java", input, false, null);
+
+		CompilationUnit astRoot= getASTRoot(cu);
+		List<IJavaCompletionProposal> proposals= collectCorrections(cu, astRoot);
+		assertNumberOfProposals(proposals, 2);
+		assertCorrectLabels(proposals);
+
+		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
+		String preview1= getPreviewContent(proposal);
+
+		String expected1= "" //
+				+ "package test1;\n" //
+				+ "\n" //
+				+ "import java.util.Map;\n" //
+				+ "\n" //
+				+ "public class E {\n" //
+				+ "    <K1, K2, V> V foo(K1 key1, Map<K1, Map<K2, V>> map) {\n" //
+				+ "        Map<K2, V> map2 = map.get(key1);\n" //
+				+ "        return (V) (map2 == null ? null : map2.entrySet());\n" //
+				+ "    }\n" //
+				+ "}\n"; //
+
+		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
+		String preview2= getPreviewContent(proposal);
+
+		String expected2= "" //
+				+ "package test1;\n" //
+				+ "\n" //
+				+ "import java.util.Map;\n" //
+				+ "import java.util.Map.Entry;\n" //
+				+ "import java.util.Set;\n" //
+				+ "\n" //
+				+ "public class E {\n" //
+				+ "    <K1, K2, V> Set<Entry<K2, V>> foo(K1 key1, Map<K1, Map<K2, V>> map) {\n" //
+				+ "        Map<K2, V> map2 = map.get(key1);\n" //
+				+ "        return map2 == null ? null : map2.entrySet();\n" //
+				+ "    }\n" //
+				+ "}\n"; //
+
+		assertEqualStringsIgnoreOrder(new String[] { preview1, preview2 }, new String[] { expected1, expected2 });
+	}
+
+	@Test
+	public void testCorrectReturnStatementInChainedConditional() throws Exception {
+		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
+
+		String input= "" //
+				+ "package test1;\n" //
+				+ "\n" //
+				+ "import java.util.Map;\n" //
+				+ "\n" //
+				+ "public class E {\n" //
+				+ "    <K1, K2, V> V foo(K1 key1, Map<K1, Map<K2, V>> aMap) {\n" //
+				+ "        Map<K2, V> newMap = aMap.get(key1);\n" //
+				+ "        return newMap == null ? null : aMap == null ? null : newMap.entrySet();\n" //
+				+ "    }\n" //
+				+ "}\n"; //
+		ICompilationUnit cu= pack1.createCompilationUnit("E.java", input, false, null);
+
+		CompilationUnit astRoot= getASTRoot(cu);
+		List<IJavaCompletionProposal> proposals= collectCorrections(cu, astRoot);
+		assertNumberOfProposals(proposals, 2);
+		assertCorrectLabels(proposals);
+
+		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
+		String preview1= getPreviewContent(proposal);
+
+		String expected1= "" //
+				+ "package test1;\n" //
+				+ "\n" //
+				+ "import java.util.Map;\n" //
+				+ "\n" //
+				+ "public class E {\n" //
+				+ "    <K1, K2, V> V foo(K1 key1, Map<K1, Map<K2, V>> aMap) {\n" //
+				+ "        Map<K2, V> newMap = aMap.get(key1);\n" //
+				+ "        return (V) (newMap == null ? null : aMap == null ? null : newMap.entrySet());\n" //
+				+ "    }\n" //
+				+ "}\n"; //
+
+		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
+		String preview2= getPreviewContent(proposal);
+
+		String expected2= "" //
+				+ "package test1;\n" //
+				+ "\n" //
+				+ "import java.util.Map;\n" //
+				+ "import java.util.Map.Entry;\n" //
+				+ "import java.util.Set;\n" //
+				+ "\n" //
+				+ "public class E {\n" //
+				+ "    <K1, K2, V> Set<Entry<K2, V>> foo(K1 key1, Map<K1, Map<K2, V>> aMap) {\n" //
+				+ "        Map<K2, V> newMap = aMap.get(key1);\n" //
+				+ "        return newMap == null ? null : aMap == null ? null : newMap.entrySet();\n" //
+				+ "    }\n" //
+				+ "}\n"; //
+
+		assertEqualStringsIgnoreOrder(new String[] { preview1, preview2 }, new String[] { expected1, expected2 });
+	}
+
 	@Test
 	public void testReturnVoid() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    /**\n");
@@ -844,7 +947,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    /**\n");
@@ -865,7 +968,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testCorrectReturnStatementForArray() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public int[][] getArray() {\n");
@@ -882,7 +985,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public int[][] getArray() {\n");
@@ -894,7 +997,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void getArray() {\n");
@@ -909,7 +1012,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMethodWithConstructorName() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public int[][] E() {\n");
@@ -926,7 +1029,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public E() {\n");
@@ -939,7 +1042,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMissingReturnStatement() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public int[][] getArray() {\n");
@@ -955,7 +1058,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public int[][] getArray() {\n");
@@ -967,7 +1070,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void getArray() {\n");
@@ -981,7 +1084,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMissingReturnStatementWithCode() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    private int[] fArray;\n");
@@ -1000,7 +1103,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    private int[] fArray;\n");
@@ -1015,7 +1118,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    private int[] fArray;\n");
@@ -1032,7 +1135,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMissingReturnStatementWithCode2() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public boolean isVisible() {\n");
@@ -1052,7 +1155,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public boolean isVisible() {\n");
@@ -1068,7 +1171,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		proposal= (ASTRewriteCorrectionProposal) proposals.get(1);
 		String preview2= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public void isVisible() {\n");
@@ -1086,7 +1189,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMissingReturnStatementWithCode3() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public String getDebugInfo() {\n");
@@ -1103,7 +1206,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public String getDebugInfo() {\n");
@@ -1119,7 +1222,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMissingReturnStatementWithCode4() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("test1", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public String getDebugInfo() {\n");
@@ -1136,7 +1239,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		ASTRewriteCorrectionProposal proposal= (ASTRewriteCorrectionProposal) proposals.get(0);
 		String preview1= getPreviewContent(proposal);
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package test1;\n");
 		buf.append("public class E {\n");
 		buf.append("    public String getDebugInfo() {\n");
@@ -1153,7 +1256,7 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 	@Test
 	public void testMethodInEnum_bug239887() throws Exception {
 		IPackageFragment pack1= fSourceFolder.createPackageFragment("p", false, null);
-		StringBuffer buf= new StringBuffer();
+		StringBuilder buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("enum Bug {X;\n");
 		buf.append("        wrap(){}\n");
@@ -1167,14 +1270,14 @@ public class ReturnTypeQuickFixTest extends QuickFixTest {
 		assertNumberOfProposals(proposals, 2);
 
 		String[] expected= new String[2];
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("enum Bug {X;\n");
 		buf.append("        void wrap(){}\n");
 		buf.append("}\n");
 		expected[0]= buf.toString();
 
-		buf= new StringBuffer();
+		buf= new StringBuilder();
 		buf.append("package p;\n");
 		buf.append("enum Bug {X;\n");
 		buf.append("        Bug(){}\n");
