@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -228,6 +228,34 @@ public class JUnitLaunchConfigurationDelegate extends AbstractJavaLaunchConfigur
 									new Status(IStatus.ERROR, JUnitTestPlugin.PLUGIN_ID, IStatus.ERROR, "", e)); //$NON-NLS-1$
 						}
 					}
+					if (!Arrays.stream(classpath).anyMatch(
+							s -> s.contains("junit-jupiter-engine") || s.contains("org.junit.jupiter.engine"))) { //$NON-NLS-1$ //$NON-NLS-2$
+						try {
+							JUnitRuntimeClasspathEntry x = new JUnitRuntimeClasspathEntry("junit-jupiter-engine", //$NON-NLS-1$
+									null);
+							String entryString = new ClasspathLocalizer(false).entryString(x);
+							int length = classpath.length;
+							System.arraycopy(classpath, 0, classpath = new String[length + 1], 0, length);
+							classpath[length] = entryString;
+						} catch (IOException | URISyntaxException e) {
+							throw new CoreException(
+									new Status(IStatus.ERROR, JUnitCorePlugin.CORE_PLUGIN_ID, IStatus.ERROR, "", e)); //$NON-NLS-1$
+						}
+					}
+					if (!Arrays.stream(classpath)
+							.anyMatch(s -> s.contains("junit-jupiter-api") || s.contains("org.junit.jupiter.api"))) { //$NON-NLS-1$ //$NON-NLS-2$
+						try {
+							JUnitRuntimeClasspathEntry x = new JUnitRuntimeClasspathEntry("junit-jupiter-api", //$NON-NLS-1$
+									null);
+							String entryString = new ClasspathLocalizer(false).entryString(x);
+							int length = classpath.length;
+							System.arraycopy(classpath, 0, classpath = new String[length + 1], 0, length);
+							classpath[length] = entryString;
+						} catch (IOException | URISyntaxException e) {
+							throw new CoreException(
+									new Status(IStatus.ERROR, JUnitCorePlugin.CORE_PLUGIN_ID, IStatus.ERROR, "", e)); //$NON-NLS-1$
+						}
+					}
 				}
 			}
 
