@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -24,43 +24,18 @@ import java.util.concurrent.atomic.AtomicReference;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import org.eclipse.unittest.ui.ConfigureViewerSupport;
-
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.Shell;
-
+import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IPath;
-
-import org.eclipse.core.resources.IResource;
-
-import org.eclipse.jface.dialogs.MessageDialog;
-import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionProvider;
-import org.eclipse.jface.viewers.IStructuredSelection;
-import org.eclipse.jface.viewers.ITreeContentProvider;
-import org.eclipse.jface.viewers.TreeViewer;
-import org.eclipse.jface.window.Window;
-
-import org.eclipse.jface.text.ITextSelection;
-
-import org.eclipse.ui.IEditorPart;
-import org.eclipse.ui.PlatformUI;
-import org.eclipse.ui.dialogs.ElementListSelectionDialog;
-import org.eclipse.ui.dialogs.ElementTreeSelectionDialog;
-
 import org.eclipse.debug.core.DebugPlugin;
 import org.eclipse.debug.core.ILaunchConfiguration;
 import org.eclipse.debug.core.ILaunchConfigurationType;
 import org.eclipse.debug.core.ILaunchConfigurationWorkingCopy;
 import org.eclipse.debug.core.ILaunchManager;
-
 import org.eclipse.debug.ui.DebugUITools;
 import org.eclipse.debug.ui.IDebugModelPresentation;
 import org.eclipse.debug.ui.ILaunchShortcut2;
-
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
@@ -73,22 +48,36 @@ import org.eclipse.jdt.core.ISourceRange;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.JavaModelException;
-
 import org.eclipse.jdt.internal.junit.launcher.AssertionVMArg;
 import org.eclipse.jdt.internal.junit.launcher.JUnitLaunchConfigurationConstants;
 import org.eclipse.jdt.internal.junit.launcher.JUnitMigrationDelegate;
 import org.eclipse.jdt.internal.junit.util.ExceptionHandler;
 import org.eclipse.jdt.internal.junit.util.JUnitStubUtility;
 import org.eclipse.jdt.internal.junit.util.TestSearchEngine;
-
+import org.eclipse.jdt.internal.ui.actions.SelectionConverter;
 import org.eclipse.jdt.launching.IJavaLaunchConfigurationConstants;
-
 import org.eclipse.jdt.ui.JavaElementLabelProvider;
 import org.eclipse.jdt.ui.JavaElementLabels;
 import org.eclipse.jdt.ui.JavaUI;
+import org.eclipse.jdt.ui.PreferenceConstants;
 import org.eclipse.jdt.ui.unittest.junit.JUnitTestPlugin;
-
-import org.eclipse.jdt.internal.ui.actions.SelectionConverter;
+import org.eclipse.jface.dialogs.MessageDialog;
+import org.eclipse.jface.preference.IPreferenceStore;
+import org.eclipse.jface.text.ITextSelection;
+import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.jface.viewers.ISelectionProvider;
+import org.eclipse.jface.viewers.IStructuredSelection;
+import org.eclipse.jface.viewers.ITreeContentProvider;
+import org.eclipse.jface.viewers.TreeViewer;
+import org.eclipse.jface.window.Window;
+import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Shell;
+import org.eclipse.ui.IEditorPart;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.dialogs.ElementListSelectionDialog;
+import org.eclipse.ui.dialogs.ElementTreeSelectionDialog;
+import org.eclipse.unittest.ui.ConfigureViewerSupport;
 
 /**
  * The launch shortcut to launch JUnit tests.
@@ -214,7 +203,7 @@ public class JUnitLaunchShortcut implements ILaunchShortcut2 {
 
 	private IType findTypeToLaunch(ICompilationUnit cu, String mode)
 			throws InterruptedException, InvocationTargetException {
-		var types= findTypesToLaunch(cu);
+		var types = findTypesToLaunch(cu);
 		if (types.isEmpty()) {
 			return null;
 		} else if (types.size() > 1) {
@@ -239,16 +228,16 @@ public class JUnitLaunchShortcut implements ILaunchShortcut2 {
 	}
 
 	static class TreeProvider implements ITreeContentProvider {
-		private final static Object ROOT= new Object();
+		private final static Object ROOT = new Object();
 
-		private final Map<Object, List<IType>> tree= new HashMap<>();
+		private final Map<Object, List<IType>> tree = new HashMap<>();
 
 		public TreeProvider(Set<IType> types) {
 			for (var type : types) {
-				var parent= type.getParent();
-				var parentInTree= types.contains(parent) ? parent : ROOT;
+				var parent = type.getParent();
+				var parentInTree = types.contains(parent) ? parent : ROOT;
 				tree.compute(parentInTree, (key, value) -> {
-					var list= value != null ? value : new ArrayList<IType>();
+					var list = value != null ? value : new ArrayList<IType>();
 					list.add(type);
 					return list;
 				});
@@ -262,7 +251,7 @@ public class JUnitLaunchShortcut implements ILaunchShortcut2 {
 
 		@Override
 		public Object[] getChildren(Object parentElement) {
-			var children= tree.get(parentElement);
+			var children = tree.get(parentElement);
 			return children != null ? children.toArray() : new Object[0];
 		}
 
@@ -273,13 +262,14 @@ public class JUnitLaunchShortcut implements ILaunchShortcut2 {
 
 		@Override
 		public boolean hasChildren(Object element) {
-			var children= tree.get(element);
+			var children = tree.get(element);
 			return children != null && !children.isEmpty();
 		}
 	}
 
 	private IType chooseType(Set<IType> types, String mode) throws InterruptedException {
-		var dialog = new ElementTreeSelectionDialog(getShell(), new JavaElementLabelProvider(JavaElementLabelProvider.SHOW_POST_QUALIFIED), new TreeProvider(types)) {
+		var dialog = new ElementTreeSelectionDialog(getShell(),
+				new JavaElementLabelProvider(JavaElementLabelProvider.SHOW_POST_QUALIFIED), new TreeProvider(types)) {
 			@Override
 			protected TreeViewer createTreeViewer(Composite parent) {
 				var tree = super.createTreeViewer(parent);
@@ -477,6 +467,9 @@ public class JUnitLaunchShortcut implements ILaunchShortcut2 {
 	 * @return The suggested name for the launch configuration.
 	 */
 	protected String suggestLaunchConfigurationName(IJavaElement element, String fullTestName) {
+		IPreferenceStore preferenceStore = PreferenceConstants.getPreferenceStore();
+		boolean useQualification = preferenceStore
+				.getBoolean(PreferenceConstants.LAUNCH_NAME_FULLY_QUALIFIED_FOR_JUNIT_TEST);
 		switch (element.getElementType()) {
 		case IJavaElement.JAVA_PROJECT:
 		case IJavaElement.PACKAGE_FRAGMENT_ROOT:
@@ -493,14 +486,16 @@ public class JUnitLaunchShortcut implements ILaunchShortcut2 {
 					String typeName = typeFQNDot >= 0 ? typeFQN.substring(typeFQNDot + 1) : typeFQN;
 					return typeName + " " + testName; //$NON-NLS-1$
 				}
-				return element.getElementName() + " " + fullTestName;//$NON-NLS-1$
+				return (useQualification ? ((IType) element).getFullyQualifiedName('.') : element.getElementName())
+						+ " " + fullTestName;//$NON-NLS-1$
 			}
-			return element.getElementName();
+			return useQualification ? ((IType) element).getFullyQualifiedName('.') : element.getElementName();
 		case IJavaElement.METHOD:
 			IMethod method = (IMethod) element;
 			String methodName = method.getElementName();
 			methodName += JUnitStubUtility.getParameterTypes(method, true); // use simple names of parameter types
-			return method.getDeclaringType().getElementName() + '.' + methodName;
+			return useQualification ? method.getDeclaringType().getFullyQualifiedName('.')
+					: method.getDeclaringType().getElementName() + '.' + methodName;
 		default:
 			throw new IllegalArgumentException(
 					"Invalid element type to create a launch configuration: " + element.getClass().getName()); //$NON-NLS-1$
