@@ -11,6 +11,7 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Nikolay Metchev <nikolaymetchev@gmail.com> - Import static (Ctrl+Shift+M) creates imports for private methods - https://bugs.eclipse.org/409594
+ *     Fabian Pfaff <fabian.pfaff@vogella.com> - Import static doesn't work when static method is referenced from subtype - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/276
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.codemanipulation;
 
@@ -21,10 +22,9 @@ import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
-import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.OperationCanceledException;
 import org.eclipse.core.runtime.Status;
-import org.eclipse.core.runtime.SubProgressMonitor;
+import org.eclipse.core.runtime.SubMonitor;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
 
 import org.eclipse.core.resources.IWorkspaceRunnable;
@@ -87,7 +87,7 @@ import org.eclipse.jdt.internal.ui.JavaUIStatus;
  */
 public class AddImportsOperation implements IWorkspaceRunnable {
 
-	public static interface IChooseImportQuery {
+	public interface IChooseImportQuery {
 		/**
 		 * Selects an import from a list of choices.
 		 * @param openChoices Array of found types
@@ -163,37 +163,31 @@ public class AddImportsOperation implements IWorkspaceRunnable {
 	 */
 	@Override
 	public void run(IProgressMonitor monitor) throws CoreException, OperationCanceledException {
-		if (monitor == null) {
-			monitor= new NullProgressMonitor();
+		SubMonitor subMonitor= SubMonitor.convert(monitor, CodeGenerationMessages.AddImportsOperation_description, 4);
+
+		CompilationUnit astRoot= SharedASTProviderCore.getAST(fCompilationUnit, SharedASTProviderCore.WAIT_YES, subMonitor.split(1));
+		if (astRoot == null)
+			throw new OperationCanceledException();
+
+		ImportRewrite importRewrite= StubUtility.createImportRewrite(astRoot, true);
+
+		MultiTextEdit res= new MultiTextEdit();
+
+		TextEdit edit= evaluateEdits(astRoot, importRewrite, fSelectionOffset, fSelectionLength, subMonitor.split(1));
+		if (edit == null) {
+			return;
 		}
-		try {
-			monitor.beginTask(CodeGenerationMessages.AddImportsOperation_description, 4);
+		res.addChild(edit);
 
-			CompilationUnit astRoot= SharedASTProviderCore.getAST(fCompilationUnit, SharedASTProviderCore.WAIT_YES, new SubProgressMonitor(monitor, 1));
-			if (astRoot == null)
-				throw new OperationCanceledException();
+		TextEdit importsEdit= importRewrite.rewriteImports(subMonitor.split(1));
+		res.addChild(importsEdit);
 
-			ImportRewrite importRewrite= StubUtility.createImportRewrite(astRoot, true);
+		fResultingEdit= res;
 
-			MultiTextEdit res= new MultiTextEdit();
-
-			TextEdit edit= evaluateEdits(astRoot, importRewrite, fSelectionOffset, fSelectionLength, new SubProgressMonitor(monitor, 1));
-			if (edit == null) {
-				return;
-			}
-			res.addChild(edit);
-
-			TextEdit importsEdit= importRewrite.rewriteImports(new SubProgressMonitor(monitor, 1));
-			res.addChild(importsEdit);
-
-			fResultingEdit= res;
-
-			if (fApply) {
-				JavaModelUtil.applyEdit(fCompilationUnit, res, fDoSave, new SubProgressMonitor(monitor, 1));
-			}
-		} finally {
-			monitor.done();
+		if (fApply) {
+			JavaModelUtil.applyEdit(fCompilationUnit, res, fDoSave, subMonitor.split(1));
 		}
+		subMonitor.setWorkRemaining(0);
 	}
 
 	/**
@@ -206,6 +200,7 @@ public class AddImportsOperation implements IWorkspaceRunnable {
 	}
 
 	private TextEdit evaluateEdits(CompilationUnit root, ImportRewrite importRewrite, int offset, int length, IProgressMonitor monitor) throws JavaModelException {
+		SubMonitor subMonitor= SubMonitor.convert(monitor, 1);
 		SimpleName nameNode= null;
 		if (root != null) { // got an AST
 			ASTNode node= NodeFinder.perform(root, offset, length);
@@ -276,7 +271,7 @@ public class AddImportsOperation implements IWorkspaceRunnable {
 						// no change necessary
 						return null;
 					}
-					return new ReplaceEdit(qualifierStart, simpleNameStart - qualifierStart, new String());
+					return new ReplaceEdit(qualifierStart, simpleNameStart - qualifierStart, ""); //$NON-NLS-1$
 				} else if (JavaModelUtil.is50OrHigher(fCompilationUnit.getJavaProject()) && (binding instanceof IVariableBinding || binding instanceof IMethodBinding)) {
 					boolean isField= binding instanceof IVariableBinding;
 					ITypeBinding declaringClass= isField ? ((IVariableBinding) binding).getDeclaringClass() : ((IMethodBinding) binding).getDeclaringClass();
@@ -285,31 +280,29 @@ public class AddImportsOperation implements IWorkspaceRunnable {
 					}
 					if (Modifier.isStatic(binding.getModifiers())) {
 						if (containerName.length() > 0) {
-							if (containerName.equals(declaringClass.getName()) || containerName.equals(declaringClass.getQualifiedName()) ) {
-								ASTNode node= nameNode.getParent();
-								boolean isDirectlyAccessible= false;
-								while (node != null) {
-									if (isTypeDeclarationSubTypeCompatible(node, declaringClass)) {
-										isDirectlyAccessible= true;
-										break;
-									}
-									node= node.getParent();
+							ASTNode node= nameNode.getParent();
+							boolean isDirectlyAccessible= false;
+							while (node != null) {
+								if (isTypeDeclarationSubTypeCompatible(node, declaringClass)) {
+									isDirectlyAccessible= true;
+									break;
 								}
-								if (!isDirectlyAccessible) {
-									if (Modifier.isPrivate(declaringClass.getModifiers())) {
-										fStatus= JavaUIStatus.createError(IStatus.ERROR,
-												Messages.format(CodeGenerationMessages.AddImportsOperation_error_not_visible_class, BasicElementLabels.getJavaElementName(declaringClass.getName())),
-												null);
-										return null;
-									}
-									String res= importRewrite.addStaticImport(declaringClass.getQualifiedName(), binding.getName(), isField);
-									if (!res.equals(simpleName)) {
-										// adding import failed
-										return null;
-									}
-								}
-								return new ReplaceEdit(qualifierStart, simpleNameStart - qualifierStart, ""); //$NON-NLS-1$
+								node= node.getParent();
 							}
+							if (!isDirectlyAccessible) {
+								if (Modifier.isPrivate(declaringClass.getModifiers())) {
+									fStatus= JavaUIStatus.createError(IStatus.ERROR,
+											Messages.format(CodeGenerationMessages.AddImportsOperation_error_not_visible_class, BasicElementLabels.getJavaElementName(declaringClass.getName())),
+											null);
+									return null;
+								}
+								String res= importRewrite.addStaticImport(declaringClass.getQualifiedName(), binding.getName(), isField);
+								if (!res.equals(simpleName)) {
+									// adding import failed
+									return null;
+								}
+							}
+							return new ReplaceEdit(qualifierStart, simpleNameStart - qualifierStart, ""); //$NON-NLS-1$
 						}
 					}
 					return null; // no static imports for packages
@@ -355,15 +348,12 @@ public class AddImportsOperation implements IWorkspaceRunnable {
 		}
 		IJavaSearchScope searchScope= SearchEngine.createJavaSearchScope(new IJavaElement[] { fCompilationUnit.getJavaProject() });
 
-		TypeNameMatch[] types= findAllTypes(simpleName, searchScope, nameNode, new SubProgressMonitor(monitor, 1));
+		TypeNameMatch[] types= findAllTypes(simpleName, searchScope, nameNode, subMonitor.split(1));
 		if (types.length == 0) {
 			fStatus= JavaUIStatus.createError(IStatus.ERROR, Messages.format(CodeGenerationMessages.AddImportsOperation_error_notresolved_message, BasicElementLabels.getJavaElementName(simpleName)), null);
 			return null;
 		}
 
-		if (monitor.isCanceled()) {
-			throw new OperationCanceledException();
-		}
 		TypeNameMatch chosen;
 		if (types.length > 1 && fQuery != null) {
 			chosen= fQuery.chooseImport(types, containerName);
