@@ -161,24 +161,23 @@ public class JavaFormatter {
 			MultiTextEdit root= new MultiTextEdit(0, document.getLength());
 			List<TextEdit> edits= new ArrayList<>();
 			boolean hasModifications= false;
-			for (int i= 0; i != variables.length; i++) {
-				final TemplateVariable variable= variables[i];
+			for (final TemplateVariable variable : variables) {
 				int[] offsets= variable.getOffsets();
 
 				String value= variable.getDefaultValue();
 				if (isWhitespaceVariable(value)) {
 					// replace whitespace positions with unformattable comments
 					String placeholder= COMMENT_START + value + COMMENT_END;
-					for (int j= 0; j != offsets.length; j++) {
-						ReplaceEdit replace= new ReplaceEdit(offsets[j], value.length(), placeholder);
+					for (int offset : offsets) {
+						ReplaceEdit replace= new ReplaceEdit(offset, value.length(), placeholder);
 						root.addChild(replace);
 						hasModifications= true;
 						markerToOriginal.put(replace, value);
 						edits.add(replace);
 					}
 				} else {
-					for (int j= 0; j != offsets.length; j++) {
-						RangeMarker marker= new RangeMarker(offsets[j], value.length());
+					for (int offset : offsets) {
+						RangeMarker marker= new RangeMarker(offset, value.length());
 						root.addChild(marker);
 						edits.add(marker);
 					}
@@ -191,8 +190,7 @@ public class JavaFormatter {
 			}
 
 			List<TypedPosition> positions= new ArrayList<>();
-			for (Iterator<TextEdit> it= edits.iterator(); it.hasNext();) {
-				TextEdit edit= it.next();
+			for (TextEdit edit : edits) {
 				try {
 					// abuse TypedPosition to piggy back the original contents of the position
 					final TypedPosition pos= new TypedPosition(edit.getOffset(), edit.getLength(), markerToOriginal.get(edit));
@@ -214,8 +212,7 @@ public class JavaFormatter {
 		private void removeRangeMarkers(List<TypedPosition> positions, IDocument document, TemplateVariable[] variables) throws MalformedTreeException, BadLocationException, BadPositionCategoryException {
 
 			// revert previous changes
-			for (Iterator<TypedPosition> it= positions.iterator(); it.hasNext();) {
-				TypedPosition position= it.next();
+			for (TypedPosition position : positions) {
 				// remove and re-add in order to not confuse ExclusivePositionUpdater
 				document.removePosition(CATEGORY, position);
 				final String original= position.getType();
@@ -227,9 +224,7 @@ public class JavaFormatter {
 			}
 
 			Iterator<TypedPosition> it= positions.iterator();
-			for (int i= 0; i != variables.length; i++) {
-				TemplateVariable variable= variables[i];
-
+			for (TemplateVariable variable : variables) {
 				int[] offsets= new int[variable.getOffsets().length];
 				for (int j= 0; j != offsets.length; j++)
 					offsets[j]= it.next().getOffset();
@@ -288,9 +283,7 @@ public class JavaFormatter {
 			try {
 				format(document, (CompilationUnitContext) context);
 				return;
-			} catch (BadLocationException e) {
-				// ignore and indent
-			} catch (MalformedTreeException e) {
+			} catch (BadLocationException | MalformedTreeException e) {
 				// ignore and indent
 			}
 		}
