@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2020 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,6 +14,11 @@
  *     Nicolaj Hoess <nicohoess@gmail.com> - [extract local] puts declaration at wrong position - https://bugs.eclipse.org/65875
  *     Pierre-Yves B. <pyvesdev@gmail.com> - [inline] Allow inlining of local variable initialized to null. - https://bugs.eclipse.org/93850
  *     Xiaye Chi <xychichina@gmail.com> - [extract local] Extract to local variable may result in NullPointerException. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/39
+ *     Xiaye Chi <xychichina@gmail.com> - [extract local] Improve the Safety of Extract Local Variable Refactorings concering ClassCasts. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/331
+ *     Xiaye Chi <xychichina@gmail.com> - [extract local] Improve the Safety of Extract Local Variable Refactorings by Identifying the Side Effect of Selected Expression. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/348
+ *     Xiaye Chi <xychichina@gmail.com> - [extract local] Improve the Safety of Extract Local Variable Refactorings by identifying statements that may change the value of the extracted expressions - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/432
+ *     Taiming Wang <3120205503@bit.edu.cn> - [extract local] Automated Name Recommendation For The Extract Local Variable Refactoring. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/601
+ *     Taiming Wang <3120205503@bit.edu.cn> - [extract local] Context-based Automated Name Recommendation For The Extract Local Variable Refactoring. - https://github.com/eclipse-jdt/eclipse.jdt.ui/issues/655
  *******************************************************************************/
 package org.eclipse.jdt.internal.corext.refactoring.code;
 
@@ -52,6 +57,7 @@ import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.NamingConventions;
 import org.eclipse.jdt.core.SourceRange;
 import org.eclipse.jdt.core.dom.AST;
+import org.eclipse.jdt.core.dom.ASTMatcher;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.Annotation;
@@ -120,6 +126,7 @@ import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatur
 import org.eclipse.jdt.internal.corext.Corext;
 import org.eclipse.jdt.internal.corext.codemanipulation.ContextSensitiveImportRewriteContext;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
+import org.eclipse.jdt.internal.corext.dom.AbortSearchException;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.dom.ScopeAnalyzer;
 import org.eclipse.jdt.internal.corext.dom.fragments.ASTFragmentFactory;
@@ -135,11 +142,13 @@ import org.eclipse.jdt.internal.corext.refactoring.RefactoringCoreMessages;
 import org.eclipse.jdt.internal.corext.refactoring.base.RefactoringStatusCodes;
 import org.eclipse.jdt.internal.corext.refactoring.rename.RefactoringAnalyzeUtil;
 import org.eclipse.jdt.internal.corext.refactoring.structure.CompilationUnitRewrite;
+import org.eclipse.jdt.internal.corext.refactoring.util.ChangedValueChecker;
 import org.eclipse.jdt.internal.corext.refactoring.util.JavaStatusContext;
 import org.eclipse.jdt.internal.corext.refactoring.util.NoCommentSourceRangeComputer;
-import org.eclipse.jdt.internal.corext.refactoring.util.NullChecker;
 import org.eclipse.jdt.internal.corext.refactoring.util.RefactoringASTParser;
 import org.eclipse.jdt.internal.corext.refactoring.util.ResourceUtil;
+import org.eclipse.jdt.internal.corext.refactoring.util.SideEffectChecker;
+import org.eclipse.jdt.internal.corext.refactoring.util.UnsafeCheckTester;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
@@ -184,6 +193,48 @@ public class ExtractTempRefactoring extends Refactoring {
 		}
 	}
 
+	private static final class LocalVariableWithIdenticalExpressionFinder extends ASTVisitor {
+		private ArrayList<String> usedNames;
+
+		private ASTNode expression;
+
+		private Boolean ifStopOnFirstMatch;
+
+
+		public LocalVariableWithIdenticalExpressionFinder(ASTNode expression, Boolean ifStopOnFirstMatch) {
+			usedNames= new ArrayList<>();
+			this.expression= expression;
+			this.ifStopOnFirstMatch= ifStopOnFirstMatch;
+		}
+
+		public String getUsedName() {
+			return this.usedNames.get(0);
+		}
+
+		public ArrayList<String> getUsedNames() {
+			return this.usedNames;
+		}
+
+		public void setUsedName(String usedName) {
+			this.usedNames.add(usedName);
+		}
+
+		@Override
+		public boolean visit(VariableDeclarationStatement node) {
+			for (Object obj : node.fragments()) {
+				VariableDeclarationFragment fragment= (VariableDeclarationFragment)obj;
+				if (fragment.getInitializer() != null) {
+					Expression initializer= fragment.getInitializer();
+					if (initializer.subtreeMatch(new ASTMatcher(), this.expression)) {
+						setUsedName(fragment.getName().toString());
+						if (this.ifStopOnFirstMatch.booleanValue())
+							throw new AbortSearchException();
+					}
+				}
+			}
+			return true;
+		}
+	}
 
 
 	private static boolean allArraysEqual(ASTNode[][] arrays, int position) {
@@ -196,6 +247,7 @@ public class ExtractTempRefactoring extends Refactoring {
 		return true;
 	}
 
+
 	private static boolean canReplace(IASTFragment fragment) {
 		ASTNode node= fragment.getAssociatedNode();
 		ASTNode parent= node.getParent();
@@ -218,6 +270,10 @@ public class ExtractTempRefactoring extends Refactoring {
 			return false;
 		if (isUsedInForInitializerOrUpdater((Expression) node))
 			return false;
+		if (parent instanceof SuperConstructorInvocation)
+			return false;
+		if (parent instanceof ConstructorInvocation)
+			return false;
 		if (parent instanceof SwitchCase)
 			return true;
 		if (node instanceof SimpleName && node.getLocationInParent() != null) {
@@ -302,6 +358,7 @@ public class ExtractTempRefactoring extends Refactoring {
 	private static boolean isReferringToLocalVariableFromFor(Expression expression) {
 		ASTNode current= expression;
 		ASTNode parent= current.getParent();
+
 		while (parent != null && !(parent instanceof BodyDeclaration)) {
 			if (parent instanceof ForStatement) {
 				ForStatement forStmt= (ForStatement) parent;
@@ -342,7 +399,66 @@ public class ExtractTempRefactoring extends Refactoring {
 				result.add(match);
 			}
 		}
-		return result.toArray(new IASTFragment[result.size()]);
+		Comparator<IASTFragment> comparator= (o1, o2) -> o1.getStartPosition() - o2.getStartPosition();
+		result.sort(comparator);
+		try {
+			boolean flag= false;
+			IExpressionFragment selectedFragment= getSelectedExpression();
+			ASTNode associatedNode= selectedFragment.getAssociatedNode();
+			IExpressionFragment firstExpression= getCertainReplacedExpression(result.toArray(new IASTFragment[result.size()]), 0);
+			if (firstExpression.getStartPosition() < selectedFragment.getStartPosition())
+				flag= false;
+			else
+				flag= (associatedNode.getParent() instanceof ExpressionStatement || associatedNode.getParent() instanceof LambdaExpression)
+						&& selectedFragment.matches(ASTFragmentFactory.createFragmentForFullSubtree(associatedNode));
+			int upper= result.size();
+			if (flag) {
+				ASTNode parent= associatedNode.getParent();
+				StructuralPropertyDescriptor location= parent.getLocationInParent();
+				while (parent != null) {
+					if (parent instanceof Block || parent instanceof BodyDeclaration || parent instanceof LambdaExpression && ((LambdaExpression) parent).resolveMethodBinding() != null
+							|| parent instanceof EnhancedForStatement || parent instanceof WhileStatement
+							|| parent instanceof ForStatement || parent instanceof DoStatement) {
+						break;
+					}
+					location= parent.getLocationInParent();
+					if (location == IfStatement.ELSE_STATEMENT_PROPERTY || location == IfStatement.THEN_STATEMENT_PROPERTY || location == SwitchStatement.STATEMENTS_PROPERTY) {
+						break;
+					}
+					parent= parent.getParent();
+				}
+				if (parent == null) {
+					return result.toArray(new IASTFragment[result.size()]);
+				}
+				int offset= parent.getStartPosition() + parent.getLength();
+				if (location == SwitchStatement.STATEMENTS_PROPERTY) {
+					SwitchStatement ss= (SwitchStatement) parent.getParent();
+					Iterator<Object> iterator= ss.statements().iterator();
+					int preOffset= -1;
+					while (iterator.hasNext()) {
+						Object obj= iterator.next();
+						if (obj instanceof ASTNode) {
+							ASTNode node= (ASTNode) obj;
+							if (node instanceof SwitchCase && node.getStartPosition() > offset) {
+								break;
+							}
+							preOffset= node.getStartPosition() + node.getLength();
+						}
+					}
+					if (preOffset > 0)
+						offset= preOffset;
+				}
+				for (int i= 0; i < result.size(); ++i) {
+					if (result.get(i).getStartPosition() > offset) {
+						upper= i;
+						break;
+					}
+				}
+			}
+			return result.subList(0, upper).toArray(new IASTFragment[upper]);
+		} catch (JavaModelException e) {
+			return result.toArray(new IASTFragment[result.size()]);
+		}
 	}
 
 	private CompilationUnit fCompilationUnitNode;
@@ -386,6 +502,7 @@ public class ExtractTempRefactoring extends Refactoring {
 
 	private HashSet<IASTFragment> fSeen= new HashSet<>();
 
+	private String fEnclosingKey;
 
 	/**
 	 * Creates a new extract temp refactoring
@@ -401,7 +518,6 @@ public class ExtractTempRefactoring extends Refactoring {
 		fSelectionLength= selectionLength;
 		fCu= unit;
 		fCompilationUnitNode= null;
-
 		fReplaceAllOccurrences= true; // default
 		fDeclareFinal= false; // default
 		fDeclareVarType= false; // default
@@ -412,6 +528,7 @@ public class ExtractTempRefactoring extends Refactoring {
 
 		fStartPoint= -1; // default
 		fEndPoint= -1; // default
+		fEnclosingKey= null;
 	}
 
 	public ExtractTempRefactoring(CompilationUnit astRoot, int selectionStart, int selectionLength) {
@@ -434,7 +551,7 @@ public class ExtractTempRefactoring extends Refactoring {
 
 		fStartPoint= -1; // default
 		fEndPoint= -1; // default
-
+		fEnclosingKey= null;
 	}
 
 	public ExtractTempRefactoring(JavaRefactoringArguments arguments, RefactoringStatus status) {
@@ -442,7 +559,7 @@ public class ExtractTempRefactoring extends Refactoring {
 
 		fStartPoint= -1; // default
 		fEndPoint= -1; // default
-
+		fEnclosingKey= null;
 
 		RefactoringStatus initializeStatus= initialize(arguments);
 		status.merge(initializeStatus);
@@ -460,9 +577,9 @@ public class ExtractTempRefactoring extends Refactoring {
 	}
 
 	private void addReplaceExpressionWithTemp() throws JavaModelException {
-		IASTFragment[] fragmentsToReplace= reSortRetainOnlyReplacableMatches();
+		IASTFragment[] fragmentsToReplace= retainOnlyReplacableMatches(getMatchingFragments());
 
-		if (fragmentsToReplace.length == 0) {
+		if (fragmentsToReplace.length == 0 || fEndPoint == -1) {
 			return;
 		}
 		//TODO: should not have to prune duplicates here...
@@ -471,6 +588,7 @@ public class ExtractTempRefactoring extends Refactoring {
 			IASTFragment fragment= fragmentsToReplace[i];
 			if (!fSeen.add(fragment))
 				continue;
+
 			SimpleName tempName= fCURewrite.getAST().newSimpleName(fTempName);
 			TextEditGroup description= fCURewrite.createGroupDescription(RefactoringCoreMessages.ExtractTempRefactoring_replace);
 
@@ -541,6 +659,20 @@ public class ExtractTempRefactoring extends Refactoring {
 			fCURewrite= new CompilationUnitRewrite(fCu, fCompilationUnitNode);
 			fCURewrite.getASTRewrite().setTargetSourceRangeComputer(new NoCommentSourceRangeComputer());
 
+			RefactoringStatus result= new RefactoringStatus();
+			fStartPoint= -1;
+			fEndPoint= -1;
+			fSeen.clear();
+			boolean replaceAll= fReplaceAllOccurrences;
+
+			if (fReplaceAllOccurrences) {
+				RefactoringStatus checkSideEffectsInSelectedExpression= checkSideEffectsInSelectedExpression();
+				if (checkSideEffectsInSelectedExpression.hasInfo()) {
+					fReplaceAllOccurrences= false;
+					result.merge(checkSideEffectsInSelectedExpression);
+				}
+			}
+
 			doCreateChange(new SubProgressMonitor(pm, 2));
 
 			fChange= fCURewrite.createChange(RefactoringCoreMessages.ExtractTempRefactoring_change_name, true, new SubProgressMonitor(pm, 1));
@@ -559,18 +691,16 @@ public class ExtractTempRefactoring extends Refactoring {
 					super.preVisit(edit);
 				}
 			});
-			RefactoringStatus result= new RefactoringStatus();
 			if (Arrays.asList(getExcludedVariableNames()).contains(fTempName))
 				result.addWarning(Messages.format(RefactoringCoreMessages.ExtractTempRefactoring_another_variable, BasicElementLabels.getJavaElementName(fTempName)));
 
 			result.merge(checkMatchingFragments());
-
 			fChange.setKeepPreviewEdits(false);
 
 			if (fCheckResultForCompileProblems) {
 				result.merge(RefactoringAnalyzeUtil.checkNewSource(fChange, fCu, fCompilationUnitNode, pm));
 			}
-
+			fReplaceAllOccurrences= replaceAll;
 			return result;
 		} finally {
 			pm.done();
@@ -620,31 +750,33 @@ public class ExtractTempRefactoring extends Refactoring {
 			try {
 				int cnt= 1;
 				getSelectedExpression();
-				fSelectionStart= fSelectedExpression.getAssociatedNode().getStartPosition();
-				fSelectionLength= fSelectedExpression.getAssociatedNode().getLength();
-				IASTFragment[] reSortRetainOnlyReplacableMatches= reSortRetainOnlyReplacableMatches();
-				int tmpFSelectionStart= fSelectionStart;
-				int tmpFSelectionLength= fSelectionLength;
-
+				fSelectionStart= fSelectedExpression.getStartPosition();
+				fSelectionLength= fSelectedExpression.getLength();
+				IASTFragment[] retainOnlyReplacableMatches= retainOnlyReplacableMatches(getMatchingFragments());
+				final int tmpFSelectionStart= fSelectionStart;
+				final int tmpFSelectionLength= fSelectionLength;
 				IExpressionFragment tmpFSelectedExpression= fSelectedExpression;
 				Collection<String> usedNames= getUsedLocalNames(fSelectedExpression.getAssociatedNode());
 				String newName= fTempName;
-				createTempDeclaration();
-				if (fStartPoint != -1 && fEndPoint != -1) {
+				if (!replaceAllOccurrences() || shouldReplaceSelectedExpressionWithTempDeclaration()
+						|| retainOnlyReplacableMatches.length == 0) {
+					createTempDeclaration();
 					addReplaceExpressionWithTemp();
 					fTempName= newName + ++cnt;
 					while (usedNames.contains(fTempName)) {
 						fTempName= newName + ++cnt;
 					}
+
 				}
-				while (replaceAllOccurrences() && reSortRetainOnlyReplacableMatches.length > fSeen.size()) {
+				while (replaceAllOccurrences() &&
+						retainOnlyReplacableMatches.length > fSeen.size()) {
 					fStartPoint= -1;
 					fEndPoint= -1;
 					boolean flag= false;
-					for (int i= 0; i < reSortRetainOnlyReplacableMatches.length; ++i) {
-						if (!fSeen.contains(reSortRetainOnlyReplacableMatches[i])) {
-							fSelectionStart= reSortRetainOnlyReplacableMatches[i].getAssociatedNode().getStartPosition();
-							fSelectionLength= reSortRetainOnlyReplacableMatches[i].getAssociatedNode().getLength();
+					for (int i= 0; i < retainOnlyReplacableMatches.length; ++i) {
+						if (!fSeen.contains(retainOnlyReplacableMatches[i])) {
+							fSelectionStart= retainOnlyReplacableMatches[i].getStartPosition();
+							fSelectionLength= retainOnlyReplacableMatches[i].getLength();
 							fSelectedExpression= null;
 							getSelectedExpression();
 							flag= true;
@@ -676,6 +808,7 @@ public class ExtractTempRefactoring extends Refactoring {
 
 	/**
 	 * Retrieves used names for the block containing a node.
+	 *
 	 * @param selected the selected node
 	 *
 	 * @return an array of used variable names to avoid
@@ -694,6 +827,49 @@ public class ExtractTempRefactoring extends Refactoring {
 		return localUsedNames;
 	}
 
+	/**
+	 * Retrieves a used name in the whole compilation unit that is assigned with the same
+	 * expression.
+	 *
+	 * @param selected the selected node
+	 *
+	 * @return a used variable name for recommending new names.
+	 */
+	private String getUsedNameForIdenticalExpressionInCu(ASTNode selected) {
+		ASTNode surroundingBlock= selected;
+		surroundingBlock= ASTNodes.getFirstAncestorOrNull(surroundingBlock, CompilationUnit.class);
+		if (surroundingBlock == null) {
+			return null;
+		}
+		LocalVariableWithIdenticalExpressionFinder localVariableWithIdenticalExpressionFinder= new LocalVariableWithIdenticalExpressionFinder(selected, Boolean.TRUE);
+		String usedNameForIdenticalExpressionInCu= null;
+		try {
+			surroundingBlock.accept(localVariableWithIdenticalExpressionFinder);
+		} catch (AbortSearchException e) {
+			usedNameForIdenticalExpressionInCu= localVariableWithIdenticalExpressionFinder.getUsedName();
+		}
+		return usedNameForIdenticalExpressionInCu;
+	}
+
+	/**
+	 * Retrieves used names in the method declaration that is assigned with the same expression.
+	 *
+	 * @param selected the selected node
+	 *
+	 * @return an array of used variable names for avoiding conflicts.
+	 */
+	private Collection<String> getUsedNameForIdenticalExpressionInMethod(ASTNode selected) {
+		ASTNode surroundingBlock= selected;
+		surroundingBlock= ASTNodes.getFirstAncestorOrNull(surroundingBlock, MethodDeclaration.class);
+		if (surroundingBlock == null) {
+			return new ArrayList<>();
+		}
+		LocalVariableWithIdenticalExpressionFinder localVariableWithIdenticalExpressionFinder= new LocalVariableWithIdenticalExpressionFinder(selected, Boolean.FALSE);
+		surroundingBlock.accept(localVariableWithIdenticalExpressionFinder);
+		List<String> UsedNameForIdenticalExpressionInMethod= localVariableWithIdenticalExpressionFinder.getUsedNames();
+		return UsedNameForIdenticalExpressionInMethod;
+	}
+
 
 	@Override
 	public RefactoringStatus checkInitialConditions(IProgressMonitor pm) throws CoreException {
@@ -732,6 +908,20 @@ public class ExtractTempRefactoring extends Refactoring {
 		return result;
 	}
 
+	private RefactoringStatus checkSideEffectsInSelectedExpression() throws JavaModelException {
+		RefactoringStatus result= new RefactoringStatus();
+		if (replaceAllOccurrences() && retainOnlyReplacableMatches(getMatchingFragments()).length > 1) {
+			SideEffectChecker ev= new SideEffectChecker(getSelectedExpression().getAssociatedNode(), fEnclosingKey);
+			ASTNode node= getSelectedExpression().getAssociatedNode();
+			node.accept(ev);
+			if (ev.hasSideEffect()) {
+				String msg= RefactoringCoreMessages.ExtractTempRefactoring_side_effcts_in_selected_expression;
+				result.addInfo(msg, JavaStatusContext.create(fCu, node));
+			}
+		}
+		return result;
+	}
+
 	private RefactoringStatus checkSelection(IProgressMonitor pm) throws JavaModelException {
 		try {
 			pm.beginTask("", 8); //$NON-NLS-1$
@@ -821,42 +1011,42 @@ public class ExtractTempRefactoring extends Refactoring {
 			fDeclareFinal= true;
 		}
 
-		IASTFragment[] reSortRetainOnlyReplacableMatches= reSortRetainOnlyReplacableMatches();
-		if (reSortRetainOnlyReplacableMatches == null) {
+		IASTFragment[] retainOnlyReplacableMatches= retainOnlyReplacableMatches(getMatchingFragments());
+		if (retainOnlyReplacableMatches == null) {
 			return;
 		}
 
 		int selectNumber= -1;
 
-		for (int i= 0; i < reSortRetainOnlyReplacableMatches.length; ++i) {
-			if (fSelectionStart == reSortRetainOnlyReplacableMatches[i].getAssociatedNode().getStartPosition()) {
+		for (int i= 0; i < retainOnlyReplacableMatches.length; ++i) {
+			if (fSelectionStart == retainOnlyReplacableMatches[i].getStartPosition()) {
 				selectNumber= i;
 				break;
 			}
 		}
-		if (node instanceof SwitchStatement) {
+		if (node instanceof SwitchStatement || node instanceof EnhancedForStatement) {
 			/* must insert above switch statement */
 			fStartPoint= 0;
-			fEndPoint= reSortRetainOnlyReplacableMatches.length - 1;
+			fEndPoint= retainOnlyReplacableMatches.length - 1;
 			insertAt(node, vds);
 			return;
 		} else {
 			if (insertAtSelection) {
 				ASTNode realCommonASTNode= null;
-				realCommonASTNode= evalStartAndEnd(reSortRetainOnlyReplacableMatches, selectNumber);
-				if (realCommonASTNode == null && selectNumber >=0 ) {
-					fSeen.add(reSortRetainOnlyReplacableMatches[selectNumber]);
+				realCommonASTNode= evalStartAndEnd(retainOnlyReplacableMatches, selectNumber, null);
+				if (realCommonASTNode == null && selectNumber >= 0) {
+					fSeen.add(retainOnlyReplacableMatches[selectNumber]);
 				}
-				if (realCommonASTNode != null || reSortRetainOnlyReplacableMatches.length ==0) {
+				if (realCommonASTNode != null || retainOnlyReplacableMatches.length == 0) {
 					insertAt(getSelectedExpression().getAssociatedNode(), vds);
 				}
 				return;
 			}
 		}
 		ASTNode realCommonASTNode= null;
-		realCommonASTNode= evalStartAndEnd(reSortRetainOnlyReplacableMatches, selectNumber);
+		realCommonASTNode= evalStartAndEnd(retainOnlyReplacableMatches, selectNumber, null);
 		if (realCommonASTNode == null && selectNumber >= 0) {
-			fSeen.add(reSortRetainOnlyReplacableMatches[selectNumber]);
+			fSeen.add(retainOnlyReplacableMatches[selectNumber]);
 		}
 		if (realCommonASTNode != null) {
 			insertAt(realCommonASTNode, vds);
@@ -864,20 +1054,25 @@ public class ExtractTempRefactoring extends Refactoring {
 		return;
 	}
 
-	private ASTNode evalStartAndEnd(IASTFragment[] reSortRetainOnlyReplacableMatches, int selectNumber) throws JavaModelException {
+	private ASTNode evalStartAndEnd(IASTFragment[] retainOnlyReplacableMatches, int selectNumber, Integer fixedStartOffset) throws JavaModelException {
 		ASTNode realCommonASTNode= null;
-		if (selectNumber < 0) {
+		if (selectNumber < 0 || selectNumber >= retainOnlyReplacableMatches.length) {
 			return realCommonASTNode;
 		}
 		ASTNode firstReplaceExpression;
 		int start= selectNumber;
 		int end= selectNumber;
 		int expandFlag= 2; // 2:backward 1:forward 0:break
+
+		ChangedValueChecker cvc= new ChangedValueChecker(getSelectedExpression().getAssociatedNode(), fEnclosingKey);
+
 		while (expandFlag > 0 && start <= end) {
-			IASTFragment iASTFragment= reSortRetainOnlyReplacableMatches[start];
-			firstReplaceExpression= getCertainReplacedExpression(reSortRetainOnlyReplacableMatches, start).getAssociatedNode();
+			IASTFragment iASTFragment= retainOnlyReplacableMatches[start];
+			firstReplaceExpression= getCertainReplacedExpression(retainOnlyReplacableMatches, start).getAssociatedNode();
 			ASTNode[] firstReplaceNodeParents= getParents(firstReplaceExpression);
-			ASTNode[] commonPath= findDeepestCommonSuperNodePathForReplacedNodes(start, end);
+			// fix (1+i)+1+i
+			ASTNode[] commonPath= start == end ? firstReplaceNodeParents : findDeepestCommonSuperNodePathForReplacedNodes(start, end);
+
 			Assert.isTrue(commonPath.length <= firstReplaceNodeParents.length);
 			ASTNode deepestCommonParent= firstReplaceNodeParents[commonPath.length - 1];
 			int startOffset;
@@ -890,18 +1085,27 @@ public class ExtractTempRefactoring extends Refactoring {
 				commonASTNode= deepestCommonParent;
 			}
 			commonASTNode= convertToExtractNode(commonASTNode);
-			startOffset= commonASTNode.getStartPosition() - 1;
-			NullChecker nullChecker= new NullChecker(fCompilationUnitNode, fCu, commonASTNode, expression, startOffset, endOffset);
-			if (!nullChecker.hasNullCheck()) {//at least one be extracted
+			boolean flag= false;
+			startOffset= fixedStartOffset != null ? fixedStartOffset : commonASTNode.getStartPosition() - 1;
+			int lastExprOffset= retainOnlyReplacableMatches[end].getStartPosition();
+
+			UnsafeCheckTester uct= new UnsafeCheckTester(fCompilationUnitNode, fCu, commonASTNode, expression, startOffset, endOffset);
+
+			ArrayList<IASTFragment> candidateList= new ArrayList<>();
+			for (int i= start; i <= end; ++i)
+				candidateList.add(retainOnlyReplacableMatches[i]);
+			cvc.detectConflict(startOffset, lastExprOffset, retainOnlyReplacableMatches[end].getAssociatedNode(), deepestCommonParent, candidateList);
+			flag= !uct.hasUnsafeCheck() && !cvc.hasConflict();
+			if (flag) {//at least one be extracted
 				fStartPoint= start;
 				fEndPoint= end;
 				realCommonASTNode= commonASTNode;
-				if (expandFlag == 2 && (end == reSortRetainOnlyReplacableMatches.length - 1
-						|| fSeen.contains(reSortRetainOnlyReplacableMatches[end + 1]))) {
+				if (expandFlag == 2 && (end == retainOnlyReplacableMatches.length - 1
+						|| fSeen.contains(retainOnlyReplacableMatches[end + 1]))) {
 					expandFlag= 1;
 				}
 				if (expandFlag == 1 && (start == 0
-						|| fSeen.contains(reSortRetainOnlyReplacableMatches[start - 1]))) {
+						|| fSeen.contains(retainOnlyReplacableMatches[start - 1]))) {
 					expandFlag= 0;
 				}
 				if (expandFlag == 1) {
@@ -968,7 +1172,7 @@ public class ExtractTempRefactoring extends Refactoring {
 			LinkedProposalPositionGroup nameGroup= fLinkedProposalModel.getPositionGroup(KEY_NAME, true);
 			nameGroup.addPosition(rewrite.track(vdf.getName()), true);
 
-			String[] nameSuggestions= guessTempNames();
+			String[] nameSuggestions= guessTempNamesWithContext();
 			if (nameSuggestions.length > 0 && !nameSuggestions[0].equals(fTempName)) {
 				nameGroup.addProposal(fTempName, null, nameSuggestions.length + 1);
 			}
@@ -1054,8 +1258,6 @@ public class ExtractTempRefactoring extends Refactoring {
 
 	private ASTNode[] findDeepestCommonSuperNodePathForReplacedNodes(int start, int end) throws JavaModelException {
 		ASTNode[] matchNodes= getMatchNodes();
-		Comparator<ASTNode> comparator= (o1, o2) -> o1.getStartPosition() - o2.getStartPosition();
-		Arrays.sort(matchNodes, comparator);
 		ASTNode[][] matchingNodesParents= new ASTNode[end + 1 - start][];
 		for (int i= start; i < matchNodes.length && i < end + 1; ++i) {
 			matchingNodesParents[i - start]= getParents(matchNodes[i]);
@@ -1079,7 +1281,15 @@ public class ExtractTempRefactoring extends Refactoring {
 		}
 		if (location == MethodDeclaration.BODY_PROPERTY || location == Initializer.BODY_PROPERTY
 				|| (location == LambdaExpression.BODY_PROPERTY && ((LambdaExpression) node).resolveMethodBinding() != null)) {
-			return (ASTNode) node.getStructuralProperty(location);
+			node= (ASTNode) node.getStructuralProperty(location);
+			if (node instanceof MethodDeclaration && ((MethodDeclaration) node).resolveBinding() != null
+					&& ((MethodDeclaration) node).resolveBinding().getMethodDeclaration() != null) {
+				fEnclosingKey= ((MethodDeclaration) node).resolveBinding().getMethodDeclaration().getKey();
+			} else if (node instanceof LambdaExpression &&
+					((LambdaExpression) node).resolveMethodBinding().getMethodDeclaration() != null) {
+				fEnclosingKey= ((LambdaExpression) node).resolveMethodBinding().getMethodDeclaration().getKey();
+			}
+			return node;
 		}
 		return null;
 	}
@@ -1145,8 +1355,10 @@ public class ExtractTempRefactoring extends Refactoring {
 	private ASTNode[] getMatchNodes() throws JavaModelException {
 		IASTFragment[] matches= retainOnlyReplacableMatches(getMatchingFragments());
 		ASTNode[] result= new ASTNode[matches.length];
-		for (int i= 0; i < matches.length; i++)
+		for (int i= 0; i < matches.length; i++) {
 			result[i]= matches[i].getAssociatedNode();
+		}
+
 		return result;
 	}
 
@@ -1180,6 +1392,7 @@ public class ExtractTempRefactoring extends Refactoring {
 		return fSelectedExpression;
 	}
 
+
 	private Type createTempType() throws CoreException {
 		Expression expression= getSelectedExpression().getAssociatedExpression();
 
@@ -1228,6 +1441,13 @@ public class ExtractTempRefactoring extends Refactoring {
 		else
 			return proposals[0];
 	}
+	public String guessTempNameWithContext() {
+		String[] proposals= guessTempNamesWithContext();
+		if (proposals.length == 0)
+			return fTempName;
+		else
+			return proposals[0];
+	}
 
 	/**
 	 * @return proposed variable names (may be empty, but not null). The first proposal should be
@@ -1242,6 +1462,31 @@ public class ExtractTempRefactoring extends Refactoring {
 					fGuessedTempNames= StubUtility.getVariableNameSuggestions(NamingConventions.VK_LOCAL, fCu.getJavaProject(), binding, expression, Arrays.asList(getExcludedVariableNames()));
 				}
 			} catch (JavaModelException e) {
+				JavaPlugin.log(e);
+			}
+			if (fGuessedTempNames == null)
+				fGuessedTempNames= new String[0];
+		}
+		return fGuessedTempNames;
+	}
+
+	/**
+	 * @return proposed variable names based on context (may be empty, but not null). The first proposal should be
+	 *         used as "best guess" (if it exists).
+	 */
+	public String[] guessTempNamesWithContext() {
+		if (fGuessedTempNames == null) {
+			try {
+				Expression expression= getSelectedExpression().getAssociatedExpression();
+				if (expression != null) {
+					ITypeBinding binding= guessBindingForReference(expression);
+					String usedNameForIdenticalExpressionInCu= getUsedNameForIdenticalExpressionInCu(fSelectedExpression.getAssociatedNode());
+					Collection<String> usedNamesForIdenticalExpressionInMethod= getUsedNameForIdenticalExpressionInMethod(fSelectedExpression.getAssociatedNode());
+					fGuessedTempNames= StubUtility.getVariableNameSuggestions(NamingConventions.VK_LOCAL, fCu.getJavaProject(), binding, expression, Arrays.asList(getExcludedVariableNames()),
+							usedNameForIdenticalExpressionInCu, usedNamesForIdenticalExpressionInMethod);
+				}
+			} catch (JavaModelException e) {
+				JavaPlugin.log(e);
 			}
 			if (fGuessedTempNames == null)
 				fGuessedTempNames= new String[0];
@@ -1256,6 +1501,7 @@ public class ExtractTempRefactoring extends Refactoring {
 		Expression expression= fragment.getAssociatedExpression();
 		if (expression == null)
 			return false;
+
 		switch (expression.getNodeType()) {
 			case ASTNode.BOOLEAN_LITERAL:
 			case ASTNode.CHARACTER_LITERAL:
@@ -1282,11 +1528,11 @@ public class ExtractTempRefactoring extends Refactoring {
 	}
 
 	private void replaceSelectedExpressionWithTempDeclaration() throws CoreException {
-		fStartPoint= 0;
-		fEndPoint= retainOnlyReplacableMatches(getMatchingFragments()).length - 1;
 		ASTRewrite rewrite= fCURewrite.getASTRewrite();
 		Expression selectedExpression= getSelectedExpression().getAssociatedExpression(); // whole expression selected
 
+		evalStartAndEnd(retainOnlyReplacableMatches(getMatchingFragments()), 0, Integer.valueOf(selectedExpression.getStartPosition() + selectedExpression.getLength()));
+
 		Expression initializer= (Expression) rewrite.createMoveTarget(selectedExpression);
 		VariableDeclarationStatement tempDeclaration= createTempDeclaration(initializer);
 		ASTNode replacement;
@@ -1334,10 +1580,10 @@ public class ExtractTempRefactoring extends Refactoring {
 
 	private boolean shouldReplaceSelectedExpressionWithTempDeclaration() throws JavaModelException {
 		IExpressionFragment selectedFragment= getSelectedExpression();
-		IExpressionFragment firstExpression= getCertainReplacedExpression(reSortRetainOnlyReplacableMatches(), 0);
+		ASTNode associatedNode= selectedFragment.getAssociatedNode();
+		IExpressionFragment firstExpression= getCertainReplacedExpression(retainOnlyReplacableMatches(getMatchingFragments()), 0);
 		if (firstExpression.getStartPosition() < selectedFragment.getStartPosition())
 			return false;
-		ASTNode associatedNode= selectedFragment.getAssociatedNode();
 		return (associatedNode.getParent() instanceof ExpressionStatement || associatedNode.getParent() instanceof LambdaExpression)
 				&& selectedFragment.matches(ASTFragmentFactory.createFragmentForFullSubtree(associatedNode));
 	}
@@ -1406,10 +1652,4 @@ public class ExtractTempRefactoring extends Refactoring {
 		return isAllowed;
 	}
 
-	private IASTFragment[] reSortRetainOnlyReplacableMatches() throws JavaModelException {
-		IASTFragment[] nodesToReplace= retainOnlyReplacableMatches(getMatchingFragments());
-		Comparator<IASTFragment> comparator= (o1, o2) -> o1.getStartPosition() - o2.getStartPosition();
-		Arrays.sort(nodesToReplace, comparator);
-		return nodesToReplace;
-	}
 }
