@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -53,7 +53,9 @@ import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.compiler.IProblem;
 import org.eclipse.jdt.core.dom.AST;
 import org.eclipse.jdt.core.dom.ASTNode;
+import org.eclipse.jdt.core.dom.ASTVisitor;
 import org.eclipse.jdt.core.dom.AbstractTypeDeclaration;
+import org.eclipse.jdt.core.dom.Annotation;
 import org.eclipse.jdt.core.dom.AnonymousClassDeclaration;
 import org.eclipse.jdt.core.dom.Assignment;
 import org.eclipse.jdt.core.dom.Block;
@@ -64,6 +66,7 @@ import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.Dimension;
 import org.eclipse.jdt.core.dom.Expression;
 import org.eclipse.jdt.core.dom.FieldDeclaration;
+import org.eclipse.jdt.core.dom.IExtendedModifier;
 import org.eclipse.jdt.core.dom.IMethodBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
@@ -75,6 +78,7 @@ import org.eclipse.jdt.core.dom.NodeFinder;
 import org.eclipse.jdt.core.dom.ReturnStatement;
 import org.eclipse.jdt.core.dom.SingleVariableDeclaration;
 import org.eclipse.jdt.core.dom.Type;
+import org.eclipse.jdt.core.dom.TypeDeclaration;
 import org.eclipse.jdt.core.dom.VariableDeclarationFragment;
 import org.eclipse.jdt.core.dom.rewrite.ASTRewrite;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite;
@@ -86,12 +90,16 @@ import org.eclipse.jdt.core.refactoring.descriptors.JavaRefactoringDescriptor;
 import org.eclipse.jdt.core.search.IJavaSearchConstants;
 import org.eclipse.jdt.core.search.SearchPattern;
 
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.core.refactoring.descriptors.RefactoringSignatureDescriptorFactory;
 import org.eclipse.jdt.internal.corext.codemanipulation.GetterSetterUtil;
 import org.eclipse.jdt.internal.corext.dom.ASTNodeFactory;
 import org.eclipse.jdt.internal.corext.dom.ASTNodes;
+import org.eclipse.jdt.internal.corext.dom.AbortSearchException;
 import org.eclipse.jdt.internal.corext.dom.Bindings;
 import org.eclipse.jdt.internal.corext.dom.DimensionRewrite;
+import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
 import org.eclipse.jdt.internal.corext.dom.VariableDeclarationRewrite;
 import org.eclipse.jdt.internal.corext.refactoring.Checks;
 import org.eclipse.jdt.internal.corext.refactoring.JDTRefactoringDescriptorComment;
@@ -113,9 +121,6 @@ import org.eclipse.jdt.internal.corext.util.Messages;
 import org.eclipse.jdt.ui.JavaElementLabels;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
-import org.eclipse.jdt.internal.corext.dom.IASTSharedValues;
-import org.eclipse.jdt.internal.core.manipulation.StubUtility;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.ui.viewsupport.BindingLabelProvider;
 
 /**
@@ -357,12 +362,17 @@ public class SelfEncapsulateFieldRefactoring extends Refactoring {
 			return result;
 		pm.setTaskName(RefactoringCoreMessages.SelfEncapsulateField_searching_for_cunits);
 		final SubProgressMonitor subPm= new SubProgressMonitor(pm, 5);
+		SearchPattern pattern= SearchPattern.createPattern(fField, IJavaSearchConstants.REFERENCES);
+		if (pattern == null) {
+			return result;
+		}
 		ICompilationUnit[] affectedCUs= RefactoringSearchEngine.findAffectedCompilationUnits(
-			SearchPattern.createPattern(fField, IJavaSearchConstants.REFERENCES),
+			pattern,
 			RefactoringScopeFactory.create(fField, fConsiderVisibility),
 			subPm,
 			result, true);
 
+		checkAffectedCUs(result, affectedCUs);
 		checkInHierarchy(result, usingLocalGetter, usingLocalSetter);
 		if (result.hasFatalError())
 			return result;
@@ -416,13 +426,62 @@ public class SelfEncapsulateFieldRefactoring extends Refactoring {
 
 		sub.done();
 		IFile[] filesToBeModified= ResourceUtil.getFiles(fChangeManager.getAllCompilationUnits());
-		result.merge(Checks.validateModifiesFiles(filesToBeModified, getValidationContext()));
+		result.merge(Checks.validateModifiesFiles(filesToBeModified, getValidationContext(), pm));
 		if (result.hasFatalError())
 			return result;
 		ResourceChangeChecker.checkFilesToBeChanged(filesToBeModified, new SubProgressMonitor(pm, 1));
 		return result;
 	}
 
+	private class AffectedCUVisitor extends ASTVisitor {
+		private String fTypeName= null;
+		private boolean fGetterConflict= false;
+
+		public String getTypeName() {
+			return fTypeName;
+		}
+
+		public boolean isGetterConflict() {
+			return fGetterConflict;
+		}
+
+		@Override
+		public boolean visit(TypeDeclaration node) {
+			ITypeBinding typeBinding= node.resolveBinding();
+			while (typeBinding != null) {
+				IMethodBinding[] methodBindings= typeBinding.getDeclaredMethods();
+				for (IMethodBinding methodBinding : methodBindings) {
+					if (methodBinding.getName().equals(getGetterName()) && methodBinding.getParameterNames().length == 0) {
+						fTypeName= typeBinding.getName();
+						fGetterConflict= true;
+						throw new AbortSearchException();
+					}
+					if (methodBinding.getName().equals(getSetterName()) && methodBinding.getParameterNames().length == 1) {
+						if (methodBinding.getParameterTypes()[0].isEqualTo(fFieldDeclaration.resolveBinding().getType())) {
+							fTypeName= typeBinding.getName();
+							throw new AbortSearchException();
+						}
+					}
+				}
+				typeBinding= typeBinding.getSuperclass();
+			}
+			return true;
+		}
+
+	}
+
+	private void checkAffectedCUs(RefactoringStatus result, ICompilationUnit[] affectedCUs) {
+		AffectedCUVisitor visitor= new AffectedCUVisitor();
+		try {
+			for (ICompilationUnit cu : affectedCUs) {
+				CompilationUnit root= new RefactoringASTParser(IASTSharedValues.SHARED_AST_LEVEL).parse(cu, true);
+				root.accept(visitor);
+			}
+		} catch (AbortSearchException e) {
+			result.addError(Messages.format(RefactoringCoreMessages.SelfEncapsulateField_subtype_method_exists, new String[] { visitor.isGetterConflict() ? getGetterName() : getSetterName(), visitor.getTypeName() }));
+		}
+	}
+
 	private void createEdits(ICompilationUnit unit, ASTRewrite rewriter, List<TextEditGroup> groups, ImportRewrite importRewrite) throws CoreException {
 		TextChange change= fChangeManager.get(unit);
 		MultiTextEdit root= new MultiTextEdit();
@@ -471,16 +530,16 @@ public class SelfEncapsulateFieldRefactoring extends Refactoring {
 			comment.addSetting(RefactoringCoreMessages.SelfEncapsulateField_generate_comments);
 		final EncapsulateFieldDescriptor descriptor= RefactoringSignatureDescriptorFactory.createEncapsulateFieldDescriptor(project, description, comment.asString(), arguments, flags);
 		arguments.put(JavaRefactoringDescriptorUtil.ATTRIBUTE_INPUT, JavaRefactoringDescriptorUtil.elementToHandle(project, fField));
-		arguments.put(ATTRIBUTE_VISIBILITY, Integer.valueOf(fVisibility).toString());
-		arguments.put(ATTRIBUTE_INSERTION, Integer.valueOf(fInsertionIndex).toString());
+		arguments.put(ATTRIBUTE_VISIBILITY, Integer.toString(fVisibility));
+		arguments.put(ATTRIBUTE_INSERTION, Integer.toString(fInsertionIndex));
 		if (fCreateSetter) {
 			arguments.put(ATTRIBUTE_SETTER, fSetterName);
 		}
 		if (fCreateGetter) {
 			arguments.put(ATTRIBUTE_GETTER, fGetterName);
 		}
-		arguments.put(ATTRIBUTE_COMMENTS, Boolean.valueOf(fGenerateJavadoc).toString());
-		arguments.put(ATTRIBUTE_DECLARING, Boolean.valueOf(fEncapsulateDeclaringClass).toString());
+		arguments.put(ATTRIBUTE_COMMENTS, Boolean.toString(fGenerateJavadoc));
+		arguments.put(ATTRIBUTE_DECLARING, Boolean.toString(fEncapsulateDeclaringClass));
 		final DynamicValidationRefactoringChange result= new DynamicValidationRefactoringChange(descriptor, getName());
 		TextChange[] changes= fChangeManager.getAllChanges();
 		pm.beginTask(NO_NAME, changes.length);
@@ -643,6 +702,17 @@ public class SelfEncapsulateFieldRefactoring extends Refactoring {
 		result.parameters().add(param);
 		param.setName(ast.newSimpleName(fArgName));
 		param.setType((Type)rewriter.createCopyTarget(type));
+		List<IExtendedModifier> modifiers= field.modifiers();
+		for (IExtendedModifier modifier : modifiers) {
+			if (modifier.isAnnotation()) {
+				String annotationName= ((Annotation)modifier).getTypeName().getFullyQualifiedName();
+				if ("NonNull".equals(annotationName) || "Nullable".equals(annotationName)) { //$NON-NLS-1$ //$NON-NLS-2$
+					Annotation fieldAnnotation= (Annotation)rewriter.createCopyTarget((Annotation)modifier);
+					param.modifiers().add(fieldAnnotation);
+				}
+			}
+		}
+
 		List<Dimension> extraDimensions= DimensionRewrite.copyDimensions(fFieldDeclaration.extraDimensions(), rewriter);
 		param.extraDimensions().addAll(extraDimensions);
 
@@ -685,6 +755,16 @@ public class SelfEncapsulateFieldRefactoring extends Refactoring {
 		MethodDeclaration result= ast.newMethodDeclaration();
 		result.setName(ast.newSimpleName(fGetterName));
 		result.modifiers().addAll(ASTNodeFactory.newModifiers(ast, createModifiers()));
+		List<IExtendedModifier> modifiers= field.modifiers();
+		for (IExtendedModifier modifier : modifiers) {
+			if (modifier.isAnnotation()) {
+				String annotationName= ((Annotation)modifier).getTypeName().getFullyQualifiedName();
+				if ("NonNull".equals(annotationName) || "Nullable".equals(annotationName)) { //$NON-NLS-1$ //$NON-NLS-2$
+					Annotation fieldAnnotation= (Annotation)rewriter.createCopyTarget((Annotation)modifier);
+					result.modifiers().add(fieldAnnotation);
+				}
+			}
+		}
 		Type returnType= DimensionRewrite.copyTypeAndAddDimensions(type, fFieldDeclaration.extraDimensions(), rewriter);
 		result.setReturnType2(returnType);
 
@@ -796,12 +876,12 @@ public class SelfEncapsulateFieldRefactoring extends Refactoring {
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_SETTER));
 		final String encapsulate= arguments.getAttribute(ATTRIBUTE_DECLARING);
 		if (encapsulate != null) {
-			fEncapsulateDeclaringClass= Boolean.valueOf(encapsulate).booleanValue();
+			fEncapsulateDeclaringClass= Boolean.parseBoolean(encapsulate);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_DECLARING));
 		final String matches= arguments.getAttribute(ATTRIBUTE_COMMENTS);
 		if (matches != null) {
-			fGenerateJavadoc= Boolean.valueOf(matches).booleanValue();
+			fGenerateJavadoc= Boolean.parseBoolean(matches);
 		} else
 			return RefactoringStatus.createFatalErrorStatus(Messages.format(RefactoringCoreMessages.InitializableRefactoring_argument_not_exist, ATTRIBUTE_COMMENTS));
 		final String visibility= arguments.getAttribute(ATTRIBUTE_VISIBILITY);
