@@ -16,7 +16,6 @@ package org.eclipse.jdt.internal.ui.refactoring;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.swt.SWT;
@@ -24,8 +23,6 @@ import org.eclipse.swt.events.KeyAdapter;
 import org.eclipse.swt.events.KeyEvent;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
-import org.eclipse.swt.events.TraverseEvent;
-import org.eclipse.swt.events.TraverseListener;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
@@ -45,13 +42,11 @@ import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.viewers.ColumnWeightData;
 import org.eclipse.jface.viewers.ICellModifier;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredContentProvider;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITableFontProvider;
 import org.eclipse.jface.viewers.ITableLabelProvider;
 import org.eclipse.jface.viewers.LabelProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.TableViewer;
 import org.eclipse.jface.viewers.Viewer;
@@ -323,20 +318,12 @@ public class ChangeParametersControl extends Composite {
 		fTableViewer.setUseHashlookup(true);
 		fTableViewer.setContentProvider(new ParameterInfoContentProvider());
 		fTableViewer.setLabelProvider(new ParameterInfoLabelProvider());
-		fTableViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				updateButtonsEnabledState();
-			}
-		});
+		fTableViewer.addSelectionChangedListener(event -> updateButtonsEnabledState());
 
-		table.addTraverseListener(new TraverseListener() {
-			@Override
-			public void keyTraversed(TraverseEvent e) {
-				if (e.detail == SWT.TRAVERSE_RETURN && e.stateMask == SWT.NONE) {
-					editColumnOrNextPossible(0);
-					e.detail= SWT.TRAVERSE_NONE;
-				}
+		table.addTraverseListener(e -> {
+			if (e.detail == SWT.TRAVERSE_RETURN && e.stateMask == SWT.NONE) {
+				editColumnOrNextPossible(0);
+				e.detail= SWT.TRAVERSE_NONE;
 			}
 		});
 		table.addKeyListener(new KeyAdapter() {
@@ -613,35 +600,29 @@ public class ChangeParametersControl extends Composite {
 			final int editorColumn= i;
 			final TableTextCellEditor editor = editors[i];
 			// support tabbing between columns while editing:
-			editor.getText().addTraverseListener(new TraverseListener() {
-				@Override
-				public void keyTraversed(TraverseEvent e) {
-					switch (e.detail) {
-						case SWT.TRAVERSE_TAB_NEXT :
-							editColumnOrNextPossible(nextColumn(editorColumn));
-							e.detail= SWT.TRAVERSE_NONE;
-							break;
+			editor.getText().addTraverseListener(e -> {
+				switch (e.detail) {
+					case SWT.TRAVERSE_TAB_NEXT :
+						editColumnOrNextPossible(nextColumn(editorColumn));
+						e.detail= SWT.TRAVERSE_NONE;
+						break;
 
-						case SWT.TRAVERSE_TAB_PREVIOUS :
-							editColumnOrPrevPossible(prevColumn(editorColumn));
-							e.detail= SWT.TRAVERSE_NONE;
-							break;
+					case SWT.TRAVERSE_TAB_PREVIOUS :
+						editColumnOrPrevPossible(prevColumn(editorColumn));
+						e.detail= SWT.TRAVERSE_NONE;
+						break;
 
-						default :
-							break;
-					}
+					default :
+						break;
 				}
 			});
 			TextFieldNavigationHandler.install(editor.getText());
 		}
 
-		editors[NEWNAME_PROP].setActivationListener(new TableTextCellEditor.IActivationListener(){
-			@Override
-			public void activate() {
-				ParameterInfo[] selected= getSelectedElements();
-				if (selected.length == 1 && fNameContentAssistHandler != null) {
-					fNameContentAssistHandler.setEnabled(selected[0].isAdded());
-				}
+		editors[NEWNAME_PROP].setActivationListener(() -> {
+			ParameterInfo[] selected= getSelectedElements();
+			if (selected.length == 1 && fNameContentAssistHandler != null) {
+				fNameContentAssistHandler.setEnabled(selected[0].isAdded());
 			}
 		});
 
@@ -699,9 +680,7 @@ public class ChangeParametersControl extends Composite {
 		}
 		res.addAll(deleted);
 		elements.clear();
-		for (Iterator<ParameterInfo> iter= res.iterator(); iter.hasNext();) {
-			elements.add(iter.next());
-		}
+		elements.addAll(res);
 	}
 
 	private boolean canMove(boolean up) {
@@ -712,8 +691,8 @@ public class ChangeParametersControl extends Composite {
 		if (indc.length == 0)
 			return false;
 		int invalid= up ? 0 : notDeletedInfosCount - 1;
-		for (int i= 0; i < indc.length; i++) {
-			if (indc[i] == invalid)
+		for (int element : indc) {
+			if (element == invalid)
 				return false;
 		}
 		return true;
