@@ -18,7 +18,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
@@ -39,13 +38,9 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.SubProgressMonitor;
 
 import org.eclipse.jface.dialogs.Dialog;
-import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.resource.JFaceResources;
-import org.eclipse.jface.viewers.CheckStateChangedEvent;
-import org.eclipse.jface.viewers.ICheckStateListener;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITreeContentProvider;
 import org.eclipse.jface.viewers.SelectionChangedEvent;
@@ -232,9 +227,9 @@ public class PullUpMethodPage extends UserInputWizardPage {
 		final Map<IType, HashSet<IMember>> typeToMemberSet= createTypeToMemberSetMapping(members);
 
 		final Map<IType, IMember[]> typeToMemberArray= new HashMap<>();
-		for (final Iterator<IType> iter= typeToMemberSet.keySet().iterator(); iter.hasNext();) {
-			final IType type= iter.next();
-			final Set<IMember> memberSet= typeToMemberSet.get(type);
+		for (Map.Entry<IType, HashSet<IMember>> entry : typeToMemberSet.entrySet()) {
+			IType type = entry.getKey();
+			final Set<IMember> memberSet= entry.getValue();
 			final IMember[] memberArray= memberSet.toArray(new IMember[memberSet.size()]);
 			typeToMemberArray.put(type, memberArray);
 		}
@@ -404,20 +399,8 @@ public class PullUpMethodPage extends UserInputWizardPage {
 		fTreeViewer.setLabelProvider(new JavaElementLabelProvider(JavaElementLabelProvider.SHOW_DEFAULT | JavaElementLabelProvider.SHOW_SMALL_ICONS));
 		fTreeViewer.setUseHashlookup(true);
 		fTreeViewer.setComparator(new JavaElementComparator());
-		fTreeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-
-			@Override
-			public void selectionChanged(final SelectionChangedEvent event) {
-				treeViewerSelectionChanged(event);
-			}
-		});
-		fTreeViewer.addCheckStateListener(new ICheckStateListener() {
-
-			@Override
-			public void checkStateChanged(final CheckStateChangedEvent event) {
-				updateSelectionLabel();
-			}
-		});
+		fTreeViewer.addSelectionChangedListener(this::treeViewerSelectionChanged);
+		fTreeViewer.addCheckStateListener(event -> updateSelectionLabel());
 	}
 
 	private void createTypeHierarchyLabel(final Composite composite) {
@@ -474,15 +457,11 @@ public class PullUpMethodPage extends UserInputWizardPage {
 
 	private void initializeTreeViewer() {
 		try {
-			getContainer().run(false, false, new IRunnableWithProgress() {
-
-				@Override
-				public void run(final IProgressMonitor pm) {
-					try {
-						initializeTreeViewer(pm);
-					} finally {
-						pm.done();
-					}
+			getContainer().run(false, false, pm -> {
+				try {
+					initializeTreeViewer(pm);
+				} finally {
+					pm.done();
 				}
 			});
 		} catch (InvocationTargetException e) {
