@@ -17,14 +17,11 @@ package org.eclipse.jdt.internal.ui.refactoring.nls;
 import java.io.InputStream;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Properties;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.SashForm;
-import org.eclipse.swt.events.ModifyEvent;
-import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.MouseAdapter;
 import org.eclipse.swt.events.MouseEvent;
 import org.eclipse.swt.events.SelectionAdapter;
@@ -70,7 +67,6 @@ import org.eclipse.jface.viewers.ColumnWeightData;
 import org.eclipse.jface.viewers.ICellModifier;
 import org.eclipse.jface.viewers.IFontProvider;
 import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITableLabelProvider;
 import org.eclipse.jface.viewers.LabelProvider;
@@ -97,6 +93,7 @@ import org.eclipse.ltk.ui.refactoring.UserInputWizardPage;
 import org.eclipse.jdt.core.ICompilationUnit;
 import org.eclipse.jdt.core.JavaModelException;
 
+import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.corext.refactoring.nls.KeyValuePair;
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSRefactoring;
 import org.eclipse.jdt.internal.corext.refactoring.nls.NLSSubstitution;
@@ -114,7 +111,6 @@ import org.eclipse.jdt.internal.ui.javaeditor.JavaSourceViewer;
 import org.eclipse.jdt.internal.ui.propertiesfileeditor.PropertiesFileEscapes;
 import org.eclipse.jdt.internal.ui.util.ExceptionHandler;
 import org.eclipse.jdt.internal.ui.util.SWTUtil;
-import org.eclipse.jdt.internal.core.manipulation.util.BasicElementLabels;
 import org.eclipse.jdt.internal.ui.viewsupport.JavaElementImageProvider;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.DialogField;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.IDialogFieldListener;
@@ -218,7 +214,7 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 						substitution.setValue(string);
 					}
 					if (PROPERTIES[STATE_PROP].equals(property)) {
-						substitution.setState(((Integer) value).intValue());
+						substitution.setState(((Integer) value));
 						if ((substitution.getState() == NLSSubstitution.EXTERNALIZED) && substitution.hasStateChanged()) {
 							substitution.generateKey(fSubstitutions, getProperties(fNLSRefactoring.getPropertyFileHandle()));
 						}
@@ -736,7 +732,7 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 								return;
 							NLSSubstitution substitution= (NLSSubstitution) widgetSel.get(0);
 							Integer value= (Integer) getCellModifier().getValue(substitution, PROPERTIES[STATE_PROP]);
-							int newValue= MultiStateCellEditor.getNextValue(NLSSubstitution.STATE_COUNT, value.intValue());
+							int newValue= MultiStateCellEditor.getNextValue(NLSSubstitution.STATE_COUNT, value);
 							getCellModifier().modify(item, PROPERTIES[STATE_PROP], Integer.valueOf(newValue));
 						}
 					}
@@ -767,12 +763,7 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 		fTableViewer.setLabelProvider(new NLSSubstitutionLabelProvider());
 		fTableViewer.setInput(fSubstitutions);
 
-		fTableViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				ExternalizeWizardPage.this.selectionChanged(event);
-			}
-		});
+		fTableViewer.addSelectionChangedListener(ExternalizeWizardPage.this::selectionChanged);
 	}
 
 	private void createDefaultExternalization(NLSSubstitution[] substitutions) {
@@ -848,12 +839,9 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 		fPrefixField.setText(fNLSRefactoring.getPrefix());
 		fPrefixField.selectAll();
 
-		fPrefixField.addModifyListener(new ModifyListener() {
-			@Override
-			public void modifyText(ModifyEvent e) {
-				fNLSRefactoring.setPrefix(fPrefixField.getText());
-				validateKeys(true);
-			}
+		fPrefixField.addModifyListener(e -> {
+			fNLSRefactoring.setPrefix(fPrefixField.getText());
+			validateKeys(true);
 		});
 	}
 
@@ -1122,9 +1110,8 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 	}
 
 	private void revertStateOfSelection() {
-		List<?> selection= getSelectedTableEntries();
-		for (Iterator<?> iter= selection.iterator(); iter.hasNext();) {
-			NLSSubstitution substitution= (NLSSubstitution) iter.next();
+		for (Object name : getSelectedTableEntries()) {
+			NLSSubstitution substitution= (NLSSubstitution) name;
 			substitution.revert();
 		}
 		fTableViewer.refresh();
@@ -1176,8 +1163,8 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 		Assert.isTrue(state == NLSSubstitution.EXTERNALIZED || state == NLSSubstitution.IGNORED || state == NLSSubstitution.INTERNALIZED);
 		List<?> selected= getSelectedTableEntries();
 		String[] props= new String[]{PROPERTIES[STATE_PROP]};
-		for (Iterator<?> iter= selected.iterator(); iter.hasNext();) {
-			NLSSubstitution substitution= (NLSSubstitution) iter.next();
+		for (Object name : selected) {
+			NLSSubstitution substitution= (NLSSubstitution) name;
 			substitution.setState(state);
 			if ((substitution.getState() == NLSSubstitution.EXTERNALIZED) && substitution.hasStateChanged()) {
 				substitution.generateKey(fSubstitutions, getProperties(fNLSRefactoring.getPropertyFileHandle()));
@@ -1230,8 +1217,8 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 	}
 
 	private boolean containsElementsWithChange(IStructuredSelection selection) {
-		for (Iterator<?> iter= selection.iterator(); iter.hasNext();) {
-			NLSSubstitution substitution= (NLSSubstitution) iter.next();
+		for (Object name : selection) {
+			NLSSubstitution substitution= (NLSSubstitution) name;
 			if (substitution.hasPropertyFileChange() || substitution.hasSourceChange()) {
 				return true;
 			}
@@ -1241,8 +1228,8 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 
 	private List<NLSSubstitution> getExternalizedElements(IStructuredSelection selection) {
 		ArrayList<NLSSubstitution> res= new ArrayList<>();
-		for (Iterator<?> iter= selection.iterator(); iter.hasNext();) {
-			NLSSubstitution substitution= (NLSSubstitution) iter.next();
+		for (Object name : selection) {
+			NLSSubstitution substitution= (NLSSubstitution) name;
 			if (substitution.getState() == NLSSubstitution.EXTERNALIZED && !substitution.hasStateChanged()) {
 				res.add(substitution);
 			}
@@ -1251,8 +1238,8 @@ class ExternalizeWizardPage extends UserInputWizardPage {
 	}
 
 	private boolean containsOnlyElementsOfSameState(int state, IStructuredSelection selection) {
-		for (Iterator<?> iter= selection.iterator(); iter.hasNext();) {
-			NLSSubstitution substitution= (NLSSubstitution) iter.next();
+		for (Object name : selection) {
+			NLSSubstitution substitution= (NLSSubstitution) name;
 			if (substitution.getState() != state) {
 				return false;
 			}
