@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,20 +17,21 @@ package org.eclipse.jdt.internal.ui.actions;
 import java.util.ArrayList;
 import java.util.ResourceBundle;
 
-import org.eclipse.swt.custom.BusyIndicator;
-import org.eclipse.swt.widgets.Display;
-
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
-
-import org.eclipse.text.edits.MultiTextEdit;
-import org.eclipse.text.edits.ReplaceEdit;
-import org.eclipse.text.edits.TextEdit;
-
-import org.eclipse.jface.viewers.ISelection;
-import org.eclipse.jface.viewers.ISelectionProvider;
-
+import org.eclipse.jdt.core.ICompilationUnit;
+import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.JavaCore;
+import org.eclipse.jdt.core.formatter.DefaultCodeFormatterConstants;
+import org.eclipse.jdt.core.formatter.IndentManipulation;
+import org.eclipse.jdt.internal.core.manipulation.util.Strings;
+import org.eclipse.jdt.internal.corext.util.CodeFormatterUtil;
+import org.eclipse.jdt.internal.ui.JavaPlugin;
+import org.eclipse.jdt.internal.ui.javaeditor.JavaEditor;
+import org.eclipse.jdt.internal.ui.text.JavaHeuristicScanner;
+import org.eclipse.jdt.internal.ui.text.JavaIndenter;
+import org.eclipse.jdt.ui.text.IJavaPartitions;
 import org.eclipse.jface.text.BadLocationException;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IRegion;
@@ -41,30 +42,19 @@ import org.eclipse.jface.text.Position;
 import org.eclipse.jface.text.TextSelection;
 import org.eclipse.jface.text.TextUtilities;
 import org.eclipse.jface.text.source.ISourceViewer;
-
+import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.jface.viewers.ISelectionProvider;
+import org.eclipse.swt.custom.BusyIndicator;
+import org.eclipse.swt.widgets.Display;
+import org.eclipse.text.edits.MultiTextEdit;
+import org.eclipse.text.edits.ReplaceEdit;
+import org.eclipse.text.edits.TextEdit;
 import org.eclipse.ui.IEditorInput;
-
 import org.eclipse.ui.texteditor.IDocumentProvider;
 import org.eclipse.ui.texteditor.ITextEditor;
 import org.eclipse.ui.texteditor.ITextEditorExtension3;
 import org.eclipse.ui.texteditor.TextEditorAction;
 
-import org.eclipse.jdt.core.ICompilationUnit;
-import org.eclipse.jdt.core.IJavaProject;
-import org.eclipse.jdt.core.JavaCore;
-import org.eclipse.jdt.core.formatter.DefaultCodeFormatterConstants;
-import org.eclipse.jdt.core.formatter.IndentManipulation;
-
-import org.eclipse.jdt.internal.core.manipulation.util.Strings;
-import org.eclipse.jdt.internal.corext.util.CodeFormatterUtil;
-
-import org.eclipse.jdt.ui.text.IJavaPartitions;
-
-import org.eclipse.jdt.internal.ui.JavaPlugin;
-import org.eclipse.jdt.internal.ui.javaeditor.JavaEditor;
-import org.eclipse.jdt.internal.ui.text.JavaHeuristicScanner;
-import org.eclipse.jdt.internal.ui.text.JavaIndenter;
-
 
 /**
  * Indents a line or range of lines in a Java document to its correct position. No complete
@@ -350,7 +340,6 @@ public class IndentAction extends TextEditorAction {
 		IRegion currentLine= document.getLineInformation(line);
 		int offset= currentLine.getOffset();
 		int wsStart= offset; // where we start searching for non-WS; after the "//" in single line comments
-
 		String indent= null;
 		if (offset < document.getLength()) {
 			ITypedRegion partition= TextUtilities.getPartition(document, IJavaPartitions.JAVA_PARTITIONING, offset, true);
@@ -381,11 +370,24 @@ public class IndentAction extends TextEditorAction {
 					indent= document.get(offset, wsStart - offset) + computed;
 				}
 			} else if (IJavaPartitions.JAVA_MULTI_LINE_STRING.equals(type)) {
-				if (textBlockInfo != null && textBlockInfo.getPartitionOffset() != partition.getOffset()) {
-					textBlockInfo.setPartitionOffset(partition.getOffset());
-					textBlockInfo.setMinIndent(IndentAction.getTextBlockMinIndent(document, partition.getOffset(), partition.getLength()));
+				if (textBlockInfo != null) {
+					if (textBlockInfo.getPartitionOffset() != partition.getOffset()) {
+						textBlockInfo.setPartitionOffset(partition.getOffset());
+						textBlockInfo.setMinIndent(IndentAction.getTextBlockMinIndent(document, partition.getOffset(), partition.getLength()));
+					}
+					indent= IndentAction.getTextBlockIndentationString(document, partition.getOffset(), currentLine.getOffset(), textBlockInfo.getMinIndent(), project);
+				}
+			} else if (document.get(currentLine.getOffset(), currentLine.getLength()).trim().equals(TEXT_BLOCK_STR)) {
+				ITypedRegion nextPartition= TextUtilities.getPartition(document, IJavaPartitions.JAVA_PARTITIONING, offset + currentLine.getLength(), false);
+				if (IJavaPartitions.JAVA_MULTI_LINE_STRING.equals(nextPartition.getType())) {
+					if (textBlockInfo != null) {
+						if (textBlockInfo.getPartitionOffset() != nextPartition.getOffset()) {
+							textBlockInfo.setPartitionOffset(nextPartition.getOffset());
+							textBlockInfo.setMinIndent(IndentAction.getTextBlockMinIndent(document, nextPartition.getOffset(), nextPartition.getLength()));
+						}
+						indent= IndentAction.getTextBlockIndentationString(document, nextPartition.getOffset(), currentLine.getOffset(), textBlockInfo.getMinIndent(), project);
+					}
 				}
-				indent= IndentAction.getTextBlockIndentationString(document, partition.getOffset(), currentLine.getOffset(), textBlockInfo.getMinIndent(), project);
 			}
 		}
 
@@ -924,71 +926,93 @@ public class IndentAction extends TextEditorAction {
 		String formatterTabValue= getFormatterTabValue(javaProject);
 		String stringTocalculate= null;
 		boolean isTextBlockStarting= false;
+		boolean prevLineEndsWithComma= false;
 		if ((fullStrNoTrim.endsWith(IndentAction.TEXT_BLOCK_STR) || fullStrNoTrim.trim().endsWith(IndentAction.TEXT_BLOCK_STR)) && startIndex != -1) {
 			stringTocalculate= fullStrNoTrim.substring(0, startIndex);
+			if (fullStrNoTrim.trim().equals(IndentAction.TEXT_BLOCK_STR)) {
+				int lineno= document.getLineOfOffset(line.getOffset());
+				boolean done= false;
+				while (--lineno > 0 && !done) {
+					IRegion prevLine= document.getLineInformation(lineno);
+					String prevLineString= document.get(prevLine.getOffset(), prevLine.getLength());
+					if (!prevLineString.trim().isEmpty()) {
+						stringTocalculate= prevLineString;
+						indentation= getLineIndentation(document, prevLine.getOffset());
+						prevLineEndsWithComma= prevLineString.trim().endsWith(","); //$NON-NLS-1$
+						done= true;
+					}
+				}
+			}
 			isTextBlockStarting= true;
 		} else {
 			stringTocalculate= indentation;
 		}
+		String commandIndent= EMPTY_STR;
 		if (isTextBlockStarting) {
-			if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_ON_COLUMN) {
-				String newStr= indentation;
-				int length= IndentAction.measureLengthInSpaces(stringTocalculate, CodeFormatterUtil.getTabWidth(javaProject));
-				StringBuilder str= new StringBuilder();
-				if (getUseTabsOnlyForLeadingIndentations(javaProject)) {
-					int existing= IndentAction.measureLengthInSpaces(indentation, CodeFormatterUtil.getTabWidth(javaProject));
-					if (length - existing > 0) {
-						for (int i= 0; i < length - existing; i++) {
-							newStr+= IndentAction.SPACE_STR;
-						}
-					}
-				} else {
-					for (int i= 0; i < length; i++) {
-						str.append(IndentAction.SPACE_STR);
-					}
-					int units= Strings.computeIndentUnits(str.toString(), javaProject);
-					newStr= CodeFormatterUtil.createIndentString(units, javaProject);
-					int newLength= IndentManipulation.measureIndentInSpaces(newStr, CodeFormatterUtil.getTabWidth(javaProject));
-					if (newLength < length) {
-						if (DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue) || JavaCore.SPACE.equals(formatterTabValue)) {
-							for (int i= newLength; i < length; i++) {
+			if (!prevLineEndsWithComma) {
+				if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_ON_COLUMN) {
+					String newStr= indentation;
+					int length= IndentAction.measureLengthInSpaces(stringTocalculate, CodeFormatterUtil.getTabWidth(javaProject));
+					StringBuilder str= new StringBuilder();
+					if (getUseTabsOnlyForLeadingIndentations(javaProject)) {
+						int existing= IndentAction.measureLengthInSpaces(indentation, CodeFormatterUtil.getTabWidth(javaProject));
+						if (length - existing > 0) {
+							for (int i= 0; i < length - existing; i++) {
 								newStr+= IndentAction.SPACE_STR;
 							}
-						} else if (JavaCore.TAB.equals(formatterTabValue)) {
-							newStr+= tabString;
+						}
+					} else {
+						for (int i= 0; i < length; i++) {
+							str.append(IndentAction.SPACE_STR);
+						}
+						int units= Strings.computeIndentUnits(str.toString(), javaProject);
+						newStr= CodeFormatterUtil.createIndentString(units, javaProject);
+						int newLength= IndentManipulation.measureIndentInSpaces(newStr, CodeFormatterUtil.getTabWidth(javaProject));
+						if (newLength < length) {
+							if (DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue) || JavaCore.SPACE.equals(formatterTabValue)) {
+								for (int i= newLength; i < length; i++) {
+									newStr+= IndentAction.SPACE_STR;
+								}
+							} else if (JavaCore.TAB.equals(formatterTabValue)) {
+								newStr+= tabString;
+							}
 						}
 					}
-				}
-				indentation= newStr;
-			} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_BY_ONE) {
-				if (JavaCore.TAB.equals(formatterTabValue)
-						|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
-					indentation+= tabString;
-				} else if (JavaCore.SPACE.equals(formatterTabValue)) {
-					indentation+= tabSpaceString;
-				}
-			} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_PRESERVE) {
-				indentation= IndentAction.EMPTY_STR;
-			} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_DEFAULT) {
-				String indentString= EMPTY_STR;
-				if (JavaCore.TAB.equals(formatterTabValue)
-						|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
-					indentString= tabString;
-				} else if (JavaCore.SPACE.equals(formatterTabValue)) {
-					indentString= tabSpaceString;
-				}
-				int count= getFormatterContinuationIndentation(javaProject);
-				for (int i= 0; i < count; i++) {
-					indentation+= indentString;
+					indentation= newStr;
+				} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_BY_ONE) {
+					if (JavaCore.TAB.equals(formatterTabValue)
+							|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
+						indentation+= tabString;
+					} else if (JavaCore.SPACE.equals(formatterTabValue)) {
+						indentation+= tabSpaceString;
+					}
+				} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_PRESERVE) {
+					indentation= IndentAction.EMPTY_STR;
+				} else if (textBlockIndentationOption == DefaultCodeFormatterConstants.INDENT_DEFAULT) {
+					String indentString= EMPTY_STR;
+					if (JavaCore.TAB.equals(formatterTabValue)
+							|| DefaultCodeFormatterConstants.MIXED.equals(formatterTabValue)) {
+						indentString= tabString;
+					} else if (JavaCore.SPACE.equals(formatterTabValue)) {
+						indentString= tabSpaceString;
+					}
+					int count= getFormatterContinuationIndentation(javaProject);
+					for (int i= 0; i < count; i++) {
+						indentation+= indentString;
+					}
 				}
 			}
 		}
-		String commandIndent= EMPTY_STR;
 		if (minIndent > 0) {
 			IRegion commandLine= document.getLineInformationOfOffset(commandOffset);
-			// handle extra indentation but ignore empty lines or short lines with only white-space
-			if (commandLine.getLength() > minIndent) {
-				commandIndent= getLineIndentation(document, commandLine.getOffset()).substring(minIndent);
+			if (commandLine.getOffset() != line.getOffset()) {
+				// handle extra indentation but ignore empty lines or short lines with only white-space
+				if (commandLine.getLength() > minIndent) {
+					String currentLineIndent= getLineIndentation(document, commandLine.getOffset());
+					if (currentLineIndent.length() > minIndent) {
+						commandIndent= currentLineIndent.substring(minIndent);
+					}
+				}
 			}
 		}
 		return indentation + commandIndent;
