@@ -120,27 +120,30 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 			sourceRefs= fragment.getCompilationUnits();
 		}
 		else {
-			IOrdinaryClassFile[] classFiles= fragment.getOrdinaryClassFiles();
 			List<IOrdinaryClassFile> topLevelClassFile= new ArrayList<>();
-			for (int i= 0; i < classFiles.length; i++) {
-				IType type= classFiles[i].getType();
-				if (type != null && type.getDeclaringType() == null && !type.isAnonymous() && !type.isLocal())
-					topLevelClassFile.add(classFiles[i]);
+			for (IOrdinaryClassFile classFile : fragment.getOrdinaryClassFiles()) {
+				IType type= classFile.getType();
+				if (type != null && type.getDeclaringType() == null && !type.isAnonymous() && !type.isLocal()) {
+					topLevelClassFile.add(classFile);
+				}
 			}
 			sourceRefs= topLevelClassFile.toArray(new ISourceReference[topLevelClassFile.size()]);
 		}
 
 		Object[] result= new Object[0];
-		for (int i= 0; i < sourceRefs.length; i++)
-			result= concatenate(result, removeImportAndPackageDeclarations(getChildren(sourceRefs[i])));
+		for (ISourceReference sourceRef : sourceRefs) {
+			result= concatenate(result, removeImportAndPackageDeclarations(getChildren(sourceRef)));
+		}
 		return concatenate(result, fragment.getNonJavaResources());
 	}
 
 	private Object[] removeImportAndPackageDeclarations(Object[] members) {
 		ArrayList<Object> tempResult= new ArrayList<>(members.length);
-		for (int i= 0; i < members.length; i++)
-			if (!(members[i] instanceof IImportContainer) && !(members[i] instanceof IPackageDeclaration))
-				tempResult.add(members[i]);
+		for (Object member : members) {
+			if (!(member instanceof IImportContainer) && !(member instanceof IPackageDeclaration)) {
+				tempResult.add(member);
+			}
+		}
 		return tempResult.toArray();
 	}
 
@@ -157,9 +160,11 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 		// Add import declarations
 		IJavaElement[] members= parent.getChildren();
 		ArrayList<IJavaElement> tempResult= new ArrayList<>(members.length);
-		for (int i= 0; i < members.length; i++)
-			if ((members[i] instanceof IImportContainer))
-				tempResult.add(members[i]);
+		for (IJavaElement member : members) {
+			if (member instanceof IImportContainer) {
+				tempResult.add(member);
+			}
+		}
 		tempResult.addAll(Arrays.asList(type.getChildren()));
 		return tempResult.toArray();
 	}
@@ -173,12 +178,10 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 		List<IJavaElement> list= new ArrayList<>(roots.length);
 		// filter out package fragments that correspond to projects and
 		// replace them with the package fragments directly
-		for (int i= 0; i < roots.length; i++) {
-			IPackageFragmentRoot root= roots[i];
+		for (IPackageFragmentRoot root : roots) {
 			if (!root.isExternal()) {
 				IJavaElement[] children= root.getChildren();
-				for (int k= 0; k < children.length; k++)
-					list.add(children[k]);
+				list.addAll(Arrays.asList(children));
 			}
 			else if (hasChildren(root)) {
 				list.add(root);
@@ -356,8 +359,8 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 				return;
 			}
 		}
-		for (int i= 0; i < affectedChildren.length; i++) {
-			processDelta(affectedChildren[i]);
+		for (IJavaElementDelta child : affectedChildren) {
+			processDelta(child);
 		}
 	}
 
@@ -372,24 +375,18 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 	 * Updates the package icon
 	 */
 	 private void postUpdateIcon(final IJavaElement element) {
-	 	postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl= fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed())
-					fViewer.update(element, new String[]{IBasicPropertyConstants.P_IMAGE});
-			}
+	 	postRunnable(() -> {
+			Control ctrl= fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed())
+				fViewer.update(element, new String[]{IBasicPropertyConstants.P_IMAGE});
 		});
 	 }
 
 	private void postRefresh(final Object root, final boolean updateLabels) {
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl= fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed())
-					fViewer.refresh(root, updateLabels);
-			}
+		postRunnable(() -> {
+			Control ctrl= fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed())
+				fViewer.refresh(root, updateLabels);
 		});
 	}
 
@@ -405,28 +402,25 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 		if (elements == null || elements.length <= 0)
 			return;
 
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl= fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed()) {
-					Object[] newElements= getNewElements(elements);
-					if (fViewer instanceof AbstractTreeViewer) {
-						if (fViewer.testFindItem(parent) == null) {
-							Object root= ((AbstractTreeViewer)fViewer).getInput();
-							if (root != null)
-								((AbstractTreeViewer)fViewer).add(root, newElements);
-						}
-						else
-							((AbstractTreeViewer)fViewer).add(parent, newElements);
+		postRunnable(() -> {
+			Control ctrl= fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed()) {
+				Object[] newElements= getNewElements(elements);
+				if (fViewer instanceof AbstractTreeViewer) {
+					if (fViewer.testFindItem(parent) == null) {
+						Object root= ((AbstractTreeViewer)fViewer).getInput();
+						if (root != null)
+							((AbstractTreeViewer)fViewer).add(root, newElements);
 					}
-					else if (fViewer instanceof ListViewer)
-						((ListViewer)fViewer).add(newElements);
-					else if (fViewer instanceof TableViewer)
-						((TableViewer)fViewer).add(newElements);
-					if (fViewer.testFindItem(elements[0]) != null)
-						fBrowsingPart.adjustInputAndSetSelection(elements[0]);
+					else
+						((AbstractTreeViewer)fViewer).add(parent, newElements);
 				}
+				else if (fViewer instanceof ListViewer)
+					((ListViewer)fViewer).add(newElements);
+				else if (fViewer instanceof TableViewer)
+					((TableViewer)fViewer).add(newElements);
+				if (fViewer.testFindItem(elements[0]) != null)
+					fBrowsingPart.adjustInputAndSetSelection(elements[0]);
 			}
 		});
 	}
@@ -450,32 +444,26 @@ class JavaBrowsingContentProvider extends StandardJavaElementContentProvider imp
 		if (elements.length <= 0)
 			return;
 
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl= fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed()) {
-					if (fViewer instanceof AbstractTreeViewer)
-						((AbstractTreeViewer)fViewer).remove(elements);
-					else if (fViewer instanceof ListViewer)
-						((ListViewer)fViewer).remove(elements);
-					else if (fViewer instanceof TableViewer)
-						((TableViewer)fViewer).remove(elements);
-				}
+		postRunnable(() -> {
+			Control ctrl= fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed()) {
+				if (fViewer instanceof AbstractTreeViewer)
+					((AbstractTreeViewer)fViewer).remove(elements);
+				else if (fViewer instanceof ListViewer)
+					((ListViewer)fViewer).remove(elements);
+				else if (fViewer instanceof TableViewer)
+					((TableViewer)fViewer).remove(elements);
 			}
 		});
 	}
 
 	private void postAdjustInputAndSetSelection(final Object element) {
-		postRunnable(new Runnable() {
-			@Override
-			public void run() {
-				Control ctrl= fViewer.getControl();
-				if (ctrl != null && !ctrl.isDisposed()) {
-					ctrl.setRedraw(false);
-					fBrowsingPart.adjustInputAndSetSelection(element);
-					ctrl.setRedraw(true);
-				}
+		postRunnable(() -> {
+			Control ctrl= fViewer.getControl();
+			if (ctrl != null && !ctrl.isDisposed()) {
+				ctrl.setRedraw(false);
+				fBrowsingPart.adjustInputAndSetSelection(element);
+				ctrl.setRedraw(true);
 			}
 		});
 	}
