@@ -180,9 +180,9 @@ public class PackagesView extends JavaBrowsingPart{
 		} else {
 			//restore from memento
 			Integer integer= memento.getInteger(this.getViewSite().getId() + TAG_VIEW_STATE);
-			if ((integer == null) || !isValidState(integer.intValue())) {
+			if ((integer == null) || !isValidState(integer)) {
 				fCurrViewState= LIST_VIEW_STATE;
-			} else fCurrViewState= integer.intValue();
+			} else fCurrViewState= integer;
 		}
 	}
 
@@ -218,12 +218,7 @@ public class PackagesView extends JavaBrowsingPart{
 	@Override
 	public <T> T getAdapter(Class<T> key) {
 		if (key == IShowInTargetList.class) {
-			return (T) new IShowInTargetList() {
-				@Override
-				public String[] getShowInTargetIds() {
-					return new String[] { JavaUI.ID_PACKAGES };
-				}
-			};
+			return (T) (IShowInTargetList) () -> new String[] { JavaUI.ID_PACKAGES };
 		}
 		return super.getAdapter(key);
 	}
@@ -626,7 +621,9 @@ public class PackagesView extends JavaBrowsingPart{
 	 */
 	@Override
 	boolean isInputResetBy(Object newInput, Object input, IWorkbenchPart part) {
-		return (!(part instanceof ProjectsView || part instanceof PackageExplorerPart)) && super.isInputResetBy(newInput, input, part);
+		return !(part instanceof ProjectsView)
+				&& !(part instanceof PackageExplorerPart)
+				&& super.isInputResetBy(newInput, input, part);
 	}
 
 }
