@@ -23,9 +23,7 @@ import org.eclipse.core.resources.ResourcesPlugin;
 
 import org.eclipse.jface.action.IToolBarManager;
 import org.eclipse.jface.commands.ActionHandler;
-import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IContentProvider;
-import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.StructuredSelection;
@@ -79,13 +77,7 @@ public class ProjectsView extends JavaBrowsingPart {
 	@Override
 	public <T> T getAdapter(Class<T> key) {
 		if (key == IShowInTargetList.class) {
-			return (T) new IShowInTargetList() {
-				@Override
-				public String[] getShowInTargetIds() {
-					return new String[] { JavaUI.ID_PACKAGES };
-				}
-
-			};
+			return (T) (IShowInTargetList) () -> new String[] { JavaUI.ID_PACKAGES };
 		}
 		return super.getAdapter(key);
 	}
@@ -118,14 +110,11 @@ public class ProjectsView extends JavaBrowsingPart {
 	@Override
 	protected void hookViewerListeners() {
 		super.hookViewerListeners();
-		getViewer().addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				TreeViewer viewer= (TreeViewer)getViewer();
-				Object element= ((IStructuredSelection)event.getSelection()).getFirstElement();
-				if (viewer.isExpandable(element))
-					viewer.setExpandedState(element, !viewer.getExpandedState(element));
-			}
+		getViewer().addDoubleClickListener(event -> {
+			TreeViewer viewer= (TreeViewer)getViewer();
+			Object element= ((IStructuredSelection)event.getSelection()).getFirstElement();
+			if (viewer.isExpandable(element))
+				viewer.setExpandedState(element, !viewer.getExpandedState(element));
 		});
 	}
 
@@ -177,7 +166,7 @@ public class ProjectsView extends JavaBrowsingPart {
 			case IJavaElement.JAVA_PROJECT:
 				return je;
 			case IJavaElement.PACKAGE_FRAGMENT_ROOT:
-				if (je.getElementName().equals(IPackageFragmentRoot.DEFAULT_PACKAGEROOT_PATH))
+				if (IPackageFragmentRoot.DEFAULT_PACKAGEROOT_PATH.equals(je.getElementName()))
 					return je.getParent();
 				else
 					return je;
