@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2016 Mateusz Matela and others.
+ * Copyright (c) 2008, 2023 Mateusz Matela and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -22,16 +22,13 @@ import java.util.Arrays;
 import java.util.Comparator;
 import java.util.List;
 
-import com.ibm.icu.text.Collator;
+import java.text.Collator;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.events.TraverseEvent;
-import org.eclipse.swt.events.TraverseListener;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -56,13 +53,9 @@ import org.eclipse.jface.fieldassist.IContentProposal;
 import org.eclipse.jface.fieldassist.IContentProposalProvider;
 import org.eclipse.jface.fieldassist.TextContentAdapter;
 import org.eclipse.jface.resource.ImageDescriptor;
-import org.eclipse.jface.viewers.CheckStateChangedEvent;
 import org.eclipse.jface.viewers.CheckboxTreeViewer;
-import org.eclipse.jface.viewers.ICheckStateListener;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITreeContentProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.StructuredSelection;
 import org.eclipse.jface.viewers.Viewer;
 
@@ -85,6 +78,7 @@ import org.eclipse.jdt.core.search.SearchEngine;
 
 import org.eclipse.jdt.internal.corext.codemanipulation.tostringgeneration.GenerateToStringOperation;
 import org.eclipse.jdt.internal.corext.codemanipulation.tostringgeneration.ToStringGenerationSettings;
+import org.eclipse.jdt.internal.corext.codemanipulation.tostringgeneration.ToStringGenerationSettingsCore;
 import org.eclipse.jdt.internal.corext.codemanipulation.tostringgeneration.ToStringGenerationSettingsCore.CustomBuilderSettings;
 import org.eclipse.jdt.internal.corext.codemanipulation.tostringgeneration.ToStringTemplateParser;
 import org.eclipse.jdt.internal.corext.util.JavaConventionsUtil;
@@ -208,7 +202,7 @@ public class GenerateToStringDialog extends SourceActionDialog {
 		}
 
 		public void sort() {
-			Comparator<IBinding> comparator= new Comparator<IBinding>() {
+			Comparator<IBinding> comparator= new Comparator<>() {
 				Collator collator= Collator.getInstance();
 				@Override
 				public int compare(IBinding b1, IBinding b2) {
@@ -396,20 +390,12 @@ public class GenerateToStringDialog extends SourceActionDialog {
 				}
 				templateName.setSelection(0, templateName.getText().length());
 
-				templateName.addModifyListener(new ModifyListener() {
-					@Override
-					public void modifyText(ModifyEvent e) {
-						validate(templateName.getText());
-					}
-				});
+				templateName.addModifyListener(e -> validate(templateName.getText()));
 
 				//Ctrl+Enter should execute the default button, workaround for https://bugs.eclipse.org/bugs/show_bug.cgi?id=145959
-				template.addTraverseListener(new TraverseListener() {
-					@Override
-					public void keyTraversed(TraverseEvent e) {
-						if (e.detail == SWT.TRAVERSE_RETURN && (e.stateMask & SWT.MODIFIER_MASK) != 0) {
-							buttonPressed(((Integer)getShell().getDefaultButton().getData()).intValue());
-						}
+				template.addTraverseListener(e -> {
+					if (e.detail == SWT.TRAVERSE_RETURN && (e.stateMask & SWT.MODIFIER_MASK) != 0) {
+						buttonPressed(((Integer)getShell().getDefaultButton().getData()));
 					}
 				});
 
@@ -458,7 +444,7 @@ public class GenerateToStringDialog extends SourceActionDialog {
 			private String fixLineBreaks(String input) {
 				String systemLineDelimiter= Text.DELIMITER;
 				final String javaLineDelimiter= "\n"; //$NON-NLS-1$
-				if (!systemLineDelimiter.equals(javaLineDelimiter)) {
+				if (!javaLineDelimiter.equals(systemLineDelimiter)) {
 					StringBuilder outputBuffer= new StringBuilder(input);
 					int pos= outputBuffer.indexOf(systemLineDelimiter);
 					while (pos >= 0) {
@@ -558,13 +544,13 @@ public class GenerateToStringDialog extends SourceActionDialog {
 			}
 		}
 
-		private final int ADD_BUTTON= IDialogConstants.CLIENT_ID + 1;
+		private static final int ADD_BUTTON= IDialogConstants.CLIENT_ID + 1;
 
-		private final int REMOVE_BUTTON= IDialogConstants.CLIENT_ID + 2;
+		private static final int REMOVE_BUTTON= IDialogConstants.CLIENT_ID + 2;
 
-		private final int APPLY_BUTTON= IDialogConstants.CLIENT_ID + 3;
+		private static final int APPLY_BUTTON= IDialogConstants.CLIENT_ID + 3;
 
-		private final int EDIT_BUTTON= IDialogConstants.CLIENT_ID + 4;
+		private static final int EDIT_BUTTON= IDialogConstants.CLIENT_ID + 4;
 
 		private Text templateTextControl;
 
@@ -662,8 +648,8 @@ public class GenerateToStringDialog extends SourceActionDialog {
 		}
 
 		private void applyChanges() {
-			getDialogSettings().put(ToStringGenerationSettings.SETTINGS_TEMPLATE_NAMES, templateNames.toArray(new String[0]));
-			getDialogSettings().put(ToStringGenerationSettings.SETTINGS_TEMPLATES, templates.toArray(new String[0]));
+			getDialogSettings().put(ToStringGenerationSettingsCore.SETTINGS_TEMPLATE_NAMES, templateNames.toArray(new String[0]));
+			getDialogSettings().put(ToStringGenerationSettingsCore.SETTINGS_TEMPLATES, templates.toArray(new String[0]));
 			getGenerationSettings().stringFormatTemplateNumber= Math.max(selectedTemplateNumber, 0);
 			somethingChanged= false;
 			getButton(APPLY_BUTTON).setEnabled(false);
@@ -810,8 +796,9 @@ public class GenerateToStringDialog extends SourceActionDialog {
 				IType type= findType(builderSettings.className);
 
 				if (type == null || !type.exists()) {
-					return new StatusInfo(IStatus.ERROR, MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidClassError,
-							new Object[] { builderSettings.className }));
+					return new StatusInfo(IStatus.ERROR,
+							MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidClassError,
+									builderSettings.className));
 				}
 
 				IStatus typeValidation= validateBuilderType(type);
@@ -819,16 +806,19 @@ public class GenerateToStringDialog extends SourceActionDialog {
 					return typeValidation;
 
 				if (!getAppendMethodSuggestions(type).contains(builderSettings.appendMethod))
-					return new StatusInfo(IStatus.ERROR, MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidAppendMethodError,
-							new Object[] { builderSettings.appendMethod }));
+					return new StatusInfo(IStatus.ERROR,
+							MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidAppendMethodError,
+									builderSettings.appendMethod));
 
 				if (!getResultMethodSuggestions(type).contains(builderSettings.resultMethod))
-					return new StatusInfo(IStatus.ERROR, MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidResultMethodError,
-							new Object[] { builderSettings.resultMethod }));
+					return new StatusInfo(IStatus.ERROR,
+							MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidResultMethodError,
+									builderSettings.resultMethod));
 
 				if (!isValidJavaIdentifier(builderSettings.variableName))
-					return new StatusInfo(IStatus.ERROR, MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidVariableNameError,
-							new Object[] { builderSettings.variableName }));
+					return new StatusInfo(IStatus.ERROR,
+							MessageFormat.format(JavaUIMessages.GenerateToStringDialog_customBuilderConfig_invalidVariableNameError,
+									builderSettings.variableName));
 
 			} catch (JavaModelException e) {
 				return new StatusInfo(IStatus.WARNING, JavaUIMessages.GenerateToStringDialog_customBuilderConfig_dataValidationError);
@@ -848,28 +838,25 @@ public class GenerateToStringDialog extends SourceActionDialog {
 			if (fLastValidBuilderType != null && fLastValidBuilderType.equals(type)) {
 				return fLastValidAppendMethodSuggestions;
 			}
-			return getMethodSuggestions(type, new MethodChecker() {
-				@Override
-				public boolean isMethodOK(IMethod method) throws JavaModelException {
-					if (!Flags.isPublic(method.getFlags()) || method.isConstructor())
-						return false;
-					/* To be an append method, it must take exactly one
-					 * Object parameter, and optionally one String parameter. */
-					String[] parameterTypes= method.getParameterTypes();
-					if (parameterTypes.length == 0 || parameterTypes.length > 2) {
-						return false;
-					}
-					int countObjects= 0, countStrings= 0;
-					for (String parameterType : parameterTypes) {
-						String resolvedParameterTypeName= JavaModelUtil.getResolvedTypeName(parameterType, type);
-						if ("java.lang.Object".equals(resolvedParameterTypeName))//$NON-NLS-1$
-							countObjects++;
-						if ("java.lang.String".equals(resolvedParameterTypeName))//$NON-NLS-1$
-							countStrings++;
-					}
-					return countObjects == 1 && countObjects + countStrings == parameterTypes.length;
-
+			return getMethodSuggestions(type, method -> {
+				if (!Flags.isPublic(method.getFlags()) || method.isConstructor())
+					return false;
+				/* To be an append method, it must take exactly one
+				 * Object parameter, and optionally one String parameter. */
+				String[] parameterTypes= method.getParameterTypes();
+				if (parameterTypes.length == 0 || parameterTypes.length > 2) {
+					return false;
 				}
+				int countObjects= 0, countStrings= 0;
+				for (String parameterType : parameterTypes) {
+					String resolvedParameterTypeName= JavaModelUtil.getResolvedTypeName(parameterType, type);
+					if ("java.lang.Object".equals(resolvedParameterTypeName))//$NON-NLS-1$
+						countObjects++;
+					if ("java.lang.String".equals(resolvedParameterTypeName))//$NON-NLS-1$
+						countStrings++;
+				}
+				return countObjects == 1 && countObjects + countStrings == parameterTypes.length;
+
 			});
 		}
 
@@ -877,12 +864,7 @@ public class GenerateToStringDialog extends SourceActionDialog {
 			if (fLastValidBuilderType != null && fLastValidBuilderType.equals(type)) {
 				return fLastValidResultMethodSuggestions;
 			}
-			return getMethodSuggestions(type, new MethodChecker() {
-				@Override
-				public boolean isMethodOK(IMethod method) throws JavaModelException {
-					return Flags.isPublic(method.getFlags()) && method.getParameterTypes().length == 0 && "java.lang.String".equals(JavaModelUtil.getResolvedTypeName(method.getReturnType(), type)); //$NON-NLS-1$
-				}
-			});
+			return getMethodSuggestions(type, method -> Flags.isPublic(method.getFlags()) && method.getParameterTypes().length == 0 && "java.lang.String".equals(JavaModelUtil.getResolvedTypeName(method.getReturnType(), type))); //$NON-NLS-1$
 		}
 
 		private interface MethodChecker {
@@ -925,21 +907,17 @@ public class GenerateToStringDialog extends SourceActionDialog {
 		/**
 		 * Listener for text fields - updates combos and validates entered data
 		 */
-		private final ModifyListener modifyListener= new ModifyListener() {
+		private final ModifyListener modifyListener= e -> {
+			if (e.widget == this.fBuilderClassName) {
+				this.fBuilderSettings.className= this.fBuilderClassName.getText();
+				updateCombos();
+			} else if (e.widget == this.fBuilderVariableName)
+				this.fBuilderSettings.variableName= this.fBuilderVariableName.getText();
 
-			@Override
-			public void modifyText(ModifyEvent e) {
-				if (e.widget == fBuilderClassName) {
-					fBuilderSettings.className= fBuilderClassName.getText();
-					updateCombos();
-				} else if (e.widget == fBuilderVariableName)
-					fBuilderSettings.variableName= fBuilderVariableName.getText();
+			IStatus status= getValidator().revalidateAll(this.fBuilderSettings);
+			updateStatus(status);
 
-				IStatus status= getValidator().revalidateAll(fBuilderSettings);
-				updateStatus(status);
-
-				enableApplyButton();
-			}
+			enableApplyButton();
 		};
 
 		private final CustomBuilderValidator fValidator= new CustomBuilderValidator(getType().getJavaProject());
@@ -1005,19 +983,16 @@ public class GenerateToStringDialog extends SourceActionDialog {
 			fResultMethodName.setLayoutData(new GridData(SWT.FILL, SWT.CENTER, true, false, 2, 1));
 
 			updateCombos();
-			ModifyListener comboListener= new ModifyListener() {
-				@Override
-				public void modifyText(ModifyEvent e) {
-					Combo c= (Combo)e.widget;
-					if (c.getText().length() > 0) {
-						if (c == fAppendMethodName)
-							fBuilderSettings.appendMethod= c.getText();
-						if (c == fResultMethodName)
-							fBuilderSettings.resultMethod= c.getText();
-					}
-					updateStatus(fValidator.revalidateAll(fBuilderSettings));
-					enableApplyButton();
+			ModifyListener comboListener= e -> {
+				Combo c= (Combo)e.widget;
+				if (c.getText().length() > 0) {
+					if (c == fAppendMethodName)
+						fBuilderSettings.appendMethod= c.getText();
+					if (c == fResultMethodName)
+						fBuilderSettings.resultMethod= c.getText();
 				}
+				updateStatus(fValidator.revalidateAll(fBuilderSettings));
+				enableApplyButton();
 			};
 			fAppendMethodName.addModifyListener(comboListener);
 			fResultMethodName.addModifyListener(comboListener);
@@ -1170,14 +1145,14 @@ public class GenerateToStringDialog extends SourceActionDialog {
 	}
 
 	public static String[] getTemplates(IDialogSettings dialogSettings) {
-		String[] result= dialogSettings.getArray(ToStringGenerationSettings.SETTINGS_TEMPLATES);
+		String[] result= dialogSettings.getArray(ToStringGenerationSettingsCore.SETTINGS_TEMPLATES);
 		if (result != null && result.length > 0)
 			return result;
 		return new String[] { ToStringTemplateParser.DEFAULT_TEMPLATE };
 	}
 
 	public String[] getTemplateNames() {
-		String[] result= getDialogSettings().getArray(ToStringGenerationSettings.SETTINGS_TEMPLATE_NAMES);
+		String[] result= getDialogSettings().getArray(ToStringGenerationSettingsCore.SETTINGS_TEMPLATE_NAMES);
 		if (result != null && result.length > 0)
 			return result;
 		return new String[] { JavaUIMessages.GenerateToStringDialog_defaultTemplateName };
@@ -1185,7 +1160,7 @@ public class GenerateToStringDialog extends SourceActionDialog {
 
 	public int getSelectedTemplate() {
 		try {
-			int result= getDialogSettings().getInt(ToStringGenerationSettings.SETTINGS_SELECTED_TEMPLATE);
+			int result= getDialogSettings().getInt(ToStringGenerationSettingsCore.SETTINGS_SELECTED_TEMPLATE);
 			if (result < 0)
 				return 0;
 			return result;
@@ -1195,7 +1170,7 @@ public class GenerateToStringDialog extends SourceActionDialog {
 	}
 
 	public void setSelectedTemplate(int templateNumber) {
-		getDialogSettings().put(ToStringGenerationSettings.SETTINGS_SELECTED_TEMPLATE, templateNumber);
+		getDialogSettings().put(ToStringGenerationSettingsCore.SETTINGS_SELECTED_TEMPLATE, templateNumber);
 	}
 
 	public GenerateToStringDialog(Shell shell, CompilationUnitEditor editor, IType type, IVariableBinding[] fields, IVariableBinding[] inheritedFields, IVariableBinding[] selectedFields,
@@ -1258,44 +1233,36 @@ public class GenerateToStringDialog extends SourceActionDialog {
 		treeViewer.collapseAll();
 		treeViewer.expandToLevel(GenerateToStringContentProvider.fieldsNode, 1);
 
-		treeViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				IStructuredSelection selection= (IStructuredSelection)getTreeViewer().getSelection();
+		treeViewer.addSelectionChangedListener(event -> {
+			IStructuredSelection selection= (IStructuredSelection)getTreeViewer().getSelection();
 
-				Object selected= selection.size() > 0 ? selection.toList().get(0) : null;
-				GenerateToStringContentProvider cp= (GenerateToStringContentProvider)getContentProvider();
-
-				fButtonControls[UP_INDEX].setEnabled(cp.canMoveUp(selected));
-				fButtonControls[DOWN_INDEX].setEnabled(cp.canMoveDown(selected));
-			}
+			Object selected= selection.size() > 0 ? selection.toList().get(0) : null;
+			GenerateToStringContentProvider cp= (GenerateToStringContentProvider)getContentProvider();
 
+			fButtonControls[UP_INDEX].setEnabled(cp.canMoveUp(selected));
+			fButtonControls[DOWN_INDEX].setEnabled(cp.canMoveDown(selected));
 		});
-		treeViewer.addCheckStateListener(new ICheckStateListener() {
-			@Override
-			public void checkStateChanged(CheckStateChangedEvent event) {
-				getTreeViewer().setSubtreeChecked(event.getElement(), event.getChecked());
-				getTreeViewer().setGrayed(event.getElement(), false);
-				Object parentElement= ((ITreeContentProvider)(getTreeViewer().getContentProvider())).getParent(event.getElement());
-				if (parentElement != null) {
-					Object[] siblings= ((ITreeContentProvider)(getTreeViewer().getContentProvider())).getChildren(parentElement);
-					int count= 0;
-					for (Object sibling : siblings) {
-						if (getTreeViewer().getChecked(sibling)) {
-							count++;
-						}
+		treeViewer.addCheckStateListener(event -> {
+			getTreeViewer().setSubtreeChecked(event.getElement(), event.getChecked());
+			getTreeViewer().setGrayed(event.getElement(), false);
+			Object parentElement= ((ITreeContentProvider)(getTreeViewer().getContentProvider())).getParent(event.getElement());
+			if (parentElement != null) {
+				Object[] siblings= ((ITreeContentProvider)(getTreeViewer().getContentProvider())).getChildren(parentElement);
+				int count= 0;
+				for (Object sibling : siblings) {
+					if (getTreeViewer().getChecked(sibling)) {
+						count++;
 					}
-					if (count == 0)
-						getTreeViewer().setGrayChecked(parentElement, false);
-					else if (count == siblings.length) {
-						getTreeViewer().setChecked(parentElement, true);
-						getTreeViewer().setGrayed(parentElement, false);
-					} else
-						getTreeViewer().setGrayChecked(parentElement, true);
 				}
-				updateOKStatus();
+				if (count == 0)
+					getTreeViewer().setGrayChecked(parentElement, false);
+				else if (count == siblings.length) {
+					getTreeViewer().setChecked(parentElement, true);
+					getTreeViewer().setGrayed(parentElement, false);
+				} else
+					getTreeViewer().setGrayChecked(parentElement, true);
 			}
-
+			updateOKStatus();
 		});
 		return treeViewer;
 	}
