@@ -16,12 +16,10 @@ package org.eclipse.jdt.internal.ui.dialogs;
 import java.util.ArrayList;
 import java.util.List;
 
-import com.ibm.icu.text.BreakIterator;
+import java.text.BreakIterator;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.StyledText;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.FocusEvent;
 import org.eclipse.swt.events.FocusListener;
 import org.eclipse.swt.events.KeyAdapter;
@@ -95,10 +93,9 @@ public class TextFieldNavigationHandler {
 			Point selection= getSelection();
 			if (selection.equals(fLastSelection)) {
 				// leave caret position
-			} else if (selection.x == selection.y) { //empty range
+			} else if (selection.x == selection.y //empty range
+					|| fLastSelection.y == selection.y) { //same end -> assume caret at start
 				fCaretPosition= selection.x;
-			} else if (fLastSelection.y == selection.y) {
-				fCaretPosition= selection.x; //same end -> assume caret at start
 			} else {
 				fCaretPosition= selection.y;
 			}
@@ -294,12 +291,7 @@ public class TextFieldNavigationHandler {
 			control.addFocusListener(this);
 			if (control.isFocusControl())
 				activate();
-			control.addDisposeListener(new DisposeListener() {
-				@Override
-				public void widgetDisposed(DisposeEvent e) {
-					deactivate();
-				}
-			});
+			control.addDisposeListener(e -> deactivate());
 		}
 
 		@Override
@@ -540,4 +532,7 @@ public class TextFieldNavigationHandler {
 		public abstract void execute();
 	}
 
+	private TextFieldNavigationHandler() {
+	}
+
 }
\ No newline at end of file
