@@ -20,6 +20,7 @@ import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
@@ -68,6 +69,7 @@ import org.eclipse.jdt.ui.jarpackager.JarPackageData;
 
 import org.eclipse.jdt.internal.ui.IJavaStatusConstants;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
+import org.eclipse.jdt.internal.ui.util.XmlProcessorFactoryJdtUi;
 
 /**
  * Reads data from an InputStream and returns a JarPackage
@@ -81,7 +83,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	/**
 	 * Reads a Jar Package from the underlying stream.
 	 * It is the client's responsibility to close the stream.
-	 * 
+	 *
 	 * @param inputStream the input stream
 	 */
 	public JarPackageReader(InputStream inputStream) {
@@ -94,10 +96,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	public void read(JarPackageData jarPackage) throws CoreException {
 		try {
 			readXML(jarPackage);
-		} catch (IOException ex) {
-			String message= (ex.getLocalizedMessage() != null ? ex.getLocalizedMessage() : ""); //$NON-NLS-1$
-			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IJavaStatusConstants.INTERNAL_ERROR, message, ex));
-		} catch (SAXException ex) {
+		} catch (IOException | SAXException ex) {
 			String message= (ex.getLocalizedMessage() != null ? ex.getLocalizedMessage() : ""); //$NON-NLS-1$
 			throw new CoreException(new Status(IStatus.ERROR, JavaPlugin.getPluginId(), IJavaStatusConstants.INTERNAL_ERROR, message, ex));
 		}
@@ -122,7 +121,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	}
 
 	public JarPackageData readXML(JarPackageData jarPackage) throws IOException, SAXException {
-	  	DocumentBuilderFactory factory= DocumentBuilderFactory.newInstance();
+	  	DocumentBuilderFactory factory= XmlProcessorFactoryJdtUi.createDocumentBuilderFactoryWithErrorOnDOCTYPE();
     	factory.setValidating(false);
 		DocumentBuilder parser= null;
 
@@ -135,7 +134,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 		}
 		parser.setErrorHandler(new DefaultHandler());
 		Element xmlJarDesc= parser.parse(new InputSource(fInputStream)).getDocumentElement();
-		if (!xmlJarDesc.getNodeName().equals(JarPackagerUtil.DESCRIPTION_EXTENSION)) {
+		if (!JarPackagerUtil.DESCRIPTION_EXTENSION.equals(xmlJarDesc.getNodeName())) {
 			throw new IOException(JarPackagerMessages.JarPackageReader_error_badFormat);
 		}
 		NodeList topLevelElements= xmlJarDesc.getChildNodes();
@@ -156,12 +155,12 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	}
 
 	private void xmlReadJarLocation(JarPackageData jarPackage, Element element) {
-		if (element.getNodeName().equals(JarPackagerUtil.JAR_EXTENSION))
+		if (JarPackagerUtil.JAR_EXTENSION.equals(element.getNodeName()))
 			jarPackage.setJarLocation(Path.fromPortableString(element.getAttribute("path"))); //$NON-NLS-1$
 	}
 
 	private void xmlReadOptions(JarPackageData jarPackage, Element element) throws java.io.IOException {
-		if (element.getNodeName().equals("options")) { //$NON-NLS-1$
+		if ("options".equals(element.getNodeName())) { //$NON-NLS-1$
 			jarPackage.setOverwrite(getBooleanAttribute(element, "overwrite")); //$NON-NLS-1$
 			jarPackage.setCompress(getBooleanAttribute(element, "compress")); //$NON-NLS-1$
 			jarPackage.setExportErrors(getBooleanAttribute(element, "exportErrors")); //$NON-NLS-1$
@@ -176,7 +175,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	}
 
 	private void xmlReadRefactoring(JarPackageData jarPackage, Element element) throws java.io.IOException {
-		if (element.getNodeName().equals("storedRefactorings")) { //$NON-NLS-1$
+		if ("storedRefactorings".equals(element.getNodeName())) { //$NON-NLS-1$
 			jarPackage.setExportStructuralOnly(getBooleanAttribute(element, "structuralOnly", jarPackage.isExportStructuralOnly())); //$NON-NLS-1$
 			jarPackage.setDeprecationAware(getBooleanAttribute(element, "deprecationInfo", jarPackage.isDeprecationAware())); //$NON-NLS-1$
 			List<IAdaptable> elements= new ArrayList<>();
@@ -203,9 +202,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 						if (history != null) {
 							final RefactoringDescriptorProxy[] descriptors= history.getDescriptors();
 							if (descriptors.length > 0) {
-								for (int index= 0; index < descriptors.length; index++) {
-									elements.add(descriptors[index]);
-								}
+								elements.addAll(Arrays.asList(descriptors));
 							}
 						}
 					} catch (CoreException exception) {
@@ -222,7 +219,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	}
 
 	private void xmlReadManifest(JarPackageData jarPackage, Element element) throws java.io.IOException {
-		if (element.getNodeName().equals("manifest")) { //$NON-NLS-1$
+		if ("manifest".equals(element.getNodeName())) { //$NON-NLS-1$
 			jarPackage.setManifestVersion(element.getAttribute("manifestVersion")); //$NON-NLS-1$
 			jarPackage.setUsesManifest(getBooleanAttribute(element, "usesManifest")); //$NON-NLS-1$
 			jarPackage.setReuseManifest(getBooleanAttribute(element, "reuseManifest")); //$NON-NLS-1$
@@ -244,7 +241,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 		for (int j= 0; j < sealingElementContainer.getLength(); j++) {
 			Node sealingNode= sealingElementContainer.item(j);
 			if (sealingNode.getNodeType() == Node.ELEMENT_NODE
-				&& sealingNode.getNodeName().equals("sealing")) { //$NON-NLS-1$
+				&& "sealing".equals(sealingNode.getNodeName())) { //$NON-NLS-1$
 				// Sealing
 				Element sealingElement= (Element)sealingNode;
 				jarPackage.setSealJar(getBooleanAttribute(sealingElement, "sealJar")); //$NON-NLS-1$
@@ -255,7 +252,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 	}
 
 	private void xmlReadSelectedElements(JarPackageData jarPackage, Element element) throws java.io.IOException {
-		if (element.getNodeName().equals("selectedElements")) { //$NON-NLS-1$
+		if ("selectedElements".equals(element.getNodeName())) { //$NON-NLS-1$
 			jarPackage.setExportClassFiles(getBooleanAttribute(element, "exportClassFiles")); //$NON-NLS-1$
 			jarPackage.setExportOutputFolders(getBooleanAttribute(element, "exportOutputFolder", false)); //$NON-NLS-1$
 			jarPackage.setExportJavaFiles(getBooleanAttribute(element, "exportJavaFiles")); //$NON-NLS-1$
@@ -266,22 +263,30 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 				if (selectedNode.getNodeType() != Node.ELEMENT_NODE)
 					continue;
 				Element selectedElement= (Element)selectedNode;
-				if (selectedElement.getNodeName().equals("file")) //$NON-NLS-1$
+				switch (selectedElement.getNodeName()) {
+				case "file": //$NON-NLS-1$
 					addFile(elementsToExport, selectedElement);
-				else if (selectedElement.getNodeName().equals("folder")) //$NON-NLS-1$
+					break;
+				case "folder": //$NON-NLS-1$
 					addFolder(elementsToExport,selectedElement);
-				else if (selectedElement.getNodeName().equals("project")) //$NON-NLS-1$
+					break;
+				case "project": //$NON-NLS-1$
 					addProject(elementsToExport ,selectedElement);
-				else if (selectedElement.getNodeName().equals("javaElement")) //$NON-NLS-1$
+					break;
+				case "javaElement": //$NON-NLS-1$
 					addJavaElement(elementsToExport, selectedElement);
-				// Note: Other file types are not handled by this writer
+					// Note: Other file types are not handled by this writer
+					break;
+				default:
+					break;
+				}
 			}
 			jarPackage.setElements(elementsToExport.toArray());
 		}
 	}
 
 	private void xmlReadSelectedProjects(JarPackageData jarPackage, Element element) throws java.io.IOException {
-		if (element.getNodeName().equals("selectedProjects")) { //$NON-NLS-1$
+		if ("selectedProjects".equals(element.getNodeName())) { //$NON-NLS-1$
 			NodeList selectedElements= element.getChildNodes();
 			Set<IAdaptable> selectedProjects= new HashSet<>(selectedElements.getLength());
 			for (int index= 0; index < selectedElements.getLength(); index++) {
@@ -289,7 +294,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 				if (node.getNodeType() != Node.ELEMENT_NODE)
 					continue;
 				Element selectedElement= (Element)node;
-				if (selectedElement.getNodeName().equals("project")) //$NON-NLS-1$
+				if ("project".equals(selectedElement.getNodeName())) //$NON-NLS-1$
 					addProject(selectedProjects ,selectedElement);
 			}
 			jarPackage.setRefactoringProjects(selectedProjects.toArray(new IProject[selectedProjects.size()]));
@@ -305,9 +310,9 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 
 	protected boolean getBooleanAttribute(Element element, String name) throws IOException {
 		String value= element.getAttribute(name);
-		if (value != null && value.equalsIgnoreCase("true")) //$NON-NLS-1$
+		if (value != null && "true".equalsIgnoreCase(value)) //$NON-NLS-1$
 			return true;
-		if (value != null && value.equalsIgnoreCase("false")) //$NON-NLS-1$
+		if (value != null && "false".equalsIgnoreCase(value)) //$NON-NLS-1$
 			return false;
 		throw new IOException(JarPackagerMessages.JarPackageReader_error_illegalValueForBooleanAttribute);
 	}
@@ -366,9 +371,9 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 		List<IJavaElement> packages= new ArrayList<>(packageNodes.getLength());
 		for (int i= 0; i < packageNodes.getLength(); i++) {
 			Node packageNode= packageNodes.item(i);
-			if (packageNode.getNodeType() == Node.ELEMENT_NODE && packageNode.getNodeName().equals("package")) { //$NON-NLS-1$
+			if (packageNode.getNodeType() == Node.ELEMENT_NODE && "package".equals(packageNode.getNodeName())) { //$NON-NLS-1$
 				String handleId= ((Element)packageNode).getAttribute("handleIdentifier"); //$NON-NLS-1$
-				if (handleId.equals("")) //$NON-NLS-1$
+				if (handleId.isEmpty())
 					throw new IOException(JarPackagerMessages.JarPackageReader_error_tagHandleIdentifierNotFoundOrEmpty);
 				IJavaElement je= JavaCore.create(handleId);
 				if (je != null && je.getElementType() == IJavaElement.PACKAGE_FRAGMENT)
@@ -382,7 +387,7 @@ public class JarPackageReader extends Object implements IJarDescriptionReader {
 
 	private IType getMainClass(Element element) {
 		String handleId= element.getAttribute("mainClassHandleIdentifier"); //$NON-NLS-1$
-		if (handleId.equals("")) //$NON-NLS-1$
+		if (handleId.isEmpty())
 			return null;	// Main-Class entry is optional or can be empty
 		IJavaElement je= JavaCore.create(handleId);
 		if (je != null && je.getElementType() == IJavaElement.TYPE)
