@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Red Hat Inc. - Bug 522218 - add raw paste support
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.javaeditor;
 
@@ -29,6 +30,7 @@ import org.eclipse.swt.custom.BusyIndicator;
 import org.eclipse.swt.dnd.ByteArrayTransfer;
 import org.eclipse.swt.dnd.Clipboard;
 import org.eclipse.swt.dnd.DND;
+import org.eclipse.swt.dnd.HTMLTransfer;
 import org.eclipse.swt.dnd.RTFTransfer;
 import org.eclipse.swt.dnd.TextTransfer;
 import org.eclipse.swt.dnd.Transfer;
@@ -38,11 +40,9 @@ import org.eclipse.swt.widgets.Shell;
 
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 
-import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.viewers.ISelection;
 
 import org.eclipse.jface.text.IRewriteTarget;
@@ -62,6 +62,7 @@ import org.eclipse.ui.progress.IWorkbenchSiteProgressService;
 import org.eclipse.ui.texteditor.IAbstractTextEditorHelpContextIds;
 import org.eclipse.ui.texteditor.ITextEditor;
 import org.eclipse.ui.texteditor.ITextEditorExtension3;
+import org.eclipse.ui.texteditor.ITextEditorExtension3.InsertMode;
 import org.eclipse.ui.texteditor.TextEditorAction;
 
 import org.eclipse.jdt.core.ICompilationUnit;
@@ -74,7 +75,6 @@ import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.dom.IBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.ImportDeclaration;
-import org.eclipse.jdt.core.dom.Name;
 import org.eclipse.jdt.core.dom.SimpleName;
 import org.eclipse.jdt.core.dom.rewrite.ImportRewrite;
 import org.eclipse.jdt.core.manipulation.ImportReferencesCollector;
@@ -86,6 +86,7 @@ import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
 import org.eclipse.jdt.ui.JavaUI;
 import org.eclipse.jdt.ui.PreferenceConstants;
+import org.eclipse.jdt.ui.actions.IJavaEditorActionDefinitionIds;
 
 import org.eclipse.jdt.internal.ui.IJavaStatusConstants;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
@@ -97,6 +98,8 @@ import org.eclipse.jdt.internal.ui.JavaUIMessages;
  */
 public final class ClipboardOperationAction extends TextEditorAction {
 
+	static final int RAW_PASTE= ITextOperationTarget.PASTE + 100; // raw paste
+
 	public static class ClipboardData {
 		private String fOriginHandle;
 		private String[] fTypeImports;
@@ -226,20 +229,30 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		super(bundle, prefix, editor);
 		fOperationCode= operationCode;
 
-		if (operationCode == ITextOperationTarget.CUT) {
-			setHelpContextId(IAbstractTextEditorHelpContextIds.CUT_ACTION);
-			setActionDefinitionId(IWorkbenchCommandConstants.EDIT_CUT);
-			updateImages(IWorkbenchCommandConstants.EDIT_CUT);
-		} else if (operationCode == ITextOperationTarget.COPY) {
-			setHelpContextId(IAbstractTextEditorHelpContextIds.COPY_ACTION);
-			setActionDefinitionId(IWorkbenchCommandConstants.EDIT_COPY);
-			updateImages(IWorkbenchCommandConstants.EDIT_COPY);
-		} else if (operationCode == ITextOperationTarget.PASTE) {
-			setHelpContextId(IAbstractTextEditorHelpContextIds.PASTE_ACTION);
-			setActionDefinitionId(IWorkbenchCommandConstants.EDIT_PASTE);
-			updateImages(IWorkbenchCommandConstants.EDIT_PASTE);
-		} else {
-			Assert.isTrue(false, "Invalid operation code"); //$NON-NLS-1$
+		switch (operationCode) {
+			case ITextOperationTarget.CUT:
+				setHelpContextId(IAbstractTextEditorHelpContextIds.CUT_ACTION);
+				setActionDefinitionId(IWorkbenchCommandConstants.EDIT_CUT);
+				updateImages(IWorkbenchCommandConstants.EDIT_CUT);
+				break;
+			case ITextOperationTarget.COPY:
+				setHelpContextId(IAbstractTextEditorHelpContextIds.COPY_ACTION);
+				setActionDefinitionId(IWorkbenchCommandConstants.EDIT_COPY);
+				updateImages(IWorkbenchCommandConstants.EDIT_COPY);
+				break;
+			case ITextOperationTarget.PASTE:
+				setHelpContextId(IAbstractTextEditorHelpContextIds.PASTE_ACTION);
+				setActionDefinitionId(IWorkbenchCommandConstants.EDIT_PASTE);
+				updateImages(IWorkbenchCommandConstants.EDIT_PASTE);
+				break;
+			case RAW_PASTE:
+				setHelpContextId(IAbstractTextEditorHelpContextIds.PASTE_ACTION);
+				setActionDefinitionId(IJavaEditorActionDefinitionIds.RAW_PASTE);
+				updateImages(IWorkbenchCommandConstants.EDIT_PASTE);
+				break;
+			default:
+				Assert.isTrue(false, "Invalid operation code"); //$NON-NLS-1$
+				break;
 		}
 		update();
 	}
@@ -271,12 +284,7 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		if (!isReadOnlyOperation() && !validateEditorInputState())
 			return;
 
-		BusyIndicator.showWhile(getDisplay(), new Runnable() {
-			@Override
-			public void run() {
-				internalDoOperation();
-			}
-		});
+		BusyIndicator.showWhile(getDisplay(), this::internalDoOperation);
 	}
 
 	private Shell getShell() {
@@ -321,8 +329,37 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		return false;
 	}
 
-	protected final void internalDoOperation() {
-		if (PreferenceConstants.getPreferenceStore().getBoolean(PreferenceConstants.EDITOR_IMPORTS_ON_PASTE) && isSmartInsertMode()) {
+	/**
+	 * Sets the Insert Mode.
+	 *
+	 * @param insertMode to set
+	 * @since 4.21
+	 */
+	private void setInsertMode(InsertMode insertMode) {
+		IWorkbenchPage page= JavaPlugin.getActivePage();
+		if (page != null) {
+			IEditorPart part= page.getActiveEditor();
+			if (part instanceof ITextEditorExtension3) {
+				ITextEditorExtension3 extension= (ITextEditorExtension3)part;
+				extension.setInsertMode(insertMode);
+			} else if (part != null && EditorUtility.isCompareEditorInput(part.getEditorInput())) {
+				ITextEditorExtension3 extension= part.getAdapter(ITextEditorExtension3.class);
+				if (extension != null)
+					extension.setInsertMode(insertMode);
+			}
+		}
+	}
+
+	protected void internalDoOperation() {
+		if (fOperationCode == RAW_PASTE) {
+			if (isSmartInsertMode()) {
+				setInsertMode(ITextEditorExtension3.INSERT);
+				fOperationTarget.doOperation(ITextOperationTarget.PASTE);
+				setInsertMode(ITextEditorExtension3.SMART_INSERT);
+			} else {
+				fOperationTarget.doOperation(ITextOperationTarget.PASTE);
+			}
+		} else if (PreferenceConstants.getPreferenceStore().getBoolean(PreferenceConstants.EDITOR_IMPORTS_ON_PASTE) && isSmartInsertMode()) {
 			if (fOperationCode == ITextOperationTarget.PASTE) {
 				doPasteWithImportsOperation();
 			} else {
@@ -346,7 +383,8 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		if (fOperationTarget == null && editor!= null && fOperationCode != -1)
 			fOperationTarget= editor.getAdapter(ITextOperationTarget.class);
 
-		boolean isEnabled= (fOperationTarget != null && fOperationTarget.canDoOperation(fOperationCode));
+		boolean isEnabled= (fOperationTarget != null &&
+				(fOperationCode == RAW_PASTE ? fOperationTarget.canDoOperation(ITextOperationTarget.PASTE) : fOperationTarget.canDoOperation(fOperationCode)));
 		setEnabled(isEnabled);
 	}
 
@@ -388,8 +426,8 @@ public final class ClipboardOperationAction extends TextEditorAction {
 				if (textData == null)
 					return;
 
-				ArrayList<Object> datas= new ArrayList<>(3);
-				ArrayList<ByteArrayTransfer> transfers= new ArrayList<>(3);
+				ArrayList<Object> datas= new ArrayList<>(4);
+				ArrayList<ByteArrayTransfer> transfers= new ArrayList<>(4);
 				datas.add(textData);
 				transfers.add(TextTransfer.getInstance());
 
@@ -399,6 +437,12 @@ public final class ClipboardOperationAction extends TextEditorAction {
 					transfers.add(RTFTransfer.getInstance());
 				}
 
+				Object htmlData= clipboard.getContents(HTMLTransfer.getInstance());
+				if (htmlData != null) {
+					datas.add(htmlData);
+					transfers.add(HTMLTransfer.getInstance());
+				}
+
 				datas.add(clipboardData);
 				transfers.add(fgTransferInstance);
 
@@ -426,8 +470,8 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		if (selection.getLength() < 30) {
 			String text= selection.getText();
 			if (text != null) {
-				for (int i= 0; i < text.length(); i++) {
-					if (!Character.isJavaIdentifierPart(text.charAt(i))) {
+				for (char c : text.toCharArray()) {
+					if (!Character.isJavaIdentifierPart(c)) {
 						return true;
 					}
 				}
@@ -466,8 +510,7 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		}
 
 		HashSet<String> namesToImport= new HashSet<>(typeImportsRefs.size());
-		for (int i= 0; i < typeImportsRefs.size(); i++) {
-			Name curr= typeImportsRefs.get(i);
+		for (SimpleName curr : typeImportsRefs) {
 			IBinding binding= curr.resolveBinding();
 			if (binding != null && binding.getKind() == IBinding.TYPE) {
 				ITypeBinding typeBinding= (ITypeBinding) binding;
@@ -488,8 +531,7 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		}
 
 		HashSet<String> staticsToImport= new HashSet<>(staticImportsRefs.size());
-		for (int i= 0; i < staticImportsRefs.size(); i++) {
-			Name curr= staticImportsRefs.get(i);
+		for (SimpleName curr : staticImportsRefs) {
 			IBinding binding= curr.resolveBinding();
 			if (binding != null) {
 				StringBuilder buf= new StringBuilder(Bindings.getImportName(binding));
@@ -559,14 +601,11 @@ public final class ClipboardOperationAction extends TextEditorAction {
 		}
 
 		try {
-			getProgressService().busyCursorWhile(new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-					try {
-						JavaModelUtil.applyEdit(unit, rewrite.rewriteImports(monitor), false, null);
-					} catch (CoreException e) {
-						throw new InvocationTargetException(e);
-					}
+			getProgressService().busyCursorWhile(monitor -> {
+				try {
+					JavaModelUtil.applyEdit(unit, rewrite.rewriteImports(monitor), false, null);
+				} catch (CoreException e) {
+					throw new InvocationTargetException(e);
 				}
 			});
 		} catch (InvocationTargetException e) {
