@@ -27,23 +27,29 @@ public interface IJavaEditorActionConstants {
 	 * Value: <code>"smartTyping"</code>
 	 * @since 3.0
 	 */
-	public static final String TOGGLE_SMART_TYPING= "smartTyping"; //$NON-NLS-1$
+	String TOGGLE_SMART_TYPING= "smartTyping"; //$NON-NLS-1$
 
 	/**
 	 * ID of the smart typing status item
 	 * Value: <code>"SmartTyping"</code>
 	 * @since 3.0
 	 */
-	public static final String STATUS_CATEGORY_SMART_TYPING= "SmartTyping"; //$NON-NLS-1$
+	String STATUS_CATEGORY_SMART_TYPING= "SmartTyping"; //$NON-NLS-1$
 
 	/**
 	 * ID of the action to toggle the style of the presentation.
 	 */
-	public static final String TOGGLE_PRESENTATION= "togglePresentation"; //$NON-NLS-1$
+	String TOGGLE_PRESENTATION= "togglePresentation"; //$NON-NLS-1$
 
 	/**
 	 * ID of the action to copy the qualified name.
 	 * @since 3.3
 	 */
-	public static final String COPY_QUALIFIED_NAME= "copyQualifiedName"; //$NON-NLS-1$
+	String COPY_QUALIFIED_NAME= "copyQualifiedName"; //$NON-NLS-1$
+
+	/**
+	 * ID of the action to paste raw text and ignore smart settings.
+	 * @since 4.21
+	 */
+	String RAW_PASTE= "rawPaste"; //$NON-NLS-1$
 }
