@@ -178,7 +178,7 @@ public class CompliancePreferencePage extends PropertyAndPreferencePage {
 			if (isProjectPreferencePage()) {
 				Boolean useProjectOptions= (Boolean) map.get(USE_PROJECT_SPECIFIC_OPTIONS);
 				if (useProjectOptions != null) {
-					enableProjectSpecificSettings(useProjectOptions.booleanValue());
+					enableProjectSpecificSettings(useProjectOptions);
 				}
 			}
 
