@@ -13,6 +13,7 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.ui.preferences;
 
+import java.util.ArrayDeque;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
@@ -20,8 +21,6 @@ import java.util.List;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.ControlAdapter;
 import org.eclipse.swt.events.ControlEvent;
-import org.eclipse.swt.events.DisposeEvent;
-import org.eclipse.swt.events.DisposeListener;
 import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
@@ -287,12 +286,14 @@ public class FilteredPreferenceTree {
 	 */
 	private Label fDescription;
 
+	/**
+	 * The filter text control.
+	 */
+	private FilterTextControl fFilterTextControl;
 
 	private ToolItem fExpandAllItem;
 	private ToolItem fCollapseAllItem;
 
-	private Text fFilterBox;
-
 
 	public FilteredPreferenceTree(Composite parentComposite, String label, String hint) {
 		this(parentComposite, label, hint, true);
@@ -309,12 +310,7 @@ public class FilteredPreferenceTree {
 
 		fRefreshJob= doCreateRefreshJob();
 		fRefreshJob.setSystem(true);
-		fParentComposite.addDisposeListener(new DisposeListener() {
-			@Override
-			public void widgetDisposed(DisposeEvent e) {
-				fRefreshJob.cancel();
-			}
-		});
+		fParentComposite.addDisposeListener(e -> fRefreshJob.cancel());
 	}
 
 	private void createDescription(String label) {
@@ -337,16 +333,18 @@ public class FilteredPreferenceTree {
 		composite.setLayout(layout);
 		composite.setFont(fParentComposite.getFont());
 
-		fFilterBox = new Text(composite, SWT.SINGLE | SWT.BORDER | SWT.SEARCH | SWT.ICON_CANCEL);
+		//TODO: Directly use the hint flags once Bug 293230 is fixed
+		fFilterTextControl= new FilterTextControl(composite);
 
-		fFilterBox.setMessage(hint);
+		Text filterBox= fFilterTextControl.getFilterControl();
+		filterBox.setMessage(hint);
 
-		fFilterBox.addModifyListener(new ModifyListener() {
+		filterBox.addModifyListener(new ModifyListener() {
 			private String fPrevFilterText;
 
 			@Override
 			public void modifyText(ModifyEvent e) {
-				String input= fFilterBox.getText();
+				String input= filterBox.getText();
 				fExpandAllItem.setEnabled(input.isEmpty());
 				fCollapseAllItem.setEnabled(input.isEmpty());
 				if (!input.equalsIgnoreCase(fPrevFilterText)) {
@@ -377,12 +375,9 @@ public class FilteredPreferenceTree {
 				setAllExpanded(null, expand);
 			}
 		});
-		item.addDisposeListener(new DisposeListener() {
-			@Override
-			public void widgetDisposed(DisposeEvent e) {
-				createdImage.dispose();
-				createdDisabledImage.dispose();
-			}
+		item.addDisposeListener(e -> {
+			createdImage.dispose();
+			createdDisabledImage.dispose();
 		});
 		return item;
 	}
@@ -439,9 +434,8 @@ public class FilteredPreferenceTree {
 			labelMatcher= createStringMatcher(filterText);
 		} else {
 			if (index == 0 && !fExpectMultiWordValueMatch) {
-				int i= 0;
-				for (; i < filterText.length(); i++) {
-					char ch= filterText.charAt(i);
+				int i= filterText.length();
+				for (char ch : filterText.toCharArray()) {
 					if (ch == ' ' || ch == '\t') {
 						break;
 					}
@@ -488,8 +482,8 @@ public class FilteredPreferenceTree {
 		//update children
 		List<PreferenceTreeNode<?>> children= node.getChildren();
 		if (children != null) {
-			for (int i= 0; i < children.size(); i++) {
-				updateUI(children.get(i));
+			for (PreferenceTreeNode<?> element : children) {
+				updateUI(element);
 			}
 		}
 	}
@@ -524,15 +518,15 @@ public class FilteredPreferenceTree {
 		fScrolledPageContent.setRedraw(false);
 		fScrolledPageContent.setReflow(false);
 
-		ArrayList<PreferenceTreeNode<?>> bfsNodes= new ArrayList<>();
+		ArrayDeque<PreferenceTreeNode<?>> bfsNodes= new ArrayDeque<>();
 		if (start != null) {
 			bfsNodes.add(start);
 		} else {
 			bfsNodes.addAll(fRoot.getChildren());
 		}
-		for (int i= 0; i < bfsNodes.size(); i++) {
-			PreferenceTreeNode<?> node= bfsNodes.get(i);
-			bfsNodes.addAll(bfsNodes.get(i).getChildren());
+		while (!bfsNodes.isEmpty()) {
+			PreferenceTreeNode<?> node= bfsNodes.remove();
+			bfsNodes.addAll(node.getChildren());
 			if (node.getControl() instanceof ExpandableComposite)
 				((ExpandableComposite) node.getControl()).setExpanded(expanded);
 		}
@@ -553,7 +547,7 @@ public class FilteredPreferenceTree {
 		if (fDescription != null) {
 			fDescription.setEnabled(enabled);
 		}
-		fFilterBox.setEnabled(enabled);
+		fFilterTextControl.setEnabled(enabled);
 		fCollapseAllItem.setEnabled(enabled);
 		fExpandAllItem.setEnabled(enabled);
 		fRoot.getChildren().forEach(node -> node.setEnabled(enabled));
