@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2022 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -845,6 +845,7 @@ public final class PreferencesMessages extends NLS {
 	public static String ComplianceConfigurationBlock_version_17;
 	public static String ComplianceConfigurationBlock_version_18;
 	public static String ComplianceConfigurationBlock_version_19;
+	public static String ComplianceConfigurationBlock_version_20;
 	public static String ComplianceConfigurationBlock_versionCLDC11;
 	public static String ComplianceConfigurationBlock_src_greater_compliance;
 	public static String ComplianceConfigurationBlock_classfile_greater_compliance;
@@ -905,6 +906,7 @@ public final class PreferencesMessages extends NLS {
 
 	public static String JavaEditorCodeMiningConfigurationBlock_common_description;
 	public static String JavaEditorCodeMiningConfigurationBlock_enableCodeMining_label;
+	public static String JavaEditorCodeMiningConfigurationBlock_ignoreInexactMatches_label;
 	public static String JavaEditorCodeMiningConfigurationBlock_showCodeMining_atLeastOne_label;
 	public static String JavaEditorCodeMiningConfigurationBlock_section_general;
 	public static String JavaEditorCodeMiningConfigurationBlock_showReferences_label;
@@ -913,4 +915,10 @@ public final class PreferencesMessages extends NLS {
 	public static String JavaEditorCodeMiningConfigurationBlock_showReferences_onMethods_label;
 	public static String JavaEditorCodeMiningConfigurationBlock_showImplementations_label;
 	public static String JavaEditorCodeMiningConfigurationBlock_showParameterNames_label;
+
+	public static String JavaLaunchingConfigurationBlock_application_name_fully_qualified_label;
+	public static String JavaLaunchingConfigurationBlock_applet_name_fully_qualified_label;
+	public static String JavaLaunchingConfigurationBlock_junit_name_fully_qualified_label;
+	public static String JavaLaunchingConfigurationBlock_name_description;
+
 }
