@@ -35,7 +35,6 @@ import javax.xml.parsers.ParserConfigurationException;
 import javax.xml.transform.OutputKeys;
 import javax.xml.transform.Transformer;
 import javax.xml.transform.TransformerException;
-import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
@@ -80,7 +79,6 @@ import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.dialogs.StatusDialog;
 import org.eclipse.jface.operation.IRunnableContext;
-import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.preference.PreferencePage;
 import org.eclipse.jface.resource.StringConverter;
 import org.eclipse.jface.util.BidiUtils;
@@ -117,6 +115,7 @@ import org.eclipse.jdt.internal.ui.IUIConstants;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.dialogs.StatusInfo;
 import org.eclipse.jdt.internal.ui.util.ExceptionHandler;
+import org.eclipse.jdt.internal.ui.util.XmlProcessorFactoryJdtUi;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.AccessRulesDialog;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.ArchiveFileFilter;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.BuildPathSupport;
@@ -208,8 +207,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 			if (name.length() == 0) {
 				return new StatusInfo(IStatus.ERROR, PreferencesMessages.UserLibraryPreferencePage_LibraryNameDialog_name_error_entername);
 			}
-			for (int i= 0; i < fExistingLibraries.size(); i++) {
-				CPUserLibraryElement curr= fExistingLibraries.get(i);
+			for (CPUserLibraryElement curr : fExistingLibraries) {
 				if (curr != fElementToEdit && name.equals(curr.getName())) {
 					return new StatusInfo(IStatus.ERROR, Messages.format(PreferencesMessages.UserLibraryPreferencePage_LibraryNameDialog_name_error_exists, name));
 				}
@@ -471,14 +469,11 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 					final String charset= encoding;
 					IRunnableContext context= PlatformUI.getWorkbench().getProgressService();
 					try {
-						context.run(true, true, new IRunnableWithProgress() {
-							@Override
-							public void run(IProgressMonitor monitor) throws InvocationTargetException, InterruptedException {
-								try {
-									saveLibraries(elements, file, charset, monitor);
-								} catch (IOException e) {
-									throw new InvocationTargetException(e);
-								}
+						context.run(true, true, monitor -> {
+							try {
+								saveLibraries(elements, file, charset, monitor);
+							} catch (IOException e) {
+								throw new InvocationTargetException(e);
 							}
 						});
 						fSettings.put(PREF_LASTPATH, file.getPath());
@@ -499,14 +494,12 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				}
 			} else {
 				HashSet<String> map= new HashSet<>(fExistingLibraries.size());
-				for (int k= 0; k < fExistingLibraries.size(); k++) {
-					CPUserLibraryElement elem= fExistingLibraries.get(k);
+				for (CPUserLibraryElement elem : fExistingLibraries) {
 					map.add(elem.getName());
 				}
 				int nReplaced= 0;
 				List<CPUserLibraryElement> elements= getLoadedLibraries();
-				for (int i= 0; i < elements.size(); i++) {
-					CPUserLibraryElement curr= elements.get(i);
+				for (CPUserLibraryElement curr : elements) {
 					if (map.contains(curr.getName())) {
 						nReplaced++;
 					}
@@ -566,10 +559,9 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		protected static void saveLibraries(List<CPUserLibraryElement> libraries, File file, String encoding, IProgressMonitor monitor) throws IOException {
 			OutputStream stream= new FileOutputStream(file);
 			try {
-				DocumentBuilder docBuilder= null;
-				DocumentBuilderFactory factory= DocumentBuilderFactory.newInstance();
+				DocumentBuilderFactory factory= XmlProcessorFactoryJdtUi.createDocumentBuilderFactoryWithErrorOnDOCTYPE();
 				factory.setValidating(false);
-				docBuilder= factory.newDocumentBuilder();
+				DocumentBuilder docBuilder= factory.newDocumentBuilder();
 				Document document= docBuilder.newDocument();
 
 				// Create the document
@@ -578,11 +570,10 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 
 				rootElement.setAttribute(TAG_VERSION, CURRENT_VERSION);
 
-				for (int i= 0; i < libraries.size(); i++) {
+				for (CPUserLibraryElement curr : libraries) {
 					Element libraryElement= document.createElement(TAG_LIBRARY);
 					rootElement.appendChild(libraryElement);
 
-					CPUserLibraryElement curr= libraries.get(i);
 					libraryElement.setAttribute(TAG_NAME, curr.getName());
 					libraryElement.setAttribute(TAG_SYSTEMLIBRARY, String.valueOf(curr.isSystemLibrary()));
 
@@ -622,7 +613,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				}
 
 				// Write the document to the stream
-				Transformer transformer=TransformerFactory.newInstance().newTransformer();
+				Transformer transformer= XmlProcessorFactoryJdtUi.createTransformerFactoryWithErrorOnDOCTYPE().newTransformer();
 				transformer.setOutputProperty(OutputKeys.METHOD, "xml"); //$NON-NLS-1$
 				transformer.setOutputProperty(OutputKeys.ENCODING, encoding);
 				transformer.setOutputProperty(OutputKeys.INDENT, "yes"); //$NON-NLS-1$
@@ -649,7 +640,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 			InputStream stream= new FileInputStream(file);
 			Element cpElement;
 			try {
-				DocumentBuilder parser = DocumentBuilderFactory.newInstance().newDocumentBuilder();
+				DocumentBuilder parser = XmlProcessorFactoryJdtUi.createDocumentBuilderFactoryWithErrorOnDOCTYPE().newDocumentBuilder();
 				parser.setErrorHandler(new DefaultHandler());
 				cpElement = parser.parse(new InputSource(stream)).getDocumentElement();
 			} catch (SAXException | ParserConfigurationException e) {
@@ -658,7 +649,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				stream.close();
 			}
 
-			if (!cpElement.getNodeName().equalsIgnoreCase(TAG_ROOT)) {
+			if (!TAG_ROOT.equalsIgnoreCase(cpElement.getNodeName())) {
 				throw new IOException(PreferencesMessages.UserLibraryPreferencePage_LoadSaveDialog_load_badformat);
 			}
 
@@ -677,7 +668,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				}
 				Element libElement= (Element) lib;
 				String name= libElement.getAttribute(TAG_NAME);
-				boolean isSystem= Boolean.valueOf(libElement.getAttribute(TAG_SYSTEMLIBRARY)).booleanValue();
+				boolean isSystem= Boolean.parseBoolean(libElement.getAttribute(TAG_SYSTEMLIBRARY));
 
 				CPUserLibraryElement newLibrary= new CPUserLibraryElement(name, isSystem, null);
 				result.add(newLibrary);
@@ -691,7 +682,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 					Element archiveElement= (Element) archiveNode;
 
 					String pathString= archiveElement.getAttribute(TAG_ARCHIVE_PATH);
-					IPath path= version.equals(VERSION1) ? Path.fromOSString(pathString) : Path.fromPortableString(pathString);
+					IPath path= VERSION1.equals(version) ? Path.fromOSString(pathString) : Path.fromPortableString(pathString);
 					path= path.makeAbsolute(); // only necessary for manually edited files: bug 202373
 
 					IResource resource= root.findMember(path); // support internal JARs: bug 133191
@@ -704,7 +695,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 
 					if (archiveElement.hasAttribute(TAG_SOURCEATTACHMENT)) {
 						String sourceAttachString= archiveElement.getAttribute(TAG_SOURCEATTACHMENT);
-						IPath sourceAttach= version.equals(VERSION1) ? Path.fromOSString(sourceAttachString) : Path.fromPortableString(sourceAttachString);
+						IPath sourceAttach= VERSION1.equals(version) ? Path.fromOSString(sourceAttachString) : Path.fromPortableString(sourceAttachString);
 						newArchive.setAttribute(CPListElement.SOURCEATTACHMENT, sourceAttach);
 					}
 					if (archiveElement.hasAttribute(TAG_SOURCE_ATTACHMENT_ENCODING)) {
@@ -842,9 +833,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 			Object selectedLibrary= map.get(DATA_LIBRARY_TO_SELECT);
 			boolean createIfNotExists= Boolean.TRUE.equals(map.get(DATA_DO_CREATE));
 			if (selectedLibrary instanceof String) {
-				int nElements= fLibraryList.getSize();
-				for (int i= 0; i < nElements; i++) {
-					CPUserLibraryElement curr= fLibraryList.getElement(i);
+				for (CPUserLibraryElement curr : fLibraryList.getElements()) {
 					if (curr.getName().equals(selectedLibrary)) {
 						fLibraryList.selectElements(new StructuredSelection(curr));
 						fLibraryList.expandElement(curr, 1);
@@ -902,20 +891,17 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 	@Override
 	public boolean performOk() {
 		try {
-			PlatformUI.getWorkbench().getProgressService().run(true, true, new IRunnableWithProgress() {
-				@Override
-				public void run(IProgressMonitor monitor) throws InvocationTargetException {
-					try {
-						if (monitor != null) {
-							monitor= new NullProgressMonitor();
-						}
-
-						updateUserLibararies(monitor);
-					} catch (CoreException e) {
-						throw new InvocationTargetException(e);
-					} finally {
-						monitor.done();
+			PlatformUI.getWorkbench().getProgressService().run(true, true, monitor -> {
+				try {
+					if (monitor != null) {
+						monitor= new NullProgressMonitor();
 					}
+
+					updateUserLibararies(monitor);
+				} catch (CoreException e) {
+					throw new InvocationTargetException(e);
+				} finally {
+					monitor.done();
 				}
 			});
 		} catch (InterruptedException e) {
@@ -935,8 +921,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		int nExisting= list.size();
 
 		HashSet<CPUserLibraryElement> newEntries= new HashSet<>(list.size());
-		for (int i= 0; i < nExisting; i++) {
-			CPUserLibraryElement element= list.get(i);
+		for (CPUserLibraryElement element : list) {
 			boolean contained= oldNames.remove(element.getName());
 			if (!contained) {
 				newEntries.add(element);
@@ -997,10 +982,10 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		boolean canEditEncoding= false;
 		for (CPListElementAttribute allAttribute : selElement.getAllAttributes()) {
 			if (CPListElement.SOURCE_ATTACHMENT_ENCODING.equals(allAttribute.getKey())) {
-				canEditEncoding= !(allAttribute.isNonModifiable() || allAttribute.isNotSupported());
+				canEditEncoding= !allAttribute.isNonModifiable() && !allAttribute.isNotSupported();
 			}
 		}
-		if (key.equals(CPListElement.SOURCEATTACHMENT)) {
+		if (CPListElement.SOURCEATTACHMENT.equals(key)) {
 			IClasspathEntry result= BuildPathDialogAccess.configureSourceAttachment(getShell(), selElement.getClasspathEntry(), canEditEncoding);
 			if (result != null) {
 				selElement.setAttribute(CPListElement.SOURCEATTACHMENT, result.getSourceAttachmentPath());
@@ -1008,7 +993,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				fLibraryList.refresh(parentContainer);
 				fLibraryList.update(selElement);
 			}
-		} else if (key.equals(CPListElement.ACCESSRULES)) {
+		} else if (CPListElement.ACCESSRULES.equals(key)) {
 			AccessRulesDialog dialog= new AccessRulesDialog(getShell(), selElement, null, false);
 			if (dialog.open() == Window.OK) {
 				selElement.setAttribute(CPListElement.ACCESSRULES, dialog.getAccessRules());
@@ -1021,7 +1006,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				IClasspathAttribute result= config.performEdit(getShell(), elem.getClasspathAttributeAccess());
 				if (result != null) {
 					elem.setValue(result.getValue());
-					if(key.equals(CPListElement.TEST) || key.equals(CPListElement.WITHOUT_TEST_CODE)) {
+					if(CPListElement.TEST.equals(key) || CPListElement.WITHOUT_TEST_CODE.equals(key)) {
 						fLibraryList.refresh(elem.getParent());
 					} else {
 						fLibraryList.refresh(elem);
@@ -1156,8 +1141,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 
 	private void doRemove(List<Object> selected) {
 		Object selectionAfter= null;
-		for (int i= 0; i < selected.size(); i++) {
-			Object curr= selected.get(i);
+		for (Object curr : selected) {
 			if (curr instanceof CPUserLibraryElement) {
 				fLibraryList.removeElement((CPUserLibraryElement) curr);
 			} else if (curr instanceof CPListElement) {
@@ -1174,7 +1158,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 				if (attrib.isBuiltIn()) {
 					Object value= null;
 					String key= attrib.getKey();
-					if (key.equals(CPListElement.ACCESSRULES)) {
+					if (CPListElement.ACCESSRULES.equals(key)) {
 						value= new IAccessRule[0];
 					}
 					attrib.getParent().setAttribute(key, value);
@@ -1269,8 +1253,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		LoadSaveDialog dialog= new LoadSaveDialog(getShell(), false, existing, fDialogSettings);
 		if (dialog.open() == Window.OK) {
 			HashMap<String, CPUserLibraryElement> map= new HashMap<>(existing.size());
-			for (int k= 0; k < existing.size(); k++) {
-				CPUserLibraryElement elem= existing.get(k);
+			for (CPUserLibraryElement elem : existing) {
 				map.put(elem.getName(), elem);
 			}
 
@@ -1320,15 +1303,14 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 		if (list.isEmpty()) {
 			return false;
 		}
-		for (int i= 0; i < list.size(); i++) {
-			Object elem= list.get(i);
+		for (Object elem : list) {
 			if (elem instanceof CPListElementAttribute) {
 				CPListElementAttribute attrib= (CPListElementAttribute) elem;
 				if (attrib.isNonModifiable()) {
 					return false;
 				}
 				if (attrib.isBuiltIn()) {
-					if (attrib.getKey().equals(CPListElement.ACCESSRULES)) {
+					if (CPListElement.ACCESSRULES.equals(attrib.getKey())) {
 						return ((IAccessRule[]) attrib.getValue()).length > 0;
 					}
 					if (attrib.getValue() == null) {
@@ -1340,9 +1322,8 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 						return false;
 					}
 				}
-			} else if (elem instanceof CPListElement) {
-				// ok to remove
-			} else if (elem instanceof CPUserLibraryElement) {
+			} else if (elem instanceof CPListElement
+					|| elem instanceof CPUserLibraryElement) {
 				// ok to remove
 			} else { // unknown element
 				return false;
@@ -1353,8 +1334,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 
 	private CPUserLibraryElement getCommonParent(List<?> list) {
 		CPUserLibraryElement parent= null;
-		for (int i= 0, len= list.size(); i < len; i++) {
-			Object curr= list.get(i);
+		for (Object curr : list) {
 			if (curr instanceof CPListElement) {
 				Object elemParent= ((CPListElement) curr).getParentContainer();
 				if (parent == null) {
@@ -1424,7 +1404,7 @@ public class UserLibraryPreferencePage extends PreferencePage implements IWorkbe
 
 	private CPListElement[] openJarFileDialog(CPListElement existing, Object parent) {
 		if (existing == null) {
-			return doOpenExternalJarFileDialog(existing, parent);
+			return doOpenExternalJarFileDialog(null, parent);
 		}
 
 		IWorkspaceRoot root= ResourcesPlugin.getWorkspace().getRoot();
