@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2014 IBM Corporation and others.
+ * Copyright (c) 2007, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -155,6 +155,7 @@ public class MatchLocations {
 
 			createButton(group, SearchMessages.MatchLocations_imports_label, IJavaSearchConstants.IMPORT_DECLARATION_TYPE_REFERENCE);
 			createButton(group, SearchMessages.MatchLocations_super_types_label, IJavaSearchConstants.SUPERTYPE_TYPE_REFERENCE);
+			createButton(group, SearchMessages.MatchLocations_permitted_types_label, IJavaSearchConstants.PERMITTYPE_TYPE_REFERENCE);
 			addSeparator(group);
 
 			createButton(group, SearchMessages.MatchLocations_annotations_label , IJavaSearchConstants.ANNOTATION_TYPE_REFERENCE);
@@ -191,8 +192,7 @@ public class MatchLocations {
 		}
 
 		protected final void performSelectAction(boolean selectAll) {
-			for (int i= 0; i < fButtons.size(); i++) {
-				Button button= fButtons.get(i);
+			for (Button button : fButtons) {
 				button.setSelection(selectAll);
 			}
 			validateSettings();
@@ -234,7 +234,7 @@ public class MatchLocations {
 		private int getIntValue(Button button) {
 			Integer bData= (Integer) button.getData();
 			if (bData != null) {
-				return bData.intValue();
+				return bData;
 			}
 			return 0;
 		}
@@ -245,8 +245,7 @@ public class MatchLocations {
 
 		private void validateSettings() {
 			int selected= 0;
-			for (int i= 0; i < fButtons.size(); i++) {
-				Button button= fButtons.get(i);
+			for (Button button : fButtons) {
 				if (button.getSelection()) {
 					selected |= getIntValue(button);
 				}
@@ -273,6 +272,9 @@ public class MatchLocations {
 		if (isSet(locations, IJavaSearchConstants.SUPERTYPE_TYPE_REFERENCE)) {
 			args.add(SearchMessages.MatchLocations_super_types_description);
 		}
+		if (isSet(locations, IJavaSearchConstants.PERMITTYPE_TYPE_REFERENCE)) {
+			args.add(SearchMessages.MatchLocations_permitted_types_description);
+		}
 		if (isSet(locations, IJavaSearchConstants.ANNOTATION_TYPE_REFERENCE)) {
 			args.add(SearchMessages.MatchLocations_annotations_description);
 		}
@@ -345,16 +347,18 @@ public class MatchLocations {
 	}
 
 	public static int getTotalNumberOfSettings(int searchFor) {
-		if (searchFor == IJavaSearchConstants.TYPE) {
-			return 15;
-		} else if (searchFor == IJavaSearchConstants.CONSTRUCTOR) {
-			return 1;
-		} else if (searchFor == IJavaSearchConstants.METHOD) {
-			return 5;
-		} else if (searchFor == IJavaSearchConstants.FIELD) {
-			return 4;
+		switch (searchFor) {
+			case IJavaSearchConstants.TYPE:
+				return 16;
+			case IJavaSearchConstants.CONSTRUCTOR:
+				return 1;
+			case IJavaSearchConstants.METHOD:
+				return 5;
+			case IJavaSearchConstants.FIELD:
+				return 4;
+			default:
+				return 0;
 		}
-		return 0;
 	}
 
 	public static int getNumberOfSelectedSettings(int locations, int searchFor) {
@@ -367,6 +371,9 @@ public class MatchLocations {
 			if (isSet(locations, IJavaSearchConstants.SUPERTYPE_TYPE_REFERENCE)) {
 				count++;
 			}
+			if (isSet(locations, IJavaSearchConstants.PERMITTYPE_TYPE_REFERENCE)) {
+				count++;
+			}
 			if (isSet(locations, IJavaSearchConstants.ANNOTATION_TYPE_REFERENCE)) {
 				count++;
 			}
@@ -427,4 +434,7 @@ public class MatchLocations {
 		}
 		return count;
 	}
+
+	private MatchLocations() {
+	}
 }
