@@ -1,13 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
  * https://www.eclipse.org/legal/epl-2.0/
  *
- * SPDX-License-Identifier: EPL-2.0
- *
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *******************************************************************************/
@@ -141,17 +139,6 @@ public final class SearchMessages extends NLS {
 	public static String Search_FindOccurrencesInFile_tooltip;
 	public static String FindOccurrencesEngine_noSource_text;
 	public static String FindOccurrencesEngine_cannotParse_text;
-	public static String ExceptionOccurrencesFinder_no_exception;
-	public static String ExceptionOccurrencesFinder_searchfor;
-	public static String ExceptionOccurrencesFinder_label_singular;
-	public static String ExceptionOccurrencesFinder_label_plural;
-	public static String ExceptionOccurrencesFinder_occurrence_description;
-	public static String ExceptionOccurrencesFinder_occurrence_implicit_close_description;
-	public static String ImplementOccurrencesFinder_invalidTarget;
-	public static String ImplementOccurrencesFinder_searchfor;
-	public static String ImplementOccurrencesFinder_label_singular;
-	public static String ImplementOccurrencesFinder_label_plural;
-	public static String ImplementOccurrencesFinder_occurrence_description;
 	public static String JavaSearchOperation_singularDeclarationsPostfix;
 	public static String JavaSearchOperation_singularReferencesPostfix;
 	public static String JavaSearchOperation_singularReadReferencesPostfix;
@@ -230,6 +217,9 @@ public final class SearchMessages extends NLS {
 	public static String MatchFilter_ImportFilter_name;
 	public static String MatchFilter_ImportFilter_actionLabel;
 	public static String MatchFilter_ImportFilter_description;
+	public static String MatchFilter_StaticImportFilter_name;
+	public static String MatchFilter_StaticImportFilter_actionLabel;
+	public static String MatchFilter_StaticImportFilter_description;
 	public static String MatchFilter_WriteFilter_name;
 	public static String MatchFilter_WriteFilter_actionLabel;
 	public static String MatchFilter_WriteFilter_description;
@@ -248,21 +238,7 @@ public final class SearchMessages extends NLS {
 	public static String MatchFilter_InexactFilter_name;
 	public static String MatchFilter_InexactFilter_actionLabel;
 	public static String MatchFilter_InexactFilter_description;
-	public static String MethodExitsFinder_job_label;
-	public static String MethodExitsFinder_label_plural;
-	public static String MethodExitsFinder_label_singular;
-	public static String MethodExitsFinder_no_return_type_selected;
-	public static String MethodExitsFinder_occurrence_exit_description;
-	public static String MethodExitsFinder_occurrence_exit_impclict_close_description;
-	public static String MethodExitsFinder_occurrence_return_description;
-	public static String BreakContinueTargetFinder_break_label_plural;
-	public static String BreakContinueTargetFinder_break_label_singular;
-	public static String BreakContinueTargetFinder_cannot_highlight;
-	public static String BreakContinueTargetFinder_continue_label_plural;
-	public static String BreakContinueTargetFinder_continue_label_singular;
-	public static String BreakContinueTargetFinder_job_label;
-	public static String BreakContinueTargetFinder_no_break_or_continue_selected;
-	public static String BreakContinueTargetFinder_occurrence_description;
+	public static String EnumConstructorTargetFinder_description;
 	public static String TextSearchLabelProvider_matchCountFormat;
 	static {
 		NLS.initializeMessages(BUNDLE_NAME, SearchMessages.class);
@@ -319,7 +295,9 @@ public final class SearchMessages extends NLS {
 	public static String MatchLocations_super_description;
 	public static String MatchLocations_super_label;
 	public static String MatchLocations_super_types_description;
+	public static String MatchLocations_permitted_types_description;
 	public static String MatchLocations_super_types_label;
+	public static String MatchLocations_permitted_types_label;
 	public static String MatchLocations_this_description;
 	public static String MatchLocations_this_label;
 	public static String MatchLocations_thrown_exceptions_description;
