@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -45,7 +45,7 @@ public final class JavaIndenter {
 	 * The JDT Core preferences.
 	 * @since 3.2
 	 */
-	private final class CorePrefs {
+	private final static class CorePrefs {
 		final boolean prefUseTabs;
 		final int prefTabSize;
 		final int prefIndentationSize;
@@ -673,10 +673,8 @@ public final class JavaIndenter {
 		if (JavaCore.SPACE.equals(fPrefs.prefTabChar)) {
 			tabs= 0;
 			spaces= missing;
-		} else if (JavaCore.TAB.equals(fPrefs.prefTabChar)) {
-			tabs= tabSize > 0 ? missing / tabSize : 0;
-			spaces= tabSize > 0 ? missing % tabSize : missing;
-		} else if (DefaultCodeFormatterConstants.MIXED.equals(fPrefs.prefTabChar)) {
+		} else if (JavaCore.TAB.equals(fPrefs.prefTabChar)
+				|| DefaultCodeFormatterConstants.MIXED.equals(fPrefs.prefTabChar)) {
 			tabs= tabSize > 0 ? missing / tabSize : 0;
 			spaces= tabSize > 0 ? missing % tabSize : missing;
 		} else {
@@ -1088,6 +1086,7 @@ public final class JavaIndenter {
 				return skipToStatementStart(danglingElse, false);
 
 			case Symbols.TokenRBRACKET:
+			case Symbols.TokenRETURN:
 				fIndent= fPrefs.prefContinuationIndent;
 				return fPosition;
 
@@ -1127,10 +1126,7 @@ public final class JavaIndenter {
 				fTokenPos = tokenPos;
 
 				return skipToPreviousListItemOrListStart();
-			case Symbols.TokenRETURN:
-				fIndent= fPrefs.prefContinuationIndent;
-				return fPosition;
-			case Symbols.TokenPLUS:
+		case Symbols.TokenPLUS:
 				if (isStringContinuation(fPosition)) {
 					try {
 						if (isSecondLineOfStringContinuation(offset)) {
@@ -1199,9 +1195,8 @@ public final class JavaIndenter {
 					fPosition= storedPos;
 					break;
 				case Symbols.TokenEOF:
-					return false;
-				default:
-					return false;
+			default:
+				return false;
 			}
 			nextToken();
 		}
@@ -1247,16 +1242,14 @@ public final class JavaIndenter {
 				case Symbols.TokenFOR:
 					return true;
 				case Symbols.TokenLBRACE:
+				case Symbols.TokenCOLON:
+				case Symbols.TokenEOF:
 					return false;
 				case Symbols.TokenSEMICOLON:
 					semiColonCount++;
 					if (semiColonCount > 2)
 						return false;
 					break;
-				case Symbols.TokenCOLON:
-					return false;
-				case Symbols.TokenEOF:
-					return false;
 			}
 		}
 	}
@@ -1274,7 +1267,6 @@ public final class JavaIndenter {
 				case Symbols.TokenTRY:
 					return true;
 				case Symbols.TokenLBRACE:
-					return false;
 				case Symbols.TokenEOF:
 					return false;
 			}
@@ -1349,8 +1341,10 @@ public final class JavaIndenter {
 
 				case Symbols.TokenCOLON:
 					int pos= fPreviousPos;
+					int pos2= fPosition;
 					if (!isConditional())
 						return pos;
+					fPosition= pos2;
 					break;
 
 				case Symbols.TokenRBRACE:
@@ -1817,7 +1811,6 @@ public final class JavaIndenter {
 					skipScope();
 					break;
 				case Symbols.TokenEOF:
-					return false;
 				default:
 					return false;
 			}
@@ -1847,7 +1840,6 @@ public final class JavaIndenter {
 					skipScope();
 					break;
 				case Symbols.TokenEOF:
-					return false;
 				default:
 					return false;
 			}
