@@ -44,6 +44,7 @@ import org.eclipse.jdt.ui.text.java.ContentAssistInvocationContext;
 import org.eclipse.jdt.ui.text.java.IJavaCompletionProposalComputer;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
+import org.eclipse.jdt.internal.ui.javaeditor.JavaSourceViewer;
 
 /**
  * The description of an extension to the
@@ -155,6 +156,8 @@ final class CompletionProposalComputerDescriptor {
 	private final boolean fRequiresUIThread;
 
 
+
+
 	/**
 	 * Creates a new descriptor.
 	 *
@@ -194,10 +197,10 @@ final class CompletionProposalComputerDescriptor {
 		}
 
 		String activateAttribute= element.getAttribute(ACTIVATE);
-		fActivate= Boolean.valueOf(activateAttribute).booleanValue();
+		fActivate= Boolean.parseBoolean(activateAttribute);
 
 		String needsSortingAfterFilteringAttribute= element.getAttribute(NEEDS_SORTING_AFTER_FILTERING);
-		fNeedsSortingAfterFiltering= Boolean.valueOf(needsSortingAfterFilteringAttribute).booleanValue();
+		fNeedsSortingAfterFiltering= Boolean.parseBoolean(needsSortingAfterFilteringAttribute);
 
 		fClass= element.getAttribute(CLASS);
 		checkNotNull(fClass, CLASS);
@@ -350,7 +353,9 @@ final class CompletionProposalComputerDescriptor {
 					return proposals;
 				}
 			} finally {
-				fIsReportingDelay= true;
+				// If computers are using non-ui thread, don't report delays.
+				fIsReportingDelay= !(context.getViewer() instanceof JavaSourceViewer)
+						|| !((JavaSourceViewer) context.getViewer()).isAsyncCompletionActive();
 			}
 			status= createAPIViolationStatus(COMPUTE_COMPLETION_PROPOSALS);
 		} catch (InvalidRegistryObjectException x) {
@@ -425,6 +430,7 @@ final class CompletionProposalComputerDescriptor {
 		if (!isEnabled())
 			return;
 
+
 		IStatus status;
 		try {
 			IJavaCompletionProposalComputer computer= getComputer(true);
