@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -37,17 +37,18 @@ import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IJavaProject;
 import org.eclipse.jdt.core.IMember;
 import org.eclipse.jdt.core.IMethod;
+import org.eclipse.jdt.core.IModuleDescription;
 import org.eclipse.jdt.core.ISourceRange;
 import org.eclipse.jdt.core.IType;
 import org.eclipse.jdt.core.JavaModelException;
+import org.eclipse.jdt.core.manipulation.CodeGeneration;
 
-import org.eclipse.jdt.internal.corext.codemanipulation.StubUtility;
 import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 import org.eclipse.jdt.internal.corext.util.MethodOverrideTester;
+import org.eclipse.jdt.internal.core.manipulation.StubUtility;
 import org.eclipse.jdt.internal.core.manipulation.util.Strings;
 import org.eclipse.jdt.internal.corext.util.SuperTypeHierarchyCache;
 
-import org.eclipse.jdt.ui.CodeGeneration;
 import org.eclipse.jdt.ui.IWorkingCopyManager;
 import org.eclipse.jdt.ui.PreferenceConstants;
 
@@ -130,7 +131,7 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 									String string= createJavaDocTags(d, c, indentation, lineDelimiter, unit);
 									buf.append(restOfLine);
 									// only add tags if they are non-empty - the empty line has already been added above.
-									if (string != null && !string.trim().equals("*")) //$NON-NLS-1$
+									if (string != null && !"*".equals(string.trim())) //$NON-NLS-1$
 										buf.append(string);
 								} catch (CoreException e) {
 									// ignore
@@ -216,6 +217,9 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 		case IJavaElement.METHOD:
 			return createMethodTags(document, command, indentation, lineDelimiter, (IMethod) element);
 
+		case IJavaElement.JAVA_MODULE:
+			return createModuleTags(document, command, indentation, lineDelimiter, (IModuleDescription) element);
+
 		default:
 			return null;
 		}
@@ -267,6 +271,19 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 		return null;
 	}
 
+	private String createModuleTags(IDocument document, DocumentCommand command, String indentation, String lineDelimiter, IModuleDescription module)
+			throws CoreException, BadLocationException
+		{
+			String comment= CodeGeneration.getModuleComment(module.getCompilationUnit(), module, lineDelimiter);
+			if (comment != null) {
+				boolean javadocComment= comment.startsWith("/**"); //$NON-NLS-1$
+				if (!isFirstComment(document, command, module, javadocComment))
+					return null;
+				return prepareTemplateComment(comment.trim(), indentation, module.getJavaProject(), lineDelimiter);
+			}
+			return null;
+		}
+
 	private String createMethodTags(IDocument document, DocumentCommand command, String indentation, String lineDelimiter, IMethod method)
 		throws CoreException, BadLocationException
 	{
@@ -278,7 +295,7 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 			boolean javadocComment= comment.startsWith("/**"); //$NON-NLS-1$
 			if (!isFirstComment(document, command, method, javadocComment))
 				return null;
-			boolean isJavaDoc= partition.getLength() >= 3 && document.get(partition.getOffset(), 3).equals("/**"); //$NON-NLS-1$
+			boolean isJavaDoc= partition.getLength() >= 3 && "/**".equals(document.get(partition.getOffset(), 3)); //$NON-NLS-1$
 			if (javadocComment == isJavaDoc) {
 				return prepareTemplateComment(comment, indentation, method.getJavaProject(), lineDelimiter);
 			}
@@ -363,6 +380,12 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 			String comment= document.get(partition.getOffset(), partition.getLength());
 			if (comment.indexOf("/*", 2) != -1) //$NON-NLS-1$
 				return true; // enclosed another comment -> probably a new comment
+			if (!hasBlockComment(comment)) {
+				return true; // missing block comment end -> probably a new comment
+			}
+			if (isBlockCommentsInsideString(comment)) {
+				return true; // block comments inside strings -> probably a new comment
+			}
 
 			return false;
 
@@ -371,6 +394,72 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 		}
 	}
 
+	/**
+	 * Return true if comment has a proper block comment ending. Handle case when '&#42;/' block
+	 * comment is after a line comment '//'
+	 *
+	 * <pre>
+	 * Partial comment with block comment after line comment:
+	 *
+	 * /&#42;&#42;
+	 *  &#42;
+	 * void Foo() {
+	 *    int a; // &#42;/
+	 * }
+	 * </pre>
+	 *
+	 * @param comment The comment block, can be partial when creating new javadoc comment
+	 * @return Return true if comment has a proper block comment ending
+	 */
+	private boolean hasBlockComment(String comment) {
+		// return early if block does not contain block comment ending '*/'
+		if (comment.indexOf("*/", 2) == -1) { //$NON-NLS-1$
+			return false;
+		}
+
+		boolean lineCommentHidesBlockComment= false;
+		for (String line : Strings.convertIntoLines(comment)) {
+			int blockCommentIndex= line.indexOf("*/"); //$NON-NLS-1$
+			int lineCommentIndex= line.indexOf("//"); //$NON-NLS-1$
+			if (lineCommentIndex != -1 && blockCommentIndex != -1) {
+				if (lineCommentIndex < blockCommentIndex) {
+					lineCommentHidesBlockComment= true;
+				}
+			}
+		}
+		return lineCommentHidesBlockComment == false;
+	}
+
+	private boolean isBlockCommentsInsideString(String comment) {
+		// return early if block does not contain block comment ending '*/' or '"' (String) token
+		if (comment.indexOf("*/") == -1 || comment.indexOf("\"") == -1) { //$NON-NLS-1$ //$NON-NLS-2$
+			return false;
+		}
+
+		boolean allBlockCommentsInsideString= true;
+		boolean stringStart= false;
+		for (int i= 0; i < comment.length(); i++) {
+			char c= comment.charAt(i);
+			if (c == '"' && !stringStart) {
+				stringStart= true;
+				continue;
+			}
+			if (c == '"' && stringStart) {
+				stringStart= false;
+				continue;
+			}
+			if (c == '*' && !stringStart) {
+				if (i < comment.length() - 1) {
+					if (comment.charAt(i + 1) == '/') {
+						// found a block end inside string
+						allBlockCommentsInsideString= false;
+					}
+				}
+			}
+		}
+		return allBlockCommentsInsideString;
+	}
+
 	private boolean isSmartMode() {
 		IWorkbenchPage page= JavaPlugin.getActivePage();
 		if (page != null)  {
@@ -409,7 +498,7 @@ public class JavaDocAutoIndentStrategy extends DefaultIndentLineAutoEditStrategy
 				}
 			}
 
-			if (command.text.equals("/")) { //$NON-NLS-1$
+			if ("/".equals(command.text)) { //$NON-NLS-1$
 				indentAfterCommentEnd(document, command);
 				return;
 			}
