@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2011 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,7 +16,7 @@ package org.eclipse.jdt.internal.ui.text.spelling;
 import java.util.LinkedList;
 import java.util.Locale;
 
-import com.ibm.icu.text.BreakIterator;
+import java.text.BreakIterator;
 
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.NullProgressMonitor;
@@ -338,10 +338,11 @@ public class SpellCheckIterator implements ISpellCheckIterator {
 
 			if (fSuccessor != BreakIterator.DONE && fContent.charAt(fPrevious) == IJavaDocTagConstants.JAVADOC_TAG_PREFIX) {
 
+				int oldNextValue= fNext;
 				nextBreak();
 				if (Character.isLetter(fContent.charAt(fPrevious + 1))) {
 					update= true;
-					token= fContent.substring(fPrevious, fNext);
+					token= fContent.substring(fPrevious, oldNextValue);
 				} else
 					fPredecessor= fNext;
 
