@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -67,14 +67,13 @@ import org.eclipse.jface.text.templates.TemplateException;
 import org.eclipse.jface.text.templates.TemplateVariable;
 
 import org.eclipse.ui.IEditorPart;
-import org.eclipse.ui.part.IWorkbenchPartOrientation;
 
 import org.eclipse.ui.texteditor.link.EditorLinkedModeUI;
 
-import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.compiler.CharOperation;
 import org.eclipse.jdt.core.search.SearchPattern;
 
+import org.eclipse.jdt.internal.core.manipulation.JavaManipulationPlugin;
 import org.eclipse.jdt.internal.corext.template.java.JavaContext;
 import org.eclipse.jdt.internal.corext.template.java.JavaDocContext;
 import org.eclipse.jdt.internal.corext.util.Messages;
@@ -249,9 +248,7 @@ public class TemplateProposal
 			MultiVariableGuess guess= fContext instanceof JavaContext ? ((JavaContext) fContext).getMultiVariableGuess() : null;
 
 			boolean hasPositions= false;
-			for (int i= 0; i != variables.length; i++) {
-				TemplateVariable variable= variables[i];
-
+			for (TemplateVariable variable : variables) {
 				if (variable.isUnambiguous())
 					continue;
 
@@ -306,11 +303,7 @@ public class TemplateProposal
 				fSelectedRegion= new Region(getCaretOffset(templateBuffer) + start, 0);
 			}
 
-		} catch (BadLocationException e) {
-			JavaPlugin.log(e);
-			openErrorDialog(viewer.getTextWidget().getShell(), e);
-			fSelectedRegion= fRegion;
-		} catch (BadPositionCategoryException e) {
+		} catch (BadLocationException | BadPositionCategoryException e) {
 			JavaPlugin.log(e);
 			openErrorDialog(viewer.getTextWidget().getShell(), e);
 			fSelectedRegion= fRegion;
@@ -390,9 +383,8 @@ public class TemplateProposal
 	private int getCaretOffset(TemplateBuffer buffer) {
 
 	    TemplateVariable[] variables= buffer.getVariables();
-		for (int i= 0; i != variables.length; i++) {
-			TemplateVariable variable= variables[i];
-			if (variable.getType().equals(GlobalTemplateVariables.Cursor.NAME))
+		for (TemplateVariable variable : variables) {
+			if (GlobalTemplateVariables.Cursor.NAME.equals(variable.getType()))
 				return variable.getOffsets()[0];
 		}
 
@@ -520,7 +512,7 @@ public class TemplateProposal
 					}
 				}
 				int matchRule= SearchPattern.R_PREFIX_MATCH;
-				if (JavaCore.ENABLED.equals(JavaCore.getOption(JavaCore.CODEASSIST_SUBSTRING_MATCH)) && CharOperation.substringMatch(pattern, displayString)) {
+				if (JavaManipulationPlugin.CODEASSIST_SUBSTRING_MATCH_ENABLED && CharOperation.substringMatch(pattern, displayString)) {
 					matchRule= SearchPattern.R_SUBSTRING_MATCH;
 				}
 				int[] matchingRegions= SearchPattern.getMatchingRegions(pattern, displayString, matchRule);
@@ -579,9 +571,9 @@ public class TemplateProposal
 	@Override
 	public IInformationControlCreator getInformationControlCreator() {
 		int orientation;
-		IEditorPart editor= getJavaEditor();
-		if (editor instanceof IWorkbenchPartOrientation)
-			orientation= ((IWorkbenchPartOrientation)editor).getOrientation();
+		JavaEditor editor= getJavaEditor();
+		if (editor != null)
+			orientation= editor.getOrientation();
 		else
 			orientation= SWT.LEFT_TO_RIGHT;
 		return new TemplateInformationControlCreator(orientation);
@@ -611,7 +603,7 @@ public class TemplateProposal
 			if (offset >= replaceOffset) {
 				String content= document.get(replaceOffset, offset - replaceOffset).toLowerCase();
 				String templateName= fTemplate.getName().toLowerCase();
-				boolean isSubstringEnabled= JavaCore.ENABLED.equals(JavaCore.getOption(JavaCore.CODEASSIST_SUBSTRING_MATCH));
+				boolean isSubstringEnabled= JavaManipulationPlugin.CODEASSIST_SUBSTRING_MATCH_ENABLED;
 				boolean valid= false;
 				fIsSubstringMatch= false;
 				if (templateName.startsWith(content)) {
