@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -53,7 +53,6 @@ import org.eclipse.core.runtime.OperationCanceledException;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.Job;
 
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IStatusLineManager;
 import org.eclipse.jface.action.IToolBarManager;
@@ -65,6 +64,7 @@ import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.util.DelegatingDropAdapter;
 import org.eclipse.jface.util.IPropertyChangeListener;
+import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.AbstractTreeViewer;
 import org.eclipse.jface.viewers.IBasicPropertyConstants;
@@ -101,7 +101,6 @@ import org.eclipse.ui.part.PluginTransfer;
 import org.eclipse.ui.part.ResourceTransfer;
 import org.eclipse.ui.part.ShowInContext;
 import org.eclipse.ui.part.ViewPart;
-import org.eclipse.ui.views.navigator.LocalSelectionTransfer;
 
 import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.IMember;
@@ -111,6 +110,7 @@ import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 
+import org.eclipse.jdt.internal.core.manipulation.MembersOrderPreferenceCacheCommon;
 import org.eclipse.jdt.internal.corext.util.Messages;
 
 import org.eclipse.jdt.ui.IContextMenuConstants;
@@ -137,7 +137,6 @@ import org.eclipse.jdt.internal.ui.javaeditor.EditorUtility;
 import org.eclipse.jdt.internal.ui.packageview.FileTransferDragAdapter;
 import org.eclipse.jdt.internal.ui.packageview.PluginTransferDropAdapter;
 import org.eclipse.jdt.internal.ui.packageview.SelectionTransferDragAdapter;
-import org.eclipse.jdt.internal.ui.preferences.MembersOrderPreferenceCache;
 import org.eclipse.jdt.internal.ui.util.ExceptionHandler;
 import org.eclipse.jdt.internal.ui.util.JavaUIHelp;
 import org.eclipse.jdt.internal.ui.util.SelectionUtil;
@@ -247,7 +246,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Indicates whether the restore job was canceled explicitly.
-	 * 
+	 *
 	 * @since 3.6
 	 */
 	private boolean fRestoreJobCanceledExplicitly= true;
@@ -255,7 +254,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	/**
 	 * Indicates whether empty viewers should keep showing. If false, replace them with
 	 * fEmptyTypesViewer.
-	 * 
+	 *
 	 * @since 3.6
 	 */
 	private boolean fKeepShowingEmptyViewers= true;
@@ -270,20 +269,10 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		fRestoreStateJob= null;
 
 		fHierarchyLifeCycle= new TypeHierarchyLifeCycle(this);
-		fTypeHierarchyLifeCycleListener= new ITypeHierarchyLifeCycleListener() {
-			@Override
-			public void typeHierarchyChanged(TypeHierarchyLifeCycle typeHierarchy, IType[] changedTypes) {
-				doTypeHierarchyChanged(typeHierarchy, changedTypes);
-			}
-		};
+		fTypeHierarchyLifeCycleListener= this::doTypeHierarchyChanged;
 		fHierarchyLifeCycle.addChangedListener(fTypeHierarchyLifeCycleListener);
 
-		fPropertyChangeListener= new IPropertyChangeListener() {
-			@Override
-			public void propertyChange(PropertyChangeEvent event) {
-				doPropertyChange(event);
-			}
-		};
+		fPropertyChangeListener= this::doPropertyChange;
 		PreferenceConstants.getPreferenceStore().addPropertyChangeListener(fPropertyChangeListener);
 
 		fIsEnableMemberFilter= false;
@@ -362,18 +351,13 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 			public void partOpened(IWorkbenchPartReference ref) {}
 		};
 
-		fSelectionChangedListener= new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				doSelectionChanged(event);
-			}
-		};
+		fSelectionChangedListener= this::doSelectionChanged;
 	}
 
 	protected void doPropertyChange(PropertyChangeEvent event) {
 		String property= event.getProperty();
 		if (fMethodsViewer != null) {
-			if (MembersOrderPreferenceCache.isMemberOrderProperty(event.getProperty())) {
+			if (MembersOrderPreferenceCacheCommon.isMemberOrderProperty(event.getProperty())) {
 				fMethodsViewer.refresh();
 			}
 		}
@@ -391,7 +375,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		for (Iterator<IJavaElement[]> iter= fInputHistory.iterator(); iter.hasNext();) {
 			IJavaElement[] elem= iter.next();
 			if (Arrays.equals(elem, entry)) {
-				fInputHistory.remove(elem);
+				iter.remove();
 				break;
 			}
 		}
@@ -401,9 +385,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	private void updateHistoryEntries() {
 		for (int i= fInputHistory.size() - 1; i >= 0; i--) {
-			IJavaElement[] entries= fInputHistory.get(i);
-			for (int j= 0; j < entries.length; j++) {
-				IJavaElement elem= entries[j];
+			for (IJavaElement elem : fInputHistory.get(i)) {
 				if (elem != null && !elem.exists()) {
 					fInputHistory.remove(i);
 					break;
@@ -415,7 +397,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Goes to the selected entry, without updating the order of history entries.
-	 * 
+	 *
 	 * @param entry the entry to open
 	 */
 	public void gotoHistoryEntry(IJavaElement[] entry) {
@@ -437,7 +419,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Sets the history entries.
-	 * 
+	 *
 	 * @param elems the history elements to set
 	 */
 	public void setHistoryEntries(IJavaElement[] elems) {
@@ -448,14 +430,13 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Sets the history entries.
-	 * 
+	 *
 	 * @param elems the history elements to set
 	 * @since 3.7
 	 */
 	public void setHistoryEntries(List<IJavaElement[]> elems) {
 		fInputHistory.clear();
-		for (Iterator<IJavaElement[]> iterator= elems.iterator(); iterator.hasNext();) {
-			IJavaElement[] elements= iterator.next();
+		for (IJavaElement[] elements : elems) {
 			if (elements != null && elements.length != 0)
 				fInputHistory.add(elements);
 		}
@@ -516,7 +497,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	/**
 	 * Returns the input element of the type hierarchy. Can be of type <code>IType</code> or
 	 * <code>IPackageFragment</code>
-	 * 
+	 *
 	 * @return the input element
 	 */
 	@Override
@@ -526,14 +507,14 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Returns the input elements of the type hierarchy.
-	 * 
+	 *
 	 * @return the input elements
 	 * @since 3.7
 	 */
 	public IJavaElement[] getInputElements() {
 		return fInputElements;
 	}
-	
+
 
 	/**
 	 * Sets the input to a new element.
@@ -547,7 +528,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Sets the input to a new element.
-	 * 
+	 *
 	 * @param javaElements the input java elements
 	 * @since 3.7
 	 */
@@ -579,7 +560,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 					}
 				}
 			}
-			if (!javaElements.equals(fInputElements)) {
+			if (!Arrays.equals(javaElements,fInputElements)) {
 				addHistoryEntry(javaElements);
 			}
 		}
@@ -618,9 +599,9 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		if (inputElements == null) {
 			clearInput();
 		} else {
-			if (!inputElements.equals(prevInput)) {
-				for (int i= 0; i < fAllViewers.length; i++) {
-					fAllViewers[i].setInput(null);
+			if (!Arrays.equals(inputElements,prevInput)) {
+				for (TypeHierarchyViewer viewer : fAllViewers) {
+					viewer.setInput(null);
 				}
 			}
 			fInputElements= inputElements;
@@ -647,7 +628,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Updates the viewers, toolbar buttons and tooltip.
-	 * 
+	 *
 	 * @since 3.6
 	 */
 	public void updateViewers() {
@@ -669,8 +650,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		updateToolbarButtons();
 		updateToolTipAndDescription();
 		showMembersInHierarchy(false);
-		fPagebook.showPage(fTypeMethodsSplitter);		
-		fSelectInEditor= true;		
+		fPagebook.showPage(fTypeMethodsSplitter);
+		fSelectInEditor= true;
 	}
 
 	private void processOutstandingEvents() {
@@ -686,7 +667,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		updateHierarchyViewer(false);
 		updateToolbarButtons();
 		updateToolTipAndDescription();
-		getViewSite().getActionBars().getStatusLineManager().setMessage(""); //$NON-NLS-1$		
+		getViewSite().getActionBars().getStatusLineManager().setMessage(""); //$NON-NLS-1$
 	}
 
 	/*
@@ -736,13 +717,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 			return (T) getShowInSource();
 		}
 		if (key == IShowInTargetList.class) {
-			return (T) new IShowInTargetList() {
-				@Override
-				public String[] getShowInTargetIds() {
-					return new String[] { JavaUI.ID_PACKAGES, JavaPlugin.ID_RES_NAV  };
-				}
-
-			};
+			return (T) (IShowInTargetList) () -> new String[] { JavaUI.ID_PACKAGES};
 		}
 		if (key == IContextProvider.class) {
 			return (T) JavaUIHelp.getHelpContextProvider(this, IJavaHelpContextIds.TYPE_HIERARCHY_VIEW);
@@ -782,8 +757,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 		fEmptyTypesViewer= new Label(fViewerbook, SWT.TOP | SWT.LEFT | SWT.WRAP);
 
-		for (int i= 0; i < fAllViewers.length; i++) {
-			fAllViewers[i].setInput(fAllViewers[i]);
+		for (TypeHierarchyViewer viewer : fAllViewers) {
+			viewer.setInput(viewer);
 		}
 
 		// force the update
@@ -816,12 +791,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	private void initializeTypesViewer(final TypeHierarchyViewer typesViewer, KeyListener keyListener, String cotextHelpId) {
 		typesViewer.getControl().setVisible(false);
 		typesViewer.getControl().addKeyListener(keyListener);
-		typesViewer.initContextMenu(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager menu) {
-				fillTypesViewerContextMenu(typesViewer, menu);
-			}
-		}, cotextHelpId,	getSite());
+		typesViewer.initContextMenu(menu -> fillTypesViewerContextMenu(typesViewer, menu), cotextHelpId,	getSite());
 		typesViewer.addPostSelectionChangedListener(fSelectionChangedListener);
 		typesViewer.setQualifiedTypeName(isQualifiedTypeNamesEnabled());
 		typesViewer.setWorkingSetFilter(fWorkingSetActionGroup.getWorkingSetFilter());
@@ -829,12 +799,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	private Control createMethodViewerControl(Composite parent) {
 		fMethodsViewer= new MethodsViewer(parent, fHierarchyLifeCycle);
-		fMethodsViewer.initContextMenu(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager menu) {
-				fillMethodsViewerContextMenu(menu);
-			}
-		}, IContextMenuConstants.TARGET_ID_MEMBERS_VIEW, getSite());
+		fMethodsViewer.initContextMenu(this::fillMethodsViewerContextMenu, IContextMenuConstants.TARGET_ID_MEMBERS_VIEW, getSite());
 		fMethodsViewer.addPostSelectionChangedListener(fSelectionChangedListener);
 
 		new OpenAndLinkWithEditorHelper(fMethodsViewer) {
@@ -879,21 +844,21 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	}
 
 	private void initDragAndDrop() {
-		for (int i= 0; i < fAllViewers.length; i++) {
-			addDragAdapters(fAllViewers[i]);
-			addDropAdapters(fAllViewers[i]);
+		for (TypeHierarchyViewer viewer : fAllViewers) {
+			addDragAdapters(viewer);
+			addDropAdapters(viewer);
 		}
 		addDragAdapters(fMethodsViewer);
 		fMethodsViewer.addDropSupport(DND.DROP_NONE, new Transfer[0], new DropTargetAdapter());
 
 		//DND on empty hierarchy
 		DropTarget dropTarget = new DropTarget(fPagebook, DND.DROP_MOVE | DND.DROP_COPY | DND.DROP_LINK | DND.DROP_DEFAULT);
-		dropTarget.setTransfer(new Transfer[] { LocalSelectionTransfer.getInstance() });
+		dropTarget.setTransfer(LocalSelectionTransfer.getTransfer());
 		dropTarget.addDropListener(new TypeHierarchyTransferDropAdapter(this, fAllViewers[0]));
 	}
 
 	private void addDropAdapters(AbstractTreeViewer viewer) {
-		Transfer[] transfers= new Transfer[] { LocalSelectionTransfer.getInstance(), PluginTransfer.getInstance() };
+		Transfer[] transfers= new Transfer[] { LocalSelectionTransfer.getTransfer(), PluginTransfer.getInstance() };
 		int ops= DND.DROP_MOVE | DND.DROP_COPY | DND.DROP_LINK | DND.DROP_DEFAULT;
 
 		DelegatingDropAdapter delegatingDropAdapter= new DelegatingDropAdapter();
@@ -905,7 +870,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	private void addDragAdapters(StructuredViewer viewer) {
 		int ops= DND.DROP_COPY | DND.DROP_LINK;
-		Transfer[] transfers= new Transfer[] { LocalSelectionTransfer.getInstance(), ResourceTransfer.getInstance(), FileTransfer.getInstance()};
+		Transfer[] transfers= new Transfer[] { LocalSelectionTransfer.getTransfer(), ResourceTransfer.getInstance(), FileTransfer.getInstance()};
 
 		JdtViewerDragAdapter dragAdapter= new JdtViewerDragAdapter(viewer);
 		dragAdapter.addDragSourceListener(new SelectionTransferDragAdapter(viewer));
@@ -983,8 +948,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		// set the filter menu items
 		IActionBars actionBars= getViewSite().getActionBars();
 		IMenuManager viewMenu= actionBars.getMenuManager();
-		for (int i= 0; i < fViewActions.length; i++) {
-			ToggleViewAction action= fViewActions[i];
+		for (ToggleViewAction action : fViewActions) {
 			viewMenu.add(action);
 			action.setEnabled(false);
 		}
@@ -996,8 +960,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 		IMenuManager layoutSubMenu= new MenuManager(TypeHierarchyMessages.TypeHierarchyViewPart_layout_submenu);
 		viewMenu.add(layoutSubMenu);
-		for (int i= 0; i < fToggleOrientationActions.length; i++) {
-			layoutSubMenu.add(fToggleOrientationActions[i]);
+		for (ToggleOrientationAction action : fToggleOrientationActions) {
+			layoutSubMenu.add(action);
 		}
 		viewMenu.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
 		viewMenu.add(fShowQualifiedTypeNamesAction);
@@ -1014,9 +978,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		// selection provider
 		int nHierarchyViewers= fAllViewers.length;
 		StructuredViewer[] trackedViewers= new StructuredViewer[nHierarchyViewers + 1];
-		for (int i= 0; i < nHierarchyViewers; i++) {
-			trackedViewers[i]= fAllViewers[i];
-		}
+		System.arraycopy(fAllViewers, 0, trackedViewers, 0, nHierarchyViewers);
 		trackedViewers[nHierarchyViewers]= fMethodsViewer;
 		fSelectionProviderMediator= new SelectionProviderMediator(trackedViewers, getCurrentViewer());
 		IStatusLineManager slManager= getViewSite().getActionBars().getStatusLineManager();
@@ -1136,8 +1098,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	}
 
 	private void updateCheckedState() {
-		for (int i= 0; i < fToggleOrientationActions.length; i++) {
-			fToggleOrientationActions[i].setChecked(getViewLayout() == fToggleOrientationActions[i].getOrientation());
+		for (ToggleOrientationAction action : fToggleOrientationActions) {
+			action.setChecked(getViewLayout() == action.getOrientation());
 		}
 	}
 
@@ -1158,8 +1120,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	private void fillMainToolBar(IToolBarManager tbmanager) {
 		tbmanager.removeAll();
-		for (int i= 0; i < fViewActions.length; i++) {
-			tbmanager.add(fViewActions[i]);
+		for (ToggleViewAction action : fViewActions) {
+			tbmanager.add(action);
 		}
 		tbmanager.add(fHistoryDropDownAction);
 		tbmanager.update(false);
@@ -1218,8 +1180,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	 */
 	private void setMemberFilter(IMember[] memberFilter) {
 		Assert.isNotNull(fAllViewers);
-		for (int i= 0; i < fAllViewers.length; i++) {
-			fAllViewers[i].setMemberFilter(memberFilter);
+		for (TypeHierarchyViewer viewer : fAllViewers) {
+			viewer.setMemberFilter(memberFilter);
 		}
 	}
 
@@ -1249,12 +1211,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 			fPagebook.showPage(fNoHierarchyShownLabel);
 		} else {
 			if (getCurrentViewer().containsElements() != null) {
-				Runnable runnable= new Runnable() {
-					@Override
-					public void run() {
-						getCurrentViewer().updateContent(doExpand); // refresh
-					}
-				};
+				Runnable runnable= () -> getCurrentViewer().updateContent(doExpand);
 				BusyIndicator.showWhile(getDisplay(), runnable);
 				if (!isChildVisible(fViewerbook, getCurrentViewer().getControl())) {
 					setViewerVisibility(true);
@@ -1270,12 +1227,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		if (!fIsEnableMemberFilter && fCurrentLayout != VIEW_LAYOUT_SINGLE) {
 			if (input == fMethodsViewer.getInput()) {
 				if (input != null) {
-					Runnable runnable= new Runnable() {
-						@Override
-						public void run() {
-							fMethodsViewer.refresh(); // refresh
-						}
-					};
+					Runnable runnable= () -> fMethodsViewer.refresh();
 					BusyIndicator.showWhile(getDisplay(), runnable);
 				}
 			} else {
@@ -1286,12 +1238,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 					fMethodViewerPaneLabel.setText(""); //$NON-NLS-1$
 					fMethodViewerPaneLabel.setImage(null);
 				}
-				Runnable runnable= new Runnable() {
-					@Override
-					public void run() {
-						fMethodsViewer.setInput(input); // refresh
-					}
-				};
+				Runnable runnable= () -> fMethodsViewer.setInput(input);
 				BusyIndicator.showWhile(getDisplay(), runnable);
 			}
 		}
@@ -1343,7 +1290,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 				if (types.size() == 1) {
 					fSelectedType= (IType) types.get(0);
 					updateMethodViewer(fSelectedType);
-				} else if (types.size() == 0) {
+				} else if (types.isEmpty()) {
 					// method selected, no change
 				}
 				if (nSelected == 1 && fSelectInEditor) {
@@ -1385,10 +1332,10 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	}
 
 	private boolean isChildVisible(Composite pb, Control child) {
-		Control[] children= pb.getChildren();
-		for (int i= 0; i < children.length; i++) {
-			if (children[i] == child && children[i].isVisible())
+		for (Control c : pb.getChildren()) {
+			if (c == child && c.isVisible()) {
 				return true;
+			}
 		}
 		return false;
 	}
@@ -1444,8 +1391,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	private void updateToolbarButtons() {
 		boolean isNull= fInputElements == null;
 		boolean isType= !isNull && fInputElements.length == 1 && fInputElements[0] instanceof IType;
-		for (int i= 0; i < fViewActions.length; i++) {
-			ToggleViewAction action= fViewActions[i];
+		for (ToggleViewAction action : fViewActions) {
 			if (action.getViewerIndex() == HIERARCHY_MODE_CLASSIC) {
 				action.setEnabled(!isNull);
 			} else {
@@ -1505,8 +1451,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 			};
 
 		}
-		for (int i= 0; i < fViewActions.length; i++) {
-			ToggleViewAction action= fViewActions[i];
+		for (ToggleViewAction action : fViewActions) {
 			action.setChecked(fCurrentViewerIndex == action.getViewerIndex());
 		}
 	}
@@ -1556,8 +1501,8 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		if (on != fShowQualifiedTypeNames) {
 			fShowQualifiedTypeNames= on;
 			if (fAllViewers != null) {
-				for (int i= 0; i < fAllViewers.length; i++) {
-					fAllViewers[i].setQualifiedTypeName(on);
+				for (TypeHierarchyViewer viewer : fAllViewers) {
+					viewer.setQualifiedTypeName(on);
 				}
 			}
 		}
@@ -1588,16 +1533,13 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		Display display= getDisplay();
 		if (display != null) {
 			fIsRefreshRunnablePosted= true;
-			display.asyncExec(new Runnable() {
-				@Override
-				public void run() {
-					try {
-						if (fPagebook != null && !fPagebook.isDisposed()) {
-							doTypeHierarchyChangedOnViewers(changedTypes);
-						}
-					} finally {
-						fIsRefreshRunnablePosted= false;
+			display.asyncExec(() -> {
+				try {
+					if (fPagebook != null && !fPagebook.isDisposed()) {
+						doTypeHierarchyChangedOnViewers(changedTypes);
 					}
+				} finally {
+					fIsRefreshRunnablePosted= false;
 				}
 			});
 		}
@@ -1707,7 +1649,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 			inputList.add(input);
 			elementId= memento.getString(TAG_INPUT + ++i);
 		}
-		if (inputList == null || inputList.size() == 0) {
+		if (inputList == null || inputList.isEmpty()) {
 			doRestoreState(memento, input);
 		} else {
 			final IJavaElement[] hierarchyInput= inputList.toArray(new IJavaElement[inputList.size()]);
@@ -1742,13 +1684,10 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 		fHierarchyLifeCycle.doHierarchyRefresh(hierarchyInput, monitor);
 		final boolean doRestore= !monitor.isCanceled();
 		if (doRestore) {
-			Display.getDefault().asyncExec(new Runnable() {
-				@Override
-				public void run() {
-					// running async: check first if view still exists
-					if (fPagebook != null && !fPagebook.isDisposed()) {
-						doRestoreState(memento, hierarchyInput);
-					}
+			Display.getDefault().asyncExec(() -> {
+				// running async: check first if view still exists
+				if (fPagebook != null && !fPagebook.isDisposed()) {
+					doRestoreState(memento, hierarchyInput);
 				}
 			});
 		}
@@ -1761,7 +1700,7 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Restores the state of the type hierarchy view from the memento.
-	 * 
+	 *
 	 * @param memento the memento
 	 * @param input the input java elements
 	 * @since 3.7
@@ -1780,11 +1719,11 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 		Integer viewerIndex= memento.getInteger(TAG_VIEW);
 		if (viewerIndex != null) {
-			setHierarchyMode(viewerIndex.intValue());
+			setHierarchyMode(viewerIndex);
 		}
 		Integer layout= memento.getInteger(TAG_LAYOUT);
 		if (layout != null) {
-			setViewLayout(layout.intValue());
+			setViewLayout(layout);
 		}
 
 		Integer val= memento.getInteger(TAG_EDITOR_LINKING);
@@ -1801,13 +1740,13 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 		Integer ratio= memento.getInteger(TAG_RATIO);
 		if (ratio != null) {
-			fTypeMethodsSplitter.setWeights(new int[] { ratio.intValue(), 1000 - ratio.intValue() });
+			fTypeMethodsSplitter.setWeights(new int[] { ratio, 1000 - ratio.intValue() });
 		}
 		ScrollBar bar= getCurrentViewer().getTree().getVerticalBar();
 		if (bar != null) {
 			Integer vScroll= memento.getInteger(TAG_VERTICAL_SCROLL);
 			if (vScroll != null) {
-				bar.setSelection(vScroll.intValue());
+				bar.setSelection(vScroll);
 			}
 		}
 		fMethodsViewer.restoreState(memento);
@@ -1864,14 +1803,9 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	 * @return Returns the <code>IShowInSource</code> for this view.
 	 */
 	protected IShowInSource getShowInSource() {
-		return new IShowInSource() {
-			@Override
-			public ShowInContext getShowInContext() {
-				return new ShowInContext(
-					null,
-				getSite().getSelectionProvider().getSelection());
-			}
-		};
+		return () -> new ShowInContext(
+			null,
+		getSite().getSelectionProvider().getSelection());
 	}
 
 	@Override
@@ -1902,19 +1836,16 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 
 	/**
 	 * Sets the empty viewer when the user cancels the computation.
-	 * 
+	 *
 	 * @since 3.6
 	 */
 	public void showEmptyViewer() {
-		Display.getDefault().asyncExec(new Runnable() {
-			@Override
-			public void run() {
-				if (isDisposed())
-					return;
+		Display.getDefault().asyncExec(() -> {
+			if (isDisposed())
+				return;
 
-				clearInput();
-				setKeepShowingEmptyViewers(true);
-			}
+			clearInput();
+			setKeepShowingEmptyViewers(true);
 		});
 	}
 
@@ -1946,18 +1877,18 @@ public class TypeHierarchyViewPart extends ViewPart implements ITypeHierarchyVie
 	 * @since 3.6
 	 */
 	public void setViewersInput() {
-		for (int i= 0; i < fAllViewers.length; i++) {
-			fAllViewers[i].setInput(fAllViewers[i]);
+		for (TypeHierarchyViewer viewer : fAllViewers) {
+			viewer.setInput(viewer);
 		}
 		setKeepShowingEmptyViewers(false);
 	}
 
 	/**
 	 * Sets whether empty viewers should keep showing. If false, replace with fEmptyTypesViewer.
-	 * 
+	 *
 	 * @param keepShowingEmptyViewers <code>true</code> if the empty viewers can be shown,
 	 *            <code>false otherwise
-	 * 
+	 *
 	 * @since 3.6
 	 */
 	public void setKeepShowingEmptyViewers(boolean keepShowingEmptyViewers) {
