@@ -20,7 +20,7 @@ import java.net.URL;
 import java.util.ArrayList;
 import java.util.List;
 
-import com.ibm.icu.text.BreakIterator;
+import java.text.BreakIterator;
 import java.util.Arrays;
 
 import org.eclipse.help.HelpSystem;
