@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2015, 2018 GK Software AG and others.
+ * Copyright (c) 2015, 2019 GK Software AG and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -30,6 +30,7 @@ import org.eclipse.jdt.core.dom.IAnnotationBinding;
 import org.eclipse.jdt.core.dom.IBinding;
 import org.eclipse.jdt.core.dom.IMemberValuePairBinding;
 import org.eclipse.jdt.core.dom.IMethodBinding;
+import org.eclipse.jdt.core.dom.IModuleBinding;
 import org.eclipse.jdt.core.dom.IPackageBinding;
 import org.eclipse.jdt.core.dom.ITypeBinding;
 import org.eclipse.jdt.core.dom.IVariableBinding;
@@ -54,7 +55,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 	private static final String INIT_NAME= ""; //$NON-NLS-1$
 
 	private static final long M_ALL_QUALIFIED= JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.M_FULLY_QUALIFIED;
-	
+
 	private static final long IS_POST_QUALIFICATION= 1L << 63;
 	private static final long TP_BOUNDS= 1L << 62;
 
@@ -102,6 +103,9 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 			case IBinding.PACKAGE:
 				appendPackageLabel((IPackageBinding) binding, flags);
 				break;
+			case IBinding.MODULE:
+				appendModuleLabel((IModuleBinding) binding, flags);
+				break;
 			case IBinding.ANNOTATION:
 			case IBinding.MEMBER_VALUE_PAIR:
 				// not used for hovers
@@ -132,7 +136,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 		if (fIsFromSource) {
 			flags &= ~JavaElementLabels.T_FULLY_QUALIFIED;
 		}
-		boolean isInitializer= method.getName().equals(INIT_NAME);
+		boolean isInitializer= INIT_NAME.equals(method.getName());
 
 		// type parameters
 		if (getFlag(flags, JavaElementLabels.M_PRE_TYPE_PARAMETERS)) {
@@ -142,13 +146,13 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 				fBuffer.append(' ');
 			}
 		}
-		
+
 		// return type
 		if (getFlag(flags, JavaElementLabels.M_PRE_RETURNTYPE) && !method.isConstructor() && !isInitializer) {
 			appendTypeBindingLabel(method.getReturnType(), flags);
 			fBuffer.append(' ');
 		}
-		
+
 		// qualification
 		if (getFlag(flags, JavaElementLabels.M_FULLY_QUALIFIED | JavaElementLabels.T_CONTAINER_QUALIFIED)) {
 			appendTypeBindingLabel(method.getDeclaringClass(), qualificationFlags);
@@ -160,13 +164,13 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 		} else {
 			appendNameLink(method, origMethod);
 		}
-		
+
 		if (!isInitializer) {
 			// constructor type arguments
 			if (getFlag(flags, JavaElementLabels.T_TYPE_PARAMETERS) && method.isConstructor()) {
 				appendTypeArgumentsBindingLabel(method.getTypeArguments(), null, flags);
 			}
-			
+
 			// parameters
 			fBuffer.append('(');
 			if (getFlag(flags, JavaElementLabels.M_PARAMETER_TYPES | JavaElementLabels.M_PARAMETER_NAMES)) {
@@ -262,8 +266,8 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 				}
 			}
 			fBuffer.append(')');
-	
-	
+
+
 			if (getFlag(flags, JavaElementLabels.M_EXCEPTIONS)) {
 				ITypeBinding[] types= method.getExceptionTypes();
 				if (types.length > 0) {
@@ -275,7 +279,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 					}
 				}
 			}
-	
+
 			if (getFlag(flags, JavaElementLabels.M_APP_TYPE_PARAMETERS)) {
 				int offset= fBuffer.length();
 				if (method.isParameterizedMethod()) {
@@ -289,7 +293,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 				}
 			}
 		}
-		
+
 		// post qualification
 		if (getFlag(flags, JavaElementLabels.M_POST_QUALIFIED)) {
 			fBuffer.append(JavaElementLabels.CONCAT_STRING);
@@ -329,7 +333,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 		} else {
 			fBuffer.append(variable.getName());
 		}
-		
+
 		if (getFlag(flags, JavaElementLabels.F_POST_QUALIFIED)) {
 			fBuffer.append(JavaElementLabels.CONCAT_STRING);
 			appendVariableQualification(variable, getPostQualificationFlags(qualificationFlags));
@@ -416,7 +420,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 				IAnnotationBinding[] typeAnnotations= typeAtDimension.getTypeAnnotations();
 				if (typeAnnotations.length > 0) {
 					appendAnnotationLabels(typeAnnotations, typeRefFlags, true, false);
-				}				
+				}
 				fBuffer.append('[').append(']');
 				typeAtDimension = typeAtDimension.getComponentType();
 			}
@@ -569,7 +573,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 			} else if (value instanceof IAnnotationBinding) {
 				appendAnnotationLabel((IAnnotationBinding) value, flags);
 			} else if (value instanceof Character) {
-				fBuffer.append(ASTNodes.getEscapedCharacterLiteral(((Character) value).charValue()));
+				fBuffer.append(ASTNodes.getEscapedCharacterLiteral(((Character) value)));
 			} else { // other primitive literals
 				fBuffer.append(String.valueOf(value));
 			}
@@ -597,12 +601,19 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 		}
 	}
 
+	protected void appendModuleLabel(IModuleBinding binding, long flags) {
+		appendAnnotationLabels(binding.getAnnotations(), flags, false, true);
+		fBuffer.append(binding.getName());
+	}
+
 	// consider only relevant bounds / ignore j.l.Object
 	private boolean hasRelevantBound(ITypeBinding[] bounds) {
 		if (bounds != null) {
-			for (int i= 0; i < bounds.length; i++)
-				if (bounds[i].isInterface() || bounds[i].getSuperclass() != null)
+			for (ITypeBinding bound : bounds) {
+				if (bound.isInterface() || bound.getSuperclass() != null) {
 					return true;
+				}
+			}
 		}
 		return false;
 	}
@@ -679,7 +690,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 				title= qualifiedName; // Not expected. Just show the whole qualifiedName.
 			}
 		}
-		
+
 		try {
 			String uri= createURI(JAVADOC_SCHEME, fEnclosingElement, qualifiedName, null, null);
 			return createHeaderLink(uri, typeName, title);
@@ -712,7 +723,7 @@ public class BindingLinkedLabelComposer extends JavaElementLinkedLabelComposer {
 							buf.append(getTypeName((ITypeBinding) declaringMember, flags));
 						} else { // field or method
 							String name= declaringMember.getName();
-							if (name.equals(INIT_NAME))
+							if (INIT_NAME.equals(name))
 								buf.append(JavaUIMessages.JavaElementLabels_initializer);
 							else
 								buf.append(name);
