@@ -28,16 +28,13 @@ import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.ISelectionProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 
 import org.eclipse.jface.text.ITextSelection;
 
 import org.eclipse.ui.ISelectionListener;
-import org.eclipse.ui.IWorkbenchPart;
 
 import org.eclipse.ui.texteditor.ITextEditor;
 
-import org.eclipse.jdt.core.IJavaElement;
 import org.eclipse.jdt.core.ITypeRoot;
 import org.eclipse.jdt.core.dom.CompilationUnit;
 import org.eclipse.jdt.core.manipulation.SharedASTProviderCore;
@@ -80,22 +77,16 @@ public class SelectionListenerWithASTManager {
 			fCurrentJob= null;
 			fAstListeners= new ListenerList<>(ListenerList.IDENTITY);
 
-			fSelectionListener= new ISelectionChangedListener() {
-				@Override
-				public void selectionChanged(SelectionChangedEvent event) {
-					ISelection selection= event.getSelection();
-					if (selection instanceof ITextSelection) {
-						fireSelectionChanged((ITextSelection) selection);
-					}
+			fSelectionListener= event -> {
+				ISelection selection= event.getSelection();
+				if (selection instanceof ITextSelection) {
+					fireSelectionChanged((ITextSelection) selection);
 				}
 			};
 
-			fPostSelectionListener= new ISelectionListener() {
-				@Override
-				public void selectionChanged(IWorkbenchPart part, ISelection selection) {
-					if (part == fPart && selection instanceof ITextSelection)
-						firePostSelectionChanged((ITextSelection) selection);
-				}
+			fPostSelectionListener= (part, selection) -> {
+				if (part == fPart && selection instanceof ITextSelection)
+					firePostSelectionChanged((ITextSelection) selection);
 			};
 		}
 
@@ -143,11 +134,11 @@ public class SelectionListenerWithASTManager {
 			if (fCurrentJob != null) {
 				fCurrentJob.cancel();
 			}
-			IJavaElement input= EditorUtility.getEditorInputJavaElement(fPart, false);
-			if (!(input instanceof ITypeRoot)) {
+			ITypeRoot input= EditorUtility.getEditorInputJavaElement(fPart, false);
+			if (input == null) {
 				return;
 			}
-			final ITypeRoot typeRoot= (ITypeRoot) input;
+			final ITypeRoot typeRoot= input;
 
 
 			fCurrentJob= new Job(JavaUIMessages.SelectionListenerWithASTManager_job_title) {
@@ -166,7 +157,7 @@ public class SelectionListenerWithASTManager {
 			fCurrentJob.schedule();
 		}
 
-		protected final IStatus calculateASTandInform(ITypeRoot input, ITextSelection selection, IProgressMonitor monitor) {
+		protected IStatus calculateASTandInform(ITypeRoot input, ITextSelection selection, IProgressMonitor monitor) {
 			if (monitor.isCanceled()) {
 				return Status.CANCEL_STATUS;
 			}
