@@ -266,9 +266,8 @@ public class NewSourceFolderWizardPage extends NewElementWizardPage {
 		} else if (field == fProjectField) {
 			updateProjectStatus();
 			updateRootStatus();
-		} else if (field == fExcludeInOthersFields) {
-			updateRootStatus();
-		} else if (field == fIgnoreOptionalProblemsField) {
+		} else if (field == fExcludeInOthersFields
+				|| field == fIgnoreOptionalProblemsField) {
 			updateRootStatus();
 		}
 		updateStatus(new IStatus[] { fProjectStatus, fRootStatus });
@@ -572,7 +571,7 @@ public class NewSourceFolderWizardPage extends NewElementWizardPage {
 		dialog.setTitle(NewWizardMessages.NewSourceFolderWizardPage_ChooseProjectDialog_title);
 		dialog.setMessage(NewWizardMessages.NewSourceFolderWizardPage_ChooseProjectDialog_description);
 		dialog.setElements(projects);
-		dialog.setInitialSelections(new Object[] { fCurrJProject });
+		dialog.setInitialSelections(fCurrJProject);
 		dialog.setHelpAvailable(false);
 		if (dialog.open() == Window.OK) {
 			return (IJavaProject) dialog.getFirstResult();
