@@ -251,7 +251,8 @@ public class VariableBlock {
 			entry= newEntry;
 			fHasChanges= true;
 		} else {
-			boolean hasChanges= !(entry.getName().equals(newEntry.getName()) && entry.getPath().equals(newEntry.getPath()));
+			boolean hasChanges= !entry.getName().equals(newEntry.getName())
+					|| !entry.getPath().equals(newEntry.getPath());
 			if (hasChanges) {
 				fHasChanges= true;
 				entry.setName(newEntry.getName());
@@ -341,7 +342,7 @@ public class VariableBlock {
 		return false;
 	}
 
-	private class VariableBlockRunnable implements IRunnableWithProgress {
+	private static class VariableBlockRunnable implements IRunnableWithProgress {
 		private final List<String> fToRemove;
 		private final List<CPVariableElement> fToChange;
 
@@ -375,14 +376,13 @@ public class VariableBlock {
 			IPath[] paths= new IPath[nVariables];
 			int k= 0;
 
-			for (int i= 0; i < fToChange.size(); i++) {
-				CPVariableElement curr= fToChange.get(i);
+			for (CPVariableElement curr : fToChange) {
 				names[k]= curr.getName();
 				paths[k]= curr.getPath();
 				k++;
 			}
-			for (int i= 0; i < fToRemove.size(); i++) {
-				names[k]= fToRemove.get(i);
+			for (String element : fToRemove) {
+				names[k]= element;
 				paths[k]= null;
 				k++;
 			}
