@@ -30,7 +30,6 @@ import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Path;
 
 import org.eclipse.core.resources.IFolder;
-import org.eclipse.core.resources.IResource;
 
 import org.eclipse.jface.action.ToolBarManager;
 import org.eclipse.jface.layout.PixelConverter;
@@ -51,7 +50,6 @@ import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.internal.corext.buildpath.BuildpathDelta;
 import org.eclipse.jdt.internal.corext.buildpath.ClasspathModifier;
 import org.eclipse.jdt.internal.corext.buildpath.IBuildpathModifierListener;
-import org.eclipse.jdt.internal.corext.util.JavaModelUtil;
 
 import org.eclipse.jdt.internal.ui.JavaPlugin;
 import org.eclipse.jdt.internal.ui.preferences.ScrolledPageContent;
@@ -62,7 +60,6 @@ import org.eclipse.jdt.internal.ui.wizards.buildpaths.BuildPathsBlock;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.CPListElement;
 import org.eclipse.jdt.internal.ui.wizards.buildpaths.CPListElementAttribute;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.DialogField;
-import org.eclipse.jdt.internal.ui.wizards.dialogfields.IDialogFieldListener;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.LayoutUtil;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.ListDialogField;
 import org.eclipse.jdt.internal.ui.wizards.dialogfields.SelectionButtonDialogField;
@@ -77,9 +74,6 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
     private HintTextGroup fHintTextGroup;
     private DialogPackageExplorer fPackageExplorer;
     private SelectionButtonDialogField fUseFolderOutputs;
-    private SelectionButtonDialogField fCreateModuleInfoFileButton;
-    private boolean fCreateModuleInfoFile;
-    private String fCompilerCompliance;
     private final StringDialogField fOutputLocationField;
 	private DialogPackageExplorerActionGroup fActionGroup;
 
@@ -112,11 +106,6 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
         fUseFolderOutputs.setLabelText(NewWizardMessages.SourceContainerWorkbookPage_folders_check);
 
 
-		fCreateModuleInfoFileButton= new SelectionButtonDialogField(SWT.CHECK);
-		fCreateModuleInfoFileButton.setSelection(true);
-		fCreateModuleInfoFile= true;
-		fCreateModuleInfoFileButton.setLabelText(NewWizardMessages.SourceContainerWorkbookPage_create_moduleinfo_check);
-
 		fPackageExplorer= new DialogPackageExplorer();
 		fHintTextGroup= new HintTextGroup();
      }
@@ -140,12 +129,7 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
 		if (Display.getCurrent() != null) {
 			doUpdateUI();
 		} else {
-			Display.getDefault().asyncExec(new Runnable() {
-				@Override
-				public void run() {
-					doUpdateUI();
-				}
-			});
+			Display.getDefault().asyncExec(this::doUpdateUI);
 		}
     }
 
@@ -165,22 +149,7 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
 		fUseFolderOutputs.setSelection(useFolderOutputs);
     }
 
-	public void setCompilerCompliance(String compilerCompliance) {
-		if (compilerCompliance != null) {
-			fCompilerCompliance= compilerCompliance;
-			try {
-				setCreateModuleInfoFile(false);
-			} catch (JavaModelException e) {
-				//do nothing
-			}
-		}
-	}
-
-	public boolean isCreateModuleInfoFile() {
-		return fCreateModuleInfoFile;
-	}
-
-    public void dispose() {
+	public void dispose() {
     	if (fActionGroup != null) {
     		fActionGroup.removeBuildpathModifierListener(this);
     		fActionGroup= null;
@@ -241,38 +210,25 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
         excomposite.setClient(fHintTextGroup.createControl(excomposite));
         fUseFolderOutputs.doFillIntoGrid(body, 1);
 
-		fCreateModuleInfoFileButton.doFillIntoGrid(body, 1);
-
-		fCreateModuleInfoFileButton.setDialogFieldListener(new IDialogFieldListener() {
-			@Override
-			public void dialogFieldChanged(DialogField field) {
-				fCreateModuleInfoFile= fCreateModuleInfoFileButton.isSelected();
-			}
-		});
-
-
-        fActionGroup= new DialogPackageExplorerActionGroup(fHintTextGroup, fContext, fPackageExplorer, this);
+		fActionGroup= new DialogPackageExplorerActionGroup(fHintTextGroup, fContext, fPackageExplorer, this);
 		fActionGroup.addBuildpathModifierListener(this);
 
 
-        fUseFolderOutputs.setDialogFieldListener(new IDialogFieldListener() {
-            @Override
-			public void dialogFieldChanged(DialogField field) {
-                boolean isUseFolders= fUseFolderOutputs.isSelected();
-                if (!isUseFolders) {
-                	ResetAllOutputFoldersAction action= new ResetAllOutputFoldersAction(fContext, fJavaProject, fPackageExplorer) {
-                		@Override
-						public void run() {
-                    		commitDefaultOutputFolder();
-                    	    super.run();
-                    	}
-                	};
-                	action.addBuildpathModifierListener(NewSourceContainerWorkbookPage.this);
-                	action.run();
-                }
-				fPackageExplorer.showOutputFolders(isUseFolders);
-            }
-        });
+        fUseFolderOutputs.setDialogFieldListener(field -> {
+		    boolean isUseFolders= fUseFolderOutputs.isSelected();
+		    if (!isUseFolders) {
+		    	ResetAllOutputFoldersAction action= new ResetAllOutputFoldersAction(fContext, fJavaProject, fPackageExplorer) {
+		    		@Override
+					public void run() {
+		        		commitDefaultOutputFolder();
+		        	    super.run();
+		        	}
+		    	};
+		    	action.addBuildpathModifierListener(NewSourceContainerWorkbookPage.this);
+		    	action.run();
+		    }
+			fPackageExplorer.showOutputFolders(isUseFolders);
+		});
 
         Composite outputLocation= new Composite(body, SWT.NONE);
         outputLocation.setLayout(new GridLayout(2, false));
@@ -335,13 +291,11 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
      */
     private ScrolledPageContent getParentScrolledComposite(Control control) {
        Control parent= control.getParent();
-       while (!(parent instanceof ScrolledPageContent)) {
+       while (!(parent instanceof ScrolledPageContent) && parent != null) {
            parent= parent.getParent();
        }
-       if (parent instanceof ScrolledPageContent) {
-           return (ScrolledPageContent) parent;
-       }
-       return null;
+
+       return (ScrolledPageContent) parent;
    }
 
     @Override
@@ -378,7 +332,7 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
 	public void setSelection(List<?> selection, boolean expand) {
 		// page switch
 
-        if (selection.size() == 0)
+        if (selection.isEmpty())
             return;
 
 		List<CPListElement> cpEntries= new ArrayList<>();
@@ -430,46 +384,11 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
 
         try {
 	        fOutputLocationField.setText(fJavaProject.getOutputLocation().makeRelative().toString());
-			setCreateModuleInfoFile(true);
         } catch (JavaModelException e) {
 	        JavaPlugin.log(e);
         }
     }
 
-	private void setCreateModuleInfoFile(boolean buildpathChanged) throws JavaModelException {
-		boolean selection= fCreateModuleInfoFileButton.isSelected();
-		boolean enabled= fCreateModuleInfoFileButton.isEnabled();
-		boolean setEnabled= true;
-		boolean setSelection= true;
-		if (JavaModelUtil.is9OrHigher(fCompilerCompliance)) {
-			IPackageFragmentRoot[] packageFragmentRoots= fJavaProject.getPackageFragmentRoots();
-			List<IPackageFragmentRoot> packageFragmentRootsAsList= new ArrayList<>(Arrays.asList(packageFragmentRoots));
-			for (IPackageFragmentRoot packageFragmentRoot : packageFragmentRoots) {
-				IResource res= packageFragmentRoot.getCorrespondingResource();
-				if (res == null || res.getType() != IResource.FOLDER || packageFragmentRoot.getKind() != IPackageFragmentRoot.K_SOURCE) {
-					packageFragmentRootsAsList.remove(packageFragmentRoot);
-				}
-			}
-
-			if (packageFragmentRootsAsList.size() == 0) {
-				setSelection= false;
-				setEnabled= false;
-			} else {
-				if (buildpathChanged) {
-					setSelection= true;
-					setEnabled= true;
-				} else {
-					setSelection= !enabled ? true : selection;
-				}
-			}
-		} else {
-			setEnabled= false;
-			setSelection= false;
-		}
-		fCreateModuleInfoFileButton.setEnabled(setEnabled);
-		fCreateModuleInfoFileButton.setSelection(setSelection);
-	}
-
 	public void commitDefaultOutputFolder() {
 		if (!fBuildPathsBlock.isOKStatus())
 			return;
@@ -486,8 +405,6 @@ public class NewSourceContainerWorkbookPage extends BuildPathBasePage implements
 				}
 			}
 	        fJavaProject.setOutputLocation(path, null);
-        } catch (JavaModelException e) {
-	     	JavaPlugin.log(e);
         } catch (CoreException e) {
 	        JavaPlugin.log(e);
         }
