@@ -62,7 +62,9 @@ public class JavadocContentAccess {
 	 */
 	public static Reader getContentReader(IMember member, boolean allowInherited) throws JavaModelException {
 		Reader contentReader= internalGetContentReader(member);
-		if (contentReader != null || !(allowInherited && (member.getElementType() == IJavaElement.METHOD)))
+		if (contentReader != null
+				|| !allowInherited
+				|| (member.getElementType() != IJavaElement.METHOD))
 			return contentReader;
 		return findDocInHierarchy((IMethod) member, false, false);
 	}
@@ -111,7 +113,7 @@ public class JavadocContentAccess {
 		} catch (IOException e) {
 			return false;
 		}
-		return new String(content).trim().equals("{@inheritDoc}"); //$NON-NLS-1$
+		return "{@inheritDoc}".equals(new String(content).trim()); //$NON-NLS-1$
 
 	}
 
