@@ -15,8 +15,8 @@ package org.eclipse.jdt.ui.actions;
 
 import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicReference;
 
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IStatus;
@@ -29,6 +29,7 @@ import org.eclipse.jface.window.Window;
 import org.eclipse.jface.text.ITextSelection;
 
 import org.eclipse.ui.IWorkbenchSite;
+import org.eclipse.ui.IWorkingSet;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.dialogs.ElementListSelectionDialog;
 import org.eclipse.ui.progress.IProgressService;
@@ -162,8 +163,7 @@ public abstract class FindAction extends SelectionDispatchAction {
 	IJavaElement[] getJavaElements(IStructuredSelection selection, boolean silent) {
 		IJavaElement[] javaElements= new IJavaElement[selection.size()];
 		int index= 0;
-		for (Iterator<?> iter= selection.iterator(); iter.hasNext();) {
-			Object firstElement= iter.next();
+		for (Object firstElement : selection) {
 			IJavaElement elem= null;
 			if (firstElement instanceof IJavaElement)
 				elem= (IJavaElement) firstElement;
@@ -232,9 +232,8 @@ public abstract class FindAction extends SelectionDispatchAction {
 			if (element == null || !element.exists()) {
 				showOperationUnavailableDialog();
 				return;
-			} else if (element == RETURN_WITHOUT_BEEP) {
-				return;
-			} else if (!ActionUtil.isProcessable(getShell(), element)) {
+			} else if ((element == RETURN_WITHOUT_BEEP)
+					|| !ActionUtil.isProcessable(getShell(), element)) {
 				return;
 			}
 		}
@@ -317,10 +316,8 @@ public abstract class FindAction extends SelectionDispatchAction {
 			performNewSearch(new JavaSearchQuery(queryList));
 		} catch (JavaModelException ex) {
 			ExceptionHandler.handle(ex, getShell(), SearchMessages.Search_Error_search_notsuccessful_title, SearchMessages.Search_Error_search_notsuccessful_message);
-		} catch (InterruptedException e) {
-			// cancelled
-		} catch (IllegalArgumentException e) {
-			// no element
+		} catch (InterruptedException | IllegalArgumentException e) {
+			// cancelled or no element
 		}
 	}
 
@@ -358,12 +355,46 @@ public abstract class FindAction extends SelectionDispatchAction {
 	 * @throws InterruptedException thrown when the user interrupted the query selection
 	 */
 	QuerySpecification createQuery(IJavaElement element) throws JavaModelException, InterruptedException {
+		return createDefaultQuery(element);
+	}
+
+	QuerySpecification createDefaultQuery(IJavaElement element) {
 		JavaSearchScopeFactory factory= JavaSearchScopeFactory.getInstance();
 		IJavaSearchScope scope= factory.createWorkspaceScope(true);
 		String description= factory.getWorkspaceScopeDescription(true);
 		return new ElementQuerySpecification(element, getLimitTo(), scope, description);
 	}
 
+	/**
+	 * @param element non null
+	 * @param action non null
+	 * @param toUpdate working sets array reference that will be updated in this method
+	 * @return {@link QuerySpecification} for given object and action, that depends on action state
+	 * @throws InterruptedException if working sets query fail
+	 */
+	static QuerySpecification createQueryWithWorkingSets(IJavaElement element, FindAction action, AtomicReference<IWorkingSet[]> toUpdate) throws InterruptedException {
+		JavaSearchScopeFactory factory= JavaSearchScopeFactory.getInstance();
+
+		final IWorkingSet[] workingSets;
+		if (toUpdate.get() == null && action.isFirstElement()) {
+			workingSets= factory.queryWorkingSets();
+			if (workingSets == null) {
+				return action.createDefaultQuery(element); // workspace
+			}
+			if (action.isMultiSelect()) {
+				toUpdate.set(workingSets);
+			}
+		} else if (action.isMultiSelect() && action.isLastElement()) {
+			workingSets = toUpdate.get();
+			toUpdate.set(null);
+		} else {
+			workingSets = toUpdate.get();
+		}
+		SearchUtil.updateLRUWorkingSets(workingSets);
+		String description= factory.getWorkingSetScopeDescription(workingSets, JavaSearchScopeFactory.NO_PROJ);
+		return new LazyScopeQuerySpecification(element, action.getLimitTo(), () -> factory.createJavaSearchScope(workingSets, JavaSearchScopeFactory.NO_PROJ), description);
+	}
+
 	abstract int getLimitTo();
 
 	IType getType(IJavaElement element) {
