@@ -14,7 +14,6 @@
 package org.eclipse.jdt.ui.actions;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.swt.events.MenuAdapter;
@@ -30,7 +29,6 @@ import org.eclipse.core.resources.ResourcesPlugin;
 
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
@@ -567,19 +565,14 @@ public class RefactorActionGroup extends ActionGroup {
 		if (fEditor != null) {
 			final ITypeRoot element= getEditorInput();
 			if (element != null && ActionUtil.isOnBuildPath(element)) {
-				refactorSubmenu.addMenuListener(new IMenuListener() {
-					@Override
-					public void menuAboutToShow(IMenuManager manager) {
-						refactorMenuShown(manager);
-					}
-				});
+				refactorSubmenu.addMenuListener(this::refactorMenuShown);
 				refactorSubmenu.add(fNoActionAvailable);
 				menu.appendToGroup(fGroupName, refactorSubmenu);
 			}
 		} else {
 			ISelection selection= fSelectionProvider.getSelection();
-			for (Iterator<SelectionDispatchAction> iter= fActions.iterator(); iter.hasNext(); ) {
-				iter.next().update(selection);
+			for (SelectionDispatchAction selectionDispatchAction : fActions) {
+				selectionDispatchAction.update(selection);
 			}
 			if (fillRefactorMenu(refactorSubmenu) > 0)
 				menu.appendToGroup(fGroupName, refactorSubmenu);
@@ -682,18 +675,18 @@ public class RefactorActionGroup extends ActionGroup {
 			ITextSelection textSelection= (ITextSelection)fEditor.getSelectionProvider().getSelection();
 			JavaTextSelection javaSelection= new JavaTextSelection(element, getDocument(), textSelection.getOffset(), textSelection.getLength());
 
-			for (Iterator<SelectionDispatchAction> iter= fActions.iterator(); iter.hasNext(); ) {
-				iter.next().update(javaSelection);
+			for (SelectionDispatchAction selectionDispatchAction : fActions) {
+				selectionDispatchAction.update(javaSelection);
 			}
 			fillRefactorMenu(menu);
-			for (Iterator<SelectionDispatchAction> iter= fActions.iterator(); iter.hasNext(); ) {
-				iter.next().update(textSelection);
+			for (SelectionDispatchAction selectionDispatchAction : fActions) {
+				selectionDispatchAction.update(textSelection);
 			}
 
 		} else {
 			ISelection selection= fSelectionProvider.getSelection();
-			for (Iterator<SelectionDispatchAction> iter= fActions.iterator(); iter.hasNext(); ) {
-				iter.next().update(selection);
+			for (SelectionDispatchAction selectionDispatchAction : fActions) {
+				selectionDispatchAction.update(selection);
 			}
 			fillRefactorMenu(menu);
 		}
