@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2006, 2013 IBM Corporation and others.
+ * Copyright (c) 2006, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,15 +13,13 @@
  *******************************************************************************/
 package org.eclipse.ltk.core.refactoring.tests.history;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	RefactoringHistorySerializationTests.class,
+	RefactoringHistoryServiceTests.class
+})
 public class RefactoringHistoryTests {
-
-	public static Test suite() {
-		TestSuite suite= new TestSuite(RefactoringHistoryTests.class.getName());
-		suite.addTestSuite(RefactoringHistorySerializationTests.class);
-		suite.addTestSuite(RefactoringHistoryServiceTests.class);
-		return suite;
-	}
-}
\ No newline at end of file
+}
