@@ -13,18 +13,15 @@
  *******************************************************************************/
 package org.eclipse.ltk.internal.core.refactoring;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Comparator;
-import java.util.Iterator;
 import java.util.List;
 
-import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.FactoryConfigurationError;
 import javax.xml.parsers.ParserConfigurationException;
 
-import com.ibm.icu.text.Collator;
-
 import org.w3c.dom.Attr;
 import org.w3c.dom.DOMException;
 import org.w3c.dom.Document;
@@ -97,8 +94,7 @@ public final class RefactoringSessionTransformer {
 		final NamedNodeMap map= node.getAttributes();
 		if (map != null) {
 			Collections.sort(list, new AttributeComparator());
-			for (final Iterator<Attr> iterator= list.iterator(); iterator.hasNext();) {
-				final Attr attribute= iterator.next();
+			for (Attr attribute : list) {
 				map.setNamedItem(attribute);
 			}
 		}
@@ -138,7 +134,7 @@ public final class RefactoringSessionTransformer {
 		Assert.isTrue(flags >= RefactoringDescriptor.NONE);
 		try {
 			if (fDocument == null)
-				fDocument= DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
+				fDocument= XmlProcessorFactoryLtk.createDocumentBuilderFactoryWithErrorOnDOCTYPE().newDocumentBuilder().newDocument();
 		} catch (ParserConfigurationException | FactoryConfigurationError exception) {
 			throw new CoreException(new Status(IStatus.ERROR, RefactoringCorePlugin.getPluginId(), IRefactoringCoreStatusCodes.REFACTORING_HISTORY_IO_ERROR, exception.getLocalizedMessage(), null));
 		}
@@ -151,7 +147,7 @@ public final class RefactoringSessionTransformer {
 				fRefactoringArguments.add(attribute);
 				if (stamp >= 0) {
 					attribute= fDocument.createAttribute(IRefactoringSerializationConstants.ATTRIBUTE_STAMP);
-					attribute.setValue(Long.valueOf(stamp).toString());
+					attribute.setValue(Long.toString(stamp));
 					fRefactoringArguments.add(attribute);
 				}
 				if (flags != RefactoringDescriptor.NONE) {
@@ -203,7 +199,7 @@ public final class RefactoringSessionTransformer {
 	public void beginSession(final String comment, final String version) throws CoreException {
 		if (fDocument == null) {
 			try {
-				fDocument= DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
+				fDocument= XmlProcessorFactoryLtk.createDocumentBuilderFactoryWithErrorOnDOCTYPE().newDocumentBuilder().newDocument();
 				fSession= fDocument.createElement(IRefactoringSerializationConstants.ELEMENT_SESSION);
 				fSessionArguments= new ArrayList<>(2);
 				Attr attribute= fDocument.createAttribute(IRefactoringSerializationConstants.ATTRIBUTE_VERSION);
