@@ -13,7 +13,7 @@
  *******************************************************************************/
 package org.eclipse.ltk.internal.ui.refactoring;
 
-import com.ibm.icu.text.MessageFormat;
+import java.text.MessageFormat;
 
 /**
  * Helper class to format message strings.
